package androidx.recyclerview.widget;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseIntArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import b.j.h.p.b;
import java.util.Arrays;

public class GridLayoutManager extends LinearLayoutManager {
    private static final boolean DEBUG = false;
    public static final int DEFAULT_SPAN_COUNT = -1;
    private static final String TAG = "GridLayoutManager";
    public int[] mCachedBorders;
    public final Rect mDecorInsets = new Rect();
    public boolean mPendingSpanCountChange = false;
    public final SparseIntArray mPreLayoutSpanIndexCache = new SparseIntArray();
    public final SparseIntArray mPreLayoutSpanSizeCache = new SparseIntArray();
    public View[] mSet;
    public int mSpanCount = -1;
    public a mSpanSizeLookup = new DefaultSpanSizeLookup();
    private boolean mUsingSpansToEstimateScrollBarDimensions;

    public static final class DefaultSpanSizeLookup extends a {
        @Override // androidx.recyclerview.widget.GridLayoutManager.a
        public int getSpanIndex(int i2, int i3) {
            return i2 % i3;
        }

        @Override // androidx.recyclerview.widget.GridLayoutManager.a
        public int getSpanSize(int i2) {
            return 1;
        }
    }

    public static abstract class a {
        private boolean mCacheSpanGroupIndices = false;
        private boolean mCacheSpanIndices = false;
        public final SparseIntArray mSpanGroupIndexCache = new SparseIntArray();
        public final SparseIntArray mSpanIndexCache = new SparseIntArray();

        public static int findFirstKeyLessThan(SparseIntArray sparseIntArray, int i2) {
            int size = sparseIntArray.size() - 1;
            int i3 = 0;
            while (i3 <= size) {
                int i4 = (i3 + size) >>> 1;
                if (sparseIntArray.keyAt(i4) < i2) {
                    i3 = i4 + 1;
                } else {
                    size = i4 - 1;
                }
            }
            int i5 = i3 - 1;
            if (i5 < 0 || i5 >= sparseIntArray.size()) {
                return -1;
            }
            return sparseIntArray.keyAt(i5);
        }

        public int getCachedSpanGroupIndex(int i2, int i3) {
            if (!this.mCacheSpanGroupIndices) {
                return getSpanGroupIndex(i2, i3);
            }
            int i4 = this.mSpanGroupIndexCache.get(i2, -1);
            if (i4 != -1) {
                return i4;
            }
            int spanGroupIndex = getSpanGroupIndex(i2, i3);
            this.mSpanGroupIndexCache.put(i2, spanGroupIndex);
            return spanGroupIndex;
        }

        public int getCachedSpanIndex(int i2, int i3) {
            if (!this.mCacheSpanIndices) {
                return getSpanIndex(i2, i3);
            }
            int i4 = this.mSpanIndexCache.get(i2, -1);
            if (i4 != -1) {
                return i4;
            }
            int spanIndex = getSpanIndex(i2, i3);
            this.mSpanIndexCache.put(i2, spanIndex);
            return spanIndex;
        }

        public int getSpanGroupIndex(int i2, int i3) {
            int i4;
            int i5;
            int i6;
            int findFirstKeyLessThan;
            if (!this.mCacheSpanGroupIndices || (findFirstKeyLessThan = findFirstKeyLessThan(this.mSpanGroupIndexCache, i2)) == -1) {
                i6 = 0;
                i5 = 0;
                i4 = 0;
            } else {
                i5 = this.mSpanGroupIndexCache.get(findFirstKeyLessThan);
                i4 = findFirstKeyLessThan + 1;
                i6 = getSpanSize(findFirstKeyLessThan) + getCachedSpanIndex(findFirstKeyLessThan, i3);
                if (i6 == i3) {
                    i5++;
                    i6 = 0;
                }
            }
            int spanSize = getSpanSize(i2);
            while (i4 < i2) {
                int spanSize2 = getSpanSize(i4);
                i6 += spanSize2;
                if (i6 == i3) {
                    i5++;
                    i6 = 0;
                } else if (i6 > i3) {
                    i5++;
                    i6 = spanSize2;
                }
                i4++;
            }
            return i6 + spanSize > i3 ? i5 + 1 : i5;
        }

        /* JADX WARNING: Removed duplicated region for block: B:10:0x0024  */
        public int getSpanIndex(int i2, int i3) {
            int i4;
            int i5;
            int spanSize = getSpanSize(i2);
            if (spanSize == i3) {
                return 0;
            }
            if (!this.mCacheSpanIndices || (i5 = findFirstKeyLessThan(this.mSpanIndexCache, i2)) < 0) {
                i5 = 0;
                i4 = 0;
            } else {
                i4 = getSpanSize(i5) + this.mSpanIndexCache.get(i5);
                i5++;
            }
            if (i5 < i2) {
                int spanSize2 = getSpanSize(i5);
                i4 += spanSize2;
                if (i4 == i3) {
                    i4 = 0;
                } else if (i4 > i3) {
                    i4 = spanSize2;
                }
                i5++;
                if (i5 < i2) {
                }
            }
            if (spanSize + i4 <= i3) {
                return i4;
            }
            return 0;
        }

        public abstract int getSpanSize(int i2);

        public void invalidateSpanGroupIndexCache() {
            this.mSpanGroupIndexCache.clear();
        }

        public void invalidateSpanIndexCache() {
            this.mSpanIndexCache.clear();
        }

        public boolean isSpanGroupIndexCacheEnabled() {
            return this.mCacheSpanGroupIndices;
        }

        public boolean isSpanIndexCacheEnabled() {
            return this.mCacheSpanIndices;
        }

        public void setSpanGroupIndexCacheEnabled(boolean z) {
            if (!z) {
                this.mSpanGroupIndexCache.clear();
            }
            this.mCacheSpanGroupIndices = z;
        }

        public void setSpanIndexCacheEnabled(boolean z) {
            if (!z) {
                this.mSpanGroupIndexCache.clear();
            }
            this.mCacheSpanIndices = z;
        }
    }

    public GridLayoutManager(Context context, AttributeSet attributeSet, int i2, int i3) {
        super(context, attributeSet, i2, i3);
        setSpanCount(RecyclerView.LayoutManager.getProperties(context, attributeSet, i2, i3).spanCount);
    }

    private void assignSpans(RecyclerView.p pVar, RecyclerView.r rVar, int i2, boolean z) {
        int i3;
        int i4;
        int i5 = 0;
        int i6 = -1;
        if (z) {
            i6 = i2;
            i4 = 0;
            i3 = 1;
        } else {
            i4 = i2 - 1;
            i3 = -1;
        }
        while (i4 != i6) {
            View view = this.mSet[i4];
            LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
            int spanSize = getSpanSize(pVar, rVar, getPosition(view));
            layoutParams.f1799f = spanSize;
            layoutParams.f1798e = i5;
            i5 += spanSize;
            i4 += i3;
        }
    }

    private void cachePreLayoutSpanMapping() {
        int childCount = getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            LayoutParams layoutParams = (LayoutParams) getChildAt(i2).getLayoutParams();
            int a2 = layoutParams.a();
            this.mPreLayoutSpanSizeCache.put(a2, layoutParams.f1799f);
            this.mPreLayoutSpanIndexCache.put(a2, layoutParams.f1798e);
        }
    }

    private void calculateItemBorders(int i2) {
        this.mCachedBorders = calculateItemBorders(this.mCachedBorders, this.mSpanCount, i2);
    }

    private void clearPreLayoutSpanMappingCache() {
        this.mPreLayoutSpanSizeCache.clear();
        this.mPreLayoutSpanIndexCache.clear();
    }

    private int computeScrollOffsetWithSpanInfo(RecyclerView.r rVar) {
        int i2;
        if (!(getChildCount() == 0 || rVar.b() == 0)) {
            ensureLayoutState();
            boolean isSmoothScrollbarEnabled = isSmoothScrollbarEnabled();
            View findFirstVisibleChildClosestToStart = findFirstVisibleChildClosestToStart(!isSmoothScrollbarEnabled, true);
            View findFirstVisibleChildClosestToEnd = findFirstVisibleChildClosestToEnd(!isSmoothScrollbarEnabled, true);
            if (!(findFirstVisibleChildClosestToStart == null || findFirstVisibleChildClosestToEnd == null)) {
                int cachedSpanGroupIndex = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount);
                int cachedSpanGroupIndex2 = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount);
                int min = Math.min(cachedSpanGroupIndex, cachedSpanGroupIndex2);
                int max = Math.max(cachedSpanGroupIndex, cachedSpanGroupIndex2);
                int cachedSpanGroupIndex3 = this.mSpanSizeLookup.getCachedSpanGroupIndex(rVar.b() - 1, this.mSpanCount) + 1;
                if (this.mShouldReverseLayout) {
                    i2 = Math.max(0, (cachedSpanGroupIndex3 - max) - 1);
                } else {
                    i2 = Math.max(0, min);
                }
                if (!isSmoothScrollbarEnabled) {
                    return i2;
                }
                return Math.round((((float) i2) * (((float) Math.abs(this.mOrientationHelper.b(findFirstVisibleChildClosestToEnd) - this.mOrientationHelper.e(findFirstVisibleChildClosestToStart))) / ((float) ((this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount) - this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount)) + 1)))) + ((float) (this.mOrientationHelper.k() - this.mOrientationHelper.e(findFirstVisibleChildClosestToStart))));
            }
        }
        return 0;
    }

    private int computeScrollRangeWithSpanInfo(RecyclerView.r rVar) {
        if (!(getChildCount() == 0 || rVar.b() == 0)) {
            ensureLayoutState();
            View findFirstVisibleChildClosestToStart = findFirstVisibleChildClosestToStart(!isSmoothScrollbarEnabled(), true);
            View findFirstVisibleChildClosestToEnd = findFirstVisibleChildClosestToEnd(!isSmoothScrollbarEnabled(), true);
            if (!(findFirstVisibleChildClosestToStart == null || findFirstVisibleChildClosestToEnd == null)) {
                if (!isSmoothScrollbarEnabled()) {
                    return this.mSpanSizeLookup.getCachedSpanGroupIndex(rVar.b() - 1, this.mSpanCount) + 1;
                }
                int b2 = this.mOrientationHelper.b(findFirstVisibleChildClosestToEnd) - this.mOrientationHelper.e(findFirstVisibleChildClosestToStart);
                int cachedSpanGroupIndex = this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToStart), this.mSpanCount);
                return (int) ((((float) b2) / ((float) ((this.mSpanSizeLookup.getCachedSpanGroupIndex(getPosition(findFirstVisibleChildClosestToEnd), this.mSpanCount) - cachedSpanGroupIndex) + 1))) * ((float) (this.mSpanSizeLookup.getCachedSpanGroupIndex(rVar.b() - 1, this.mSpanCount) + 1)));
            }
        }
        return 0;
    }

    private void ensureAnchorIsInCorrectSpan(RecyclerView.p pVar, RecyclerView.r rVar, LinearLayoutManager.a aVar, int i2) {
        boolean z = i2 == 1;
        int spanIndex = getSpanIndex(pVar, rVar, aVar.f1814b);
        if (z) {
            while (spanIndex > 0) {
                int i3 = aVar.f1814b;
                if (i3 > 0) {
                    int i4 = i3 - 1;
                    aVar.f1814b = i4;
                    spanIndex = getSpanIndex(pVar, rVar, i4);
                } else {
                    return;
                }
            }
            return;
        }
        int b2 = rVar.b() - 1;
        int i5 = aVar.f1814b;
        while (i5 < b2) {
            int i6 = i5 + 1;
            int spanIndex2 = getSpanIndex(pVar, rVar, i6);
            if (spanIndex2 <= spanIndex) {
                break;
            }
            i5 = i6;
            spanIndex = spanIndex2;
        }
        aVar.f1814b = i5;
    }

    private void ensureViewSet() {
        View[] viewArr = this.mSet;
        if (viewArr == null || viewArr.length != this.mSpanCount) {
            this.mSet = new View[this.mSpanCount];
        }
    }

    private int getSpanGroupIndex(RecyclerView.p pVar, RecyclerView.r rVar, int i2) {
        if (!rVar.f1886g) {
            return this.mSpanSizeLookup.getCachedSpanGroupIndex(i2, this.mSpanCount);
        }
        int c2 = pVar.c(i2);
        if (c2 != -1) {
            return this.mSpanSizeLookup.getCachedSpanGroupIndex(c2, this.mSpanCount);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. " + i2);
        return 0;
    }

    private int getSpanIndex(RecyclerView.p pVar, RecyclerView.r rVar, int i2) {
        if (!rVar.f1886g) {
            return this.mSpanSizeLookup.getCachedSpanIndex(i2, this.mSpanCount);
        }
        int i3 = this.mPreLayoutSpanIndexCache.get(i2, -1);
        if (i3 != -1) {
            return i3;
        }
        int c2 = pVar.c(i2);
        if (c2 != -1) {
            return this.mSpanSizeLookup.getCachedSpanIndex(c2, this.mSpanCount);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. It is not cached, not in the adapter. Pos:" + i2);
        return 0;
    }

    private int getSpanSize(RecyclerView.p pVar, RecyclerView.r rVar, int i2) {
        if (!rVar.f1886g) {
            return this.mSpanSizeLookup.getSpanSize(i2);
        }
        int i3 = this.mPreLayoutSpanSizeCache.get(i2, -1);
        if (i3 != -1) {
            return i3;
        }
        int c2 = pVar.c(i2);
        if (c2 != -1) {
            return this.mSpanSizeLookup.getSpanSize(c2);
        }
        Log.w(TAG, "Cannot find span size for pre layout position. It is not cached, not in the adapter. Pos:" + i2);
        return 1;
    }

    private void guessMeasurement(float f2, int i2) {
        calculateItemBorders(Math.max(Math.round(f2 * ((float) this.mSpanCount)), i2));
    }

    private void measureChild(View view, int i2, boolean z) {
        int i3;
        int i4;
        LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
        Rect rect = layoutParams.f1862b;
        int i5 = rect.top + rect.bottom + ((ViewGroup.MarginLayoutParams) layoutParams).topMargin + ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
        int i6 = rect.left + rect.right + ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin + ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
        int spaceForSpanRange = getSpaceForSpanRange(layoutParams.f1798e, layoutParams.f1799f);
        if (this.mOrientation == 1) {
            i3 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, i2, i6, ((ViewGroup.MarginLayoutParams) layoutParams).width, false);
            i4 = RecyclerView.LayoutManager.getChildMeasureSpec(this.mOrientationHelper.l(), getHeightMode(), i5, ((ViewGroup.MarginLayoutParams) layoutParams).height, true);
        } else {
            int childMeasureSpec = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, i2, i5, ((ViewGroup.MarginLayoutParams) layoutParams).height, false);
            int childMeasureSpec2 = RecyclerView.LayoutManager.getChildMeasureSpec(this.mOrientationHelper.l(), getWidthMode(), i6, ((ViewGroup.MarginLayoutParams) layoutParams).width, true);
            i4 = childMeasureSpec;
            i3 = childMeasureSpec2;
        }
        measureChildWithDecorationsAndMargin(view, i3, i4, z);
    }

    private void measureChildWithDecorationsAndMargin(View view, int i2, int i3, boolean z) {
        boolean z2;
        RecyclerView.l lVar = (RecyclerView.l) view.getLayoutParams();
        if (z) {
            z2 = shouldReMeasureChild(view, i2, i3, lVar);
        } else {
            z2 = shouldMeasureChild(view, i2, i3, lVar);
        }
        if (z2) {
            view.measure(i2, i3);
        }
    }

    private void updateMeasurements() {
        int i2;
        int i3;
        if (getOrientation() == 1) {
            i3 = getWidth() - getPaddingRight();
            i2 = getPaddingLeft();
        } else {
            i3 = getHeight() - getPaddingBottom();
            i2 = getPaddingTop();
        }
        calculateItemBorders(i3 - i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public boolean checkLayoutParams(RecyclerView.l lVar) {
        return lVar instanceof LayoutParams;
    }

    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void collectPrefetchPositionsForLayoutState(RecyclerView.r rVar, LinearLayoutManager.c cVar, RecyclerView.LayoutManager.LayoutPrefetchRegistry layoutPrefetchRegistry) {
        int i2 = this.mSpanCount;
        for (int i3 = 0; i3 < this.mSpanCount && cVar.b(rVar) && i2 > 0; i3++) {
            int i4 = cVar.f1825d;
            layoutPrefetchRegistry.addPosition(i4, Math.max(0, cVar.f1828g));
            i2 -= this.mSpanSizeLookup.getSpanSize(i4);
            cVar.f1825d += cVar.f1826e;
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeHorizontalScrollOffset(RecyclerView.r rVar) {
        if (this.mUsingSpansToEstimateScrollBarDimensions) {
            return computeScrollOffsetWithSpanInfo(rVar);
        }
        return super.computeHorizontalScrollOffset(rVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeHorizontalScrollRange(RecyclerView.r rVar) {
        if (this.mUsingSpansToEstimateScrollBarDimensions) {
            return computeScrollRangeWithSpanInfo(rVar);
        }
        return super.computeHorizontalScrollRange(rVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeVerticalScrollOffset(RecyclerView.r rVar) {
        if (this.mUsingSpansToEstimateScrollBarDimensions) {
            return computeScrollOffsetWithSpanInfo(rVar);
        }
        return super.computeVerticalScrollOffset(rVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int computeVerticalScrollRange(RecyclerView.r rVar) {
        if (this.mUsingSpansToEstimateScrollBarDimensions) {
            return computeScrollRangeWithSpanInfo(rVar);
        }
        return super.computeVerticalScrollRange(rVar);
    }

    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public View findReferenceChild(RecyclerView.p pVar, RecyclerView.r rVar, boolean z, boolean z2) {
        int i2;
        int childCount = getChildCount();
        int i3 = -1;
        int i4 = 1;
        if (z2) {
            i2 = getChildCount() - 1;
            i4 = -1;
        } else {
            i3 = childCount;
            i2 = 0;
        }
        int b2 = rVar.b();
        ensureLayoutState();
        int k2 = this.mOrientationHelper.k();
        int g2 = this.mOrientationHelper.g();
        View view = null;
        View view2 = null;
        while (i2 != i3) {
            View childAt = getChildAt(i2);
            int position = getPosition(childAt);
            if (position >= 0 && position < b2 && getSpanIndex(pVar, rVar, position) == 0) {
                if (((RecyclerView.l) childAt.getLayoutParams()).c()) {
                    if (view2 == null) {
                        view2 = childAt;
                    }
                } else if (this.mOrientationHelper.e(childAt) < g2 && this.mOrientationHelper.b(childAt) >= k2) {
                    return childAt;
                } else {
                    if (view == null) {
                        view = childAt;
                    }
                }
            }
            i2 += i4;
        }
        return view != null ? view : view2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public RecyclerView.l generateDefaultLayoutParams() {
        if (this.mOrientation == 0) {
            return new LayoutParams(-2, -1);
        }
        return new LayoutParams(-1, -2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public RecyclerView.l generateLayoutParams(Context context, AttributeSet attributeSet) {
        return new LayoutParams(context, attributeSet);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int getColumnCountForAccessibility(RecyclerView.p pVar, RecyclerView.r rVar) {
        if (this.mOrientation == 1) {
            return this.mSpanCount;
        }
        if (rVar.b() < 1) {
            return 0;
        }
        return getSpanGroupIndex(pVar, rVar, rVar.b() - 1) + 1;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int getRowCountForAccessibility(RecyclerView.p pVar, RecyclerView.r rVar) {
        if (this.mOrientation == 0) {
            return this.mSpanCount;
        }
        if (rVar.b() < 1) {
            return 0;
        }
        return getSpanGroupIndex(pVar, rVar, rVar.b() - 1) + 1;
    }

    public int getSpaceForSpanRange(int i2, int i3) {
        if (this.mOrientation != 1 || !isLayoutRTL()) {
            int[] iArr = this.mCachedBorders;
            return iArr[i3 + i2] - iArr[i2];
        }
        int[] iArr2 = this.mCachedBorders;
        int i4 = this.mSpanCount;
        return iArr2[i4 - i2] - iArr2[(i4 - i2) - i3];
    }

    public int getSpanCount() {
        return this.mSpanCount;
    }

    public a getSpanSizeLookup() {
        return this.mSpanSizeLookup;
    }

    public boolean isUsingSpansToEstimateScrollbarDimensions() {
        return this.mUsingSpansToEstimateScrollBarDimensions;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r18v0, resolved type: androidx.recyclerview.widget.GridLayoutManager */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r5v0 */
    /* JADX WARN: Type inference failed for: r5v1, types: [boolean, int] */
    /* JADX WARN: Type inference failed for: r5v21 */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void layoutChunk(RecyclerView.p pVar, RecyclerView.r rVar, LinearLayoutManager.c cVar, LinearLayoutManager.b bVar) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        View c2;
        int j2 = this.mOrientationHelper.j();
        ?? r5 = 0;
        boolean z = j2 != 1073741824;
        int i14 = getChildCount() > 0 ? this.mCachedBorders[this.mSpanCount] : 0;
        if (z) {
            updateMeasurements();
        }
        boolean z2 = cVar.f1826e == 1;
        int i15 = this.mSpanCount;
        if (!z2) {
            i15 = getSpanIndex(pVar, rVar, cVar.f1825d) + getSpanSize(pVar, rVar, cVar.f1825d);
        }
        int i16 = 0;
        while (i16 < this.mSpanCount && cVar.b(rVar) && i15 > 0) {
            int i17 = cVar.f1825d;
            int spanSize = getSpanSize(pVar, rVar, i17);
            if (spanSize <= this.mSpanCount) {
                i15 -= spanSize;
                if (i15 < 0 || (c2 = cVar.c(pVar)) == null) {
                    break;
                }
                this.mSet[i16] = c2;
                i16++;
            } else {
                throw new IllegalArgumentException(d.a.a.a.a.v(d.a.a.a.a.D("Item at position ", i17, " requires ", spanSize, " spans but GridLayoutManager has only "), this.mSpanCount, " spans."));
            }
        }
        if (i16 == 0) {
            bVar.f1819b = true;
            return;
        }
        float f2 = 0.0f;
        assignSpans(pVar, rVar, i16, z2);
        int i18 = 0;
        int i19 = 0;
        while (i18 < i16) {
            View view = this.mSet[i18];
            if (cVar.f1832k == null) {
                if (z2) {
                    addView(view);
                } else {
                    addView(view, r5);
                }
            } else if (z2) {
                addDisappearingView(view);
            } else {
                int i20 = r5 == true ? 1 : 0;
                int i21 = r5 == true ? 1 : 0;
                int i22 = r5 == true ? 1 : 0;
                addDisappearingView(view, i20);
            }
            calculateItemDecorationsForChild(view, this.mDecorInsets);
            measureChild(view, j2, (boolean) r5);
            int c3 = this.mOrientationHelper.c(view);
            if (c3 > i19) {
                i19 = c3;
            }
            float d2 = (((float) this.mOrientationHelper.d(view)) * 1.0f) / ((float) ((LayoutParams) view.getLayoutParams()).f1799f);
            if (d2 > f2) {
                f2 = d2;
            }
            i18++;
            r5 = 0;
        }
        if (z) {
            guessMeasurement(f2, i14);
            i19 = 0;
            for (int i23 = 0; i23 < i16; i23++) {
                View view2 = this.mSet[i23];
                measureChild(view2, 1073741824, true);
                int c4 = this.mOrientationHelper.c(view2);
                if (c4 > i19) {
                    i19 = c4;
                }
            }
        }
        for (int i24 = 0; i24 < i16; i24++) {
            View view3 = this.mSet[i24];
            if (this.mOrientationHelper.c(view3) != i19) {
                LayoutParams layoutParams = (LayoutParams) view3.getLayoutParams();
                Rect rect = layoutParams.f1862b;
                int i25 = rect.top + rect.bottom + ((ViewGroup.MarginLayoutParams) layoutParams).topMargin + ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
                int i26 = rect.left + rect.right + ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin + ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
                int spaceForSpanRange = getSpaceForSpanRange(layoutParams.f1798e, layoutParams.f1799f);
                if (this.mOrientation == 1) {
                    i13 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, 1073741824, i26, ((ViewGroup.MarginLayoutParams) layoutParams).width, false);
                    i12 = View.MeasureSpec.makeMeasureSpec(i19 - i25, 1073741824);
                } else {
                    int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(i19 - i26, 1073741824);
                    i12 = RecyclerView.LayoutManager.getChildMeasureSpec(spaceForSpanRange, 1073741824, i25, ((ViewGroup.MarginLayoutParams) layoutParams).height, false);
                    i13 = makeMeasureSpec;
                }
                measureChildWithDecorationsAndMargin(view3, i13, i12, true);
            }
        }
        bVar.f1818a = i19;
        if (this.mOrientation == 1) {
            if (cVar.f1827f == -1) {
                i4 = cVar.f1823b;
                i5 = i4 - i19;
            } else {
                int i27 = cVar.f1823b;
                i4 = i19 + i27;
                i5 = i27;
            }
            i3 = 0;
            i2 = 0;
        } else if (cVar.f1827f == -1) {
            i3 = cVar.f1823b;
            i2 = i3 - i19;
            i5 = 0;
            i4 = 0;
        } else {
            i2 = cVar.f1823b;
            i3 = i19 + i2;
            i4 = 0;
            i5 = 0;
        }
        int i28 = 0;
        while (i28 < i16) {
            View view4 = this.mSet[i28];
            LayoutParams layoutParams2 = (LayoutParams) view4.getLayoutParams();
            if (this.mOrientation == 1) {
                if (isLayoutRTL()) {
                    i11 = getPaddingLeft() + this.mCachedBorders[this.mSpanCount - layoutParams2.f1798e];
                    i10 = i11 - this.mOrientationHelper.d(view4);
                } else {
                    i10 = this.mCachedBorders[layoutParams2.f1798e] + getPaddingLeft();
                    i11 = this.mOrientationHelper.d(view4) + i10;
                }
                i7 = i11;
                i9 = i5;
                i8 = i4;
                i6 = i10;
            } else {
                int paddingTop = getPaddingTop() + this.mCachedBorders[layoutParams2.f1798e];
                i9 = paddingTop;
                i8 = this.mOrientationHelper.d(view4) + paddingTop;
                i7 = i3;
                i6 = i2;
            }
            layoutDecoratedWithMargins(view4, i6, i9, i7, i8);
            if (layoutParams2.c() || layoutParams2.b()) {
                bVar.f1820c = true;
            }
            bVar.f1821d |= view4.hasFocusable();
            i28++;
            i5 = i9;
            i4 = i8;
            i3 = i7;
            i2 = i6;
        }
        Arrays.fill(this.mSet, (Object) null);
    }

    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void onAnchorReady(RecyclerView.p pVar, RecyclerView.r rVar, LinearLayoutManager.a aVar, int i2) {
        super.onAnchorReady(pVar, rVar, aVar, i2);
        updateMeasurements();
        if (rVar.b() > 0 && !rVar.f1886g) {
            ensureAnchorIsInCorrectSpan(pVar, rVar, aVar, i2);
        }
        ensureViewSet();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:54:0x00d6, code lost:
        if (r13 == (r2 > r15)) goto L_0x00b0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x00f6, code lost:
        if (r13 == r11) goto L_0x00b8;
     */
    /* JADX WARNING: Removed duplicated region for block: B:71:0x0107  */
    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public View onFocusSearchFailed(View view, int i2, RecyclerView.p pVar, RecyclerView.r rVar) {
        int i3;
        int i4;
        int i5;
        int i6;
        View view2;
        View view3;
        int i7;
        int i8;
        int i9;
        boolean z;
        RecyclerView.p pVar2 = pVar;
        RecyclerView.r rVar2 = rVar;
        View findContainingItemView = findContainingItemView(view);
        View view4 = null;
        if (findContainingItemView == null) {
            return null;
        }
        LayoutParams layoutParams = (LayoutParams) findContainingItemView.getLayoutParams();
        int i10 = layoutParams.f1798e;
        int i11 = layoutParams.f1799f + i10;
        if (super.onFocusSearchFailed(view, i2, pVar, rVar) == null) {
            return null;
        }
        if ((convertFocusDirectionToLayoutDirection(i2) == 1) != this.mShouldReverseLayout) {
            i5 = getChildCount() - 1;
            i4 = -1;
            i3 = -1;
        } else {
            i4 = getChildCount();
            i5 = 0;
            i3 = 1;
        }
        boolean z2 = this.mOrientation == 1 && isLayoutRTL();
        int spanGroupIndex = getSpanGroupIndex(pVar2, rVar2, i5);
        int i12 = i5;
        int i13 = 0;
        int i14 = -1;
        int i15 = -1;
        int i16 = 0;
        View view5 = null;
        while (i12 != i4) {
            int spanGroupIndex2 = getSpanGroupIndex(pVar2, rVar2, i12);
            View childAt = getChildAt(i12);
            if (childAt == findContainingItemView) {
                break;
            }
            if (!childAt.hasFocusable() || spanGroupIndex2 == spanGroupIndex) {
                LayoutParams layoutParams2 = (LayoutParams) childAt.getLayoutParams();
                int i17 = layoutParams2.f1798e;
                view2 = findContainingItemView;
                int i18 = layoutParams2.f1799f + i17;
                if (childAt.hasFocusable() && i17 == i10 && i18 == i11) {
                    return childAt;
                }
                if ((!childAt.hasFocusable() || view4 != null) && (childAt.hasFocusable() || view5 != null)) {
                    view3 = view5;
                    int min = Math.min(i18, i11) - Math.max(i17, i10);
                    if (childAt.hasFocusable()) {
                        if (min <= i13) {
                            if (min == i13) {
                            }
                        }
                    } else if (view4 == null) {
                        i7 = i13;
                        i6 = i4;
                        z = true;
                        if (isViewPartiallyVisible(childAt, false, true)) {
                            i8 = i16;
                            if (min > i8) {
                                i9 = i15;
                                if (z) {
                                    if (childAt.hasFocusable()) {
                                        i14 = layoutParams2.f1798e;
                                        i15 = i9;
                                        i16 = i8;
                                        view5 = view3;
                                        view4 = childAt;
                                        i13 = Math.min(i18, i11) - Math.max(i17, i10);
                                    } else {
                                        int i19 = layoutParams2.f1798e;
                                        i16 = Math.min(i18, i11) - Math.max(i17, i10);
                                        i15 = i19;
                                        i13 = i7;
                                        view5 = childAt;
                                    }
                                    i12 += i3;
                                    pVar2 = pVar;
                                    rVar2 = rVar;
                                    findContainingItemView = view2;
                                    i4 = i6;
                                }
                            } else {
                                if (min == i8) {
                                    i9 = i15;
                                    if (i17 <= i9) {
                                        z = false;
                                    }
                                } else {
                                    i9 = i15;
                                }
                                z = false;
                                if (z) {
                                }
                            }
                        }
                        i9 = i15;
                        i8 = i16;
                        z = false;
                        if (z) {
                        }
                    }
                    i7 = i13;
                    i6 = i4;
                    i9 = i15;
                    i8 = i16;
                    z = false;
                    if (z) {
                    }
                } else {
                    view3 = view5;
                }
                i7 = i13;
                i6 = i4;
                i9 = i15;
                i8 = i16;
                z = true;
                if (z) {
                }
            } else if (view4 != null) {
                break;
            } else {
                view2 = findContainingItemView;
                view3 = view5;
                i7 = i13;
                i6 = i4;
                i9 = i15;
                i8 = i16;
            }
            i15 = i9;
            i16 = i8;
            i13 = i7;
            view5 = view3;
            i12 += i3;
            pVar2 = pVar;
            rVar2 = rVar;
            findContainingItemView = view2;
            i4 = i6;
        }
        return view4 != null ? view4 : view5;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onInitializeAccessibilityNodeInfoForItem(RecyclerView.p pVar, RecyclerView.r rVar, View view, b bVar) {
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (!(layoutParams instanceof LayoutParams)) {
            super.onInitializeAccessibilityNodeInfoForItem(view, bVar);
            return;
        }
        LayoutParams layoutParams2 = (LayoutParams) layoutParams;
        int spanGroupIndex = getSpanGroupIndex(pVar, rVar, layoutParams2.a());
        if (this.mOrientation == 0) {
            bVar.t(b.c.a(layoutParams2.f1798e, layoutParams2.f1799f, spanGroupIndex, 1, false, false));
        } else {
            bVar.t(b.c.a(spanGroupIndex, 1, layoutParams2.f1798e, layoutParams2.f1799f, false, false));
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsAdded(RecyclerView recyclerView, int i2, int i3) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsChanged(RecyclerView recyclerView) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsMoved(RecyclerView recyclerView, int i2, int i3, int i4) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsRemoved(RecyclerView recyclerView, int i2, int i3) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onItemsUpdated(RecyclerView recyclerView, int i2, int i3, Object obj) {
        this.mSpanSizeLookup.invalidateSpanIndexCache();
        this.mSpanSizeLookup.invalidateSpanGroupIndexCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public void onLayoutChildren(RecyclerView.p pVar, RecyclerView.r rVar) {
        if (rVar.f1886g) {
            cachePreLayoutSpanMapping();
        }
        super.onLayoutChildren(pVar, rVar);
        clearPreLayoutSpanMappingCache();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public void onLayoutCompleted(RecyclerView.r rVar) {
        super.onLayoutCompleted(rVar);
        this.mPendingSpanCountChange = false;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int scrollHorizontallyBy(int i2, RecyclerView.p pVar, RecyclerView.r rVar) {
        updateMeasurements();
        ensureViewSet();
        return super.scrollHorizontallyBy(i2, pVar, rVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public int scrollVerticallyBy(int i2, RecyclerView.p pVar, RecyclerView.r rVar) {
        updateMeasurements();
        ensureViewSet();
        return super.scrollVerticallyBy(i2, pVar, rVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void setMeasuredDimension(Rect rect, int i2, int i3) {
        int i4;
        int i5;
        if (this.mCachedBorders == null) {
            super.setMeasuredDimension(rect, i2, i3);
        }
        int paddingRight = getPaddingRight() + getPaddingLeft();
        int paddingBottom = getPaddingBottom() + getPaddingTop();
        if (this.mOrientation == 1) {
            i5 = RecyclerView.LayoutManager.chooseSize(i3, rect.height() + paddingBottom, getMinimumHeight());
            int[] iArr = this.mCachedBorders;
            i4 = RecyclerView.LayoutManager.chooseSize(i2, iArr[iArr.length - 1] + paddingRight, getMinimumWidth());
        } else {
            i4 = RecyclerView.LayoutManager.chooseSize(i2, rect.width() + paddingRight, getMinimumWidth());
            int[] iArr2 = this.mCachedBorders;
            i5 = RecyclerView.LayoutManager.chooseSize(i3, iArr2[iArr2.length - 1] + paddingBottom, getMinimumHeight());
        }
        setMeasuredDimension(i4, i5);
    }

    public void setSpanCount(int i2) {
        if (i2 != this.mSpanCount) {
            this.mPendingSpanCountChange = true;
            if (i2 >= 1) {
                this.mSpanCount = i2;
                this.mSpanSizeLookup.invalidateSpanIndexCache();
                requestLayout();
                return;
            }
            throw new IllegalArgumentException(d.a.a.a.a.k("Span count should be at least 1. Provided ", i2));
        }
    }

    public void setSpanSizeLookup(a aVar) {
        this.mSpanSizeLookup = aVar;
    }

    @Override // androidx.recyclerview.widget.LinearLayoutManager
    public void setStackFromEnd(boolean z) {
        if (!z) {
            super.setStackFromEnd(false);
            return;
        }
        throw new UnsupportedOperationException("GridLayoutManager does not support stack from end. Consider using reverse layout");
    }

    public void setUsingSpansToEstimateScrollbarDimensions(boolean z) {
        this.mUsingSpansToEstimateScrollBarDimensions = z;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
    public boolean supportsPredictiveItemAnimations() {
        return this.mPendingSavedState == null && !this.mPendingSpanCountChange;
    }

    public static int[] calculateItemBorders(int[] iArr, int i2, int i3) {
        int i4;
        if (!(iArr != null && iArr.length == i2 + 1 && iArr[iArr.length - 1] == i3)) {
            iArr = new int[(i2 + 1)];
        }
        int i5 = 0;
        iArr[0] = 0;
        int i6 = i3 / i2;
        int i7 = i3 % i2;
        int i8 = 0;
        for (int i9 = 1; i9 <= i2; i9++) {
            i5 += i7;
            if (i5 <= 0 || i2 - i5 >= i7) {
                i4 = i6;
            } else {
                i4 = i6 + 1;
                i5 -= i2;
            }
            i8 += i4;
            iArr[i9] = i8;
        }
        return iArr;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public RecyclerView.l generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
            return new LayoutParams((ViewGroup.MarginLayoutParams) layoutParams);
        }
        return new LayoutParams(layoutParams);
    }

    public static class LayoutParams extends RecyclerView.l {

        /* renamed from: e  reason: collision with root package name */
        public int f1798e = -1;

        /* renamed from: f  reason: collision with root package name */
        public int f1799f = 0;

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        public LayoutParams(int i2, int i3) {
            super(i2, i3);
        }

        public LayoutParams(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }
    }

    public GridLayoutManager(Context context, int i2) {
        super(context);
        setSpanCount(i2);
    }

    public GridLayoutManager(Context context, int i2, int i3, boolean z) {
        super(context, i3, z);
        setSpanCount(i2);
    }
}
