package com.chad.library.adapter.base;

import android.annotation.SuppressLint;
import android.util.SparseArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import b.u.a.f;
import com.chad.library.adapter.base.binder.BaseItemBinder;
import com.chad.library.adapter.base.viewholder.BaseViewHolder;
import d.a.a.a.a;
import h.p.b.m;
import h.p.b.o;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

/* compiled from: BaseBinderAdapter.kt */
public class BaseBinderAdapter extends BaseQuickAdapter<Object, BaseViewHolder> {
    private final HashMap<Class<?>, f.e<Object>> classDiffMap;
    private final SparseArray<BaseItemBinder<Object, ?>> mBinderArray;
    private final HashMap<Class<?>, Integer> mTypeMap;

    /* compiled from: BaseBinderAdapter.kt */
    public final class ItemCallback extends f.e<Object> {
        public ItemCallback() {
        }

        @Override // b.u.a.f.e
        @SuppressLint({"DiffUtilEquals"})
        public boolean areContentsTheSame(Object obj, Object obj2) {
            f.e eVar;
            o.f(obj, "oldItem");
            o.f(obj2, "newItem");
            if (!o.a(obj.getClass(), obj2.getClass()) || (eVar = (f.e) BaseBinderAdapter.this.classDiffMap.get(obj.getClass())) == null) {
                return true;
            }
            return eVar.areContentsTheSame(obj, obj2);
        }

        @Override // b.u.a.f.e
        public boolean areItemsTheSame(Object obj, Object obj2) {
            f.e eVar;
            o.f(obj, "oldItem");
            o.f(obj2, "newItem");
            if (!o.a(obj.getClass(), obj2.getClass()) || (eVar = (f.e) BaseBinderAdapter.this.classDiffMap.get(obj.getClass())) == null) {
                return o.a(obj, obj2);
            }
            return eVar.areItemsTheSame(obj, obj2);
        }

        @Override // b.u.a.f.e
        public Object getChangePayload(Object obj, Object obj2) {
            f.e eVar;
            o.f(obj, "oldItem");
            o.f(obj2, "newItem");
            if (!o.a(obj.getClass(), obj2.getClass()) || (eVar = (f.e) BaseBinderAdapter.this.classDiffMap.get(obj.getClass())) == null) {
                return null;
            }
            return eVar.getChangePayload(obj, obj2);
        }
    }

    public BaseBinderAdapter() {
        this(null, 1, null);
    }

    public BaseBinderAdapter(List<Object> list) {
        super(0, list);
        this.classDiffMap = new HashMap<>();
        this.mTypeMap = new HashMap<>();
        this.mBinderArray = new SparseArray<>();
        setDiffCallback(new ItemCallback());
    }

    public static /* synthetic */ BaseBinderAdapter addItemBinder$default(BaseBinderAdapter baseBinderAdapter, Class cls, BaseItemBinder baseItemBinder, f.e eVar, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 4) != 0) {
                eVar = null;
            }
            return baseBinderAdapter.addItemBinder(cls, baseItemBinder, eVar);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: addItemBinder");
    }

    public final <T> BaseBinderAdapter addItemBinder(Class<? extends T> cls, BaseItemBinder<T, ?> baseItemBinder) {
        return addItemBinder$default(this, cls, baseItemBinder, null, 4, null);
    }

    public final <T> BaseBinderAdapter addItemBinder(Class<? extends T> cls, BaseItemBinder<T, ?> baseItemBinder, f.e<T> eVar) {
        o.f(cls, "clazz");
        o.f(baseItemBinder, "baseItemBinder");
        int size = this.mTypeMap.size() + 1;
        this.mTypeMap.put(cls, Integer.valueOf(size));
        this.mBinderArray.append(size, baseItemBinder);
        baseItemBinder.set_adapter$com_github_CymChad_brvah(this);
        if (eVar != null) {
            this.classDiffMap.put(cls, eVar);
        }
        return this;
    }

    public void bindChildClick(BaseViewHolder baseViewHolder, int i2) {
        o.f(baseViewHolder, "viewHolder");
        if (getOnItemChildClickListener() == null) {
            BaseItemBinder<Object, BaseViewHolder> itemBinder = getItemBinder(i2);
            Iterator<T> it = itemBinder.getChildClickViewIds().iterator();
            while (it.hasNext()) {
                View findViewById = baseViewHolder.itemView.findViewById(it.next().intValue());
                if (findViewById != null) {
                    if (!findViewById.isClickable()) {
                        findViewById.setClickable(true);
                    }
                    findViewById.setOnClickListener(new BaseBinderAdapter$bindChildClick$$inlined$forEach$lambda$1(this, baseViewHolder, itemBinder));
                }
            }
        }
        if (getOnItemChildLongClickListener() == null) {
            BaseItemBinder<Object, BaseViewHolder> itemBinder2 = getItemBinder(i2);
            Iterator<T> it2 = itemBinder2.getChildLongClickViewIds().iterator();
            while (it2.hasNext()) {
                View findViewById2 = baseViewHolder.itemView.findViewById(it2.next().intValue());
                if (findViewById2 != null) {
                    if (!findViewById2.isLongClickable()) {
                        findViewById2.setLongClickable(true);
                    }
                    findViewById2.setOnLongClickListener(new BaseBinderAdapter$bindChildClick$$inlined$forEach$lambda$2(this, baseViewHolder, itemBinder2));
                }
            }
        }
    }

    public void bindClick(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "viewHolder");
        if (getOnItemClickListener() == null) {
            baseViewHolder.itemView.setOnClickListener(new BaseBinderAdapter$bindClick$1(this, baseViewHolder));
        }
        if (getOnItemLongClickListener() == null) {
            baseViewHolder.itemView.setOnLongClickListener(new BaseBinderAdapter$bindClick$2(this, baseViewHolder));
        }
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void bindViewClickListener(BaseViewHolder baseViewHolder, int i2) {
        o.f(baseViewHolder, "viewHolder");
        super.bindViewClickListener(baseViewHolder, i2);
        bindClick(baseViewHolder);
        bindChildClick(baseViewHolder, i2);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void convert(BaseViewHolder baseViewHolder, Object obj) {
        o.f(baseViewHolder, "holder");
        o.f(obj, "item");
        getItemBinder(baseViewHolder.getItemViewType()).convert(baseViewHolder, obj);
    }

    public final int findViewType(Class<?> cls) {
        o.f(cls, "clazz");
        Integer num = this.mTypeMap.get(cls);
        if (num != null) {
            return num.intValue();
        }
        throw new IllegalStateException(("findViewType: ViewType: " + cls + " Not Find!").toString());
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public int getDefItemViewType(int i2) {
        return findViewType(getData().get(i2).getClass());
    }

    /* JADX DEBUG: Type inference failed for r0v2. Raw type applied. Possible types: com.chad.library.adapter.base.binder.BaseItemBinder<java.lang.Object, ?>, com.chad.library.adapter.base.binder.BaseItemBinder<java.lang.Object, com.chad.library.adapter.base.viewholder.BaseViewHolder> */
    public BaseItemBinder<Object, BaseViewHolder> getItemBinder(int i2) {
        BaseItemBinder baseItemBinder = this.mBinderArray.get(i2);
        if (baseItemBinder != null) {
            return baseItemBinder;
        }
        throw new IllegalStateException(a.m("getItemBinder: viewType '", i2, "' no such Binder found，please use addItemBinder() first!").toString());
    }

    /* JADX DEBUG: Type inference failed for r2v2. Raw type applied. Possible types: com.chad.library.adapter.base.binder.BaseItemBinder<java.lang.Object, ?>, com.chad.library.adapter.base.binder.BaseItemBinder<java.lang.Object, com.chad.library.adapter.base.viewholder.BaseViewHolder> */
    public BaseItemBinder<Object, BaseViewHolder> getItemBinderOrNull(int i2) {
        BaseItemBinder baseItemBinder = this.mBinderArray.get(i2);
        if (!(baseItemBinder instanceof BaseItemBinder)) {
            return null;
        }
        return baseItemBinder;
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public BaseViewHolder onCreateDefViewHolder(ViewGroup viewGroup, int i2) {
        o.f(viewGroup, "parent");
        BaseItemBinder<Object, BaseViewHolder> itemBinder = getItemBinder(i2);
        itemBinder.set_context$com_github_CymChad_brvah(getContext());
        return itemBinder.onCreateViewHolder(viewGroup, i2);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void convert(BaseViewHolder baseViewHolder, Object obj, List<? extends Object> list) {
        o.f(baseViewHolder, "holder");
        o.f(obj, "item");
        o.f(list, "payloads");
        getItemBinder(baseViewHolder.getItemViewType()).convert(baseViewHolder, obj, list);
    }

    public boolean onFailedToRecycleView(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "holder");
        BaseItemBinder<Object, BaseViewHolder> itemBinderOrNull = getItemBinderOrNull(baseViewHolder.getItemViewType());
        if (itemBinderOrNull != null) {
            return itemBinderOrNull.onFailedToRecycleView(baseViewHolder);
        }
        return false;
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void onViewAttachedToWindow(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "holder");
        super.onViewAttachedToWindow(baseViewHolder);
        BaseItemBinder<Object, BaseViewHolder> itemBinderOrNull = getItemBinderOrNull(baseViewHolder.getItemViewType());
        if (itemBinderOrNull != null) {
            itemBinderOrNull.onViewAttachedToWindow(baseViewHolder);
        }
    }

    public void onViewDetachedFromWindow(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "holder");
        super.onViewDetachedFromWindow((RecyclerView.ViewHolder) baseViewHolder);
        BaseItemBinder<Object, BaseViewHolder> itemBinderOrNull = getItemBinderOrNull(baseViewHolder.getItemViewType());
        if (itemBinderOrNull != null) {
            itemBinderOrNull.onViewDetachedFromWindow(baseViewHolder);
        }
    }

    public static /* synthetic */ BaseBinderAdapter addItemBinder$default(BaseBinderAdapter baseBinderAdapter, BaseItemBinder baseItemBinder, f.e eVar, int i2, Object obj) {
        if (obj == null) {
            int i3 = i2 & 2;
            o.f(baseItemBinder, "baseItemBinder");
            o.i();
            throw null;
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: addItemBinder");
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ BaseBinderAdapter(List list, int i2, m mVar) {
        this((i2 & 1) != 0 ? null : list);
    }

    public final /* synthetic */ <T> BaseBinderAdapter addItemBinder(BaseItemBinder<T, ?> baseItemBinder, f.e<T> eVar) {
        o.f(baseItemBinder, "baseItemBinder");
        o.i();
        throw null;
    }
}
