package com.chad.library.adapter.base;

import android.animation.Animator;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import b.u.a.f;
import com.chad.library.adapter.base.BaseQuickAdapterModuleImp;
import com.chad.library.adapter.base.animation.AlphaInAnimation;
import com.chad.library.adapter.base.animation.BaseAnimation;
import com.chad.library.adapter.base.animation.ScaleInAnimation;
import com.chad.library.adapter.base.animation.SlideInBottomAnimation;
import com.chad.library.adapter.base.animation.SlideInLeftAnimation;
import com.chad.library.adapter.base.animation.SlideInRightAnimation;
import com.chad.library.adapter.base.diff.BrvahAsyncDiffer;
import com.chad.library.adapter.base.diff.BrvahAsyncDifferConfig;
import com.chad.library.adapter.base.diff.BrvahListUpdateCallback;
import com.chad.library.adapter.base.listener.BaseListenerImp;
import com.chad.library.adapter.base.listener.GridSpanSizeLookup;
import com.chad.library.adapter.base.listener.OnItemChildClickListener;
import com.chad.library.adapter.base.listener.OnItemChildLongClickListener;
import com.chad.library.adapter.base.listener.OnItemClickListener;
import com.chad.library.adapter.base.listener.OnItemLongClickListener;
import com.chad.library.adapter.base.module.BaseDraggableModule;
import com.chad.library.adapter.base.module.BaseLoadMoreModule;
import com.chad.library.adapter.base.module.BaseUpFetchModule;
import com.chad.library.adapter.base.module.DraggableModule;
import com.chad.library.adapter.base.module.LoadMoreModule;
import com.chad.library.adapter.base.module.UpFetchModule;
import com.chad.library.adapter.base.util.AdapterUtilsKt;
import com.chad.library.adapter.base.viewholder.BaseViewHolder;
import d.l.b.g.g.b;
import h.p.b.m;
import h.p.b.o;
import java.lang.ref.WeakReference;
import java.lang.reflect.Constructor;
import java.lang.reflect.GenericSignatureFormatError;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.MalformedParameterizedTypeException;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import kotlin.NoWhenBranchMatchedException;
import kotlin.TypeCastException;

/* compiled from: BaseQuickAdapter.kt */
public abstract class BaseQuickAdapter<T, VH extends BaseViewHolder> extends RecyclerView.Adapter<VH> implements BaseQuickAdapterModuleImp, BaseListenerImp {
    public static final Companion Companion = new Companion(null);
    public static final int EMPTY_VIEW = 268436821;
    public static final int FOOTER_VIEW = 268436275;
    public static final int HEADER_VIEW = 268435729;
    public static final int LOAD_MORE_VIEW = 268436002;
    private BaseAnimation adapterAnimation;
    private boolean animationEnable;
    private final LinkedHashSet<Integer> childClickViewIds;
    private final LinkedHashSet<Integer> childLongClickViewIds;
    private Context context;
    private List<T> data;
    private boolean footerViewAsFlow;
    private boolean footerWithEmptyEnable;
    private boolean headerViewAsFlow;
    private boolean headerWithEmptyEnable;
    private boolean isAnimationFirstOnly;
    private boolean isUseEmpty;
    private final int layoutResId;
    private BrvahAsyncDiffer<T> mDiffHelper;
    private BaseDraggableModule mDraggableModule;
    private FrameLayout mEmptyLayout;
    private LinearLayout mFooterLayout;
    private LinearLayout mHeaderLayout;
    private int mLastPosition;
    private BaseLoadMoreModule mLoadMoreModule;
    private OnItemChildClickListener mOnItemChildClickListener;
    private OnItemChildLongClickListener mOnItemChildLongClickListener;
    private OnItemClickListener mOnItemClickListener;
    private OnItemLongClickListener mOnItemLongClickListener;
    private RecyclerView mRecyclerView;
    private GridSpanSizeLookup mSpanSizeLookup;
    private BaseUpFetchModule mUpFetchModule;
    public WeakReference<RecyclerView> weakRecyclerView;

    /* compiled from: BaseQuickAdapter.kt */
    public enum AnimationType {
        AlphaIn,
        ScaleIn,
        SlideInBottom,
        SlideInLeft,
        SlideInRight
    }

    /* compiled from: BaseQuickAdapter.kt */
    public static final class Companion {
        private Companion() {
        }

        public /* synthetic */ Companion(m mVar) {
            this();
        }
    }

    public final /* synthetic */ class WhenMappings {
        public static final /* synthetic */ int[] $EnumSwitchMapping$0;

        static {
            AnimationType.values();
            int[] iArr = new int[5];
            $EnumSwitchMapping$0 = iArr;
            iArr[AnimationType.AlphaIn.ordinal()] = 1;
            iArr[AnimationType.ScaleIn.ordinal()] = 2;
            iArr[AnimationType.SlideInBottom.ordinal()] = 3;
            iArr[AnimationType.SlideInLeft.ordinal()] = 4;
            iArr[AnimationType.SlideInRight.ordinal()] = 5;
        }
    }

    public BaseQuickAdapter(int i2) {
        this(i2, null, 2, null);
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ BaseQuickAdapter(int i2, List list, int i3, m mVar) {
        this(i2, (i3 & 2) != 0 ? null : list);
    }

    public static final /* synthetic */ FrameLayout access$getMEmptyLayout$p(BaseQuickAdapter baseQuickAdapter) {
        FrameLayout frameLayout = baseQuickAdapter.mEmptyLayout;
        if (frameLayout != null) {
            return frameLayout;
        }
        o.m("mEmptyLayout");
        throw null;
    }

    public static final /* synthetic */ LinearLayout access$getMFooterLayout$p(BaseQuickAdapter baseQuickAdapter) {
        LinearLayout linearLayout = baseQuickAdapter.mFooterLayout;
        if (linearLayout != null) {
            return linearLayout;
        }
        o.m("mFooterLayout");
        throw null;
    }

    public static final /* synthetic */ LinearLayout access$getMHeaderLayout$p(BaseQuickAdapter baseQuickAdapter) {
        LinearLayout linearLayout = baseQuickAdapter.mHeaderLayout;
        if (linearLayout != null) {
            return linearLayout;
        }
        o.m("mHeaderLayout");
        throw null;
    }

    private final void addAnimation(RecyclerView.ViewHolder viewHolder) {
        if (!this.animationEnable) {
            return;
        }
        if (!this.isAnimationFirstOnly || viewHolder.getLayoutPosition() > this.mLastPosition) {
            BaseAnimation baseAnimation = this.adapterAnimation;
            if (baseAnimation == null) {
                baseAnimation = new AlphaInAnimation(0.0f, 1, null);
            }
            View view = viewHolder.itemView;
            o.b(view, "holder.itemView");
            for (Animator animator : baseAnimation.animators(view)) {
                startAnim(animator, viewHolder.getLayoutPosition());
            }
            this.mLastPosition = viewHolder.getLayoutPosition();
        }
    }

    public static /* synthetic */ int addFooterView$default(BaseQuickAdapter baseQuickAdapter, View view, int i2, int i3, int i4, Object obj) {
        if (obj == null) {
            if ((i4 & 2) != 0) {
                i2 = -1;
            }
            if ((i4 & 4) != 0) {
                i3 = 1;
            }
            return baseQuickAdapter.addFooterView(view, i2, i3);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: addFooterView");
    }

    public static /* synthetic */ int addHeaderView$default(BaseQuickAdapter baseQuickAdapter, View view, int i2, int i3, int i4, Object obj) {
        if (obj == null) {
            if ((i4 & 2) != 0) {
                i2 = -1;
            }
            if ((i4 & 4) != 0) {
                i3 = 1;
            }
            return baseQuickAdapter.addHeaderView(view, i2, i3);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: addHeaderView");
    }

    private final void checkModule() {
        if (this instanceof LoadMoreModule) {
            this.mLoadMoreModule = addLoadMoreModule(this);
        }
        if (this instanceof UpFetchModule) {
            this.mUpFetchModule = addUpFetchModule(this);
        }
        if (this instanceof DraggableModule) {
            this.mDraggableModule = addDraggableModule(this);
        }
    }

    private final VH createBaseGenericKInstance(Class<?> cls, View view) {
        try {
            if (!cls.isMemberClass() || Modifier.isStatic(cls.getModifiers())) {
                Constructor<?> declaredConstructor = cls.getDeclaredConstructor(View.class);
                o.b(declaredConstructor, "z.getDeclaredConstructor(View::class.java)");
                declaredConstructor.setAccessible(true);
                Object newInstance = declaredConstructor.newInstance(view);
                if (newInstance != null) {
                    return (VH) ((BaseViewHolder) newInstance);
                }
                throw new TypeCastException("null cannot be cast to non-null type VH");
            }
            Constructor<?> declaredConstructor2 = cls.getDeclaredConstructor(getClass(), View.class);
            o.b(declaredConstructor2, "z.getDeclaredConstructor…aClass, View::class.java)");
            declaredConstructor2.setAccessible(true);
            Object newInstance2 = declaredConstructor2.newInstance(this, view);
            if (newInstance2 != null) {
                return (VH) ((BaseViewHolder) newInstance2);
            }
            throw new TypeCastException("null cannot be cast to non-null type VH");
        } catch (NoSuchMethodException e2) {
            e2.printStackTrace();
            return null;
        } catch (IllegalAccessException e3) {
            e3.printStackTrace();
            return null;
        } catch (InstantiationException e4) {
            e4.printStackTrace();
            return null;
        } catch (InvocationTargetException e5) {
            e5.printStackTrace();
            return null;
        }
    }

    private final Class<?> getInstancedGenericKClass(Class<?> cls) {
        try {
            Type genericSuperclass = cls.getGenericSuperclass();
            if (!(genericSuperclass instanceof ParameterizedType)) {
                return null;
            }
            Type[] actualTypeArguments = ((ParameterizedType) genericSuperclass).getActualTypeArguments();
            o.b(actualTypeArguments, "type.actualTypeArguments");
            for (Type type : actualTypeArguments) {
                if (type instanceof Class) {
                    if (BaseViewHolder.class.isAssignableFrom((Class) type)) {
                        return (Class) type;
                    }
                } else if (type instanceof ParameterizedType) {
                    Type rawType = ((ParameterizedType) type).getRawType();
                    o.b(rawType, "temp.rawType");
                    if ((rawType instanceof Class) && BaseViewHolder.class.isAssignableFrom((Class) rawType)) {
                        return (Class) rawType;
                    }
                } else {
                    continue;
                }
            }
            return null;
        } catch (GenericSignatureFormatError e2) {
            e2.printStackTrace();
            return null;
        } catch (TypeNotPresentException e3) {
            e3.printStackTrace();
            return null;
        } catch (MalformedParameterizedTypeException e4) {
            e4.printStackTrace();
            return null;
        }
    }

    public static /* synthetic */ int setFooterView$default(BaseQuickAdapter baseQuickAdapter, View view, int i2, int i3, int i4, Object obj) {
        if (obj == null) {
            if ((i4 & 2) != 0) {
                i2 = 0;
            }
            if ((i4 & 4) != 0) {
                i3 = 1;
            }
            return baseQuickAdapter.setFooterView(view, i2, i3);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: setFooterView");
    }

    public static /* synthetic */ int setHeaderView$default(BaseQuickAdapter baseQuickAdapter, View view, int i2, int i3, int i4, Object obj) {
        if (obj == null) {
            if ((i4 & 2) != 0) {
                i2 = 0;
            }
            if ((i4 & 4) != 0) {
                i3 = 1;
            }
            return baseQuickAdapter.setHeaderView(view, i2, i3);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: setHeaderView");
    }

    public static /* synthetic */ void weakRecyclerView$annotations() {
    }

    public final void addChildClickViewIds(int... iArr) {
        o.f(iArr, "viewIds");
        for (int i2 : iArr) {
            this.childClickViewIds.add(Integer.valueOf(i2));
        }
    }

    public final void addChildLongClickViewIds(int... iArr) {
        o.f(iArr, "viewIds");
        for (int i2 : iArr) {
            this.childLongClickViewIds.add(Integer.valueOf(i2));
        }
    }

    public void addData(int i2, T t) {
        this.data.add(i2, t);
        notifyItemInserted(getHeaderLayoutCount() + i2);
        compatibilityDataSizeChanged(1);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapterModuleImp
    public BaseDraggableModule addDraggableModule(BaseQuickAdapter<?, ?> baseQuickAdapter) {
        o.f(baseQuickAdapter, "baseQuickAdapter");
        return BaseQuickAdapterModuleImp.DefaultImpls.addDraggableModule(this, baseQuickAdapter);
    }

    public final int addFooterView(View view) {
        return addFooterView$default(this, view, 0, 0, 6, null);
    }

    public final int addFooterView(View view, int i2) {
        return addFooterView$default(this, view, i2, 0, 4, null);
    }

    public final int addFooterView(View view, int i2, int i3) {
        int footerViewPosition;
        RecyclerView.l lVar;
        o.f(view, "view");
        if (this.mFooterLayout == null) {
            LinearLayout linearLayout = new LinearLayout(view.getContext());
            this.mFooterLayout = linearLayout;
            linearLayout.setOrientation(i3);
            LinearLayout linearLayout2 = this.mFooterLayout;
            if (linearLayout2 != null) {
                if (i3 == 1) {
                    lVar = new RecyclerView.l(-1, -2);
                } else {
                    lVar = new RecyclerView.l(-2, -1);
                }
                linearLayout2.setLayoutParams(lVar);
            } else {
                o.m("mFooterLayout");
                throw null;
            }
        }
        LinearLayout linearLayout3 = this.mFooterLayout;
        if (linearLayout3 != null) {
            int childCount = linearLayout3.getChildCount();
            if (i2 < 0 || i2 > childCount) {
                i2 = childCount;
            }
            LinearLayout linearLayout4 = this.mFooterLayout;
            if (linearLayout4 != null) {
                linearLayout4.addView(view, i2);
                LinearLayout linearLayout5 = this.mFooterLayout;
                if (linearLayout5 != null) {
                    if (linearLayout5.getChildCount() == 1 && (footerViewPosition = getFooterViewPosition()) != -1) {
                        notifyItemInserted(footerViewPosition);
                    }
                    return i2;
                }
                o.m("mFooterLayout");
                throw null;
            }
            o.m("mFooterLayout");
            throw null;
        }
        o.m("mFooterLayout");
        throw null;
    }

    public final int addHeaderView(View view) {
        return addHeaderView$default(this, view, 0, 0, 6, null);
    }

    public final int addHeaderView(View view, int i2) {
        return addHeaderView$default(this, view, i2, 0, 4, null);
    }

    public final int addHeaderView(View view, int i2, int i3) {
        int headerViewPosition;
        RecyclerView.l lVar;
        o.f(view, "view");
        if (this.mHeaderLayout == null) {
            LinearLayout linearLayout = new LinearLayout(view.getContext());
            this.mHeaderLayout = linearLayout;
            linearLayout.setOrientation(i3);
            LinearLayout linearLayout2 = this.mHeaderLayout;
            if (linearLayout2 != null) {
                if (i3 == 1) {
                    lVar = new RecyclerView.l(-1, -2);
                } else {
                    lVar = new RecyclerView.l(-2, -1);
                }
                linearLayout2.setLayoutParams(lVar);
            } else {
                o.m("mHeaderLayout");
                throw null;
            }
        }
        LinearLayout linearLayout3 = this.mHeaderLayout;
        if (linearLayout3 != null) {
            int childCount = linearLayout3.getChildCount();
            if (i2 < 0 || i2 > childCount) {
                i2 = childCount;
            }
            LinearLayout linearLayout4 = this.mHeaderLayout;
            if (linearLayout4 != null) {
                linearLayout4.addView(view, i2);
                LinearLayout linearLayout5 = this.mHeaderLayout;
                if (linearLayout5 != null) {
                    if (linearLayout5.getChildCount() == 1 && (headerViewPosition = getHeaderViewPosition()) != -1) {
                        notifyItemInserted(headerViewPosition);
                    }
                    return i2;
                }
                o.m("mHeaderLayout");
                throw null;
            }
            o.m("mHeaderLayout");
            throw null;
        }
        o.m("mHeaderLayout");
        throw null;
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapterModuleImp
    public BaseLoadMoreModule addLoadMoreModule(BaseQuickAdapter<?, ?> baseQuickAdapter) {
        o.f(baseQuickAdapter, "baseQuickAdapter");
        return BaseQuickAdapterModuleImp.DefaultImpls.addLoadMoreModule(this, baseQuickAdapter);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapterModuleImp
    public BaseUpFetchModule addUpFetchModule(BaseQuickAdapter<?, ?> baseQuickAdapter) {
        o.f(baseQuickAdapter, "baseQuickAdapter");
        return BaseQuickAdapterModuleImp.DefaultImpls.addUpFetchModule(this, baseQuickAdapter);
    }

    public void bindViewClickListener(VH vh, int i2) {
        o.f(vh, "viewHolder");
        if (this.mOnItemClickListener != null) {
            vh.itemView.setOnClickListener(new BaseQuickAdapter$bindViewClickListener$$inlined$let$lambda$1(this, vh));
        }
        if (this.mOnItemLongClickListener != null) {
            vh.itemView.setOnLongClickListener(new BaseQuickAdapter$bindViewClickListener$$inlined$let$lambda$2(this, vh));
        }
        if (this.mOnItemChildClickListener != null) {
            Iterator<Integer> it = getChildClickViewIds().iterator();
            while (it.hasNext()) {
                Integer next = it.next();
                View view = vh.itemView;
                o.b(next, "id");
                View findViewById = view.findViewById(next.intValue());
                if (findViewById != null) {
                    if (!findViewById.isClickable()) {
                        findViewById.setClickable(true);
                    }
                    findViewById.setOnClickListener(new BaseQuickAdapter$bindViewClickListener$$inlined$let$lambda$3(this, vh));
                }
            }
        }
        if (this.mOnItemChildLongClickListener != null) {
            Iterator<Integer> it2 = getChildLongClickViewIds().iterator();
            while (it2.hasNext()) {
                Integer next2 = it2.next();
                View view2 = vh.itemView;
                o.b(next2, "id");
                View findViewById2 = view2.findViewById(next2.intValue());
                if (findViewById2 != null) {
                    if (!findViewById2.isLongClickable()) {
                        findViewById2.setLongClickable(true);
                    }
                    findViewById2.setOnLongClickListener(new BaseQuickAdapter$bindViewClickListener$$inlined$let$lambda$4(this, vh));
                }
            }
        }
    }

    public final void compatibilityDataSizeChanged(int i2) {
        if (this.data.size() == i2) {
            notifyDataSetChanged();
        }
    }

    public abstract void convert(VH vh, T t);

    public void convert(VH vh, T t, List<? extends Object> list) {
        o.f(vh, "holder");
        o.f(list, "payloads");
    }

    public VH createBaseViewHolder(ViewGroup viewGroup, int i2) {
        o.f(viewGroup, "parent");
        return createBaseViewHolder(AdapterUtilsKt.getItemView(viewGroup, i2));
    }

    public final BaseAnimation getAdapterAnimation() {
        return this.adapterAnimation;
    }

    public final boolean getAnimationEnable() {
        return this.animationEnable;
    }

    public final LinkedHashSet<Integer> getChildClickViewIds() {
        return this.childClickViewIds;
    }

    public final LinkedHashSet<Integer> getChildLongClickViewIds() {
        return this.childLongClickViewIds;
    }

    public final Context getContext() {
        Context context2 = this.context;
        if (context2 != null) {
            return context2;
        }
        o.m("context");
        throw null;
    }

    public final List<T> getData() {
        return this.data;
    }

    public int getDefItemCount() {
        return this.data.size();
    }

    public int getDefItemViewType(int i2) {
        return super.getItemViewType(i2);
    }

    public final BrvahAsyncDiffer<T> getDiffHelper() {
        return getDiffer();
    }

    public final BrvahAsyncDiffer<T> getDiffer() {
        BrvahAsyncDiffer<T> brvahAsyncDiffer = this.mDiffHelper;
        if (brvahAsyncDiffer == null) {
            throw new IllegalStateException("Please use setDiffCallback() or setDiffConfig() first!".toString());
        } else if (brvahAsyncDiffer != null) {
            return brvahAsyncDiffer;
        } else {
            o.l();
            throw null;
        }
    }

    public final BaseDraggableModule getDraggableModule() {
        BaseDraggableModule baseDraggableModule = this.mDraggableModule;
        if (baseDraggableModule == null) {
            throw new IllegalStateException("Please first implements DraggableModule".toString());
        } else if (baseDraggableModule != null) {
            return baseDraggableModule;
        } else {
            o.l();
            throw null;
        }
    }

    public final FrameLayout getEmptyLayout() {
        FrameLayout frameLayout = this.mEmptyLayout;
        if (frameLayout == null) {
            return null;
        }
        if (frameLayout != null) {
            return frameLayout;
        }
        o.m("mEmptyLayout");
        throw null;
    }

    public final LinearLayout getFooterLayout() {
        LinearLayout linearLayout = this.mFooterLayout;
        if (linearLayout == null) {
            return null;
        }
        if (linearLayout != null) {
            return linearLayout;
        }
        o.m("mFooterLayout");
        throw null;
    }

    public final int getFooterLayoutCount() {
        return hasFooterLayout() ? 1 : 0;
    }

    public final boolean getFooterViewAsFlow() {
        return this.footerViewAsFlow;
    }

    public final int getFooterViewPosition() {
        if (hasEmptyView()) {
            int i2 = 1;
            if (this.headerWithEmptyEnable && hasHeaderLayout()) {
                i2 = 2;
            }
            if (this.footerWithEmptyEnable) {
                return i2;
            }
            return -1;
        }
        return this.data.size() + getHeaderLayoutCount();
    }

    public final boolean getFooterWithEmptyEnable() {
        return this.footerWithEmptyEnable;
    }

    public final LinearLayout getHeaderLayout() {
        LinearLayout linearLayout = this.mHeaderLayout;
        if (linearLayout == null) {
            return null;
        }
        if (linearLayout != null) {
            return linearLayout;
        }
        o.m("mHeaderLayout");
        throw null;
    }

    public final int getHeaderLayoutCount() {
        return hasHeaderLayout() ? 1 : 0;
    }

    public final boolean getHeaderViewAsFlow() {
        return this.headerViewAsFlow;
    }

    public final int getHeaderViewPosition() {
        if (!hasEmptyView() || this.headerWithEmptyEnable) {
            return 0;
        }
        return -1;
    }

    public final boolean getHeaderWithEmptyEnable() {
        return this.headerWithEmptyEnable;
    }

    public T getItem(int i2) {
        return this.data.get(i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        int i2 = 1;
        if (hasEmptyView()) {
            if (this.headerWithEmptyEnable && hasHeaderLayout()) {
                i2 = 2;
            }
            return (!this.footerWithEmptyEnable || !hasFooterLayout()) ? i2 : i2 + 1;
        }
        BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
        if (baseLoadMoreModule == null || !baseLoadMoreModule.hasLoadMoreView()) {
            i2 = 0;
        }
        return getFooterLayoutCount() + getDefItemCount() + getHeaderLayoutCount() + i2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public long getItemId(int i2) {
        return (long) i2;
    }

    public T getItemOrNull(int i2) {
        List<T> list = this.data;
        o.e(list, "$this$getOrNull");
        if (i2 < 0 || i2 > b.I(list)) {
            return null;
        }
        return list.get(i2);
    }

    public int getItemPosition(T t) {
        if (t == null || !(!this.data.isEmpty())) {
            return -1;
        }
        return this.data.indexOf(t);
    }

    /* JADX WARN: Type inference failed for: r0v4, types: [boolean] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int i2) {
        if (hasEmptyView()) {
            boolean z = this.headerWithEmptyEnable && hasHeaderLayout();
            if (i2 != 0) {
                if (i2 != 1) {
                }
                return FOOTER_VIEW;
            } else if (z) {
                return HEADER_VIEW;
            }
            return EMPTY_VIEW;
        }
        boolean hasHeaderLayout = hasHeaderLayout();
        if (hasHeaderLayout && i2 == 0) {
            return HEADER_VIEW;
        }
        if (hasHeaderLayout) {
            i2--;
        }
        int size = this.data.size();
        if (i2 < size) {
            return getDefItemViewType(i2);
        }
        if (i2 - size < hasFooterLayout()) {
            return FOOTER_VIEW;
        }
        return LOAD_MORE_VIEW;
    }

    public final BaseLoadMoreModule getLoadMoreModule() {
        BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
        if (baseLoadMoreModule == null) {
            throw new IllegalStateException("Please first implements LoadMoreModule".toString());
        } else if (baseLoadMoreModule != null) {
            return baseLoadMoreModule;
        } else {
            o.l();
            throw null;
        }
    }

    public final BaseLoadMoreModule getMLoadMoreModule$com_github_CymChad_brvah() {
        return this.mLoadMoreModule;
    }

    public final RecyclerView getMRecyclerView$com_github_CymChad_brvah() {
        return this.mRecyclerView;
    }

    public final OnItemChildClickListener getOnItemChildClickListener() {
        return this.mOnItemChildClickListener;
    }

    public final OnItemChildLongClickListener getOnItemChildLongClickListener() {
        return this.mOnItemChildLongClickListener;
    }

    public final OnItemClickListener getOnItemClickListener() {
        return this.mOnItemClickListener;
    }

    public final OnItemLongClickListener getOnItemLongClickListener() {
        return this.mOnItemLongClickListener;
    }

    public final RecyclerView getRecyclerView() {
        RecyclerView recyclerView = this.mRecyclerView;
        if (recyclerView == null) {
            throw new IllegalStateException("Please get it after onAttachedToRecyclerView()".toString());
        } else if (recyclerView != null) {
            return recyclerView;
        } else {
            o.l();
            throw null;
        }
    }

    public final BaseUpFetchModule getUpFetchModule() {
        BaseUpFetchModule baseUpFetchModule = this.mUpFetchModule;
        if (baseUpFetchModule == null) {
            throw new IllegalStateException("Please first implements UpFetchModule".toString());
        } else if (baseUpFetchModule != null) {
            return baseUpFetchModule;
        } else {
            o.l();
            throw null;
        }
    }

    public final View getViewByPosition(int i2, int i3) {
        BaseViewHolder baseViewHolder;
        RecyclerView recyclerView = this.mRecyclerView;
        if (recyclerView == null || (baseViewHolder = (BaseViewHolder) recyclerView.findViewHolderForLayoutPosition(i2)) == null) {
            return null;
        }
        return baseViewHolder.getViewOrNull(i3);
    }

    public final WeakReference<RecyclerView> getWeakRecyclerView() {
        WeakReference<RecyclerView> weakReference = this.weakRecyclerView;
        if (weakReference != null) {
            return weakReference;
        }
        o.m("weakRecyclerView");
        throw null;
    }

    public final boolean hasEmptyView() {
        FrameLayout frameLayout = this.mEmptyLayout;
        if (frameLayout != null) {
            if (frameLayout == null) {
                o.m("mEmptyLayout");
                throw null;
            } else if (frameLayout.getChildCount() != 0 && this.isUseEmpty) {
                return this.data.isEmpty();
            } else {
                return false;
            }
        }
        return false;
    }

    public final boolean hasFooterLayout() {
        LinearLayout linearLayout = this.mFooterLayout;
        if (linearLayout == null) {
            return false;
        }
        if (linearLayout != null) {
            return linearLayout.getChildCount() > 0;
        }
        o.m("mFooterLayout");
        throw null;
    }

    public final boolean hasHeaderLayout() {
        LinearLayout linearLayout = this.mHeaderLayout;
        if (linearLayout == null) {
            return false;
        }
        if (linearLayout != null) {
            return linearLayout.getChildCount() > 0;
        }
        o.m("mHeaderLayout");
        throw null;
    }

    public final boolean isAnimationFirstOnly() {
        return this.isAnimationFirstOnly;
    }

    public boolean isFixedViewType(int i2) {
        return i2 == 268436821 || i2 == 268435729 || i2 == 268436275 || i2 == 268436002;
    }

    public final boolean isUseEmpty() {
        return this.isUseEmpty;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        o.f(recyclerView, "recyclerView");
        super.onAttachedToRecyclerView(recyclerView);
        this.weakRecyclerView = new WeakReference<>(recyclerView);
        this.mRecyclerView = recyclerView;
        Context context2 = recyclerView.getContext();
        o.b(context2, "recyclerView.context");
        this.context = context2;
        BaseDraggableModule baseDraggableModule = this.mDraggableModule;
        if (baseDraggableModule != null) {
            baseDraggableModule.attachToRecyclerView(recyclerView);
        }
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        if (layoutManager instanceof GridLayoutManager) {
            GridLayoutManager gridLayoutManager = (GridLayoutManager) layoutManager;
            gridLayoutManager.setSpanSizeLookup(new BaseQuickAdapter$onAttachedToRecyclerView$1(this, layoutManager, gridLayoutManager.getSpanSizeLookup()));
        }
    }

    public VH onCreateDefViewHolder(ViewGroup viewGroup, int i2) {
        o.f(viewGroup, "parent");
        return createBaseViewHolder(viewGroup, this.layoutResId);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onDetachedFromRecyclerView(RecyclerView recyclerView) {
        o.f(recyclerView, "recyclerView");
        super.onDetachedFromRecyclerView(recyclerView);
        this.mRecyclerView = null;
    }

    public void onItemViewHolderCreated(VH vh, int i2) {
        o.f(vh, "viewHolder");
    }

    public void remove(int i2) {
        removeAt(i2);
    }

    public final void removeAllFooterView() {
        if (hasFooterLayout()) {
            LinearLayout linearLayout = this.mFooterLayout;
            if (linearLayout != null) {
                linearLayout.removeAllViews();
                int footerViewPosition = getFooterViewPosition();
                if (footerViewPosition != -1) {
                    notifyItemRemoved(footerViewPosition);
                    return;
                }
                return;
            }
            o.m("mFooterLayout");
            throw null;
        }
    }

    public final void removeAllHeaderView() {
        if (hasHeaderLayout()) {
            LinearLayout linearLayout = this.mHeaderLayout;
            if (linearLayout != null) {
                linearLayout.removeAllViews();
                int headerViewPosition = getHeaderViewPosition();
                if (headerViewPosition != -1) {
                    notifyItemRemoved(headerViewPosition);
                    return;
                }
                return;
            }
            o.m("mHeaderLayout");
            throw null;
        }
    }

    public void removeAt(int i2) {
        if (i2 < this.data.size()) {
            this.data.remove(i2);
            int headerLayoutCount = getHeaderLayoutCount() + i2;
            notifyItemRemoved(headerLayoutCount);
            compatibilityDataSizeChanged(0);
            notifyItemRangeChanged(headerLayoutCount, this.data.size() - headerLayoutCount);
        }
    }

    public final void removeEmptyView() {
        FrameLayout frameLayout = this.mEmptyLayout;
        if (frameLayout == null) {
            return;
        }
        if (frameLayout != null) {
            frameLayout.removeAllViews();
        } else {
            o.m("mEmptyLayout");
            throw null;
        }
    }

    public final void removeFooterView(View view) {
        int footerViewPosition;
        o.f(view, "footer");
        if (hasFooterLayout()) {
            LinearLayout linearLayout = this.mFooterLayout;
            if (linearLayout != null) {
                linearLayout.removeView(view);
                LinearLayout linearLayout2 = this.mFooterLayout;
                if (linearLayout2 == null) {
                    o.m("mFooterLayout");
                    throw null;
                } else if (linearLayout2.getChildCount() == 0 && (footerViewPosition = getFooterViewPosition()) != -1) {
                    notifyItemRemoved(footerViewPosition);
                }
            } else {
                o.m("mFooterLayout");
                throw null;
            }
        }
    }

    public final void removeHeaderView(View view) {
        int headerViewPosition;
        o.f(view, "header");
        if (hasHeaderLayout()) {
            LinearLayout linearLayout = this.mHeaderLayout;
            if (linearLayout != null) {
                linearLayout.removeView(view);
                LinearLayout linearLayout2 = this.mHeaderLayout;
                if (linearLayout2 == null) {
                    o.m("mHeaderLayout");
                    throw null;
                } else if (linearLayout2.getChildCount() == 0 && (headerViewPosition = getHeaderViewPosition()) != -1) {
                    notifyItemRemoved(headerViewPosition);
                }
            } else {
                o.m("mHeaderLayout");
                throw null;
            }
        }
    }

    public void replaceData(Collection<? extends T> collection) {
        o.f(collection, "newData");
        setList(collection);
    }

    public final void setAdapterAnimation(BaseAnimation baseAnimation) {
        this.animationEnable = true;
        this.adapterAnimation = baseAnimation;
    }

    public final void setAnimationEnable(boolean z) {
        this.animationEnable = z;
    }

    public final void setAnimationFirstOnly(boolean z) {
        this.isAnimationFirstOnly = z;
    }

    public final void setAnimationWithDefault(AnimationType animationType) {
        BaseAnimation baseAnimation;
        o.f(animationType, "animationType");
        int ordinal = animationType.ordinal();
        if (ordinal == 0) {
            baseAnimation = new AlphaInAnimation(0.0f, 1, null);
        } else if (ordinal == 1) {
            baseAnimation = new ScaleInAnimation(0.0f, 1, null);
        } else if (ordinal == 2) {
            baseAnimation = new SlideInBottomAnimation();
        } else if (ordinal == 3) {
            baseAnimation = new SlideInLeftAnimation();
        } else if (ordinal == 4) {
            baseAnimation = new SlideInRightAnimation();
        } else {
            throw new NoWhenBranchMatchedException();
        }
        setAdapterAnimation(baseAnimation);
    }

    public void setData(int i2, T t) {
        if (i2 < this.data.size()) {
            this.data.set(i2, t);
            notifyItemChanged(getHeaderLayoutCount() + i2);
        }
    }

    public final void setData$com_github_CymChad_brvah(List<T> list) {
        o.f(list, "<set-?>");
        this.data = list;
    }

    public final void setDiffCallback(f.e<T> eVar) {
        o.f(eVar, "diffCallback");
        setDiffConfig(new BrvahAsyncDifferConfig.Builder(eVar).build());
    }

    public final void setDiffConfig(BrvahAsyncDifferConfig<T> brvahAsyncDifferConfig) {
        o.f(brvahAsyncDifferConfig, "config");
        this.mDiffHelper = new BrvahAsyncDiffer<>(this, brvahAsyncDifferConfig);
    }

    public void setDiffNewData(List<T> list) {
        if (hasEmptyView()) {
            setNewInstance(list);
            return;
        }
        BrvahAsyncDiffer<T> brvahAsyncDiffer = this.mDiffHelper;
        if (brvahAsyncDiffer != null) {
            BrvahAsyncDiffer.submitList$default(brvahAsyncDiffer, list, null, 2, null);
        }
    }

    public final void setEmptyView(View view) {
        boolean z;
        ViewGroup.LayoutParams layoutParams;
        o.f(view, "emptyView");
        int itemCount = getItemCount();
        int i2 = 0;
        if (this.mEmptyLayout == null) {
            FrameLayout frameLayout = new FrameLayout(view.getContext());
            this.mEmptyLayout = frameLayout;
            if (frameLayout != null) {
                ViewGroup.LayoutParams layoutParams2 = view.getLayoutParams();
                if (layoutParams2 != null) {
                    layoutParams = new ViewGroup.LayoutParams(layoutParams2.width, layoutParams2.height);
                } else {
                    layoutParams = new ViewGroup.LayoutParams(-1, -1);
                }
                frameLayout.setLayoutParams(layoutParams);
                z = true;
            } else {
                o.m("mEmptyLayout");
                throw null;
            }
        } else {
            ViewGroup.LayoutParams layoutParams3 = view.getLayoutParams();
            if (layoutParams3 != null) {
                FrameLayout frameLayout2 = this.mEmptyLayout;
                if (frameLayout2 != null) {
                    ViewGroup.LayoutParams layoutParams4 = frameLayout2.getLayoutParams();
                    layoutParams4.width = layoutParams3.width;
                    layoutParams4.height = layoutParams3.height;
                    FrameLayout frameLayout3 = this.mEmptyLayout;
                    if (frameLayout3 != null) {
                        frameLayout3.setLayoutParams(layoutParams4);
                    } else {
                        o.m("mEmptyLayout");
                        throw null;
                    }
                } else {
                    o.m("mEmptyLayout");
                    throw null;
                }
            }
            z = false;
        }
        FrameLayout frameLayout4 = this.mEmptyLayout;
        if (frameLayout4 != null) {
            frameLayout4.removeAllViews();
            FrameLayout frameLayout5 = this.mEmptyLayout;
            if (frameLayout5 != null) {
                frameLayout5.addView(view);
                this.isUseEmpty = true;
                if (z && hasEmptyView()) {
                    if (this.headerWithEmptyEnable && hasHeaderLayout()) {
                        i2 = 1;
                    }
                    if (getItemCount() > itemCount) {
                        notifyItemInserted(i2);
                    } else {
                        notifyDataSetChanged();
                    }
                }
            } else {
                o.m("mEmptyLayout");
                throw null;
            }
        } else {
            o.m("mEmptyLayout");
            throw null;
        }
    }

    public final int setFooterView(View view) {
        return setFooterView$default(this, view, 0, 0, 6, null);
    }

    public final int setFooterView(View view, int i2) {
        return setFooterView$default(this, view, i2, 0, 4, null);
    }

    public final int setFooterView(View view, int i2, int i3) {
        o.f(view, "view");
        LinearLayout linearLayout = this.mFooterLayout;
        if (linearLayout != null) {
            if (linearLayout == null) {
                o.m("mFooterLayout");
                throw null;
            } else if (linearLayout.getChildCount() > i2) {
                LinearLayout linearLayout2 = this.mFooterLayout;
                if (linearLayout2 != null) {
                    linearLayout2.removeViewAt(i2);
                    LinearLayout linearLayout3 = this.mFooterLayout;
                    if (linearLayout3 != null) {
                        linearLayout3.addView(view, i2);
                        return i2;
                    }
                    o.m("mFooterLayout");
                    throw null;
                }
                o.m("mFooterLayout");
                throw null;
            }
        }
        return addFooterView(view, i2, i3);
    }

    public final void setFooterViewAsFlow(boolean z) {
        this.footerViewAsFlow = z;
    }

    public final void setFooterWithEmptyEnable(boolean z) {
        this.footerWithEmptyEnable = z;
    }

    public void setFullSpan(RecyclerView.ViewHolder viewHolder) {
        o.f(viewHolder, "holder");
        View view = viewHolder.itemView;
        o.b(view, "holder.itemView");
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (layoutParams instanceof StaggeredGridLayoutManager.LayoutParams) {
            ((StaggeredGridLayoutManager.LayoutParams) layoutParams).f1923f = true;
        }
    }

    @Override // com.chad.library.adapter.base.listener.BaseListenerImp
    public void setGridSpanSizeLookup(GridSpanSizeLookup gridSpanSizeLookup) {
        this.mSpanSizeLookup = gridSpanSizeLookup;
    }

    public final int setHeaderView(View view) {
        return setHeaderView$default(this, view, 0, 0, 6, null);
    }

    public final int setHeaderView(View view, int i2) {
        return setHeaderView$default(this, view, i2, 0, 4, null);
    }

    public final int setHeaderView(View view, int i2, int i3) {
        o.f(view, "view");
        LinearLayout linearLayout = this.mHeaderLayout;
        if (linearLayout != null) {
            if (linearLayout == null) {
                o.m("mHeaderLayout");
                throw null;
            } else if (linearLayout.getChildCount() > i2) {
                LinearLayout linearLayout2 = this.mHeaderLayout;
                if (linearLayout2 != null) {
                    linearLayout2.removeViewAt(i2);
                    LinearLayout linearLayout3 = this.mHeaderLayout;
                    if (linearLayout3 != null) {
                        linearLayout3.addView(view, i2);
                        return i2;
                    }
                    o.m("mHeaderLayout");
                    throw null;
                }
                o.m("mHeaderLayout");
                throw null;
            }
        }
        return addHeaderView(view, i2, i3);
    }

    public final void setHeaderViewAsFlow(boolean z) {
        this.headerViewAsFlow = z;
    }

    public final void setHeaderWithEmptyEnable(boolean z) {
        this.headerWithEmptyEnable = z;
    }

    public void setList(Collection<? extends T> collection) {
        List<T> list = this.data;
        boolean z = false;
        if (collection != list) {
            list.clear();
            if (collection == null || collection.isEmpty()) {
                z = true;
            }
            if (!z) {
                this.data.addAll(collection);
            }
        } else {
            if (collection == null || collection.isEmpty()) {
                z = true;
            }
            if (!z) {
                ArrayList arrayList = new ArrayList(collection);
                this.data.clear();
                this.data.addAll(arrayList);
            } else {
                this.data.clear();
            }
        }
        BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
        if (baseLoadMoreModule != null) {
            baseLoadMoreModule.reset$com_github_CymChad_brvah();
        }
        this.mLastPosition = -1;
        notifyDataSetChanged();
        BaseLoadMoreModule baseLoadMoreModule2 = this.mLoadMoreModule;
        if (baseLoadMoreModule2 != null) {
            baseLoadMoreModule2.checkDisableLoadMoreIfNotFullPage();
        }
    }

    public final void setMLoadMoreModule$com_github_CymChad_brvah(BaseLoadMoreModule baseLoadMoreModule) {
        this.mLoadMoreModule = baseLoadMoreModule;
    }

    public final void setMRecyclerView$com_github_CymChad_brvah(RecyclerView recyclerView) {
        this.mRecyclerView = recyclerView;
    }

    public void setNewData(List<T> list) {
        setNewInstance(list);
    }

    public void setNewInstance(List<T> list) {
        if (list != this.data) {
            if (list == null) {
                list = new ArrayList<>();
            }
            this.data = list;
            BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
            if (baseLoadMoreModule != null) {
                baseLoadMoreModule.reset$com_github_CymChad_brvah();
            }
            this.mLastPosition = -1;
            notifyDataSetChanged();
            BaseLoadMoreModule baseLoadMoreModule2 = this.mLoadMoreModule;
            if (baseLoadMoreModule2 != null) {
                baseLoadMoreModule2.checkDisableLoadMoreIfNotFullPage();
            }
        }
    }

    public void setOnItemChildClick(View view, int i2) {
        o.f(view, "v");
        OnItemChildClickListener onItemChildClickListener = this.mOnItemChildClickListener;
        if (onItemChildClickListener != null) {
            onItemChildClickListener.onItemChildClick(this, view, i2);
        }
    }

    @Override // com.chad.library.adapter.base.listener.BaseListenerImp
    public void setOnItemChildClickListener(OnItemChildClickListener onItemChildClickListener) {
        this.mOnItemChildClickListener = onItemChildClickListener;
    }

    public boolean setOnItemChildLongClick(View view, int i2) {
        o.f(view, "v");
        OnItemChildLongClickListener onItemChildLongClickListener = this.mOnItemChildLongClickListener;
        if (onItemChildLongClickListener != null) {
            return onItemChildLongClickListener.onItemChildLongClick(this, view, i2);
        }
        return false;
    }

    @Override // com.chad.library.adapter.base.listener.BaseListenerImp
    public void setOnItemChildLongClickListener(OnItemChildLongClickListener onItemChildLongClickListener) {
        this.mOnItemChildLongClickListener = onItemChildLongClickListener;
    }

    public void setOnItemClick(View view, int i2) {
        o.f(view, "v");
        OnItemClickListener onItemClickListener = this.mOnItemClickListener;
        if (onItemClickListener != null) {
            onItemClickListener.onItemClick(this, view, i2);
        }
    }

    @Override // com.chad.library.adapter.base.listener.BaseListenerImp
    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.mOnItemClickListener = onItemClickListener;
    }

    public boolean setOnItemLongClick(View view, int i2) {
        o.f(view, "v");
        OnItemLongClickListener onItemLongClickListener = this.mOnItemLongClickListener;
        if (onItemLongClickListener != null) {
            return onItemLongClickListener.onItemLongClick(this, view, i2);
        }
        return false;
    }

    @Override // com.chad.library.adapter.base.listener.BaseListenerImp
    public void setOnItemLongClickListener(OnItemLongClickListener onItemLongClickListener) {
        this.mOnItemLongClickListener = onItemLongClickListener;
    }

    public final void setRecyclerView(RecyclerView recyclerView) {
        o.f(recyclerView, "value");
        this.mRecyclerView = recyclerView;
    }

    public final void setUseEmpty(boolean z) {
        this.isUseEmpty = z;
    }

    public final void setWeakRecyclerView(WeakReference<RecyclerView> weakReference) {
        o.f(weakReference, "<set-?>");
        this.weakRecyclerView = weakReference;
    }

    public void startAnim(Animator animator, int i2) {
        o.f(animator, "anim");
        animator.start();
    }

    public BaseQuickAdapter(int i2, List<T> list) {
        this.layoutResId = i2;
        this.data = list == null ? new ArrayList<>() : list;
        this.isUseEmpty = true;
        this.isAnimationFirstOnly = true;
        this.mLastPosition = -1;
        checkModule();
        this.childClickViewIds = new LinkedHashSet<>();
        this.childLongClickViewIds = new LinkedHashSet<>();
    }

    public VH createBaseViewHolder(View view) {
        o.f(view, "view");
        Class<?> cls = getClass();
        Class<?> cls2 = null;
        while (cls2 == null && cls != null) {
            cls2 = getInstancedGenericKClass(cls);
            cls = cls.getSuperclass();
        }
        VH createBaseGenericKInstance = cls2 == null ? (VH) new BaseViewHolder(view) : createBaseGenericKInstance(cls2, view);
        return createBaseGenericKInstance != null ? createBaseGenericKInstance : (VH) new BaseViewHolder(view);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: com.chad.library.adapter.base.BaseQuickAdapter<T, VH extends com.chad.library.adapter.base.viewholder.BaseViewHolder> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public /* bridge */ /* synthetic */ void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i2, List list) {
        onBindViewHolder((BaseViewHolder) viewHolder, i2, (List<Object>) list);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public VH onCreateViewHolder(ViewGroup viewGroup, int i2) {
        o.f(viewGroup, "parent");
        switch (i2) {
            case HEADER_VIEW /*{ENCODED_INT: 268435729}*/:
                LinearLayout linearLayout = this.mHeaderLayout;
                if (linearLayout != null) {
                    ViewParent parent = linearLayout.getParent();
                    if (parent instanceof ViewGroup) {
                        ViewGroup viewGroup2 = (ViewGroup) parent;
                        LinearLayout linearLayout2 = this.mHeaderLayout;
                        if (linearLayout2 != null) {
                            viewGroup2.removeView(linearLayout2);
                        } else {
                            o.m("mHeaderLayout");
                            throw null;
                        }
                    }
                    LinearLayout linearLayout3 = this.mHeaderLayout;
                    if (linearLayout3 != null) {
                        return createBaseViewHolder(linearLayout3);
                    }
                    o.m("mHeaderLayout");
                    throw null;
                }
                o.m("mHeaderLayout");
                throw null;
            case LOAD_MORE_VIEW /*{ENCODED_INT: 268436002}*/:
                BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
                if (baseLoadMoreModule != null) {
                    VH createBaseViewHolder = createBaseViewHolder(baseLoadMoreModule.getLoadMoreView().getRootView(viewGroup));
                    BaseLoadMoreModule baseLoadMoreModule2 = this.mLoadMoreModule;
                    if (baseLoadMoreModule2 != null) {
                        baseLoadMoreModule2.setupViewHolder$com_github_CymChad_brvah(createBaseViewHolder);
                        return createBaseViewHolder;
                    }
                    o.l();
                    throw null;
                }
                o.l();
                throw null;
            case FOOTER_VIEW /*{ENCODED_INT: 268436275}*/:
                LinearLayout linearLayout4 = this.mFooterLayout;
                if (linearLayout4 != null) {
                    ViewParent parent2 = linearLayout4.getParent();
                    if (parent2 instanceof ViewGroup) {
                        ViewGroup viewGroup3 = (ViewGroup) parent2;
                        LinearLayout linearLayout5 = this.mFooterLayout;
                        if (linearLayout5 != null) {
                            viewGroup3.removeView(linearLayout5);
                        } else {
                            o.m("mFooterLayout");
                            throw null;
                        }
                    }
                    LinearLayout linearLayout6 = this.mFooterLayout;
                    if (linearLayout6 != null) {
                        return createBaseViewHolder(linearLayout6);
                    }
                    o.m("mFooterLayout");
                    throw null;
                }
                o.m("mFooterLayout");
                throw null;
            case EMPTY_VIEW /*{ENCODED_INT: 268436821}*/:
                FrameLayout frameLayout = this.mEmptyLayout;
                if (frameLayout != null) {
                    ViewParent parent3 = frameLayout.getParent();
                    if (parent3 instanceof ViewGroup) {
                        ViewGroup viewGroup4 = (ViewGroup) parent3;
                        FrameLayout frameLayout2 = this.mEmptyLayout;
                        if (frameLayout2 != null) {
                            viewGroup4.removeView(frameLayout2);
                        } else {
                            o.m("mEmptyLayout");
                            throw null;
                        }
                    }
                    FrameLayout frameLayout3 = this.mEmptyLayout;
                    if (frameLayout3 != null) {
                        return createBaseViewHolder(frameLayout3);
                    }
                    o.m("mEmptyLayout");
                    throw null;
                }
                o.m("mEmptyLayout");
                throw null;
            default:
                VH onCreateDefViewHolder = onCreateDefViewHolder(viewGroup, i2);
                bindViewClickListener(onCreateDefViewHolder, i2);
                BaseDraggableModule baseDraggableModule = this.mDraggableModule;
                if (baseDraggableModule != null) {
                    baseDraggableModule.initView$com_github_CymChad_brvah(onCreateDefViewHolder);
                }
                onItemViewHolderCreated(onCreateDefViewHolder, i2);
                return onCreateDefViewHolder;
        }
    }

    public void onViewAttachedToWindow(VH vh) {
        o.f(vh, "holder");
        super.onViewAttachedToWindow((RecyclerView.ViewHolder) vh);
        if (isFixedViewType(vh.getItemViewType())) {
            setFullSpan(vh);
        } else {
            addAnimation(vh);
        }
    }

    public void remove(T t) {
        int indexOf = this.data.indexOf(t);
        if (indexOf != -1) {
            removeAt(indexOf);
        }
    }

    public void onBindViewHolder(VH vh, int i2) {
        o.f(vh, "holder");
        BaseUpFetchModule baseUpFetchModule = this.mUpFetchModule;
        if (baseUpFetchModule != null) {
            baseUpFetchModule.autoUpFetch$com_github_CymChad_brvah(i2);
        }
        BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
        if (baseLoadMoreModule != null) {
            baseLoadMoreModule.autoLoadMore$com_github_CymChad_brvah(i2);
        }
        switch (vh.getItemViewType()) {
            case HEADER_VIEW /*{ENCODED_INT: 268435729}*/:
            case FOOTER_VIEW /*{ENCODED_INT: 268436275}*/:
            case EMPTY_VIEW /*{ENCODED_INT: 268436821}*/:
                return;
            case LOAD_MORE_VIEW /*{ENCODED_INT: 268436002}*/:
                BaseLoadMoreModule baseLoadMoreModule2 = this.mLoadMoreModule;
                if (baseLoadMoreModule2 != null) {
                    baseLoadMoreModule2.getLoadMoreView().convert(vh, i2, baseLoadMoreModule2.getLoadMoreStatus());
                    return;
                }
                return;
            default:
                convert(vh, getItem(i2 - getHeaderLayoutCount()));
                return;
        }
    }

    public void addData(T t) {
        this.data.add(t);
        notifyItemInserted(getHeaderLayoutCount() + this.data.size());
        compatibilityDataSizeChanged(1);
    }

    public void setDiffNewData(f.d dVar, List<T> list) {
        o.f(dVar, "diffResult");
        o.f(list, "list");
        if (hasEmptyView()) {
            setNewInstance(list);
            return;
        }
        dVar.a(new BrvahListUpdateCallback(this));
        this.data = list;
    }

    public void addData(int i2, Collection<? extends T> collection) {
        o.f(collection, "newData");
        this.data.addAll(i2, collection);
        notifyItemRangeInserted(getHeaderLayoutCount() + i2, collection.size());
        compatibilityDataSizeChanged(collection.size());
    }

    public void onBindViewHolder(VH vh, int i2, List<Object> list) {
        o.f(vh, "holder");
        o.f(list, "payloads");
        if (list.isEmpty()) {
            onBindViewHolder((BaseViewHolder) vh, i2);
            return;
        }
        BaseUpFetchModule baseUpFetchModule = this.mUpFetchModule;
        if (baseUpFetchModule != null) {
            baseUpFetchModule.autoUpFetch$com_github_CymChad_brvah(i2);
        }
        BaseLoadMoreModule baseLoadMoreModule = this.mLoadMoreModule;
        if (baseLoadMoreModule != null) {
            baseLoadMoreModule.autoLoadMore$com_github_CymChad_brvah(i2);
        }
        switch (vh.getItemViewType()) {
            case HEADER_VIEW /*{ENCODED_INT: 268435729}*/:
            case FOOTER_VIEW /*{ENCODED_INT: 268436275}*/:
            case EMPTY_VIEW /*{ENCODED_INT: 268436821}*/:
                return;
            case LOAD_MORE_VIEW /*{ENCODED_INT: 268436002}*/:
                BaseLoadMoreModule baseLoadMoreModule2 = this.mLoadMoreModule;
                if (baseLoadMoreModule2 != null) {
                    baseLoadMoreModule2.getLoadMoreView().convert(vh, i2, baseLoadMoreModule2.getLoadMoreStatus());
                    return;
                }
                return;
            default:
                convert(vh, getItem(i2 - getHeaderLayoutCount()), list);
                return;
        }
    }

    public void addData(Collection<? extends T> collection) {
        o.f(collection, "newData");
        this.data.addAll(collection);
        notifyItemRangeInserted(getHeaderLayoutCount() + (this.data.size() - collection.size()), collection.size());
        compatibilityDataSizeChanged(collection.size());
    }

    public final void setEmptyView(int i2) {
        RecyclerView recyclerView = this.mRecyclerView;
        if (recyclerView != null) {
            View inflate = LayoutInflater.from(recyclerView.getContext()).inflate(i2, (ViewGroup) recyclerView, false);
            o.b(inflate, "view");
            setEmptyView(inflate);
        }
    }
}
