package com.contrarywind.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.os.Handler;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import com.contrarywind.adapter.WheelAdapter;
import com.contrarywind.interfaces.IPickerViewData;
import com.contrarywind.listener.LoopViewGestureListener;
import com.contrarywind.listener.OnItemSelectedListener;
import com.contrarywind.timer.InertiaTimerTask;
import com.contrarywind.timer.MessageHandler;
import com.contrarywind.timer.SmoothScrollTimerTask;
import com.shuyu.gsyvideoplayer.utils.NeuQuant;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;

public class WheelView extends View {
    private static final float SCALE_CONTENT = 0.8f;
    private static final String[] TIME_NUM = {"00", "01", "02", "03", "04", "05", "06", "07", "08", "09"};
    private static final int VELOCITY_FLING = 5;
    private float CENTER_CONTENT_OFFSET;
    private WheelAdapter adapter;
    private float centerY;
    private Context context;
    private int dividerColor;
    private DividerType dividerType;
    private int dividerWidth;
    private int drawCenterContentStart;
    private int drawOutContentStart;
    private float firstLineY;
    private GestureDetector gestureDetector;
    private Handler handler;
    private int initPosition;
    private boolean isAlphaGradient;
    private boolean isCenterLabel;
    private boolean isLoop;
    private boolean isOptions;
    private float itemHeight;
    private int itemsVisible;
    private String label;
    private float lineSpacingMultiplier;
    private ScheduledExecutorService mExecutor;
    private ScheduledFuture<?> mFuture;
    private int mGravity;
    private int mOffset;
    private int maxTextHeight;
    private int maxTextWidth;
    private int measuredHeight;
    private int measuredWidth;
    private OnItemSelectedListener onItemSelectedListener;
    private Paint paintCenterText;
    private Paint paintIndicator;
    private Paint paintOuterText;
    private int preCurrentIndex;
    private float previousY;
    private int radius;
    private float secondLineY;
    private int selectedItem;
    private long startTime;
    private int textColorCenter;
    private int textColorOut;
    private int textSize;
    private int textXOffset;
    private float totalScrollY;
    private Typeface typeface;
    private int widthMeasureSpec;

    public enum ACTION {
        CLICK,
        FLING,
        DAGGLE
    }

    public enum DividerType {
        FILL,
        WRAP,
        CIRCLE
    }

    public WheelView(Context context2) {
        this(context2, null);
    }

    private String getContentText(Object obj) {
        if (obj == null) {
            return "";
        }
        if (obj instanceof IPickerViewData) {
            return ((IPickerViewData) obj).getPickerViewText();
        }
        if (obj instanceof Integer) {
            return getFixNum(((Integer) obj).intValue());
        }
        return obj.toString();
    }

    private String getFixNum(int i2) {
        return (i2 < 0 || i2 >= 10) ? String.valueOf(i2) : TIME_NUM[i2];
    }

    private int getLoopMappingIndex(int i2) {
        if (i2 < 0) {
            return getLoopMappingIndex(this.adapter.getItemsCount() + i2);
        }
        return i2 > this.adapter.getItemsCount() + -1 ? getLoopMappingIndex(i2 - this.adapter.getItemsCount()) : i2;
    }

    private void initLoopView(Context context2) {
        this.context = context2;
        this.handler = new MessageHandler(this);
        GestureDetector gestureDetector2 = new GestureDetector(context2, new LoopViewGestureListener(this));
        this.gestureDetector = gestureDetector2;
        gestureDetector2.setIsLongpressEnabled(false);
        this.isLoop = true;
        this.totalScrollY = 0.0f;
        this.initPosition = -1;
        initPaints();
    }

    private void initPaints() {
        Paint paint = new Paint();
        this.paintOuterText = paint;
        paint.setColor(this.textColorOut);
        this.paintOuterText.setAntiAlias(true);
        this.paintOuterText.setTypeface(this.typeface);
        this.paintOuterText.setTextSize((float) this.textSize);
        Paint paint2 = new Paint();
        this.paintCenterText = paint2;
        paint2.setColor(this.textColorCenter);
        this.paintCenterText.setAntiAlias(true);
        this.paintCenterText.setTextScaleX(1.1f);
        this.paintCenterText.setTypeface(this.typeface);
        this.paintCenterText.setTextSize((float) this.textSize);
        Paint paint3 = new Paint();
        this.paintIndicator = paint3;
        paint3.setColor(this.dividerColor);
        this.paintIndicator.setAntiAlias(true);
        setLayerType(1, null);
    }

    private void judgeLineSpace() {
        float f2 = this.lineSpacingMultiplier;
        if (f2 < 1.0f) {
            this.lineSpacingMultiplier = 1.0f;
        } else if (f2 > 4.0f) {
            this.lineSpacingMultiplier = 4.0f;
        }
    }

    private void measureTextWidthHeight() {
        Rect rect = new Rect();
        for (int i2 = 0; i2 < this.adapter.getItemsCount(); i2++) {
            String contentText = getContentText(this.adapter.getItem(i2));
            this.paintCenterText.getTextBounds(contentText, 0, contentText.length(), rect);
            int width = rect.width();
            if (width > this.maxTextWidth) {
                this.maxTextWidth = width;
            }
        }
        this.paintCenterText.getTextBounds("星期", 0, 2, rect);
        int height = rect.height() + 2;
        this.maxTextHeight = height;
        this.itemHeight = this.lineSpacingMultiplier * ((float) height);
    }

    private void measuredCenterContentStart(String str) {
        String str2;
        Rect rect = new Rect();
        this.paintCenterText.getTextBounds(str, 0, str.length(), rect);
        int i2 = this.mGravity;
        if (i2 == 3) {
            this.drawCenterContentStart = 0;
        } else if (i2 == 5) {
            this.drawCenterContentStart = (this.measuredWidth - rect.width()) - ((int) this.CENTER_CONTENT_OFFSET);
        } else if (i2 == 17) {
            if (this.isOptions || (str2 = this.label) == null || str2.equals("") || !this.isCenterLabel) {
                this.drawCenterContentStart = (int) (((double) (this.measuredWidth - rect.width())) * 0.5d);
            } else {
                this.drawCenterContentStart = (int) (((double) (this.measuredWidth - rect.width())) * 0.25d);
            }
        }
    }

    private void measuredOutContentStart(String str) {
        String str2;
        Rect rect = new Rect();
        this.paintOuterText.getTextBounds(str, 0, str.length(), rect);
        int i2 = this.mGravity;
        if (i2 == 3) {
            this.drawOutContentStart = 0;
        } else if (i2 == 5) {
            this.drawOutContentStart = (this.measuredWidth - rect.width()) - ((int) this.CENTER_CONTENT_OFFSET);
        } else if (i2 == 17) {
            if (this.isOptions || (str2 = this.label) == null || str2.equals("") || !this.isCenterLabel) {
                this.drawOutContentStart = (int) (((double) (this.measuredWidth - rect.width())) * 0.5d);
            } else {
                this.drawOutContentStart = (int) (((double) (this.measuredWidth - rect.width())) * 0.25d);
            }
        }
    }

    private void reMeasure() {
        if (this.adapter != null) {
            measureTextWidthHeight();
            int i2 = (int) (this.itemHeight * ((float) (this.itemsVisible - 1)));
            this.measuredHeight = (int) (((double) (i2 * 2)) / 3.141592653589793d);
            this.radius = (int) (((double) i2) / 3.141592653589793d);
            this.measuredWidth = View.MeasureSpec.getSize(this.widthMeasureSpec);
            int i3 = this.measuredHeight;
            float f2 = this.itemHeight;
            this.firstLineY = (((float) i3) - f2) / 2.0f;
            float f3 = (((float) i3) + f2) / 2.0f;
            this.secondLineY = f3;
            this.centerY = (f3 - ((f2 - ((float) this.maxTextHeight)) / 2.0f)) - this.CENTER_CONTENT_OFFSET;
            if (this.initPosition == -1) {
                if (this.isLoop) {
                    this.initPosition = (this.adapter.getItemsCount() + 1) / 2;
                } else {
                    this.initPosition = 0;
                }
            }
            this.preCurrentIndex = this.initPosition;
        }
    }

    private void reMeasureTextSize(String str) {
        Rect rect = new Rect();
        this.paintCenterText.getTextBounds(str, 0, str.length(), rect);
        int i2 = this.textSize;
        for (int width = rect.width(); width > this.measuredWidth; width = rect.width()) {
            i2--;
            this.paintCenterText.setTextSize((float) i2);
            this.paintCenterText.getTextBounds(str, 0, str.length(), rect);
        }
        this.paintOuterText.setTextSize((float) i2);
    }

    private void setOutPaintStyle(float f2, float f3) {
        int i2 = this.textXOffset;
        int i3 = -1;
        int i4 = i2 > 0 ? 1 : i2 < 0 ? -1 : 0;
        Paint paint = this.paintOuterText;
        if (f3 <= 0.0f) {
            i3 = 1;
        }
        paint.setTextSkewX(((float) (i4 * i3)) * 0.5f * f2);
        this.paintOuterText.setAlpha(this.isAlphaGradient ? (int) (((90.0f - Math.abs(f3)) / 90.0f) * 255.0f) : NeuQuant.maxnetpos);
    }

    public void cancelFuture() {
        ScheduledFuture<?> scheduledFuture = this.mFuture;
        if (scheduledFuture != null && !scheduledFuture.isCancelled()) {
            this.mFuture.cancel(true);
            this.mFuture = null;
        }
    }

    public final WheelAdapter getAdapter() {
        return this.adapter;
    }

    public final int getCurrentItem() {
        int i2;
        WheelAdapter wheelAdapter = this.adapter;
        if (wheelAdapter == null) {
            return 0;
        }
        if (!this.isLoop || ((i2 = this.selectedItem) >= 0 && i2 < wheelAdapter.getItemsCount())) {
            return Math.max(0, Math.min(this.selectedItem, this.adapter.getItemsCount() - 1));
        }
        return Math.max(0, Math.min(Math.abs(Math.abs(this.selectedItem) - this.adapter.getItemsCount()), this.adapter.getItemsCount() - 1));
    }

    public Handler getHandler() {
        return this.handler;
    }

    public int getInitPosition() {
        return this.initPosition;
    }

    public float getItemHeight() {
        return this.itemHeight;
    }

    public int getItemsCount() {
        WheelAdapter wheelAdapter = this.adapter;
        if (wheelAdapter != null) {
            return wheelAdapter.getItemsCount();
        }
        return 0;
    }

    public int getTextWidth(Paint paint, String str) {
        if (str == null || str.length() <= 0) {
            return 0;
        }
        int length = str.length();
        float[] fArr = new float[length];
        paint.getTextWidths(str, fArr);
        int i2 = 0;
        for (int i3 = 0; i3 < length; i3++) {
            i2 += (int) Math.ceil((double) fArr[i3]);
        }
        return i2;
    }

    public float getTotalScrollY() {
        return this.totalScrollY;
    }

    public void isCenterLabel(boolean z) {
        this.isCenterLabel = z;
    }

    public boolean isLoop() {
        return this.isLoop;
    }

    public void onDraw(Canvas canvas) {
        float f2;
        String str;
        float f3;
        int i2;
        if (this.adapter != null) {
            int min = Math.min(Math.max(0, this.initPosition), this.adapter.getItemsCount() - 1);
            this.initPosition = min;
            try {
                this.preCurrentIndex = min + (((int) (this.totalScrollY / this.itemHeight)) % this.adapter.getItemsCount());
            } catch (ArithmeticException unused) {
                Log.e("WheelView", "出错了！adapter.getItemsCount() == 0，联动数据不匹配");
            }
            if (!this.isLoop) {
                if (this.preCurrentIndex < 0) {
                    this.preCurrentIndex = 0;
                }
                if (this.preCurrentIndex > this.adapter.getItemsCount() - 1) {
                    this.preCurrentIndex = this.adapter.getItemsCount() - 1;
                }
            } else {
                if (this.preCurrentIndex < 0) {
                    this.preCurrentIndex = this.adapter.getItemsCount() + this.preCurrentIndex;
                }
                if (this.preCurrentIndex > this.adapter.getItemsCount() - 1) {
                    this.preCurrentIndex -= this.adapter.getItemsCount();
                }
            }
            float f4 = this.totalScrollY % this.itemHeight;
            DividerType dividerType2 = this.dividerType;
            float f5 = 10.0f;
            if (dividerType2 == DividerType.WRAP) {
                if (TextUtils.isEmpty(this.label)) {
                    i2 = (this.measuredWidth - this.maxTextWidth) / 2;
                } else {
                    i2 = (this.measuredWidth - this.maxTextWidth) / 4;
                }
                float f6 = (float) (i2 - 12);
                float f7 = f6 <= 0.0f ? 10.0f : f6;
                float f8 = ((float) this.measuredWidth) - f7;
                float f9 = this.firstLineY;
                canvas.drawLine(f7, f9, f8, f9, this.paintIndicator);
                float f10 = this.secondLineY;
                canvas.drawLine(f7, f10, f8, f10, this.paintIndicator);
            } else if (dividerType2 == DividerType.CIRCLE) {
                this.paintIndicator.setStyle(Paint.Style.STROKE);
                this.paintIndicator.setStrokeWidth((float) this.dividerWidth);
                if (TextUtils.isEmpty(this.label)) {
                    f3 = ((float) (this.measuredWidth - this.maxTextWidth)) / 2.0f;
                } else {
                    f3 = ((float) (this.measuredWidth - this.maxTextWidth)) / 4.0f;
                }
                float f11 = f3 - 12.0f;
                if (f11 > 0.0f) {
                    f5 = f11;
                }
                canvas.drawCircle(((float) this.measuredWidth) / 2.0f, ((float) this.measuredHeight) / 2.0f, Math.max((((float) this.measuredWidth) - f5) - f5, this.itemHeight) / 1.8f, this.paintIndicator);
            } else {
                float f12 = this.firstLineY;
                canvas.drawLine(0.0f, f12, (float) this.measuredWidth, f12, this.paintIndicator);
                float f13 = this.secondLineY;
                canvas.drawLine(0.0f, f13, (float) this.measuredWidth, f13, this.paintIndicator);
            }
            if (!TextUtils.isEmpty(this.label) && this.isCenterLabel) {
                canvas.drawText(this.label, ((float) (this.measuredWidth - getTextWidth(this.paintCenterText, this.label))) - this.CENTER_CONTENT_OFFSET, this.centerY, this.paintCenterText);
            }
            int i3 = 0;
            while (true) {
                int i4 = this.itemsVisible;
                if (i3 < i4) {
                    int i5 = this.preCurrentIndex - ((i4 / 2) - i3);
                    Object obj = "";
                    if (this.isLoop) {
                        obj = this.adapter.getItem(getLoopMappingIndex(i5));
                    } else if (i5 >= 0 && i5 <= this.adapter.getItemsCount() - 1) {
                        obj = this.adapter.getItem(i5);
                    }
                    canvas.save();
                    double d2 = (double) (((this.itemHeight * ((float) i3)) - f4) / ((float) this.radius));
                    float f14 = (float) (90.0d - ((d2 / 3.141592653589793d) * 180.0d));
                    if (f14 > 90.0f || f14 < -90.0f) {
                        f2 = f4;
                        canvas.restore();
                    } else {
                        if (this.isCenterLabel || TextUtils.isEmpty(this.label) || TextUtils.isEmpty(getContentText(obj))) {
                            str = getContentText(obj);
                        } else {
                            str = getContentText(obj) + this.label;
                        }
                        float pow = (float) Math.pow((double) (Math.abs(f14) / 90.0f), 2.2d);
                        reMeasureTextSize(str);
                        measuredCenterContentStart(str);
                        measuredOutContentStart(str);
                        f2 = f4;
                        float cos = (float) ((((double) this.radius) - (Math.cos(d2) * ((double) this.radius))) - ((Math.sin(d2) * ((double) this.maxTextHeight)) / 2.0d));
                        canvas.translate(0.0f, cos);
                        float f15 = this.firstLineY;
                        if (cos > f15 || ((float) this.maxTextHeight) + cos < f15) {
                            float f16 = this.secondLineY;
                            if (cos > f16 || ((float) this.maxTextHeight) + cos < f16) {
                                if (cos >= f15) {
                                    int i6 = this.maxTextHeight;
                                    if (((float) i6) + cos <= f16) {
                                        canvas.drawText(str, (float) this.drawCenterContentStart, ((float) i6) - this.CENTER_CONTENT_OFFSET, this.paintCenterText);
                                        this.selectedItem = this.preCurrentIndex - ((this.itemsVisible / 2) - i3);
                                    }
                                }
                                canvas.save();
                                canvas.clipRect(0, 0, this.measuredWidth, (int) this.itemHeight);
                                canvas.scale(1.0f, ((float) Math.sin(d2)) * SCALE_CONTENT);
                                setOutPaintStyle(pow, f14);
                                canvas.drawText(str, (((float) this.textXOffset) * pow) + ((float) this.drawOutContentStart), (float) this.maxTextHeight, this.paintOuterText);
                                canvas.restore();
                                canvas.restore();
                                this.paintCenterText.setTextSize((float) this.textSize);
                            } else {
                                canvas.save();
                                canvas.clipRect(0.0f, 0.0f, (float) this.measuredWidth, this.secondLineY - cos);
                                canvas.scale(1.0f, ((float) Math.sin(d2)) * 1.0f);
                                canvas.drawText(str, (float) this.drawCenterContentStart, ((float) this.maxTextHeight) - this.CENTER_CONTENT_OFFSET, this.paintCenterText);
                                canvas.restore();
                                canvas.save();
                                canvas.clipRect(0.0f, this.secondLineY - cos, (float) this.measuredWidth, (float) ((int) this.itemHeight));
                                canvas.scale(1.0f, ((float) Math.sin(d2)) * SCALE_CONTENT);
                                setOutPaintStyle(pow, f14);
                                canvas.drawText(str, (float) this.drawOutContentStart, (float) this.maxTextHeight, this.paintOuterText);
                                canvas.restore();
                            }
                        } else {
                            canvas.save();
                            canvas.clipRect(0.0f, 0.0f, (float) this.measuredWidth, this.firstLineY - cos);
                            canvas.scale(1.0f, ((float) Math.sin(d2)) * SCALE_CONTENT);
                            setOutPaintStyle(pow, f14);
                            canvas.drawText(str, (float) this.drawOutContentStart, (float) this.maxTextHeight, this.paintOuterText);
                            canvas.restore();
                            canvas.save();
                            canvas.clipRect(0.0f, this.firstLineY - cos, (float) this.measuredWidth, (float) ((int) this.itemHeight));
                            canvas.scale(1.0f, ((float) Math.sin(d2)) * 1.0f);
                            canvas.drawText(str, (float) this.drawCenterContentStart, ((float) this.maxTextHeight) - this.CENTER_CONTENT_OFFSET, this.paintCenterText);
                            canvas.restore();
                        }
                        canvas.restore();
                        this.paintCenterText.setTextSize((float) this.textSize);
                    }
                    i3++;
                    f4 = f2;
                } else {
                    return;
                }
            }
        }
    }

    public final void onItemSelected() {
        if (this.onItemSelectedListener != null) {
            postDelayed(new Runnable() {
                /* class com.contrarywind.view.WheelView.AnonymousClass1 */

                public void run() {
                    WheelView.this.onItemSelectedListener.onItemSelected(WheelView.this.getCurrentItem());
                }
            }, 200);
        }
    }

    public void onMeasure(int i2, int i3) {
        this.widthMeasureSpec = i2;
        reMeasure();
        setMeasuredDimension(this.measuredWidth, this.measuredHeight);
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        boolean onTouchEvent = this.gestureDetector.onTouchEvent(motionEvent);
        float f2 = ((float) (-this.initPosition)) * this.itemHeight;
        float itemsCount = ((float) ((this.adapter.getItemsCount() - 1) - this.initPosition)) * this.itemHeight;
        int action = motionEvent.getAction();
        boolean z = false;
        if (action == 0) {
            this.startTime = System.currentTimeMillis();
            cancelFuture();
            this.previousY = motionEvent.getRawY();
        } else if (action == 2) {
            float rawY = this.previousY - motionEvent.getRawY();
            this.previousY = motionEvent.getRawY();
            float f3 = this.totalScrollY + rawY;
            this.totalScrollY = f3;
            if (!this.isLoop) {
                float f4 = this.itemHeight;
                if ((f3 - (f4 * 0.25f) < f2 && rawY < 0.0f) || ((f4 * 0.25f) + f3 > itemsCount && rawY > 0.0f)) {
                    this.totalScrollY = f3 - rawY;
                    z = true;
                }
            }
        } else if (!onTouchEvent) {
            float y = motionEvent.getY();
            int i2 = this.radius;
            float f5 = this.itemHeight;
            this.mOffset = (int) ((((float) (((int) (((Math.acos((double) ((((float) i2) - y) / ((float) i2))) * ((double) this.radius)) + ((double) (f5 / 2.0f))) / ((double) f5))) - (this.itemsVisible / 2))) * f5) - (((this.totalScrollY % f5) + f5) % f5));
            if (System.currentTimeMillis() - this.startTime > 120) {
                smoothScroll(ACTION.DAGGLE);
            } else {
                smoothScroll(ACTION.CLICK);
            }
        }
        if (!z && motionEvent.getAction() != 0) {
            invalidate();
        }
        return true;
    }

    public final void scrollBy(float f2) {
        cancelFuture();
        this.mFuture = this.mExecutor.scheduleWithFixedDelay(new InertiaTimerTask(this, f2), 0, 5, TimeUnit.MILLISECONDS);
    }

    public final void setAdapter(WheelAdapter wheelAdapter) {
        this.adapter = wheelAdapter;
        reMeasure();
        invalidate();
    }

    public void setAlphaGradient(boolean z) {
        this.isAlphaGradient = z;
    }

    public final void setCurrentItem(int i2) {
        this.selectedItem = i2;
        this.initPosition = i2;
        this.totalScrollY = 0.0f;
        invalidate();
    }

    public final void setCyclic(boolean z) {
        this.isLoop = z;
    }

    public void setDividerColor(int i2) {
        this.dividerColor = i2;
        this.paintIndicator.setColor(i2);
    }

    public void setDividerType(DividerType dividerType2) {
        this.dividerType = dividerType2;
    }

    public void setDividerWidth(int i2) {
        this.dividerWidth = i2;
        this.paintIndicator.setStrokeWidth((float) i2);
    }

    public void setGravity(int i2) {
        this.mGravity = i2;
    }

    public void setIsOptions(boolean z) {
        this.isOptions = z;
    }

    public void setItemsVisibleCount(int i2) {
        if (i2 % 2 == 0) {
            i2++;
        }
        this.itemsVisible = i2 + 2;
    }

    public void setLabel(String str) {
        this.label = str;
    }

    public void setLineSpacingMultiplier(float f2) {
        if (f2 != 0.0f) {
            this.lineSpacingMultiplier = f2;
            judgeLineSpace();
        }
    }

    public final void setOnItemSelectedListener(OnItemSelectedListener onItemSelectedListener2) {
        this.onItemSelectedListener = onItemSelectedListener2;
    }

    public void setTextColorCenter(int i2) {
        this.textColorCenter = i2;
        this.paintCenterText.setColor(i2);
    }

    public void setTextColorOut(int i2) {
        this.textColorOut = i2;
        this.paintOuterText.setColor(i2);
    }

    public final void setTextSize(float f2) {
        if (f2 > 0.0f) {
            int i2 = (int) (this.context.getResources().getDisplayMetrics().density * f2);
            this.textSize = i2;
            this.paintOuterText.setTextSize((float) i2);
            this.paintCenterText.setTextSize((float) this.textSize);
        }
    }

    public void setTextXOffset(int i2) {
        this.textXOffset = i2;
        if (i2 != 0) {
            this.paintCenterText.setTextScaleX(1.0f);
        }
    }

    public void setTotalScrollY(float f2) {
        this.totalScrollY = f2;
    }

    public final void setTypeface(Typeface typeface2) {
        this.typeface = typeface2;
        this.paintOuterText.setTypeface(typeface2);
        this.paintCenterText.setTypeface(this.typeface);
    }

    public void smoothScroll(ACTION action) {
        cancelFuture();
        if (action == ACTION.FLING || action == ACTION.DAGGLE) {
            float f2 = this.totalScrollY;
            float f3 = this.itemHeight;
            int i2 = (int) (((f2 % f3) + f3) % f3);
            this.mOffset = i2;
            if (((float) i2) > f3 / 2.0f) {
                this.mOffset = (int) (f3 - ((float) i2));
            } else {
                this.mOffset = -i2;
            }
        }
        this.mFuture = this.mExecutor.scheduleWithFixedDelay(new SmoothScrollTimerTask(this, this.mOffset), 0, 10, TimeUnit.MILLISECONDS);
    }

    public WheelView(Context context2, AttributeSet attributeSet) {
        super(context2, attributeSet);
        this.isOptions = false;
        this.isCenterLabel = true;
        this.mExecutor = Executors.newSingleThreadScheduledExecutor();
        this.typeface = Typeface.MONOSPACE;
        this.lineSpacingMultiplier = 1.6f;
        this.itemsVisible = 11;
        this.mOffset = 0;
        this.previousY = 0.0f;
        this.startTime = 0;
        this.mGravity = 17;
        this.drawCenterContentStart = 0;
        this.drawOutContentStart = 0;
        this.isAlphaGradient = false;
        this.textSize = getResources().getDimensionPixelSize(R.dimen.pickerview_textsize);
        float f2 = getResources().getDisplayMetrics().density;
        if (f2 < 1.0f) {
            this.CENTER_CONTENT_OFFSET = 2.4f;
        } else if (1.0f <= f2 && f2 < 2.0f) {
            this.CENTER_CONTENT_OFFSET = 4.0f;
        } else if (2.0f <= f2 && f2 < 3.0f) {
            this.CENTER_CONTENT_OFFSET = 6.0f;
        } else if (f2 >= 3.0f) {
            this.CENTER_CONTENT_OFFSET = f2 * 2.5f;
        }
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context2.obtainStyledAttributes(attributeSet, R.styleable.pickerview, 0, 0);
            this.mGravity = obtainStyledAttributes.getInt(R.styleable.pickerview_wheelview_gravity, 17);
            this.textColorOut = obtainStyledAttributes.getColor(R.styleable.pickerview_wheelview_textColorOut, -5723992);
            this.textColorCenter = obtainStyledAttributes.getColor(R.styleable.pickerview_wheelview_textColorCenter, -14013910);
            this.dividerColor = obtainStyledAttributes.getColor(R.styleable.pickerview_wheelview_dividerColor, -2763307);
            this.dividerWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.pickerview_wheelview_dividerWidth, 2);
            this.textSize = obtainStyledAttributes.getDimensionPixelOffset(R.styleable.pickerview_wheelview_textSize, this.textSize);
            this.lineSpacingMultiplier = obtainStyledAttributes.getFloat(R.styleable.pickerview_wheelview_lineSpacingMultiplier, this.lineSpacingMultiplier);
            obtainStyledAttributes.recycle();
        }
        judgeLineSpace();
        initLoopView(context2);
    }
}
