package com.danikula.videocache.file;

import com.danikula.videocache.Cache;
import com.danikula.videocache.ProxyCacheException;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;

public class FileCache implements Cache {
    private static final String TEMP_POSTFIX = ".download";
    private RandomAccessFile dataFile;
    private final DiskUsage diskUsage;
    public File file;

    public FileCache(File file2) {
        this(file2, new UnlimitedDiskUsage());
    }

    private boolean isTempFile(File file2) {
        return file2.getName().endsWith(TEMP_POSTFIX);
    }

    @Override // com.danikula.videocache.Cache
    public synchronized void append(byte[] bArr, int i2) {
        try {
            if (!isCompleted()) {
                this.dataFile.seek(available());
                this.dataFile.write(bArr, 0, i2);
            } else {
                throw new ProxyCacheException("Error append cache: cache file " + this.file + " is completed!");
            }
        } catch (IOException e2) {
            throw new ProxyCacheException(String.format("Error writing %d bytes to %s from buffer with size %d", Integer.valueOf(i2), this.dataFile, Integer.valueOf(bArr.length)), e2);
        }
    }

    @Override // com.danikula.videocache.Cache
    public synchronized long available() {
        try {
        } catch (IOException e2) {
            throw new ProxyCacheException("Error reading length of file " + this.file, e2);
        }
        return (long) ((int) this.dataFile.length());
    }

    @Override // com.danikula.videocache.Cache
    public synchronized void close() {
        try {
            this.dataFile.close();
            this.diskUsage.touch(this.file);
        } catch (IOException e2) {
            throw new ProxyCacheException("Error closing file " + this.file, e2);
        }
    }

    @Override // com.danikula.videocache.Cache
    public synchronized void complete() {
        if (!isCompleted()) {
            close();
            File file2 = new File(this.file.getParentFile(), this.file.getName().substring(0, this.file.getName().length() - 9));
            if (this.file.renameTo(file2)) {
                this.file = file2;
                try {
                    this.dataFile = new RandomAccessFile(this.file, "r");
                    this.diskUsage.touch(this.file);
                } catch (IOException e2) {
                    throw new ProxyCacheException("Error opening " + this.file + " as disc cache", e2);
                }
            } else {
                throw new ProxyCacheException("Error renaming file " + this.file + " to " + file2 + " for completion!");
            }
        }
    }

    public File getFile() {
        return this.file;
    }

    @Override // com.danikula.videocache.Cache
    public synchronized boolean isCompleted() {
        return !isTempFile(this.file);
    }

    @Override // com.danikula.videocache.Cache
    public synchronized int read(byte[] bArr, long j2, int i2) {
        try {
            this.dataFile.seek(j2);
        } catch (IOException e2) {
            throw new ProxyCacheException(String.format("Error reading %d bytes with offset %d from file[%d bytes] to buffer[%d bytes]", Integer.valueOf(i2), Long.valueOf(j2), Long.valueOf(available()), Integer.valueOf(bArr.length)), e2);
        }
        return this.dataFile.read(bArr, 0, i2);
    }

    public FileCache(File file2, DiskUsage diskUsage2) {
        File file3;
        if (diskUsage2 != null) {
            try {
                this.diskUsage = diskUsage2;
                Files.makeDir(file2.getParentFile());
                boolean exists = file2.exists();
                if (exists) {
                    file3 = file2;
                } else {
                    File parentFile = file2.getParentFile();
                    file3 = new File(parentFile, file2.getName() + TEMP_POSTFIX);
                }
                this.file = file3;
                this.dataFile = new RandomAccessFile(this.file, exists ? "r" : "rw");
            } catch (IOException e2) {
                throw new ProxyCacheException("Error using file " + file2 + " as disc cache", e2);
            }
        } else {
            throw new NullPointerException();
        }
    }
}
