package com.google.android.exoplayer;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.os.Parcel;
import android.os.Parcelable;
import android.text.TextUtils;
import d.h.a.a.m0.r;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import tv.danmaku.ijk.media.player.IjkMediaMeta;
import tv.danmaku.ijk.media.player.misc.IMediaFormat;

public final class MediaFormat implements Parcelable {
    public static final Parcelable.Creator<MediaFormat> CREATOR = new a();
    public static final int NO_VALUE = -1;
    public static final long OFFSET_SAMPLE_RELATIVE = Long.MAX_VALUE;
    public final boolean adaptive;
    public final int bitrate;
    public final int channelCount;
    public final long durationUs;
    public final int encoderDelay;
    public final int encoderPadding;
    private android.media.MediaFormat frameworkMediaFormat;
    private int hashCode;
    public final int height;
    public final List<byte[]> initializationData;
    public final String language;
    public final int maxHeight;
    public final int maxInputSize;
    public final int maxWidth;
    public final String mimeType;
    public final int pcmEncoding;
    public final float pixelWidthHeightRatio;
    public final byte[] projectionData;
    public final int rotationDegrees;
    public final int sampleRate;
    public final int stereoMode;
    public final long subsampleOffsetUs;
    public final String trackId;
    public final int width;

    public static class a implements Parcelable.Creator<MediaFormat> {
        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // android.os.Parcelable.Creator
        public MediaFormat createFromParcel(Parcel parcel) {
            return new MediaFormat(parcel);
        }

        /* Return type fixed from 'java.lang.Object[]' to match base method */
        @Override // android.os.Parcelable.Creator
        public MediaFormat[] newArray(int i2) {
            return new MediaFormat[i2];
        }
    }

    public MediaFormat(Parcel parcel) {
        this.trackId = parcel.readString();
        this.mimeType = parcel.readString();
        this.bitrate = parcel.readInt();
        this.maxInputSize = parcel.readInt();
        this.durationUs = parcel.readLong();
        this.width = parcel.readInt();
        this.height = parcel.readInt();
        this.rotationDegrees = parcel.readInt();
        this.pixelWidthHeightRatio = parcel.readFloat();
        this.channelCount = parcel.readInt();
        this.sampleRate = parcel.readInt();
        this.language = parcel.readString();
        this.subsampleOffsetUs = parcel.readLong();
        ArrayList arrayList = new ArrayList();
        this.initializationData = arrayList;
        byte[] bArr = null;
        parcel.readList(arrayList, null);
        boolean z = false;
        this.adaptive = parcel.readInt() == 1;
        this.maxWidth = parcel.readInt();
        this.maxHeight = parcel.readInt();
        this.pcmEncoding = parcel.readInt();
        this.encoderDelay = parcel.readInt();
        this.encoderPadding = parcel.readInt();
        this.projectionData = parcel.readInt() != 0 ? true : z ? parcel.createByteArray() : bArr;
        this.stereoMode = parcel.readInt();
    }

    public static MediaFormat createAudioFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, List<byte[]> list, String str3) {
        return createAudioFormat(str, str2, i2, i3, j2, i4, i5, list, str3, -1);
    }

    public static MediaFormat createFormatForMimeType(String str, String str2, int i2, long j2) {
        return new MediaFormat(str, str2, i2, -1, j2, -1, -1, -1, -1.0f, -1, -1, null, Long.MAX_VALUE, null, false, -1, -1, -1, -1, -1, null, -1);
    }

    public static MediaFormat createId3Format() {
        return createFormatForMimeType(null, "application/id3", -1, -1);
    }

    public static MediaFormat createImageFormat(String str, String str2, int i2, long j2, List<byte[]> list, String str3) {
        return new MediaFormat(str, str2, i2, -1, j2, -1, -1, -1, -1.0f, -1, -1, str3, Long.MAX_VALUE, list, false, -1, -1, -1, -1, -1, null, -1);
    }

    public static MediaFormat createTextFormat(String str, String str2, int i2, long j2, String str3) {
        return createTextFormat(str, str2, i2, j2, str3, Long.MAX_VALUE);
    }

    public static MediaFormat createVideoFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, List<byte[]> list) {
        return createVideoFormat(str, str2, i2, i3, j2, i4, i5, list, -1, -1.0f, null, -1);
    }

    @TargetApi(16)
    private static final void maybeSetIntegerV16(android.media.MediaFormat mediaFormat, String str, int i2) {
        if (i2 != -1) {
            mediaFormat.setInteger(str, i2);
        }
    }

    @TargetApi(16)
    private static final void maybeSetStringV16(android.media.MediaFormat mediaFormat, String str, String str2) {
        if (str2 != null) {
            mediaFormat.setString(str, str2);
        }
    }

    public MediaFormat copyAsAdaptive(String str) {
        return new MediaFormat(str, this.mimeType, -1, -1, this.durationUs, -1, -1, -1, -1.0f, -1, -1, null, Long.MAX_VALUE, null, true, this.maxWidth, this.maxHeight, -1, -1, -1, null, this.stereoMode);
    }

    public MediaFormat copyWithDurationUs(long j2) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, this.maxInputSize, j2, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, this.language, this.subsampleOffsetUs, this.initializationData, this.adaptive, this.maxWidth, this.maxHeight, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithFixedTrackInfo(String str, int i2, int i3, int i4, String str2) {
        return new MediaFormat(str, this.mimeType, i2, this.maxInputSize, this.durationUs, i3, i4, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, str2, this.subsampleOffsetUs, this.initializationData, this.adaptive, -1, -1, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithGaplessInfo(int i2, int i3) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, this.maxInputSize, this.durationUs, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, this.language, this.subsampleOffsetUs, this.initializationData, this.adaptive, this.maxWidth, this.maxHeight, this.pcmEncoding, i2, i3, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithLanguage(String str) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, this.maxInputSize, this.durationUs, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, str, this.subsampleOffsetUs, this.initializationData, this.adaptive, this.maxWidth, this.maxHeight, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithMaxInputSize(int i2) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, i2, this.durationUs, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, this.language, this.subsampleOffsetUs, this.initializationData, this.adaptive, this.maxWidth, this.maxHeight, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithMaxVideoDimensions(int i2, int i3) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, this.maxInputSize, this.durationUs, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, this.language, this.subsampleOffsetUs, this.initializationData, this.adaptive, i2, i3, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public MediaFormat copyWithSubsampleOffsetUs(long j2) {
        return new MediaFormat(this.trackId, this.mimeType, this.bitrate, this.maxInputSize, this.durationUs, this.width, this.height, this.rotationDegrees, this.pixelWidthHeightRatio, this.channelCount, this.sampleRate, this.language, j2, this.initializationData, this.adaptive, this.maxWidth, this.maxHeight, this.pcmEncoding, this.encoderDelay, this.encoderPadding, this.projectionData, this.stereoMode);
    }

    public int describeContents() {
        return 0;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj != null && MediaFormat.class == obj.getClass()) {
            MediaFormat mediaFormat = (MediaFormat) obj;
            if (this.adaptive == mediaFormat.adaptive && this.bitrate == mediaFormat.bitrate && this.maxInputSize == mediaFormat.maxInputSize && this.durationUs == mediaFormat.durationUs && this.width == mediaFormat.width && this.height == mediaFormat.height && this.rotationDegrees == mediaFormat.rotationDegrees && this.pixelWidthHeightRatio == mediaFormat.pixelWidthHeightRatio && this.maxWidth == mediaFormat.maxWidth && this.maxHeight == mediaFormat.maxHeight && this.channelCount == mediaFormat.channelCount && this.sampleRate == mediaFormat.sampleRate && this.pcmEncoding == mediaFormat.pcmEncoding && this.encoderDelay == mediaFormat.encoderDelay && this.encoderPadding == mediaFormat.encoderPadding && this.subsampleOffsetUs == mediaFormat.subsampleOffsetUs && r.a(this.trackId, mediaFormat.trackId) && r.a(this.language, mediaFormat.language) && r.a(this.mimeType, mediaFormat.mimeType) && this.initializationData.size() == mediaFormat.initializationData.size() && Arrays.equals(this.projectionData, mediaFormat.projectionData) && this.stereoMode == mediaFormat.stereoMode) {
                for (int i2 = 0; i2 < this.initializationData.size(); i2++) {
                    if (!Arrays.equals(this.initializationData.get(i2), mediaFormat.initializationData.get(i2))) {
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }

    @SuppressLint({"InlinedApi"})
    @TargetApi(16)
    public final android.media.MediaFormat getFrameworkMediaFormatV16() {
        if (this.frameworkMediaFormat == null) {
            android.media.MediaFormat mediaFormat = new android.media.MediaFormat();
            mediaFormat.setString(IMediaFormat.KEY_MIME, this.mimeType);
            maybeSetStringV16(mediaFormat, IjkMediaMeta.IJKM_KEY_LANGUAGE, this.language);
            maybeSetIntegerV16(mediaFormat, "max-input-size", this.maxInputSize);
            maybeSetIntegerV16(mediaFormat, "width", this.width);
            maybeSetIntegerV16(mediaFormat, "height", this.height);
            maybeSetIntegerV16(mediaFormat, "rotation-degrees", this.rotationDegrees);
            maybeSetIntegerV16(mediaFormat, "max-width", this.maxWidth);
            maybeSetIntegerV16(mediaFormat, "max-height", this.maxHeight);
            maybeSetIntegerV16(mediaFormat, "channel-count", this.channelCount);
            maybeSetIntegerV16(mediaFormat, "sample-rate", this.sampleRate);
            maybeSetIntegerV16(mediaFormat, "encoder-delay", this.encoderDelay);
            maybeSetIntegerV16(mediaFormat, "encoder-padding", this.encoderPadding);
            for (int i2 = 0; i2 < this.initializationData.size(); i2++) {
                mediaFormat.setByteBuffer(d.a.a.a.a.k("csd-", i2), ByteBuffer.wrap(this.initializationData.get(i2)));
            }
            long j2 = this.durationUs;
            if (j2 != -1) {
                mediaFormat.setLong("durationUs", j2);
            }
            this.frameworkMediaFormat = mediaFormat;
        }
        return this.frameworkMediaFormat;
    }

    public int hashCode() {
        if (this.hashCode == 0) {
            String str = this.trackId;
            int hashCode2 = (527 + (str == null ? 0 : str.hashCode())) * 31;
            String str2 = this.mimeType;
            int floatToRawIntBits = (((((((((((((((((((Float.floatToRawIntBits(this.pixelWidthHeightRatio) + ((((((((((((hashCode2 + (str2 == null ? 0 : str2.hashCode())) * 31) + this.bitrate) * 31) + this.maxInputSize) * 31) + this.width) * 31) + this.height) * 31) + this.rotationDegrees) * 31)) * 31) + ((int) this.durationUs)) * 31) + (this.adaptive ? 1231 : 1237)) * 31) + this.maxWidth) * 31) + this.maxHeight) * 31) + this.channelCount) * 31) + this.sampleRate) * 31) + this.pcmEncoding) * 31) + this.encoderDelay) * 31) + this.encoderPadding) * 31;
            String str3 = this.language;
            int hashCode3 = ((floatToRawIntBits + (str3 == null ? 0 : str3.hashCode())) * 31) + ((int) this.subsampleOffsetUs);
            for (int i2 = 0; i2 < this.initializationData.size(); i2++) {
                hashCode3 = (hashCode3 * 31) + Arrays.hashCode(this.initializationData.get(i2));
            }
            this.hashCode = ((Arrays.hashCode(this.projectionData) + (hashCode3 * 31)) * 31) + this.stereoMode;
        }
        return this.hashCode;
    }

    @TargetApi(16)
    @Deprecated
    public final void setFrameworkFormatV16(android.media.MediaFormat mediaFormat) {
        this.frameworkMediaFormat = mediaFormat;
    }

    public String toString() {
        StringBuilder B = d.a.a.a.a.B("MediaFormat(");
        B.append(this.trackId);
        B.append(", ");
        B.append(this.mimeType);
        B.append(", ");
        B.append(this.bitrate);
        B.append(", ");
        B.append(this.maxInputSize);
        B.append(", ");
        B.append(this.width);
        B.append(", ");
        B.append(this.height);
        B.append(", ");
        B.append(this.rotationDegrees);
        B.append(", ");
        B.append(this.pixelWidthHeightRatio);
        B.append(", ");
        B.append(this.channelCount);
        B.append(", ");
        B.append(this.sampleRate);
        B.append(", ");
        B.append(this.language);
        B.append(", ");
        B.append(this.durationUs);
        B.append(", ");
        B.append(this.adaptive);
        B.append(", ");
        B.append(this.maxWidth);
        B.append(", ");
        B.append(this.maxHeight);
        B.append(", ");
        B.append(this.pcmEncoding);
        B.append(", ");
        B.append(this.encoderDelay);
        B.append(", ");
        return d.a.a.a.a.v(B, this.encoderPadding, ")");
    }

    public void writeToParcel(Parcel parcel, int i2) {
        parcel.writeString(this.trackId);
        parcel.writeString(this.mimeType);
        parcel.writeInt(this.bitrate);
        parcel.writeInt(this.maxInputSize);
        parcel.writeLong(this.durationUs);
        parcel.writeInt(this.width);
        parcel.writeInt(this.height);
        parcel.writeInt(this.rotationDegrees);
        parcel.writeFloat(this.pixelWidthHeightRatio);
        parcel.writeInt(this.channelCount);
        parcel.writeInt(this.sampleRate);
        parcel.writeString(this.language);
        parcel.writeLong(this.subsampleOffsetUs);
        parcel.writeList(this.initializationData);
        parcel.writeInt(this.adaptive ? 1 : 0);
        parcel.writeInt(this.maxWidth);
        parcel.writeInt(this.maxHeight);
        parcel.writeInt(this.pcmEncoding);
        parcel.writeInt(this.encoderDelay);
        parcel.writeInt(this.encoderPadding);
        parcel.writeInt(this.projectionData != null ? 1 : 0);
        byte[] bArr = this.projectionData;
        if (bArr != null) {
            parcel.writeByteArray(bArr);
        }
        parcel.writeInt(this.stereoMode);
    }

    public static MediaFormat createAudioFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, List<byte[]> list, String str3, int i6) {
        return new MediaFormat(str, str2, i2, i3, j2, -1, -1, -1, -1.0f, i4, i5, str3, Long.MAX_VALUE, list, false, -1, -1, i6, -1, -1, null, -1);
    }

    public static MediaFormat createTextFormat(String str, String str2, int i2, long j2, String str3, long j3) {
        return new MediaFormat(str, str2, i2, -1, j2, -1, -1, -1, -1.0f, -1, -1, str3, j3, null, false, -1, -1, -1, -1, -1, null, -1);
    }

    public static MediaFormat createVideoFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, List<byte[]> list, int i6, float f2) {
        return new MediaFormat(str, str2, i2, i3, j2, i4, i5, i6, f2, -1, -1, null, Long.MAX_VALUE, list, false, -1, -1, -1, -1, -1, null, -1);
    }

    public static MediaFormat createVideoFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, List<byte[]> list, int i6, float f2, byte[] bArr, int i7) {
        return new MediaFormat(str, str2, i2, i3, j2, i4, i5, i6, f2, -1, -1, null, Long.MAX_VALUE, list, false, -1, -1, -1, -1, -1, bArr, i7);
    }

    public MediaFormat(String str, String str2, int i2, int i3, long j2, int i4, int i5, int i6, float f2, int i7, int i8, String str3, long j3, List<byte[]> list, boolean z, int i9, int i10, int i11, int i12, int i13, byte[] bArr, int i14) {
        this.trackId = str;
        if (!TextUtils.isEmpty(str2)) {
            this.mimeType = str2;
            this.bitrate = i2;
            this.maxInputSize = i3;
            this.durationUs = j2;
            this.width = i4;
            this.height = i5;
            this.rotationDegrees = i6;
            this.pixelWidthHeightRatio = f2;
            this.channelCount = i7;
            this.sampleRate = i8;
            this.language = str3;
            this.subsampleOffsetUs = j3;
            this.initializationData = list == null ? Collections.emptyList() : list;
            this.adaptive = z;
            this.maxWidth = i9;
            this.maxHeight = i10;
            this.pcmEncoding = i11;
            this.encoderDelay = i12;
            this.encoderPadding = i13;
            this.projectionData = bArr;
            this.stereoMode = i14;
            return;
        }
        throw new IllegalArgumentException();
    }
}
