package com.google.android.material.datepicker;

import android.content.Context;
import android.os.Parcel;
import android.os.Parcelable;
import android.text.format.DateUtils;
import d.h.a.b.k.t;
import java.util.Arrays;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.TimeZone;

public final class Month implements Comparable<Month>, Parcelable {
    public static final Parcelable.Creator<Month> CREATOR = new a();
    public final int daysInMonth;
    public final int daysInWeek;
    private final Calendar firstOfMonth;
    private String longName;
    public final int month;
    public final long timeInMillis;
    public final int year;

    public static class a implements Parcelable.Creator<Month> {
        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // android.os.Parcelable.Creator
        public Month createFromParcel(Parcel parcel) {
            return Month.create(parcel.readInt(), parcel.readInt());
        }

        /* Return type fixed from 'java.lang.Object[]' to match base method */
        @Override // android.os.Parcelable.Creator
        public Month[] newArray(int i2) {
            return new Month[i2];
        }
    }

    private Month(Calendar calendar) {
        calendar.set(5, 1);
        Calendar d2 = t.d(calendar);
        this.firstOfMonth = d2;
        this.month = d2.get(2);
        this.year = d2.get(1);
        this.daysInWeek = d2.getMaximum(7);
        this.daysInMonth = d2.getActualMaximum(5);
        this.timeInMillis = d2.getTimeInMillis();
    }

    public static Month create(long j2) {
        Calendar i2 = t.i();
        i2.setTimeInMillis(j2);
        return new Month(i2);
    }

    public static Month current() {
        return new Month(t.h());
    }

    public int daysFromStartOfWeekToFirstOfMonth() {
        int firstDayOfWeek = this.firstOfMonth.get(7) - this.firstOfMonth.getFirstDayOfWeek();
        return firstDayOfWeek < 0 ? firstDayOfWeek + this.daysInWeek : firstDayOfWeek;
    }

    public int describeContents() {
        return 0;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof Month)) {
            return false;
        }
        Month month2 = (Month) obj;
        if (this.month == month2.month && this.year == month2.year) {
            return true;
        }
        return false;
    }

    public long getDay(int i2) {
        Calendar d2 = t.d(this.firstOfMonth);
        d2.set(5, i2);
        return d2.getTimeInMillis();
    }

    public int getDayOfMonth(long j2) {
        Calendar d2 = t.d(this.firstOfMonth);
        d2.setTimeInMillis(j2);
        return d2.get(5);
    }

    public String getLongName(Context context) {
        if (this.longName == null) {
            long timeInMillis2 = this.firstOfMonth.getTimeInMillis();
            this.longName = DateUtils.formatDateTime(context, timeInMillis2 - ((long) TimeZone.getDefault().getOffset(timeInMillis2)), 36);
        }
        return this.longName;
    }

    public long getStableId() {
        return this.firstOfMonth.getTimeInMillis();
    }

    public int hashCode() {
        return Arrays.hashCode(new Object[]{Integer.valueOf(this.month), Integer.valueOf(this.year)});
    }

    public Month monthsLater(int i2) {
        Calendar d2 = t.d(this.firstOfMonth);
        d2.add(2, i2);
        return new Month(d2);
    }

    public int monthsUntil(Month month2) {
        if (this.firstOfMonth instanceof GregorianCalendar) {
            return (month2.month - this.month) + ((month2.year - this.year) * 12);
        }
        throw new IllegalArgumentException("Only Gregorian calendars are supported.");
    }

    public void writeToParcel(Parcel parcel, int i2) {
        parcel.writeInt(this.year);
        parcel.writeInt(this.month);
    }

    public int compareTo(Month month2) {
        return this.firstOfMonth.compareTo(month2.firstOfMonth);
    }

    public static Month create(int i2, int i3) {
        Calendar i4 = t.i();
        i4.set(1, i2);
        i4.set(2, i3);
        return new Month(i4);
    }
}
