package com.grass.mh.utils;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import d.a.a.a.a;
import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;

public class CThreadPoolExecutor {
    private static final int CORE_POOL_SIZE;
    private static final int CPU_COUNT;
    private static final long KEEP_ALIVE_TIME = 30;
    private static final int MAXIMUM_POOL_SIZE;
    private static final String TAG = "CThreadPoolExecutor";
    private static final int WAIT_COUNT = 128;
    private static ExecutorService jobsForUI;
    private static Handler mainHandler;
    private static Thread mainThread;
    private static HashMap<Runnable, Runnable> mapToMainHandler = new HashMap<>();
    private static ThreadPoolExecutor pool = createThreadPoolExecutor();

    public static class CHandlerException extends ThreadPoolExecutor.AbortPolicy {
        private CHandlerException() {
        }

        public void rejectedExecution(Runnable runnable, ThreadPoolExecutor threadPoolExecutor) {
            String str = CThreadPoolExecutor.TAG;
            Log.d(str, "rejectedExecution:" + runnable);
            Log.e(CThreadPoolExecutor.TAG, CThreadPoolExecutor.logAllThreadStackTrace().toString());
            if (!CThreadPoolExecutor.pool.isShutdown()) {
                CThreadPoolExecutor.pool.shutdown();
                ThreadPoolExecutor unused = CThreadPoolExecutor.pool = null;
            }
            ThreadPoolExecutor unused2 = CThreadPoolExecutor.pool = CThreadPoolExecutor.createThreadPoolExecutor();
        }
    }

    static {
        int availableProcessors = Runtime.getRuntime().availableProcessors();
        CPU_COUNT = availableProcessors;
        int max = Math.max(2, Math.min(availableProcessors - 1, 4));
        CORE_POOL_SIZE = max;
        MAXIMUM_POOL_SIZE = (availableProcessors * 2) + 1;
        jobsForUI = Executors.newFixedThreadPool(max, new CThreadFactory("CJobsForUI", 4));
        Looper mainLooper = Looper.getMainLooper();
        mainThread = mainLooper.getThread();
        mainHandler = new Handler(mainLooper);
    }

    public static <T> void cancelTask(Future<T> future) {
        if (future != null) {
            future.cancel(true);
        }
    }

    /* access modifiers changed from: private */
    public static ThreadPoolExecutor createThreadPoolExecutor() {
        if (pool == null) {
            pool = new ThreadPoolExecutor(CORE_POOL_SIZE, MAXIMUM_POOL_SIZE, KEEP_ALIVE_TIME, TimeUnit.SECONDS, new LinkedBlockingQueue(128), new CThreadFactory("CThreadPool", 3), new CHandlerException());
        }
        return pool;
    }

    public static <T> T getFromTask(Future<T> future, String str, String str2) {
        try {
            return future.get();
        } catch (Exception e2) {
            StringBuilder sb = new StringBuilder();
            sb.append(str2 != null ? a.s(str2, ": ") : "");
            sb.append(e2.toString());
            Log.e(str, sb.toString());
            return null;
        }
    }

    public static boolean isOnMainThread() {
        return mainThread == Thread.currentThread();
    }

    public static StringBuilder logAllThreadStackTrace() {
        StackTraceElement[] stackTraceElementArr;
        StringBuilder sb = new StringBuilder();
        Map<Thread, StackTraceElement[]> allStackTraces = Thread.getAllStackTraces();
        for (Thread thread : allStackTraces.keySet()) {
            sb.append("Thread ");
            sb.append(thread.getName());
            sb.append("\n");
            for (StackTraceElement stackTraceElement : allStackTraces.get(thread)) {
                sb.append("\tat ");
                sb.append(stackTraceElement);
                sb.append("\n");
            }
        }
        return sb;
    }

    public static void logStatus() {
        StringBuilder B = a.B("getActiveCount");
        B.append(pool.getActiveCount());
        B.append("\ngetTaskCount");
        B.append(pool.getTaskCount());
        B.append("\ngetCompletedTaskCount");
        B.append(pool.getCompletedTaskCount());
        Log.d(TAG, B.toString());
    }

    public static void main(String[] strArr) {
        for (final int i2 = 0; i2 < 10000; i2++) {
            PrintStream printStream = System.out;
            printStream.println("index=" + i2);
            runInBackground(new Runnable() {
                /* class com.grass.mh.utils.CThreadPoolExecutor.AnonymousClass3 */

                public void run() {
                    PrintStream printStream = System.out;
                    StringBuilder B = a.B("正在运行第[");
                    B.append(i2 + 1);
                    B.append("]个线程.");
                    printStream.println(B.toString());
                }
            });
            try {
                Thread.sleep(10);
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
        }
    }

    public static void removeCallbackInBackground(Runnable runnable) {
        Runnable runnable2 = mapToMainHandler.get(runnable);
        if (runnable2 != null) {
            mainHandler.removeCallbacks(runnable2);
        }
    }

    public static void removeCallbackOnMainThread(Runnable runnable) {
        mainHandler.removeCallbacks(runnable);
    }

    public static void runInBackground(Runnable runnable) {
        if (pool == null) {
            createThreadPoolExecutor();
        }
        pool.execute(runnable);
    }

    public static void runOnMainThread(Runnable runnable) {
        if (isOnMainThread()) {
            runnable.run();
        } else {
            mainHandler.post(runnable);
        }
    }

    public static void startConsumer(final Runnable runnable, final String str) {
        runInBackground(new Runnable() {
            /* class com.grass.mh.utils.CThreadPoolExecutor.AnonymousClass1 */

            public void run() {
                new CThreadFactory(str, 2).newThread(runnable).start();
            }
        });
    }

    public static <T> Future<T> submitTask(Callable<T> callable) {
        return jobsForUI.submit(callable);
    }

    public static void runInBackground(final Runnable runnable, long j2) {
        if (j2 <= 0) {
            runInBackground(runnable);
            return;
        }
        AnonymousClass2 r0 = new Runnable() {
            /* class com.grass.mh.utils.CThreadPoolExecutor.AnonymousClass2 */

            public void run() {
                CThreadPoolExecutor.mapToMainHandler.remove(runnable);
                CThreadPoolExecutor.pool.execute(runnable);
            }
        };
        mapToMainHandler.put(runnable, r0);
        mainHandler.postDelayed(r0, j2);
    }

    public static void runOnMainThread(Runnable runnable, long j2) {
        if (j2 <= 0) {
            runOnMainThread(runnable);
        } else {
            mainHandler.postDelayed(runnable, j2);
        }
    }

    public static class CThreadFactory implements ThreadFactory {
        private AtomicInteger counter = new AtomicInteger(1);
        private String prefix = "";
        private int priority = 5;

        public CThreadFactory(String str, int i2) {
            this.prefix = str;
            this.priority = i2;
        }

        public Thread newThread(Runnable runnable) {
            Thread thread = new Thread(runnable, this.prefix + " #" + this.counter.getAndIncrement());
            thread.setDaemon(true);
            thread.setPriority(this.priority);
            return thread;
        }

        public CThreadFactory(String str) {
            this.prefix = str;
        }
    }
}
