package com.grass.mh.utils;

import android.os.CountDownTimer;

public class CountDownTimerUtils {
    private static final long ONE_SECOND = 1000;
    private long mCountDownInterval;
    private MyCountDownTimer mCountDownTimer;
    private FinishDelegate mFinishDelegate;
    private long mMillisInFuture = 0;
    private TickDelegate mTickDelegate;

    public interface FinishDelegate {
        void onFinish();
    }

    public static class MyCountDownTimer extends CountDownTimer {
        private FinishDelegate mFinishDelegate;
        private TickDelegate mTickDelegate;

        public MyCountDownTimer(long j2, long j3) {
            super(j2, j3);
        }

        public void onFinish() {
            FinishDelegate finishDelegate = this.mFinishDelegate;
            if (finishDelegate != null) {
                finishDelegate.onFinish();
            }
        }

        public void onTick(long j2) {
            TickDelegate tickDelegate = this.mTickDelegate;
            if (tickDelegate != null) {
                tickDelegate.onTick(j2);
            }
        }

        public void setFinishDelegate(FinishDelegate finishDelegate) {
            this.mFinishDelegate = finishDelegate;
        }

        public void setTickDelegate(TickDelegate tickDelegate) {
            this.mTickDelegate = tickDelegate;
        }
    }

    public interface TickDelegate {
        void onTick(long j2);
    }

    public static CountDownTimerUtils getCountDownTimer() {
        return new CountDownTimerUtils();
    }

    public void cancel() {
        MyCountDownTimer myCountDownTimer = this.mCountDownTimer;
        if (myCountDownTimer != null) {
            myCountDownTimer.cancel();
        }
    }

    public void create() {
        MyCountDownTimer myCountDownTimer = this.mCountDownTimer;
        if (myCountDownTimer != null) {
            myCountDownTimer.cancel();
            this.mCountDownTimer = null;
        }
        if (this.mCountDownInterval <= 0) {
            this.mCountDownInterval = this.mMillisInFuture + ONE_SECOND;
        }
        MyCountDownTimer myCountDownTimer2 = new MyCountDownTimer(this.mMillisInFuture, this.mCountDownInterval);
        this.mCountDownTimer = myCountDownTimer2;
        myCountDownTimer2.setTickDelegate(this.mTickDelegate);
        this.mCountDownTimer.setFinishDelegate(this.mFinishDelegate);
    }

    public CountDownTimerUtils setCountDownInterval(long j2) {
        this.mCountDownInterval = j2;
        return this;
    }

    public CountDownTimerUtils setFinishDelegate(FinishDelegate finishDelegate) {
        this.mFinishDelegate = finishDelegate;
        return this;
    }

    public CountDownTimerUtils setMillisInFuture(long j2) {
        this.mMillisInFuture = j2;
        return this;
    }

    public CountDownTimerUtils setTickDelegate(TickDelegate tickDelegate) {
        this.mTickDelegate = tickDelegate;
        return this;
    }

    public void start() {
        if (this.mCountDownTimer == null) {
            create();
        }
        this.mCountDownTimer.start();
    }
}
