package com.grass.mh.utils;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.view.View;
import androidx.recyclerview.widget.RecyclerView;

public class StaggeredDecoration extends RecyclerView.k {
    private static final int[] ATTRS = {16843284};
    private Drawable mDivider;

    public StaggeredDecoration(Context context) {
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(ATTRS);
        this.mDivider = obtainStyledAttributes.getDrawable(0);
        obtainStyledAttributes.recycle();
    }

    public void drawHorizontal(Canvas canvas, RecyclerView recyclerView) {
        int childCount = recyclerView.getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            View childAt = recyclerView.getChildAt(i2);
            int paddingLeft = childAt.getPaddingLeft() + childAt.getLeft();
            int left = (childAt.getLeft() + childAt.getWidth()) - childAt.getPaddingRight();
            int bottom = (childAt.getBottom() - this.mDivider.getIntrinsicHeight()) - childAt.getPaddingBottom();
            this.mDivider.setBounds(paddingLeft, bottom, left, this.mDivider.getIntrinsicHeight() + bottom);
            this.mDivider.draw(canvas);
        }
    }

    public void drawVertical(Canvas canvas, RecyclerView recyclerView) {
        int childCount = recyclerView.getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            View childAt = recyclerView.getChildAt(i2);
            int right = childAt.getRight() - childAt.getPaddingRight();
            int paddingTop = childAt.getPaddingTop() + childAt.getTop();
            int height = (childAt.getHeight() + childAt.getTop()) - childAt.getPaddingBottom();
            this.mDivider.setBounds(right - this.mDivider.getIntrinsicWidth(), paddingTop, right, height);
            this.mDivider.draw(canvas);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.k
    public void getItemOffsets(Rect rect, View view, RecyclerView recyclerView, RecyclerView.r rVar) {
        rect.set(0, 0, this.mDivider.getIntrinsicWidth(), this.mDivider.getIntrinsicHeight());
    }

    @Override // androidx.recyclerview.widget.RecyclerView.k
    public void onDraw(Canvas canvas, RecyclerView recyclerView, RecyclerView.r rVar) {
        drawHorizontal(canvas, recyclerView);
        drawVertical(canvas, recyclerView);
    }
}
