package com.grass.mh.view;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.TextView;
import com.androidjks.acfan.d1682156448763174048.R;
import java.text.ParseException;
import java.util.Calendar;
import java.util.Date;

public class TimePickerView extends BasePickerView implements View.OnClickListener {
    private Context mContext;
    private View mHeadView;
    private OnTimeSelectListener mTimeSelectListener;
    private TextView mTvCancel;
    private TextView mTvOk;
    private TextView mTxtTitle;
    private WheelTime mWheelTime;

    public interface OnTimeSelectListener {
        void onTimeSelect(Date date);
    }

    public class TextSize {
        public static final float BIG = 6.0f;
        public static final float DEFAULT = 5.0f;
        public static final float SMALL = 4.0f;
        public static final float SMALLER = 3.3f;

        public TextSize() {
        }
    }

    public enum Type {
        ALL,
        YEAR_MONTH_DAY,
        HOURS_MINS,
        MONTH_DAY_HOUR_MIN,
        YEAR_MONTH
    }

    public TimePickerView(Context context, Type type) {
        super(context);
        this.mContext = context;
        initView();
        initSelectTime(type);
    }

    private void initSelectTime(Type type) {
        this.mWheelTime = new WheelTime(findViewById(R.id.view_time_picker), type);
        Calendar instance = Calendar.getInstance();
        instance.setTimeInMillis(System.currentTimeMillis());
        int i2 = instance.get(1);
        int i3 = instance.get(2);
        int i4 = instance.get(5);
        int i5 = instance.get(11);
        int i6 = instance.get(12);
        Calendar instance2 = Calendar.getInstance();
        setRange(instance2.get(1) - 100, instance2.get(1) + 100);
        this.mWheelTime.setPicker(i2, i3, i4, i5, i6);
    }

    private void initView() {
        LayoutInflater.from(this.mContext).inflate(R.layout.layout_picker_view_time, this.contentContainer);
        this.mHeadView = findViewById(R.id.rl_head_view);
        this.mTxtTitle = (TextView) findViewById(R.id.tvTitle);
        this.mTvOk = (TextView) findViewById(R.id.tv_ok);
        this.mTvCancel = (TextView) findViewById(R.id.tv_cancel);
        this.mTvOk.setOnClickListener(this);
        this.mTvCancel.setOnClickListener(this);
    }

    public void onClick(View view) {
        int id = view.getId();
        if (id == R.id.tv_ok) {
            if (this.mTimeSelectListener != null) {
                try {
                    this.mTimeSelectListener.onTimeSelect(WheelTime.dateFormat.parse(this.mWheelTime.getTime()));
                } catch (ParseException e2) {
                    e2.printStackTrace();
                }
            }
            dismiss();
        } else if (id == R.id.tv_cancel) {
            dismiss();
        }
    }

    public void setCancelText(String str) {
        this.mTvCancel.setText(str);
    }

    public void setCancelTextColor(int i2) {
        this.mTvCancel.setTextColor(i2);
    }

    public void setCancelTextSize(float f2) {
        this.mTvCancel.setTextSize(f2);
    }

    public void setCyclic(boolean z) {
        this.mWheelTime.setCyclic(z);
    }

    public void setHeadBackgroundColor(int i2) {
        this.mHeadView.setBackgroundColor(i2);
    }

    public void setOnTimeSelectListener(OnTimeSelectListener onTimeSelectListener) {
        this.mTimeSelectListener = onTimeSelectListener;
    }

    public void setRange(int i2, int i3) {
        this.mWheelTime.setStartYear(i2);
        this.mWheelTime.setEndYear(i3);
    }

    public void setSubmitText(String str) {
        this.mTvOk.setText(str);
    }

    public void setSubmitTextColor(int i2) {
        this.mTvOk.setTextColor(i2);
    }

    public void setSubmitTextSize(float f2) {
        this.mTvOk.setTextSize(f2);
    }

    public void setTextSize(float f2) {
        this.mWheelTime.setTextSize(f2);
    }

    public void setTime(Date date) {
        Calendar instance = Calendar.getInstance();
        if (date == null) {
            instance.setTimeInMillis(System.currentTimeMillis());
        } else {
            instance.setTime(date);
        }
        this.mWheelTime.setPicker(instance.get(1), instance.get(2), instance.get(5), instance.get(11), instance.get(12));
    }

    public void setTitle(String str) {
        this.mTxtTitle.setText(str);
    }

    public void setTitleColor(int i2) {
        this.mTxtTitle.setTextColor(i2);
    }

    public void setTitleSize(float f2) {
        this.mTxtTitle.setTextSize(f2);
    }
}
