package com.grass.mh.view.headerview;

import android.content.Context;
import android.util.AttributeSet;
import android.view.View;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

public class HeaderRecyclerView extends RecyclerView {
    private HeaderViewAdapter mAdapter;

    public HeaderRecyclerView(Context context) {
        super(context);
        wrapHeaderAdapter();
    }

    private void wrapHeaderAdapter() {
        HeaderViewAdapter headerViewAdapter = new HeaderViewAdapter(super.getAdapter());
        this.mAdapter = headerViewAdapter;
        super.setAdapter(headerViewAdapter);
    }

    public void addFooterView(View view) {
        this.mAdapter.addFooterView(view);
    }

    public void addHeaderView(View view) {
        this.mAdapter.addHeaderView(view);
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public RecyclerView.Adapter getAdapter() {
        return this.mAdapter.getAdapter();
    }

    public int getFootersCount() {
        return this.mAdapter.getFootersCount();
    }

    public int getHeadersCount() {
        return this.mAdapter.getHeadersCount();
    }

    public boolean removeFooterView(View view) {
        return this.mAdapter.removeFooterView(view);
    }

    public boolean removeHeaderView(View view) {
        return this.mAdapter.removeHeaderView(view);
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void setAdapter(RecyclerView.Adapter adapter) {
        this.mAdapter.setAdapter(adapter);
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void setLayoutManager(RecyclerView.LayoutManager layoutManager) {
        if (!(layoutManager instanceof GridLayoutManager) || (layoutManager instanceof HeaderViewGridLayoutManager)) {
            super.setLayoutManager(layoutManager);
        } else {
            super.setLayoutManager(new HeaderViewGridLayoutManager(getContext(), ((GridLayoutManager) layoutManager).getSpanCount(), this.mAdapter));
        }
    }

    public HeaderRecyclerView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        wrapHeaderAdapter();
    }

    public HeaderRecyclerView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        wrapHeaderAdapter();
    }
}
