package com.grass.mh.view.headerview;

import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import java.util.ArrayList;
import java.util.List;

public class HeaderViewAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {
    private RecyclerView.Adapter mAdapter;
    private final List<FixedViewInfo> mFooterViewInfos = new ArrayList();
    private final List<FixedViewInfo> mHeaderViewInfos = new ArrayList();
    private RecyclerView.h mObserver;

    public class FixedViewInfo {
        public int itemViewType;
        public View view;

        private FixedViewInfo() {
        }
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public ViewHolder(View view) {
            super(view);
        }
    }

    public HeaderViewAdapter(RecyclerView.Adapter adapter) {
        AnonymousClass1 r0 = new RecyclerView.h() {
            /* class com.grass.mh.view.headerview.HeaderViewAdapter.AnonymousClass1 */

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onChanged() {
                HeaderViewAdapter.this.notifyDataSetChanged();
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeChanged(int i2, int i3) {
                super.onItemRangeChanged(i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeInserted(int i2, int i3) {
                HeaderViewAdapter headerViewAdapter = HeaderViewAdapter.this;
                headerViewAdapter.notifyItemRangeInserted(headerViewAdapter.getHeadersCount() + i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeMoved(int i2, int i3, int i4) {
                HeaderViewAdapter headerViewAdapter = HeaderViewAdapter.this;
                headerViewAdapter.notifyItemMoved(headerViewAdapter.getHeadersCount() + i2, HeaderViewAdapter.this.getHeadersCount() + i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeRemoved(int i2, int i3) {
                HeaderViewAdapter headerViewAdapter = HeaderViewAdapter.this;
                headerViewAdapter.notifyItemRangeRemoved(headerViewAdapter.getHeadersCount() + i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeChanged(int i2, int i3, Object obj) {
                HeaderViewAdapter headerViewAdapter = HeaderViewAdapter.this;
                headerViewAdapter.notifyItemRangeChanged(headerViewAdapter.getHeadersCount() + i2, i3, obj);
            }
        };
        this.mObserver = r0;
        this.mAdapter = adapter;
        if (adapter != null) {
            adapter.registerAdapterDataObserver(r0);
        }
    }

    private View findViewForInfos(int i2) {
        for (FixedViewInfo fixedViewInfo : this.mHeaderViewInfos) {
            if (fixedViewInfo.itemViewType == i2) {
                return fixedViewInfo.view;
            }
        }
        for (FixedViewInfo fixedViewInfo2 : this.mFooterViewInfos) {
            if (fixedViewInfo2.itemViewType == i2) {
                return fixedViewInfo2.view;
            }
        }
        return null;
    }

    private int generateUniqueViewType() {
        boolean z;
        int random;
        int itemCount = getItemCount();
        do {
            z = true;
            random = ((int) (Math.random() * 2.147483647E9d)) + 1;
            int i2 = 0;
            while (true) {
                if (i2 >= itemCount) {
                    z = false;
                    continue;
                    break;
                } else if (random == getItemViewType(i2)) {
                    continue;
                    break;
                } else {
                    i2++;
                }
            }
        } while (z);
        return random;
    }

    private void handleLayoutIfStaggeredGridLayout(RecyclerView.ViewHolder viewHolder, int i2) {
        if (isHeader(i2) || isFooter(i2)) {
            ((StaggeredGridLayoutManager.LayoutParams) viewHolder.itemView.getLayoutParams()).f1923f = true;
        }
    }

    private boolean isStaggeredGridLayout(RecyclerView.ViewHolder viewHolder) {
        ViewGroup.LayoutParams layoutParams = viewHolder.itemView.getLayoutParams();
        return layoutParams != null && (layoutParams instanceof StaggeredGridLayoutManager.LayoutParams);
    }

    public void addFooterView(View view) {
        addFooterView(view, generateUniqueViewType());
    }

    public void addHeaderView(View view) {
        addHeaderView(view, generateUniqueViewType());
    }

    public RecyclerView.Adapter getAdapter() {
        return this.mAdapter;
    }

    public int getFootersCount() {
        return this.mFooterViewInfos.size();
    }

    public int getHeadersCount() {
        return this.mHeaderViewInfos.size();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        int size = this.mFooterViewInfos.size() + this.mHeaderViewInfos.size();
        RecyclerView.Adapter adapter = this.mAdapter;
        return size + (adapter == null ? 0 : adapter.getItemCount());
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int i2) {
        if (isHeader(i2)) {
            return this.mHeaderViewInfos.get(i2).itemViewType;
        }
        if (isFooter(i2)) {
            return this.mFooterViewInfos.get((i2 - this.mHeaderViewInfos.size()) - this.mAdapter.getItemCount()).itemViewType;
        }
        return this.mAdapter.getItemViewType(i2 - getHeadersCount());
    }

    public boolean isFooter(int i2) {
        return getItemCount() - i2 <= getFootersCount();
    }

    public boolean isHeader(int i2) {
        return i2 < getHeadersCount();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        RecyclerView.Adapter adapter = this.mAdapter;
        if (adapter != null) {
            adapter.onAttachedToRecyclerView(recyclerView);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i2) {
        if (!isHeader(i2) && !isFooter(i2)) {
            this.mAdapter.onBindViewHolder(viewHolder, i2 - getHeadersCount());
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i2) {
        View findViewForInfos = findViewForInfos(i2);
        if (findViewForInfos != null) {
            return new ViewHolder(findViewForInfos);
        }
        return this.mAdapter.onCreateViewHolder(viewGroup, i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onDetachedFromRecyclerView(RecyclerView recyclerView) {
        RecyclerView.Adapter adapter = this.mAdapter;
        if (adapter != null) {
            adapter.onDetachedFromRecyclerView(recyclerView);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public boolean onFailedToRecycleView(RecyclerView.ViewHolder viewHolder) {
        if (viewHolder instanceof ViewHolder) {
            return super.onFailedToRecycleView(viewHolder);
        }
        return this.mAdapter.onFailedToRecycleView(viewHolder);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewAttachedToWindow(RecyclerView.ViewHolder viewHolder) {
        if (viewHolder instanceof ViewHolder) {
            super.onViewAttachedToWindow(viewHolder);
        } else {
            this.mAdapter.onViewAttachedToWindow(viewHolder);
        }
        if (isStaggeredGridLayout(viewHolder)) {
            handleLayoutIfStaggeredGridLayout(viewHolder, viewHolder.getLayoutPosition());
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewDetachedFromWindow(RecyclerView.ViewHolder viewHolder) {
        if (viewHolder instanceof ViewHolder) {
            super.onViewDetachedFromWindow(viewHolder);
        } else {
            this.mAdapter.onViewDetachedFromWindow(viewHolder);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewRecycled(RecyclerView.ViewHolder viewHolder) {
        if (viewHolder instanceof ViewHolder) {
            super.onViewRecycled(viewHolder);
        } else {
            this.mAdapter.onViewRecycled(viewHolder);
        }
    }

    public boolean removeFooterView(View view) {
        for (FixedViewInfo fixedViewInfo : this.mFooterViewInfos) {
            if (fixedViewInfo.view == view) {
                this.mFooterViewInfos.remove(fixedViewInfo);
                notifyDataSetChanged();
                return true;
            }
        }
        return false;
    }

    public boolean removeHeaderView(View view) {
        for (FixedViewInfo fixedViewInfo : this.mHeaderViewInfos) {
            if (fixedViewInfo.view == view) {
                this.mHeaderViewInfos.remove(fixedViewInfo);
                notifyDataSetChanged();
                return true;
            }
        }
        return false;
    }

    public void setAdapter(RecyclerView.Adapter adapter) {
        if (!(adapter instanceof HeaderViewAdapter)) {
            this.mAdapter = adapter;
            if (adapter != null) {
                adapter.registerAdapterDataObserver(this.mObserver);
            }
            notifyDataSetChanged();
            return;
        }
        throw new IllegalArgumentException("Cannot wrap a HeaderViewAdapter");
    }

    private void addFooterView(View view, int i2) {
        FixedViewInfo fixedViewInfo = new FixedViewInfo();
        fixedViewInfo.view = view;
        fixedViewInfo.itemViewType = i2;
        this.mFooterViewInfos.add(fixedViewInfo);
        notifyDataSetChanged();
    }

    private void addHeaderView(View view, int i2) {
        FixedViewInfo fixedViewInfo = new FixedViewInfo();
        fixedViewInfo.view = view;
        fixedViewInfo.itemViewType = i2;
        this.mHeaderViewInfos.add(fixedViewInfo);
        notifyDataSetChanged();
    }
}
