package com.grass.mh.view.smartpopupwindow;

import android.animation.ValueAnimator;
import android.app.Activity;
import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.util.AttributeSet;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewTreeObserver;
import android.view.Window;
import android.view.WindowManager;
import android.widget.PopupWindow;

public class SmartPopupWindow extends PopupWindow {
    private boolean isOnlyGetWH;
    private boolean isTouchOutsideDismiss;
    private float mAlpha;
    private View mAnchorView;
    private int mAnimationStyle;
    private View mContentView;
    private Context mContext;
    private int mHeight;
    private int mHorizontalGravity;
    private int mOffsetX;
    private int mOffsetY;
    private final ViewTreeObserver.OnGlobalLayoutListener mOnGlobalLayoutListener;
    private int mVerticalGravity;
    private int mWidth;

    public static class Builder {
        private SmartPopupWindow mWindow;

        private Builder(Activity activity, View view) {
            SmartPopupWindow smartPopupWindow = new SmartPopupWindow(activity);
            this.mWindow = smartPopupWindow;
            smartPopupWindow.mContext = activity;
            this.mWindow.mContentView = view;
        }

        public static Builder build(Activity activity, View view) {
            return new Builder(activity, view);
        }

        public SmartPopupWindow createPopupWindow() {
            this.mWindow.init();
            return this.mWindow;
        }

        public Builder setAlpha(float f2) {
            this.mWindow.mAlpha = f2;
            return this;
        }

        public Builder setAnimationStyle(int i2) {
            this.mWindow.mAnimationStyle = i2;
            return this;
        }

        public Builder setOutsideTouchDismiss(boolean z) {
            this.mWindow.isTouchOutsideDismiss = z;
            return this;
        }

        public Builder setSize(int i2, int i3) {
            this.mWindow.mWidth = i2;
            this.mWindow.mHeight = i3;
            return this;
        }
    }

    public SmartPopupWindow(Context context) {
        this(context, null);
    }

    private void addGlobalLayoutListener(View view) {
        view.getViewTreeObserver().addOnGlobalLayoutListener(this.mOnGlobalLayoutListener);
    }

    private int calculateX(View view, int i2, int i3, int i4) {
        int i5;
        if (i2 != 0) {
            if (i2 != 1) {
                if (i2 == 2) {
                    i5 = view.getWidth();
                } else if (i2 != 4) {
                    return i4;
                } else {
                    i3 -= view.getWidth();
                }
            }
            return i4 - i3;
        }
        i5 = (view.getWidth() / 2) - (i3 / 2);
        return i4 + i5;
    }

    private int calculateY(View view, int i2, int i3, int i4) {
        int i5;
        if (i2 != 0) {
            if (i2 == 1) {
                i5 = view.getHeight() + i3;
            } else if (i2 == 3) {
                i5 = view.getHeight();
            } else if (i2 != 4) {
                return i4;
            }
            return i4 - i5;
        }
        i3 = (i3 / 2) + (view.getHeight() / 2);
        return i4 - i3;
    }

    private void dismissBackgroundAnimator() {
        float f2 = this.mAlpha;
        if (f2 < 1.0f) {
            ValueAnimator ofFloat = ValueAnimator.ofFloat(f2, 1.0f);
            ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
                /* class com.grass.mh.view.smartpopupwindow.SmartPopupWindow.AnonymousClass5 */

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    SmartPopupWindow.this.setWindowBackgroundAlpha(((Float) valueAnimator.getAnimatedValue()).floatValue());
                }
            });
            ofFloat.setDuration(360L);
            ofFloat.start();
        }
    }

    private static int getDropDownMeasureSpecMode(int i2) {
        return i2 != -2 ? 1073741824 : 0;
    }

    private static int makeDropDownMeasureSpec(int i2) {
        return View.MeasureSpec.makeMeasureSpec(View.MeasureSpec.getSize(i2), getDropDownMeasureSpecMode(i2));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void removeGlobalLayoutListener() {
        if (getContentView() != null) {
            getContentView().getViewTreeObserver().removeOnGlobalLayoutListener(this.mOnGlobalLayoutListener);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setWindowBackgroundAlpha(float f2) {
        Context context = this.mContext;
        if (context != null && (context instanceof Activity)) {
            Window window = ((Activity) context).getWindow();
            WindowManager.LayoutParams attributes = window.getAttributes();
            attributes.alpha = f2;
            window.setAttributes(attributes);
        }
    }

    private void showBackgroundAnimator() {
        float f2 = this.mAlpha;
        if (f2 < 1.0f) {
            ValueAnimator ofFloat = ValueAnimator.ofFloat(1.0f, f2);
            ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
                /* class com.grass.mh.view.smartpopupwindow.SmartPopupWindow.AnonymousClass4 */

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    SmartPopupWindow.this.setWindowBackgroundAlpha(((Float) valueAnimator.getAnimatedValue()).floatValue());
                }
            });
            ofFloat.setDuration(360L);
            ofFloat.start();
        }
    }

    private void touchOutsideDismiss(boolean z) {
        if (!z) {
            setFocusable(true);
            setOutsideTouchable(false);
            setBackgroundDrawable(null);
            getContentView().setFocusable(true);
            getContentView().setFocusableInTouchMode(true);
            getContentView().setOnKeyListener(new View.OnKeyListener() {
                /* class com.grass.mh.view.smartpopupwindow.SmartPopupWindow.AnonymousClass1 */

                public boolean onKey(View view, int i2, KeyEvent keyEvent) {
                    if (i2 != 4) {
                        return false;
                    }
                    SmartPopupWindow.this.dismiss();
                    return true;
                }
            });
            setTouchInterceptor(new View.OnTouchListener() {
                /* class com.grass.mh.view.smartpopupwindow.SmartPopupWindow.AnonymousClass2 */

                public boolean onTouch(View view, MotionEvent motionEvent) {
                    int x = (int) motionEvent.getX();
                    int y = (int) motionEvent.getY();
                    if ((motionEvent.getAction() != 0 || (x >= 0 && x < SmartPopupWindow.this.mWidth && y >= 0 && y < SmartPopupWindow.this.mHeight)) && motionEvent.getAction() != 4) {
                        return false;
                    }
                    return true;
                }
            });
            return;
        }
        setFocusable(true);
        setOutsideTouchable(true);
        setBackgroundDrawable(new ColorDrawable(0));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateLocation(int i2, int i3, View view, int i4, int i5, int i6, int i7) {
        update(view, calculateX(view, i5, i2, i6), calculateY(view, i4, i3, i7), i2, i3);
    }

    public void dismiss() {
        super.dismiss();
        dismissBackgroundAnimator();
        removeGlobalLayoutListener();
    }

    public void init() {
        setContentView(this.mContentView);
        setHeight(this.mHeight);
        setWidth(this.mWidth);
        touchOutsideDismiss(this.isTouchOutsideDismiss);
        int i2 = this.mAnimationStyle;
        if (i2 != -1) {
            setAnimationStyle(i2);
        }
    }

    public void showAtAnchorView(View view, int i2, int i3) {
        showAtAnchorView(view, i2, i3, true);
    }

    public void showAtLocation(View view, int i2, int i3, int i4) {
        this.isOnlyGetWH = true;
        this.mAnchorView = view;
        this.mOffsetX = i3;
        this.mOffsetY = i4;
        addGlobalLayoutListener(getContentView());
        super.showAtLocation(view, i2, i3, i4);
    }

    public SmartPopupWindow(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public void showAtAnchorView(View view, int i2, int i3, boolean z) {
        showAtAnchorView(view, i2, i3, 0, 0, z);
    }

    public SmartPopupWindow(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mWidth = -2;
        this.mHeight = -2;
        this.mAlpha = 1.0f;
        this.isTouchOutsideDismiss = true;
        this.mAnimationStyle = -1;
        this.isOnlyGetWH = true;
        this.mVerticalGravity = 2;
        this.mHorizontalGravity = 1;
        this.mOnGlobalLayoutListener = new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class com.grass.mh.view.smartpopupwindow.SmartPopupWindow.AnonymousClass3 */

            public void onGlobalLayout() {
                SmartPopupWindow smartPopupWindow = SmartPopupWindow.this;
                smartPopupWindow.mWidth = smartPopupWindow.getContentView().getWidth();
                SmartPopupWindow smartPopupWindow2 = SmartPopupWindow.this;
                smartPopupWindow2.mHeight = smartPopupWindow2.getContentView().getHeight();
                if (SmartPopupWindow.this.isOnlyGetWH) {
                    SmartPopupWindow.this.removeGlobalLayoutListener();
                    return;
                }
                SmartPopupWindow smartPopupWindow3 = SmartPopupWindow.this;
                smartPopupWindow3.updateLocation(smartPopupWindow3.mWidth, SmartPopupWindow.this.mHeight, SmartPopupWindow.this.mAnchorView, SmartPopupWindow.this.mVerticalGravity, SmartPopupWindow.this.mHorizontalGravity, SmartPopupWindow.this.mOffsetX, SmartPopupWindow.this.mOffsetY);
                SmartPopupWindow.this.removeGlobalLayoutListener();
            }
        };
        this.mContext = context;
    }

    public void showAtAnchorView(View view, int i2, int i3, int i4, int i5) {
        showAtAnchorView(view, i2, i3, i4, i5, true);
    }

    public void showAtAnchorView(View view, int i2, int i3, int i4, int i5, boolean z) {
        this.isOnlyGetWH = false;
        this.mAnchorView = view;
        this.mOffsetX = i4;
        this.mOffsetY = i5;
        this.mVerticalGravity = i2;
        this.mHorizontalGravity = i3;
        showBackgroundAnimator();
        View contentView = getContentView();
        addGlobalLayoutListener(contentView);
        setClippingEnabled(z);
        contentView.measure(makeDropDownMeasureSpec(getWidth()), makeDropDownMeasureSpec(getHeight()));
        int measuredWidth = contentView.getMeasuredWidth();
        int measuredHeight = contentView.getMeasuredHeight();
        if (!z) {
            int[] iArr = new int[2];
            view.getLocationInWindow(iArr);
            i4 += iArr[0];
            i5 += view.getHeight() + iArr[1];
        }
        int calculateY = calculateY(view, i2, measuredHeight, i5);
        int calculateX = calculateX(view, i3, measuredWidth, i4);
        if (z) {
            showAsDropDown(view, calculateX, calculateY, 0);
        } else {
            showAtLocation(view, 0, calculateX, calculateY);
        }
    }
}
