package com.grass.mh.widget;

import android.content.Context;
import android.graphics.Color;
import android.text.Layout;
import android.text.Selection;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.method.LinkMovementMethod;
import android.text.method.Touch;
import android.text.style.BackgroundColorSpan;
import android.text.style.ClickableSpan;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.TextView;
import androidx.appcompat.widget.AppCompatTextView;
import com.androidjks.acfan.d1682156448763174048.R;
import com.androidx.lv.base.utils.ResourcesUtils;
import d.i.a.o.a;
import d.i.a.o.b;

public class ExpandTextView extends AppCompatTextView {
    private SpannableString closeSpan;
    private String closeSuffix = "...\t收起";
    private SpannableString expandSpan;
    private String expandSuffix = "...\t全部";
    public boolean isClick;

    public class ButtonSpan extends ClickableSpan {
        private View.OnClickListener onClickListener;

        public ButtonSpan(View.OnClickListener onClickListener2) {
            this.onClickListener = onClickListener2;
        }

        public void onClick(View view) {
            View.OnClickListener onClickListener2 = this.onClickListener;
            if (onClickListener2 != null) {
                onClickListener2.onClick(view);
            }
        }

        public void updateDrawState(TextPaint textPaint) {
            textPaint.setColor(ResourcesUtils.getColor(R.color.color_FF2600));
            textPaint.setUnderlineText(false);
            textPaint.setLinearText(false);
            textPaint.setFakeBoldText(false);
            textPaint.setUnderlineText(false);
        }
    }

    public static class CustomLinkMovementMethod extends LinkMovementMethod {
        public static CustomLinkMovementMethod sInstance;

        public static CustomLinkMovementMethod getInstance() {
            if (sInstance == null) {
                sInstance = new CustomLinkMovementMethod();
            }
            return sInstance;
        }

        public boolean onTouchEvent(TextView textView, Spannable spannable, MotionEvent motionEvent) {
            int action = motionEvent.getAction();
            if (action != 1 && action != 0) {
                return Touch.onTouchEvent(textView, spannable, motionEvent);
            }
            int x = ((int) motionEvent.getX()) - textView.getTotalPaddingLeft();
            int y = ((int) motionEvent.getY()) - textView.getTotalPaddingTop();
            int scrollX = textView.getScrollX() + x;
            int scrollY = textView.getScrollY() + y;
            Layout layout = textView.getLayout();
            int offsetForHorizontal = layout.getOffsetForHorizontal(layout.getLineForVertical(scrollY), (float) scrollX);
            Object[] objArr = (ClickableSpan[]) spannable.getSpans(offsetForHorizontal, offsetForHorizontal, ClickableSpan.class);
            if (objArr.length != 0) {
                if (action == 1) {
                    objArr[0].onClick(textView);
                    spannable.setSpan(new BackgroundColorSpan(Color.parseColor("#00000000")), spannable.getSpanStart(objArr[0]), spannable.getSpanEnd(objArr[0]), 33);
                } else {
                    spannable.setSpan(new BackgroundColorSpan(Color.parseColor("#00000000")), spannable.getSpanStart(objArr[0]), spannable.getSpanEnd(objArr[0]), 33);
                    Selection.setSelection(spannable, spannable.getSpanStart(objArr[0]), spannable.getSpanEnd(objArr[0]));
                }
                if (textView instanceof ExpandTextView) {
                    ((ExpandTextView) textView).isClick = true;
                    textView.setBackground(null);
                }
                return true;
            }
            Selection.removeSelection(spannable);
            super.onTouchEvent(textView, spannable, motionEvent);
            return false;
        }
    }

    public ExpandTextView(Context context) {
        super(context);
    }

    public /* synthetic */ void a(View view) {
        setText(this.closeSpan);
    }

    public /* synthetic */ void b(View view) {
        setText(this.expandSpan);
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        this.isClick = false;
        return super.onTouchEvent(motionEvent);
    }

    public boolean performClick() {
        if (this.isClick) {
            return true;
        }
        return super.performClick();
    }

    public void setContent(CharSequence charSequence) {
        StaticLayout staticLayout = new StaticLayout(charSequence, getPaint(), getContext().getResources().getDisplayMetrics().widthPixels, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
        if (staticLayout.getLineCount() > 5) {
            SpannableString spannableString = new SpannableString(((Object) charSequence.subSequence(0, staticLayout.getLineStart(2) - 7)) + this.expandSuffix);
            this.expandSpan = spannableString;
            spannableString.setSpan(new ButtonSpan(new a(this)), this.expandSpan.length() - this.expandSuffix.length(), this.expandSpan.length(), 17);
            SpannableString spannableString2 = new SpannableString(((Object) charSequence) + this.closeSuffix);
            this.closeSpan = spannableString2;
            spannableString2.setSpan(new ButtonSpan(new b(this)), this.closeSpan.length() - this.closeSuffix.length(), this.closeSpan.length(), 17);
            setText(this.expandSpan);
            setMovementMethod(CustomLinkMovementMethod.getInstance());
            return;
        }
        setText(charSequence);
    }

    public ExpandTextView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
    }

    public ExpandTextView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
    }
}
