package com.grass.mh.widget;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.TypedArray;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import com.androidjks.acfan.d1682156448763174048.R;
import com.grass.mh.R$styleable;
import java.util.ArrayList;
import java.util.List;

public class LabelsView extends ViewGroup implements View.OnClickListener {
    private static final String KEY_BG_RES_ID_STATE = "key_bg_res_id_state";
    private static final String KEY_COMPULSORY_LABELS_STATE = "key_select_compulsory_state";
    private static final int KEY_DATA = 2131297336;
    private static final String KEY_INDICATOR_STATE = "key_indicator_state";
    private static final String KEY_LABELS_STATE = "key_labels_state";
    private static final String KEY_LABEL_GRAVITY_STATE = "key_label_gravity_state";
    private static final String KEY_LABEL_HEIGHT_STATE = "key_label_height_state";
    private static final String KEY_LABEL_WIDTH_STATE = "key_label_width_state";
    private static final String KEY_LINE_MARGIN_STATE = "key_line_margin_state";
    private static final String KEY_MAX_COLUMNS_STATE = "key_max_columns_state";
    private static final String KEY_MAX_LINES_STATE = "key_max_lines_state";
    private static final String KEY_MAX_SELECT_STATE = "key_max_select_state";
    private static final String KEY_MIN_SELECT_STATE = "key_min_select_state";
    private static final String KEY_PADDING_STATE = "key_padding_state";
    private static final int KEY_POSITION = 2131297337;
    private static final String KEY_SELECT_LABELS_STATE = "key_select_labels_state";
    private static final String KEY_SELECT_TYPE_STATE = "key_select_type_state";
    private static final String KEY_SINGLE_LINE_STATE = "key_single_line_state";
    private static final String KEY_SUPER_STATE = "key_super_state";
    private static final String KEY_TEXT_COLOR_STATE = "key_text_color_state";
    private static final String KEY_TEXT_SIZE_STATE = "key_text_size_state";
    private static final String KEY_TEXT_STYLE_STATE = "key_text_style_state";
    private static final String KEY_WORD_MARGIN_STATE = "key_word_margin_state";
    private boolean isIndicator;
    private boolean isSingleLine = false;
    private boolean isTextBold = false;
    private ArrayList<Integer> mCompulsorys = new ArrayList<>();
    private Context mContext;
    private Drawable mLabelBg;
    private OnLabelClickListener mLabelClickListener;
    private int mLabelGravity = 17;
    private int mLabelHeight = -2;
    private OnLabelLongClickListener mLabelLongClickListener;
    private OnLabelSelectChangeListener mLabelSelectChangeListener;
    private int mLabelWidth = -2;
    private ArrayList<Object> mLabels = new ArrayList<>();
    private int mLineMargin;
    private int mLines;
    private int mMaxColumns;
    private int mMaxLines;
    private int mMaxSelect;
    private int mMinSelect;
    private OnSelectChangeIntercept mOnSelectChangeIntercept;
    private ArrayList<Integer> mSelectLabels = new ArrayList<>();
    private SelectType mSelectType;
    private ColorStateList mTextColor;
    private int mTextPaddingBottom;
    private int mTextPaddingLeft;
    private int mTextPaddingRight;
    private int mTextPaddingTop;
    private float mTextSize;
    private int mWordMargin;

    public interface LabelTextProvider<T> {
        CharSequence getLabelText(TextView textView, int i2, T t);
    }

    public interface OnLabelClickListener {
        void onLabelClick(TextView textView, Object obj, int i2);
    }

    public interface OnLabelLongClickListener {
        boolean onLabelLongClick(TextView textView, Object obj, int i2);
    }

    public interface OnLabelSelectChangeListener {
        void onLabelSelectChange(TextView textView, Object obj, boolean z, int i2);
    }

    public interface OnSelectChangeIntercept {
        boolean onIntercept(TextView textView, Object obj, boolean z, boolean z2, int i2);
    }

    public enum SelectType {
        NONE(1),
        SINGLE(2),
        SINGLE_IRREVOCABLY(3),
        MULTI(4);
        
        public int value;

        private SelectType(int i2) {
            this.value = i2;
        }

        public static SelectType get(int i2) {
            if (i2 == 1) {
                return NONE;
            }
            if (i2 == 2) {
                return SINGLE;
            }
            if (i2 == 3) {
                return SINGLE_IRREVOCABLY;
            }
            if (i2 != 4) {
                return NONE;
            }
            return MULTI;
        }
    }

    public interface Selectable {
        boolean isSelected();

        void onSelected(boolean z);
    }

    public LabelsView(Context context) {
        super(context);
        this.mContext = context;
        showEditPreview();
    }

    private <T> void addLabel(T t, int i2, LabelTextProvider<T> labelTextProvider) {
        TextView textView = new TextView(this.mContext);
        textView.setPadding(this.mTextPaddingLeft, this.mTextPaddingTop, this.mTextPaddingRight, this.mTextPaddingBottom);
        textView.setTextSize(0, this.mTextSize);
        textView.setGravity(this.mLabelGravity);
        textView.setTextColor(this.mTextColor);
        textView.setBackgroundDrawable(this.mLabelBg.getConstantState().newDrawable());
        textView.setTag(R.id.tag_key_data, t);
        textView.setTag(R.id.tag_key_position, Integer.valueOf(i2));
        textView.setOnClickListener(this);
        textView.getPaint().setFakeBoldText(this.isTextBold);
        addView(textView, this.mLabelWidth, this.mLabelHeight);
        textView.setText(labelTextProvider.getLabelText(textView, i2, t));
    }

    private void clearNotCompulsorySelect() {
        int childCount = getChildCount();
        ArrayList arrayList = new ArrayList();
        for (int i2 = 0; i2 < childCount; i2++) {
            if (!this.mCompulsorys.contains(Integer.valueOf(i2))) {
                setLabelSelect((TextView) getChildAt(i2), false);
                arrayList.add(Integer.valueOf(i2));
            }
        }
        this.mSelectLabels.removeAll(arrayList);
    }

    private int dp2px(float f2) {
        return (int) TypedValue.applyDimension(1, f2, getResources().getDisplayMetrics());
    }

    private void ensureLabelClickable() {
        int childCount = getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            ((TextView) getChildAt(i2)).setClickable((this.mLabelClickListener == null && this.mLabelLongClickListener == null && this.mSelectType == SelectType.NONE) ? false : true);
        }
    }

    private void getAttrs(Context context, AttributeSet attributeSet) {
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.LabelsView);
            this.mSelectType = SelectType.get(obtainStyledAttributes.getInt(18, 1));
            this.mMaxSelect = obtainStyledAttributes.getInteger(16, 0);
            this.mMinSelect = obtainStyledAttributes.getInteger(17, 0);
            this.mMaxLines = obtainStyledAttributes.getInteger(15, 0);
            this.mMaxColumns = obtainStyledAttributes.getInteger(14, 0);
            this.isIndicator = obtainStyledAttributes.getBoolean(0, false);
            this.mLabelGravity = obtainStyledAttributes.getInt(3, this.mLabelGravity);
            this.mLabelWidth = obtainStyledAttributes.getLayoutDimension(12, this.mLabelWidth);
            this.mLabelHeight = obtainStyledAttributes.getLayoutDimension(5, this.mLabelHeight);
            if (obtainStyledAttributes.hasValue(4)) {
                this.mTextColor = obtainStyledAttributes.getColorStateList(4);
            } else {
                this.mTextColor = ColorStateList.valueOf(-16777216);
            }
            this.mTextSize = obtainStyledAttributes.getDimension(11, (float) sp2px(14.0f));
            if (obtainStyledAttributes.hasValue(6)) {
                int dimensionPixelOffset = obtainStyledAttributes.getDimensionPixelOffset(6, 0);
                this.mTextPaddingBottom = dimensionPixelOffset;
                this.mTextPaddingRight = dimensionPixelOffset;
                this.mTextPaddingTop = dimensionPixelOffset;
                this.mTextPaddingLeft = dimensionPixelOffset;
            } else {
                this.mTextPaddingLeft = obtainStyledAttributes.getDimensionPixelOffset(8, dp2px(10.0f));
                this.mTextPaddingTop = obtainStyledAttributes.getDimensionPixelOffset(10, dp2px(5.0f));
                this.mTextPaddingRight = obtainStyledAttributes.getDimensionPixelOffset(9, dp2px(10.0f));
                this.mTextPaddingBottom = obtainStyledAttributes.getDimensionPixelOffset(7, dp2px(5.0f));
            }
            this.mLineMargin = obtainStyledAttributes.getDimensionPixelOffset(13, dp2px(5.0f));
            this.mWordMargin = obtainStyledAttributes.getDimensionPixelOffset(20, dp2px(5.0f));
            if (obtainStyledAttributes.hasValue(2)) {
                int resourceId = obtainStyledAttributes.getResourceId(2, 0);
                if (resourceId != 0) {
                    this.mLabelBg = getResources().getDrawable(resourceId);
                } else {
                    this.mLabelBg = new ColorDrawable(obtainStyledAttributes.getColor(2, 0));
                }
            }
            this.isSingleLine = obtainStyledAttributes.getBoolean(19, false);
            this.isTextBold = obtainStyledAttributes.getBoolean(1, false);
            obtainStyledAttributes.recycle();
        }
    }

    private void innerClearAllSelect() {
        int childCount = getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            setLabelSelect((TextView) getChildAt(i2), false);
        }
        this.mSelectLabels.clear();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0039, code lost:
        r10 = r10 - 1;
     */
    private void measureMultiLine(int i2, int i3) {
        int i4;
        int childCount = getChildCount();
        int size = (View.MeasureSpec.getSize(i2) - getPaddingLeft()) - getPaddingRight();
        int i5 = 0;
        int i6 = 0;
        int i7 = 0;
        int i8 = 0;
        int i9 = 0;
        int i10 = 0;
        int i11 = 0;
        int i12 = 1;
        while (true) {
            if (i6 >= childCount) {
                break;
            }
            View childAt = getChildAt(i6);
            measureChild(childAt, i2, i3);
            if (childAt.getMeasuredWidth() + i7 > size || ((i4 = this.mMaxColumns) > 0 && i8 == i4)) {
                i12++;
                int i13 = this.mMaxLines;
                if (i13 > 0 && i12 > i13) {
                    break;
                }
                i10 = i10 + this.mLineMargin + i9;
                i11 = Math.max(i11, i7);
                i7 = 0;
                i8 = 0;
                i9 = 0;
            }
            i7 += childAt.getMeasuredWidth();
            i8++;
            i9 = Math.max(i9, childAt.getMeasuredHeight());
            if (i6 != childCount - 1) {
                int i14 = this.mWordMargin;
                if (i7 + i14 > size) {
                    i12++;
                    int i15 = this.mMaxLines;
                    if (i15 > 0 && i12 > i15) {
                        break;
                    }
                    i10 = i10 + this.mLineMargin + i9;
                    i11 = Math.max(i11, i7);
                    i7 = 0;
                    i8 = 0;
                    i9 = 0;
                } else {
                    i7 += i14;
                }
            }
            i6++;
        }
        setMeasuredDimension(measureSize(i2, getPaddingRight() + getPaddingLeft() + Math.max(i11, i7)), measureSize(i3, getPaddingBottom() + getPaddingTop() + i10 + i9));
        if (childCount > 0) {
            i5 = i12;
        }
        this.mLines = i5;
    }

    private void measureSingleLine(int i2, int i3) {
        int childCount = getChildCount();
        int i4 = 0;
        int i5 = 0;
        int i6 = 0;
        for (int i7 = 0; i7 < childCount; i7++) {
            int i8 = this.mMaxColumns;
            if (i8 > 0 && i7 == i8) {
                break;
            }
            View childAt = getChildAt(i7);
            measureChild(childAt, i2, i3);
            int measuredWidth = childAt.getMeasuredWidth() + i5;
            if (i7 != childCount - 1) {
                measuredWidth += this.mWordMargin;
            }
            i5 = measuredWidth;
            i6 = Math.max(i6, childAt.getMeasuredHeight());
        }
        setMeasuredDimension(measureSize(i2, getPaddingRight() + getPaddingLeft() + i5), measureSize(i3, getPaddingBottom() + getPaddingTop() + i6));
        if (childCount > 0) {
            i4 = 1;
        }
        this.mLines = i4;
    }

    private int measureSize(int i2, int i3) {
        int mode = View.MeasureSpec.getMode(i2);
        int size = View.MeasureSpec.getSize(i2);
        if (mode == 1073741824) {
            i3 = size;
        } else if (mode == Integer.MIN_VALUE) {
            i3 = Math.min(i3, size);
        }
        return ViewGroup.resolveSizeAndState(Math.max(i3, getSuggestedMinimumWidth()), i2, 0);
    }

    private boolean selectChangeIntercept(TextView textView) {
        OnSelectChangeIntercept onSelectChangeIntercept = this.mOnSelectChangeIntercept;
        if (onSelectChangeIntercept == null || !onSelectChangeIntercept.onIntercept(textView, textView.getTag(R.id.tag_key_data), textView.isSelected(), !textView.isSelected(), ((Integer) textView.getTag(R.id.tag_key_position)).intValue())) {
            return false;
        }
        return true;
    }

    private void setLabelSelect(TextView textView, boolean z) {
        if (textView.isSelected() != z) {
            textView.setSelected(z);
            if (z) {
                this.mSelectLabels.add((Integer) textView.getTag(R.id.tag_key_position));
            } else {
                this.mSelectLabels.remove((Integer) textView.getTag(R.id.tag_key_position));
            }
            OnLabelSelectChangeListener onLabelSelectChangeListener = this.mLabelSelectChangeListener;
            if (onLabelSelectChangeListener != null) {
                onLabelSelectChangeListener.onLabelSelectChange(textView, textView.getTag(R.id.tag_key_data), z, ((Integer) textView.getTag(R.id.tag_key_position)).intValue());
            }
        }
    }

    private void showEditPreview() {
        if (isInEditMode()) {
            ArrayList arrayList = new ArrayList();
            arrayList.add("Label 1");
            arrayList.add("Label 2");
            arrayList.add("Label 3");
            arrayList.add("Label 4");
            arrayList.add("Label 5");
            arrayList.add("Label 6");
            arrayList.add("Label 7");
            setLabels(arrayList);
        }
    }

    private int sp2px(float f2) {
        return (int) TypedValue.applyDimension(2, f2, getResources().getDisplayMetrics());
    }

    public void clearAllSelect() {
        SelectType selectType = this.mSelectType;
        if (selectType == SelectType.SINGLE_IRREVOCABLY) {
            return;
        }
        if (selectType != SelectType.MULTI || this.mCompulsorys.isEmpty()) {
            innerClearAllSelect();
        } else {
            clearNotCompulsorySelect();
        }
    }

    public void clearCompulsorys() {
        if (this.mSelectType == SelectType.MULTI && !this.mCompulsorys.isEmpty()) {
            this.mCompulsorys.clear();
            innerClearAllSelect();
        }
    }

    public List<Integer> getCompulsorys() {
        return this.mCompulsorys;
    }

    public int getLabelGravity() {
        return this.mLabelGravity;
    }

    public ColorStateList getLabelTextColor() {
        return this.mTextColor;
    }

    public float getLabelTextSize() {
        return this.mTextSize;
    }

    public <T> List<T> getLabels() {
        return this.mLabels;
    }

    public int getLineMargin() {
        return this.mLineMargin;
    }

    public int getLines() {
        return this.mLines;
    }

    public int getMaxColumns() {
        return this.mMaxColumns;
    }

    public int getMaxLines() {
        return this.mMaxLines;
    }

    public int getMaxSelect() {
        return this.mMaxSelect;
    }

    public int getMinSelect() {
        return this.mMinSelect;
    }

    public <T> List<T> getSelectLabelDatas() {
        ArrayList arrayList = new ArrayList();
        int size = this.mSelectLabels.size();
        for (int i2 = 0; i2 < size; i2++) {
            Object tag = getChildAt(this.mSelectLabels.get(i2).intValue()).getTag(R.id.tag_key_data);
            if (tag != null) {
                arrayList.add(tag);
            }
        }
        return arrayList;
    }

    public List<Integer> getSelectLabels() {
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(this.mSelectLabels);
        return arrayList;
    }

    public SelectType getSelectType() {
        return this.mSelectType;
    }

    public int getTextPaddingBottom() {
        return this.mTextPaddingBottom;
    }

    public int getTextPaddingLeft() {
        return this.mTextPaddingLeft;
    }

    public int getTextPaddingRight() {
        return this.mTextPaddingRight;
    }

    public int getTextPaddingTop() {
        return this.mTextPaddingTop;
    }

    public int getWordMargin() {
        return this.mWordMargin;
    }

    public boolean isIndicator() {
        return this.isIndicator;
    }

    public boolean isSingleLine() {
        return this.isSingleLine;
    }

    public boolean isTextBold() {
        return this.isTextBold;
    }

    public void onClick(View view) {
        int i2;
        if (view instanceof TextView) {
            TextView textView = (TextView) view;
            if (!this.isIndicator && this.mSelectType != SelectType.NONE) {
                boolean z = true;
                if (textView.isSelected()) {
                    SelectType selectType = this.mSelectType;
                    SelectType selectType2 = SelectType.MULTI;
                    if (!((selectType == selectType2 && this.mCompulsorys.contains((Integer) textView.getTag(R.id.tag_key_position))) || (this.mSelectType == selectType2 && this.mSelectLabels.size() <= this.mMinSelect)) && this.mSelectType != SelectType.SINGLE_IRREVOCABLY) {
                        z = false;
                    }
                    if (!z && !selectChangeIntercept(textView)) {
                        setLabelSelect(textView, false);
                    }
                } else {
                    SelectType selectType3 = this.mSelectType;
                    if (selectType3 == SelectType.SINGLE || selectType3 == SelectType.SINGLE_IRREVOCABLY) {
                        if (!selectChangeIntercept(textView)) {
                            innerClearAllSelect();
                            setLabelSelect(textView, true);
                        }
                    } else if (selectType3 == SelectType.MULTI && (((i2 = this.mMaxSelect) <= 0 || i2 > this.mSelectLabels.size()) && !selectChangeIntercept(textView))) {
                        setLabelSelect(textView, true);
                    }
                }
            }
            OnLabelClickListener onLabelClickListener = this.mLabelClickListener;
            if (onLabelClickListener != null) {
                onLabelClickListener.onLabelClick(textView, textView.getTag(R.id.tag_key_data), ((Integer) textView.getTag(R.id.tag_key_position)).intValue());
            }
        }
    }

    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        int i6;
        int i7;
        int paddingLeft = getPaddingLeft();
        int paddingTop = getPaddingTop();
        int i8 = i4 - i2;
        int childCount = getChildCount();
        int i9 = 1;
        int i10 = 0;
        int i11 = 0;
        for (int i12 = 0; i12 < childCount; i12++) {
            View childAt = getChildAt(i12);
            if (!this.isSingleLine) {
                if (i8 < getPaddingRight() + childAt.getMeasuredWidth() + paddingLeft || ((i7 = this.mMaxColumns) > 0 && i10 == i7)) {
                    i9++;
                    int i13 = this.mMaxLines;
                    if (i13 <= 0 || i9 <= i13) {
                        paddingLeft = getPaddingLeft();
                        paddingTop = paddingTop + this.mLineMargin + i11;
                        i10 = 0;
                        i11 = 0;
                    } else {
                        return;
                    }
                }
            }
            if (!this.isSingleLine || (i6 = this.mMaxColumns) <= 0 || i10 != i6) {
                childAt.layout(paddingLeft, paddingTop, childAt.getMeasuredWidth() + paddingLeft, childAt.getMeasuredHeight() + paddingTop);
                paddingLeft = this.mWordMargin + childAt.getMeasuredWidth() + paddingLeft;
                i11 = Math.max(i11, childAt.getMeasuredHeight());
                i10++;
            } else {
                return;
            }
        }
    }

    public void onMeasure(int i2, int i3) {
        if (this.isSingleLine) {
            measureSingleLine(i2, i3);
        } else {
            measureMultiLine(i2, i3);
        }
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof Bundle) {
            Bundle bundle = (Bundle) parcelable;
            super.onRestoreInstanceState(bundle.getParcelable(KEY_SUPER_STATE));
            ColorStateList colorStateList = (ColorStateList) bundle.getParcelable(KEY_TEXT_COLOR_STATE);
            if (colorStateList != null) {
                setLabelTextColor(colorStateList);
            }
            setLabelTextSize(bundle.getFloat(KEY_TEXT_SIZE_STATE, this.mTextSize));
            this.mLabelWidth = bundle.getInt(KEY_LABEL_WIDTH_STATE, this.mLabelWidth);
            this.mLabelHeight = bundle.getInt(KEY_LABEL_HEIGHT_STATE, this.mLabelHeight);
            setLabelGravity(bundle.getInt(KEY_LABEL_GRAVITY_STATE, this.mLabelGravity));
            int[] intArray = bundle.getIntArray(KEY_PADDING_STATE);
            if (intArray != null && intArray.length == 4) {
                setLabelTextPadding(intArray[0], intArray[1], intArray[2], intArray[3]);
            }
            setWordMargin(bundle.getInt(KEY_WORD_MARGIN_STATE, this.mWordMargin));
            setLineMargin(bundle.getInt(KEY_LINE_MARGIN_STATE, this.mLineMargin));
            setSelectType(SelectType.get(bundle.getInt(KEY_SELECT_TYPE_STATE, this.mSelectType.value)));
            setMaxSelect(bundle.getInt(KEY_MAX_SELECT_STATE, this.mMaxSelect));
            setMinSelect(bundle.getInt(KEY_MIN_SELECT_STATE, this.mMinSelect));
            setMaxLines(bundle.getInt(KEY_MAX_LINES_STATE, this.mMaxLines));
            setMaxLines(bundle.getInt(KEY_MAX_COLUMNS_STATE, this.mMaxColumns));
            setIndicator(bundle.getBoolean(KEY_INDICATOR_STATE, this.isIndicator));
            setSingleLine(bundle.getBoolean(KEY_SINGLE_LINE_STATE, this.isSingleLine));
            setTextBold(bundle.getBoolean(KEY_TEXT_STYLE_STATE, this.isTextBold));
            ArrayList<Integer> integerArrayList = bundle.getIntegerArrayList(KEY_COMPULSORY_LABELS_STATE);
            if (integerArrayList != null && !integerArrayList.isEmpty()) {
                setCompulsorys(integerArrayList);
            }
            ArrayList<Integer> integerArrayList2 = bundle.getIntegerArrayList(KEY_SELECT_LABELS_STATE);
            if (!(integerArrayList2 == null || integerArrayList2.isEmpty())) {
                int size = integerArrayList2.size();
                int[] iArr = new int[size];
                for (int i2 = 0; i2 < size; i2++) {
                    iArr[i2] = integerArrayList2.get(i2).intValue();
                }
                setSelects(iArr);
                return;
            }
            return;
        }
        super.onRestoreInstanceState(parcelable);
    }

    public Parcelable onSaveInstanceState() {
        Bundle bundle = new Bundle();
        bundle.putParcelable(KEY_SUPER_STATE, super.onSaveInstanceState());
        ColorStateList colorStateList = this.mTextColor;
        if (colorStateList != null) {
            bundle.putParcelable(KEY_TEXT_COLOR_STATE, colorStateList);
        }
        bundle.putFloat(KEY_TEXT_SIZE_STATE, this.mTextSize);
        bundle.putInt(KEY_LABEL_WIDTH_STATE, this.mLabelWidth);
        bundle.putInt(KEY_LABEL_HEIGHT_STATE, this.mLabelHeight);
        bundle.putInt(KEY_LABEL_GRAVITY_STATE, this.mLabelGravity);
        bundle.putIntArray(KEY_PADDING_STATE, new int[]{this.mTextPaddingLeft, this.mTextPaddingTop, this.mTextPaddingRight, this.mTextPaddingBottom});
        bundle.putInt(KEY_WORD_MARGIN_STATE, this.mWordMargin);
        bundle.putInt(KEY_LINE_MARGIN_STATE, this.mLineMargin);
        bundle.putInt(KEY_SELECT_TYPE_STATE, this.mSelectType.value);
        bundle.putInt(KEY_MAX_SELECT_STATE, this.mMaxSelect);
        bundle.putInt(KEY_MIN_SELECT_STATE, this.mMinSelect);
        bundle.putInt(KEY_MAX_LINES_STATE, this.mMaxLines);
        bundle.putInt(KEY_MAX_COLUMNS_STATE, this.mMaxColumns);
        bundle.putBoolean(KEY_INDICATOR_STATE, this.isIndicator);
        if (!this.mSelectLabels.isEmpty()) {
            bundle.putIntegerArrayList(KEY_SELECT_LABELS_STATE, this.mSelectLabels);
        }
        if (!this.mCompulsorys.isEmpty()) {
            bundle.putIntegerArrayList(KEY_COMPULSORY_LABELS_STATE, this.mCompulsorys);
        }
        bundle.putBoolean(KEY_SINGLE_LINE_STATE, this.isSingleLine);
        bundle.putBoolean(KEY_TEXT_STYLE_STATE, this.isTextBold);
        return bundle;
    }

    public void setCompulsorys(List<Integer> list) {
        if (this.mSelectType == SelectType.MULTI && list != null) {
            this.mCompulsorys.clear();
            this.mCompulsorys.addAll(list);
            innerClearAllSelect();
            setSelects(list);
        }
    }

    public void setIndicator(boolean z) {
        this.isIndicator = z;
    }

    public void setLabelBackgroundColor(int i2) {
        setLabelBackgroundDrawable(new ColorDrawable(i2));
    }

    public void setLabelBackgroundDrawable(Drawable drawable) {
        this.mLabelBg = drawable;
        int childCount = getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            ((TextView) getChildAt(i2)).setBackgroundDrawable(this.mLabelBg.getConstantState().newDrawable());
        }
    }

    public void setLabelBackgroundResource(int i2) {
        setLabelBackgroundDrawable(getResources().getDrawable(i2));
    }

    public void setLabelGravity(int i2) {
        if (this.mLabelGravity != i2) {
            this.mLabelGravity = i2;
            int childCount = getChildCount();
            for (int i3 = 0; i3 < childCount; i3++) {
                ((TextView) getChildAt(i3)).setGravity(i2);
            }
        }
    }

    public void setLabelTextColor(int i2) {
        setLabelTextColor(ColorStateList.valueOf(i2));
    }

    public void setLabelTextPadding(int i2, int i3, int i4, int i5) {
        if (!(this.mTextPaddingLeft == i2 && this.mTextPaddingTop == i3 && this.mTextPaddingRight == i4 && this.mTextPaddingBottom == i5)) {
            this.mTextPaddingLeft = i2;
            this.mTextPaddingTop = i3;
            this.mTextPaddingRight = i4;
            this.mTextPaddingBottom = i5;
            int childCount = getChildCount();
            for (int i6 = 0; i6 < childCount; i6++) {
                ((TextView) getChildAt(i6)).setPadding(i2, i3, i4, i5);
            }
        }
    }

    public void setLabelTextSize(float f2) {
        if (this.mTextSize != f2) {
            this.mTextSize = f2;
            int childCount = getChildCount();
            for (int i2 = 0; i2 < childCount; i2++) {
                ((TextView) getChildAt(i2)).setTextSize(0, f2);
            }
        }
    }

    public void setLabels(List<String> list) {
        setLabels(list, new LabelTextProvider<String>() {
            /* class com.grass.mh.widget.LabelsView.AnonymousClass1 */

            public CharSequence getLabelText(TextView textView, int i2, String str) {
                return str.trim();
            }
        });
    }

    public void setLineMargin(int i2) {
        if (this.mLineMargin != i2) {
            this.mLineMargin = i2;
            requestLayout();
        }
    }

    public void setMaxColumns(int i2) {
        if (this.mMaxColumns != i2) {
            this.mMaxColumns = i2;
            requestLayout();
        }
    }

    public void setMaxLines(int i2) {
        if (this.mMaxLines != i2) {
            this.mMaxLines = i2;
            requestLayout();
        }
    }

    public void setMaxSelect(int i2) {
        if (this.mMaxSelect != i2) {
            this.mMaxSelect = i2;
            if (this.mSelectType == SelectType.MULTI) {
                innerClearAllSelect();
            }
        }
    }

    public void setMinSelect(int i2) {
        this.mMinSelect = i2;
    }

    public void setOnLabelClickListener(OnLabelClickListener onLabelClickListener) {
        this.mLabelClickListener = onLabelClickListener;
        ensureLabelClickable();
    }

    public void setOnLabelLongClickListener(OnLabelLongClickListener onLabelLongClickListener) {
        this.mLabelLongClickListener = onLabelLongClickListener;
        ensureLabelClickable();
    }

    public void setOnLabelSelectChangeListener(OnLabelSelectChangeListener onLabelSelectChangeListener) {
        this.mLabelSelectChangeListener = onLabelSelectChangeListener;
    }

    public void setOnSelect(int i2) {
    }

    public void setOnSelectChangeIntercept(OnSelectChangeIntercept onSelectChangeIntercept) {
        this.mOnSelectChangeIntercept = onSelectChangeIntercept;
    }

    public void setSelectType(SelectType selectType) {
        if (this.mSelectType != selectType) {
            this.mSelectType = selectType;
            innerClearAllSelect();
            if (this.mSelectType == SelectType.SINGLE_IRREVOCABLY) {
                setSelects(0);
            }
            if (this.mSelectType != SelectType.MULTI) {
                this.mCompulsorys.clear();
            }
            ensureLabelClickable();
        }
    }

    public void setSelects(List<Integer> list) {
        if (list != null) {
            int size = list.size();
            int[] iArr = new int[size];
            for (int i2 = 0; i2 < size; i2++) {
                iArr[i2] = list.get(i2).intValue();
            }
            setSelects(iArr);
        }
    }

    public void setSingleLine(boolean z) {
        if (this.isSingleLine != z) {
            this.isSingleLine = z;
            requestLayout();
        }
    }

    public void setTextBold(boolean z) {
        if (this.isTextBold != z) {
            this.isTextBold = z;
            int childCount = getChildCount();
            for (int i2 = 0; i2 < childCount; i2++) {
                TextView textView = (TextView) getChildAt(i2);
                textView.getPaint().setFakeBoldText(this.isTextBold);
                textView.invalidate();
            }
        }
    }

    public void setWordMargin(int i2) {
        if (this.mWordMargin != i2) {
            this.mWordMargin = i2;
            requestLayout();
        }
    }

    public void setLabelTextColor(ColorStateList colorStateList) {
        this.mTextColor = colorStateList;
        int childCount = getChildCount();
        for (int i2 = 0; i2 < childCount; i2++) {
            ((TextView) getChildAt(i2)).setTextColor(this.mTextColor);
        }
    }

    public <T> void setLabels(List<T> list, LabelTextProvider<T> labelTextProvider) {
        innerClearAllSelect();
        removeAllViews();
        this.mLabels.clear();
        if (list != null) {
            this.mLabels.addAll(list);
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                addLabel(list.get(i2), i2, labelTextProvider);
            }
            ensureLabelClickable();
        }
        if (this.mSelectType == SelectType.SINGLE_IRREVOCABLY) {
            setSelects(0);
        }
    }

    public void setSelects(int... iArr) {
        if (this.mSelectType != SelectType.NONE) {
            ArrayList arrayList = new ArrayList();
            int childCount = getChildCount();
            SelectType selectType = this.mSelectType;
            int i2 = (selectType == SelectType.SINGLE || selectType == SelectType.SINGLE_IRREVOCABLY) ? 1 : this.mMaxSelect;
            for (int i3 : iArr) {
                if (i3 < childCount) {
                    TextView textView = (TextView) getChildAt(i3);
                    if (!arrayList.contains(textView)) {
                        setLabelSelect(textView, true);
                        arrayList.add(textView);
                    }
                    if (i2 > 0 && arrayList.size() == i2) {
                        break;
                    }
                }
            }
            for (int i4 = 0; i4 < childCount; i4++) {
                TextView textView2 = (TextView) getChildAt(i4);
                if (!arrayList.contains(textView2)) {
                    setLabelSelect(textView2, false);
                }
            }
        }
    }

    public void setCompulsorys(int... iArr) {
        if (this.mSelectType == SelectType.MULTI && iArr != null) {
            ArrayList arrayList = new ArrayList(iArr.length);
            for (int i2 : iArr) {
                arrayList.add(Integer.valueOf(i2));
            }
            setCompulsorys(arrayList);
        }
    }

    public LabelsView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mContext = context;
        getAttrs(context, attributeSet);
        showEditPreview();
    }

    public LabelsView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mContext = context;
        getAttrs(context, attributeSet);
        showEditPreview();
    }
}
