package com.just.agentweb;

import android.app.Activity;
import android.content.Context;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;
import android.webkit.DownloadListener;
import android.webkit.WebView;
import com.androidx.lv.base.utils.ToastUtils;
import com.download.library.DownloadTask;
import com.download.library.Extra;
import com.just.agentweb.AgentActionFragment;
import com.lzy.okgo.model.HttpHeaders;
import d.e.a.c0;
import d.e.a.d0;
import d.e.a.e;
import d.e.a.g;
import d.e.a.o;
import d.e.a.r;
import d.e.a.u;
import d.e.a.x;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.ConcurrentHashMap;

public class DefaultDownloadImpl implements DownloadListener {
    private static final String TAG = DefaultDownloadImpl.class.getSimpleName();
    private static Handler mHandler = new Handler(Looper.getMainLooper());
    private boolean clickLimit = true;
    private boolean isInstallDownloader;
    private long lastClickTime;
    public WeakReference<Activity> mActivityWeakReference = null;
    public WeakReference<AbsAgentWebUIController> mAgentWebUIController;
    public Context mContext;
    public ConcurrentHashMap<String, c0> mDownloadTasks = new ConcurrentHashMap<>();
    public PermissionInterceptor mPermissionListener = null;

    public DefaultDownloadImpl(Activity activity, WebView webView, PermissionInterceptor permissionInterceptor) {
        this.mContext = activity.getApplicationContext();
        this.mActivityWeakReference = new WeakReference<>(activity);
        this.mPermissionListener = permissionInterceptor;
        this.mAgentWebUIController = new WeakReference<>(AgentWebUtils.getAgentWebUIControllerByWebView(webView));
        try {
            e.c(this.mContext);
            this.isInstallDownloader = true;
        } catch (Throwable th) {
            LogUtils.e(TAG, "implementation 'com.download.library:Downloader:x.x.x'");
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
            this.isInstallDownloader = false;
        }
    }

    public static DefaultDownloadImpl create(Activity activity, WebView webView, PermissionInterceptor permissionInterceptor) {
        return new DefaultDownloadImpl(activity, webView, permissionInterceptor);
    }

    public List<String> checkNeedPermission() {
        ArrayList arrayList = new ArrayList();
        String[] strArr = AgentWebPermissions.STORAGE;
        if (!AgentWebUtils.hasPermission(this.mActivityWeakReference.get(), strArr)) {
            arrayList.addAll(Arrays.asList(strArr));
        }
        return arrayList;
    }

    public Handler.Callback createCallback(final String str) {
        return new Handler.Callback() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass3 */

            public boolean handleMessage(Message message) {
                DefaultDownloadImpl.this.forceDownload(str);
                return true;
            }
        };
    }

    public c0 createResourceRequest(String str) {
        DownloadTask clone;
        Objects.requireNonNull(e.c(this.mContext));
        Context context = e.f8454b;
        c0 c0Var = new c0();
        d0 d0Var = d0.f8443a;
        synchronized (d0Var) {
            if (d0Var.f8446d == null) {
                d0Var.b();
            }
            clone = d0Var.f8446d.clone();
        }
        c0Var.f8441a = clone;
        clone.setContext(context);
        c0Var.f8441a.setUrl(str);
        DownloadTask downloadTask = c0Var.f8441a;
        downloadTask.mEnableIndicator = true;
        downloadTask.autoOpenIgnoreMD5();
        return c0Var;
    }

    public void forceDownload(String str) {
        this.mDownloadTasks.get(str).f8441a.mIsForceDownload = true;
        performDownload(str);
    }

    public AgentActionFragment.PermissionListener getPermissionListener(final String str) {
        return new AgentActionFragment.PermissionListener() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass2 */

            @Override // com.just.agentweb.AgentActionFragment.PermissionListener
            public void onRequestPermissionsResult(String[] strArr, int[] iArr, Bundle bundle) {
                if (DefaultDownloadImpl.this.checkNeedPermission().isEmpty()) {
                    DefaultDownloadImpl.this.preDownload(str);
                    return;
                }
                if (DefaultDownloadImpl.this.mAgentWebUIController.get() != null) {
                    DefaultDownloadImpl.this.mAgentWebUIController.get().onPermissionsDeny((String[]) DefaultDownloadImpl.this.checkNeedPermission().toArray(new String[0]), AgentWebPermissions.ACTION_STORAGE, "Download");
                }
                LogUtils.e(DefaultDownloadImpl.TAG, "储存权限获取失败~");
            }
        };
    }

    public boolean isForceRequest(String str) {
        c0 c0Var = this.mDownloadTasks.get(str);
        if (c0Var != null) {
            return c0Var.f8441a.isForceDownload();
        }
        return false;
    }

    public boolean isOnClick() {
        long currentTimeMillis = System.currentTimeMillis();
        long j2 = currentTimeMillis - this.lastClickTime;
        int i2 = (j2 > 2000 ? 1 : (j2 == 2000 ? 0 : -1));
        if (i2 > 0) {
            this.lastClickTime = currentTimeMillis;
        }
        return !this.clickLimit ? j2 < 0 : i2 <= 0;
    }

    public void onDownloadStart(final String str, final String str2, final String str3, final String str4, final long j2) {
        if (!isOnClick()) {
            ToastUtils.getInstance().showCorrect("开始下载");
        }
        if (!this.isInstallDownloader) {
            String str5 = TAG;
            LogUtils.e(str5, "unable start download " + str + "; implementation 'com.download.library:Downloader:x.x.x'");
            return;
        }
        mHandler.post(new Runnable() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass1 */

            public void run() {
                DefaultDownloadImpl.this.onDownloadStartInternal(str, str2, str3, str4, j2);
            }
        });
    }

    public void onDownloadStartInternal(String str, String str2, String str3, String str4, long j2) {
        if (this.mActivityWeakReference.get() != null && !this.mActivityWeakReference.get().isFinishing()) {
            PermissionInterceptor permissionInterceptor = this.mPermissionListener;
            if (permissionInterceptor == null || !permissionInterceptor.intercept(str, AgentWebPermissions.STORAGE, "download")) {
                this.mDownloadTasks.put(str, createResourceRequest(str));
                if (Build.VERSION.SDK_INT >= 23) {
                    List<String> checkNeedPermission = checkNeedPermission();
                    if (checkNeedPermission.isEmpty()) {
                        preDownload(str);
                        return;
                    }
                    Action createPermissionsAction = Action.createPermissionsAction((String[]) checkNeedPermission.toArray(new String[0]));
                    createPermissionsAction.setPermissionListener(getPermissionListener(str));
                    AgentActionFragment.start(this.mActivityWeakReference.get(), createPermissionsAction);
                    return;
                }
                preDownload(str);
            }
        }
    }

    public void performDownload(String str) {
        try {
            String str2 = TAG;
            LogUtils.e(str2, "performDownload:" + str + " exist:" + e.c(this.mContext).b(str));
            if (!e.c(this.mContext).b(str)) {
                c0 c0Var = this.mDownloadTasks.get(str);
                String cookiesByUrl = AgentWebConfig.getCookiesByUrl(str);
                DownloadTask downloadTask = c0Var.f8441a;
                if (downloadTask.mHeaders == null) {
                    downloadTask.mHeaders = new HashMap<>();
                }
                c0Var.f8441a.mHeaders.put(HttpHeaders.HEAD_KEY_COOKIE, cookiesByUrl);
                taskEnqueue(c0Var);
            } else if (this.mAgentWebUIController.get() != null) {
                this.mAgentWebUIController.get().onShowMessage(this.mActivityWeakReference.get().getString(R.string.agentweb_download_task_has_been_exist), "preDownload");
            }
        } catch (Throwable th) {
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
        }
    }

    public void preDownload(String str) {
        if (isForceRequest(str) || AgentWebUtils.checkNetworkType(this.mContext) <= 1) {
            performDownload(str);
        } else {
            showDialog(str);
        }
    }

    public void showDialog(String str) {
        AbsAgentWebUIController absAgentWebUIController;
        Activity activity = this.mActivityWeakReference.get();
        if (activity != null && !activity.isFinishing() && (absAgentWebUIController = this.mAgentWebUIController.get()) != null) {
            absAgentWebUIController.onForceDownloadAlert(str, createCallback(str));
        }
    }

    public void taskEnqueue(c0 c0Var) {
        c0Var.f8441a.setDownloadListenerAdapter(new g() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass4 */

            @Override // d.e.a.g, d.e.a.f
            public boolean onResult(Throwable th, Uri uri, String str, Extra extra) {
                DefaultDownloadImpl.this.mDownloadTasks.remove(str);
                return super.onResult(th, uri, str, extra);
            }
        });
        e c2 = e.c(c0Var.f8441a.mContext);
        DownloadTask downloadTask = c0Var.f8441a;
        Objects.requireNonNull(c2);
        Objects.requireNonNull(downloadTask.getContext(), "context can't be null .");
        if (!TextUtils.isEmpty(downloadTask.getUrl())) {
            String str = r.f8491a;
            r rVar = r.c.f8507a;
            Objects.requireNonNull(rVar);
            boolean z = false;
            if (!TextUtils.isEmpty(downloadTask.getUrl())) {
                synchronized (rVar.f8495e) {
                    x xVar = x.b.f8523a;
                    if (xVar.a(downloadTask.getUrl())) {
                        String str2 = r.f8491a;
                        Log.e(str2, "task exists:" + downloadTask.getUrl());
                        return;
                    }
                    u uVar = new u();
                    uVar.f8513e = downloadTask;
                    uVar.f8515g = downloadTask.getTotalsLength();
                    uVar.f8520l = downloadTask.getDownloadTimeOut();
                    uVar.m = downloadTask.getConnectTimeOut();
                    uVar.p = downloadTask.isQuickProgress();
                    if (downloadTask.isEnableIndicator() || downloadTask.getDownloadingListener() != null) {
                        z = true;
                    }
                    uVar.n = z;
                    String url = downloadTask.getUrl();
                    if (url != null) {
                        xVar.f8522a.put(url, uVar);
                    }
                    rVar.f8492b.execute(new o(rVar, new r.a(downloadTask, uVar)));
                    return;
                }
            }
            return;
        }
        throw new NullPointerException("url can't be empty .");
    }
}
