package com.just.agentweb;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.graphics.Bitmap;
import android.net.Uri;
import android.net.http.SslError;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.view.KeyEvent;
import android.webkit.HttpAuthHandler;
import android.webkit.SslErrorHandler;
import android.webkit.WebResourceError;
import android.webkit.WebResourceRequest;
import android.webkit.WebResourceResponse;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import com.alipay.sdk.app.H5PayCallback;
import com.alipay.sdk.app.PayTask;
import com.alipay.sdk.util.H5PayResultModel;
import d.a.a.a.a;
import java.lang.ref.WeakReference;
import java.lang.reflect.Method;
import java.net.URISyntaxException;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class DefaultWebClient extends MiddlewareWebClientBase {
    public static final String ALIPAYS_SCHEME = "alipays://";
    public static final int ASK_USER_OPEN_OTHER_PAGE = 250;
    private static final int CONSTANTS_ABNORMAL_BIG = 7;
    public static final int DERECT_OPEN_OTHER_PAGE = 1001;
    public static final int DISALLOW_OPEN_OTHER_APP = 62;
    private static final boolean HAS_ALIPAY_LIB;
    public static final String HTTPS_SCHEME = "https://";
    public static final String HTTP_SCHEME = "http://";
    public static final String INTENT_SCHEME = "intent://";
    public static final String SCHEME_SMS = "sms:";
    private static final String TAG = DefaultWebClient.class.getSimpleName();
    public static final String WEBCHAT_PAY_SCHEME = "weixin://wap/pay?";
    private WeakReference<AbsAgentWebUIController> mAgentWebUIController = null;
    private Handler.Callback mCallback = null;
    private Set<String> mErrorUrlsSet = new HashSet();
    private boolean mIsInterceptUnkownUrl = true;
    private Object mPayTask;
    private int mUrlHandleWays = 250;
    private Set<String> mWaittingFinishSet = new HashSet();
    private WeakReference<Activity> mWeakReference = null;
    private WebView mWebView;
    private WebViewClient mWebViewClient;
    private Method onMainFrameErrorMethod = null;
    private boolean webClientHelper = true;

    public static class Builder {
        private Activity mActivity;
        private WebViewClient mClient;
        private boolean mIsInterceptUnkownScheme = true;
        private PermissionInterceptor mPermissionInterceptor;
        private int mUrlHandleWays;
        private boolean mWebClientHelper;
        private WebView mWebView;

        public DefaultWebClient build() {
            return new DefaultWebClient(this);
        }

        public Builder setActivity(Activity activity) {
            this.mActivity = activity;
            return this;
        }

        public Builder setClient(WebViewClient webViewClient) {
            this.mClient = webViewClient;
            return this;
        }

        public Builder setInterceptUnkownUrl(boolean z) {
            this.mIsInterceptUnkownScheme = z;
            return this;
        }

        public Builder setPermissionInterceptor(PermissionInterceptor permissionInterceptor) {
            this.mPermissionInterceptor = permissionInterceptor;
            return this;
        }

        public Builder setUrlHandleWays(int i2) {
            this.mUrlHandleWays = i2;
            return this;
        }

        public Builder setWebClientHelper(boolean z) {
            this.mWebClientHelper = z;
            return this;
        }

        public Builder setWebView(WebView webView) {
            this.mWebView = webView;
            return this;
        }
    }

    public enum OpenOtherPageWays {
        DERECT(1001),
        ASK(250),
        DISALLOW(62);
        
        public int code;

        private OpenOtherPageWays(int i2) {
            this.code = i2;
        }
    }

    static {
        boolean z;
        try {
            Class.forName("com.alipay.sdk.app.PayTask");
            z = true;
        } catch (Throwable unused) {
            z = false;
        }
        HAS_ALIPAY_LIB = z;
        String str = TAG;
        LogUtils.i(str, "HAS_ALIPAY_LIB:" + z);
    }

    public DefaultWebClient(Builder builder) {
        super(builder.mClient);
        this.mWebView = builder.mWebView;
        this.mWebViewClient = builder.mClient;
        this.mWeakReference = new WeakReference<>(builder.mActivity);
        this.webClientHelper = builder.mWebClientHelper;
        this.mAgentWebUIController = new WeakReference<>(AgentWebUtils.getAgentWebUIControllerByWebView(builder.mWebView));
        this.mIsInterceptUnkownUrl = builder.mIsInterceptUnkownScheme;
        if (builder.mUrlHandleWays <= 0) {
            this.mUrlHandleWays = 250;
        } else {
            this.mUrlHandleWays = builder.mUrlHandleWays;
        }
    }

    public static Builder createBuilder() {
        return new Builder();
    }

    private boolean deepLink(String str) {
        ResolveInfo lookupResolveInfo;
        int i2 = this.mUrlHandleWays;
        if (i2 == 250) {
            Activity activity = this.mWeakReference.get();
            if (activity == null || (lookupResolveInfo = lookupResolveInfo(str)) == null) {
                return false;
            }
            ActivityInfo activityInfo = lookupResolveInfo.activityInfo;
            String str2 = TAG;
            StringBuilder B = a.B("resolve package:");
            B.append(lookupResolveInfo.activityInfo.packageName);
            B.append(" app package:");
            B.append(activity.getPackageName());
            LogUtils.e(str2, B.toString());
            if (activityInfo != null && !TextUtils.isEmpty(activityInfo.packageName) && activityInfo.packageName.equals(activity.getPackageName())) {
                return lookup(str);
            }
            if (this.mAgentWebUIController.get() != null) {
                WebView webView = this.mWebView;
                this.mAgentWebUIController.get().onOpenPagePrompt(webView, webView.getUrl(), getCallback(str));
            }
            return true;
        } else if (i2 != 1001) {
            return false;
        } else {
            lookup(str);
            return true;
        }
    }

    private Handler.Callback getCallback(final String str) {
        Handler.Callback callback = this.mCallback;
        if (callback != null) {
            return callback;
        }
        AnonymousClass2 r0 = new Handler.Callback() {
            /* class com.just.agentweb.DefaultWebClient.AnonymousClass2 */

            public boolean handleMessage(Message message) {
                if (message.what != 1) {
                    return true;
                }
                DefaultWebClient.this.lookup(str);
                return true;
            }
        };
        this.mCallback = r0;
        return r0;
    }

    private boolean handleCommonLink(String str) {
        if (!str.startsWith("tel:") && !str.startsWith(SCHEME_SMS) && !str.startsWith("mailto:") && !str.startsWith("geo:0,0?q=")) {
            return false;
        }
        try {
            Activity activity = this.mWeakReference.get();
            if (activity == null) {
                return false;
            }
            Intent intent = new Intent("android.intent.action.VIEW");
            intent.setData(Uri.parse(str));
            activity.startActivity(intent);
            return true;
        } catch (ActivityNotFoundException e2) {
            if (!AgentWebConfig.DEBUG) {
                return true;
            }
            e2.printStackTrace();
            return true;
        }
    }

    private void handleIntentUrl(String str) {
        try {
            if (TextUtils.isEmpty(str)) {
                return;
            }
            if (str.startsWith(INTENT_SCHEME)) {
                if (!lookup(str)) {
                }
            }
        } catch (Throwable th) {
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
        }
    }

    private boolean isAlipay(final WebView webView, String str) {
        try {
            Activity activity = this.mWeakReference.get();
            if (activity == null) {
                return false;
            }
            if (this.mPayTask == null) {
                this.mPayTask = Class.forName("com.alipay.sdk.app.PayTask").getConstructor(Activity.class).newInstance(activity);
            }
            boolean payInterceptorWithUrl = ((PayTask) this.mPayTask).payInterceptorWithUrl(str, true, new H5PayCallback() {
                /* class com.just.agentweb.DefaultWebClient.AnonymousClass1 */

                public void onPayResult(H5PayResultModel h5PayResultModel) {
                    final String returnUrl = h5PayResultModel.getReturnUrl();
                    if (!TextUtils.isEmpty(returnUrl)) {
                        AgentWebUtils.runInUiThread(new Runnable() {
                            /* class com.just.agentweb.DefaultWebClient.AnonymousClass1.AnonymousClass1 */

                            public void run() {
                                webView.loadUrl(returnUrl);
                            }
                        });
                    }
                }
            });
            if (payInterceptorWithUrl) {
                String str2 = TAG;
                LogUtils.i(str2, "alipay-isIntercepted:" + payInterceptorWithUrl + "  url:" + str);
            }
            return payInterceptorWithUrl;
        } catch (Throwable unused) {
            boolean z = AgentWebConfig.DEBUG;
            return false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean lookup(String str) {
        try {
            Activity activity = this.mWeakReference.get();
            if (activity == null) {
                return true;
            }
            PackageManager packageManager = activity.getPackageManager();
            Intent parseUri = Intent.parseUri(str, 1);
            if (packageManager.resolveActivity(parseUri, 65536) == null) {
                return false;
            }
            activity.startActivity(parseUri);
            return true;
        } catch (Throwable th) {
            if (!LogUtils.isDebug()) {
                return false;
            }
            th.printStackTrace();
            return false;
        }
    }

    private ResolveInfo lookupResolveInfo(String str) {
        try {
            Activity activity = this.mWeakReference.get();
            if (activity == null) {
                return null;
            }
            return activity.getPackageManager().resolveActivity(Intent.parseUri(str, 1), 65536);
        } catch (Throwable th) {
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
            return null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:7:0x0033, code lost:
        if (r2 != null) goto L_0x0035;
     */
    private void onMainFrameError(WebView webView, int i2, String str, String str2) {
        this.mErrorUrlsSet.add(str2);
        WebViewClient webViewClient = this.mWebViewClient;
        if (webViewClient != null && this.webClientHelper) {
            Method method = this.onMainFrameErrorMethod;
            if (method == null) {
                method = AgentWebUtils.isExistMethod(webViewClient, "onMainFrameError", AbsAgentWebUIController.class, WebView.class, Integer.TYPE, String.class, String.class);
                this.onMainFrameErrorMethod = method;
            }
            try {
                method.invoke(this.mWebViewClient, this.mAgentWebUIController.get(), webView, Integer.valueOf(i2), str, str2);
                return;
            } catch (Throwable th) {
                if (LogUtils.isDebug()) {
                    th.printStackTrace();
                    return;
                }
                return;
            }
        }
        if (this.mAgentWebUIController.get() != null) {
            this.mAgentWebUIController.get().onMainFrameError(webView, i2, str, str2);
        }
    }

    private int queryActiviesNumber(String str) {
        try {
            if (this.mWeakReference.get() == null) {
                return 0;
            }
            List<ResolveInfo> queryIntentActivities = this.mWeakReference.get().getPackageManager().queryIntentActivities(Intent.parseUri(str, 1), 65536);
            if (queryIntentActivities == null) {
                return 0;
            }
            return queryIntentActivities.size();
        } catch (URISyntaxException e2) {
            if (LogUtils.isDebug()) {
                e2.printStackTrace();
            }
            return 0;
        }
    }

    private void startActivity(String str) {
        try {
            if (this.mWeakReference.get() != null) {
                Intent intent = new Intent();
                intent.setAction("android.intent.action.VIEW");
                intent.setData(Uri.parse(str));
                this.mWeakReference.get().startActivity(intent);
            }
        } catch (Exception e2) {
            if (LogUtils.isDebug()) {
                e2.printStackTrace();
            }
        }
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void doUpdateVisitedHistory(WebView webView, String str, boolean z) {
        if (!this.mWaittingFinishSet.contains(str)) {
            this.mWaittingFinishSet.add(str);
        }
        super.doUpdateVisitedHistory(webView, str, z);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onPageFinished(WebView webView, String str) {
        if (this.mErrorUrlsSet.contains(str) || !this.mWaittingFinishSet.contains(str)) {
            webView.setVisibility(0);
        } else if (this.mAgentWebUIController.get() != null) {
            this.mAgentWebUIController.get().onShowMainFrame();
        }
        if (this.mWaittingFinishSet.contains(str)) {
            this.mWaittingFinishSet.remove(str);
        }
        if (!this.mErrorUrlsSet.isEmpty()) {
            this.mErrorUrlsSet.clear();
        }
        super.onPageFinished(webView, str);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onPageStarted(WebView webView, String str, Bitmap bitmap) {
        if (!this.mWaittingFinishSet.contains(str)) {
            this.mWaittingFinishSet.add(str);
        }
        super.onPageStarted(webView, str, bitmap);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onReceivedError(WebView webView, int i2, String str, String str2) {
        String str3 = TAG;
        LogUtils.i(str3, "onReceivedError：" + str + "  CODE:" + i2);
        if ((str2 == null && i2 != -12) || i2 == -1) {
            return;
        }
        if (i2 == -2 || str2 == null || str2.equals(webView.getUrl()) || str2.equals(webView.getOriginalUrl())) {
            onMainFrameError(webView, i2, str, str2);
        }
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onReceivedHttpAuthRequest(WebView webView, HttpAuthHandler httpAuthHandler, String str, String str2) {
        super.onReceivedHttpAuthRequest(webView, httpAuthHandler, str, str2);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onReceivedHttpError(WebView webView, WebResourceRequest webResourceRequest, WebResourceResponse webResourceResponse) {
        super.onReceivedHttpError(webView, webResourceRequest, webResourceResponse);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onReceivedSslError(WebView webView, SslErrorHandler sslErrorHandler, SslError sslError) {
        if (this.mAgentWebUIController.get() != null) {
            this.mAgentWebUIController.get().onShowSslCertificateErrorDialog(webView, sslErrorHandler, sslError);
        }
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public void onScaleChanged(WebView webView, float f2, float f3) {
        String str = TAG;
        LogUtils.i(str, "onScaleChanged:" + f2 + "   n:" + f3);
        if (f3 - f2 > 7.0f) {
            webView.setInitialScale((int) ((f2 / f3) * 100.0f));
        }
    }

    @Override // android.webkit.WebViewClient, com.just.agentweb.WebViewClientDelegate
    public WebResourceResponse shouldInterceptRequest(WebView webView, String str) {
        return super.shouldInterceptRequest(webView, str);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    public boolean shouldOverrideKeyEvent(WebView webView, KeyEvent keyEvent) {
        return super.shouldOverrideKeyEvent(webView, keyEvent);
    }

    @Override // android.webkit.WebViewClient, com.just.agentweb.WebViewClientDelegate
    public boolean shouldOverrideUrlLoading(WebView webView, WebResourceRequest webResourceRequest) {
        String uri = webResourceRequest.getUrl().toString();
        if (uri.startsWith(HTTP_SCHEME) || uri.startsWith(HTTPS_SCHEME)) {
            if (!this.webClientHelper || !HAS_ALIPAY_LIB || !isAlipay(webView, uri)) {
                return false;
            }
            return true;
        } else if (!this.webClientHelper) {
            return super.shouldOverrideUrlLoading(webView, webResourceRequest);
        } else {
            if (handleCommonLink(uri)) {
                return true;
            }
            if (uri.startsWith(INTENT_SCHEME)) {
                handleIntentUrl(uri);
                LogUtils.i(TAG, "intent url ");
                return true;
            } else if (uri.startsWith(WEBCHAT_PAY_SCHEME)) {
                LogUtils.i(TAG, "lookup wechat to pay ~~");
                startActivity(uri);
                return true;
            } else if (uri.startsWith(ALIPAYS_SCHEME) && lookup(uri)) {
                LogUtils.i(TAG, "alipays url lookup alipay ~~ ");
                return true;
            } else if (queryActiviesNumber(uri) > 0 && deepLink(uri)) {
                String str = TAG;
                LogUtils.i(str, "intercept url:" + uri);
                return true;
            } else if (!this.mIsInterceptUnkownUrl) {
                return super.shouldOverrideUrlLoading(webView, webResourceRequest);
            } else {
                String str2 = TAG;
                StringBuilder B = a.B("intercept UnkownUrl :");
                B.append(webResourceRequest.getUrl());
                LogUtils.i(str2, B.toString());
                return true;
            }
        }
    }

    @Override // android.webkit.WebViewClient, com.just.agentweb.WebViewClientDelegate
    public WebResourceResponse shouldInterceptRequest(WebView webView, WebResourceRequest webResourceRequest) {
        return super.shouldInterceptRequest(webView, webResourceRequest);
    }

    @Override // com.just.agentweb.WebViewClientDelegate
    @TargetApi(23)
    public void onReceivedError(WebView webView, WebResourceRequest webResourceRequest, WebResourceError webResourceError) {
        String uri = webResourceRequest.getUrl().toString();
        int errorCode = webResourceError.getErrorCode();
        if (webResourceRequest.isForMainFrame()) {
            if ((uri != null || errorCode == -12) && errorCode != -1) {
                String str = TAG;
                StringBuilder B = a.B("onReceivedError:");
                B.append((Object) webResourceError.getDescription());
                B.append(" code:");
                B.append(webResourceError.getErrorCode());
                B.append(" failingUrl:");
                B.append(uri);
                B.append(" getUrl:");
                B.append(webView.getUrl());
                B.append(" getOriginalUrl:");
                B.append(webView.getOriginalUrl());
                LogUtils.i(str, B.toString());
                if (errorCode == -2 || uri == null || uri.equals(webView.getUrl()) || uri.equals(webView.getOriginalUrl())) {
                    onMainFrameError(webView, webResourceError.getErrorCode(), webResourceError.getDescription().toString(), webResourceRequest.getUrl().toString());
                }
            }
        }
    }

    @Override // android.webkit.WebViewClient, com.just.agentweb.WebViewClientDelegate
    public boolean shouldOverrideUrlLoading(WebView webView, String str) {
        if (str.startsWith(HTTP_SCHEME) || str.startsWith(HTTPS_SCHEME)) {
            if (!this.webClientHelper || !HAS_ALIPAY_LIB || !isAlipay(webView, str)) {
                return false;
            }
            return true;
        } else if (!this.webClientHelper) {
            return false;
        } else {
            if (handleCommonLink(str)) {
                return true;
            }
            if (str.startsWith(INTENT_SCHEME)) {
                handleIntentUrl(str);
                return true;
            } else if (str.startsWith(WEBCHAT_PAY_SCHEME)) {
                startActivity(str);
                return true;
            } else if (str.startsWith(ALIPAYS_SCHEME) && lookup(str)) {
                return true;
            } else {
                if (queryActiviesNumber(str) > 0 && deepLink(str)) {
                    LogUtils.i(TAG, "intercept OtherAppScheme");
                    return true;
                } else if (!this.mIsInterceptUnkownUrl) {
                    return super.shouldOverrideUrlLoading(webView, str);
                } else {
                    String str2 = TAG;
                    LogUtils.i(str2, "intercept InterceptUnkownScheme : " + str);
                    return true;
                }
            }
        }
    }
}
