package com.just.agentweb;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.AnimatorSet;
import android.animation.ObjectAnimator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.LinearInterpolator;
import android.widget.FrameLayout;
import d.a.a.a.a;

public class WebIndicator extends BaseIndicatorView implements BaseIndicatorSpec {
    public static final int DO_END_ANIMATION_DURATION = 600;
    public static final int FINISH = 2;
    public static final int MAX_DECELERATE_SPEED_DURATION = 450;
    public static final int MAX_UNIFORM_SPEED_DURATION = 8000;
    public static final int STARTED = 1;
    public static final int UN_START = 0;
    private int indicatorStatus;
    private Animator mAnimator;
    private AnimatorListenerAdapter mAnimatorListenerAdapter;
    private ValueAnimator.AnimatorUpdateListener mAnimatorUpdateListener;
    private int mColor;
    private int mCurrentDoEndAnimationDuration;
    private int mCurrentMaxDecelerateSpeedDuration;
    private int mCurrentMaxUniformSpeedDuration;
    private float mCurrentProgress;
    private Paint mPaint;
    private int mTargetWidth;
    public int mWebIndicatorDefaultHeight;

    public WebIndicator(Context context) {
        this(context, null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doEnd() {
        if (this.indicatorStatus == 2 && this.mCurrentProgress == 100.0f) {
            setVisibility(8);
            this.mCurrentProgress = 0.0f;
            setAlpha(1.0f);
        }
        this.indicatorStatus = 0;
    }

    private void init(Context context, AttributeSet attributeSet, int i2) {
        this.mPaint = new Paint();
        this.mColor = Color.parseColor("#1aad19");
        this.mPaint.setAntiAlias(true);
        this.mPaint.setColor(this.mColor);
        this.mPaint.setDither(true);
        this.mPaint.setStrokeCap(Paint.Cap.SQUARE);
        this.mTargetWidth = context.getResources().getDisplayMetrics().widthPixels;
        this.mWebIndicatorDefaultHeight = AgentWebUtils.dp2px(context, 3.0f);
    }

    private void startAnim(boolean z) {
        float f2 = z ? 100.0f : 95.0f;
        Animator animator = this.mAnimator;
        if (animator != null && animator.isStarted()) {
            this.mAnimator.cancel();
        }
        float f3 = this.mCurrentProgress;
        if (f3 == 0.0f) {
            f3 = 1.0E-8f;
        }
        this.mCurrentProgress = f3;
        if (!z) {
            AnimatorSet animatorSet = new AnimatorSet();
            float f4 = f2 * 0.6f;
            ValueAnimator ofFloat = ValueAnimator.ofFloat(this.mCurrentProgress, f4);
            ValueAnimator ofFloat2 = ValueAnimator.ofFloat(f4, f2);
            float f5 = (float) ((long) (((1.0f - (this.mCurrentProgress / 100.0f)) - 0.05f) * ((float) this.mCurrentMaxUniformSpeedDuration)));
            ofFloat.setInterpolator(new LinearInterpolator());
            ofFloat.setDuration((long) (f5 * 0.4f));
            ofFloat.addUpdateListener(this.mAnimatorUpdateListener);
            ofFloat2.setInterpolator(new LinearInterpolator());
            ofFloat2.setDuration((long) (0.6f * f5));
            ofFloat2.addUpdateListener(this.mAnimatorUpdateListener);
            animatorSet.play(ofFloat2).after(ofFloat);
            animatorSet.start();
            this.mAnimator = animatorSet;
        } else {
            ValueAnimator valueAnimator = null;
            if (f3 < 95.0f) {
                valueAnimator = ValueAnimator.ofFloat(f3, 95.0f);
                valueAnimator.setDuration((long) (((1.0f - (this.mCurrentProgress / 100.0f)) - 0.05f) * ((float) this.mCurrentMaxDecelerateSpeedDuration)));
                valueAnimator.setInterpolator(new DecelerateInterpolator());
                valueAnimator.addUpdateListener(this.mAnimatorUpdateListener);
            }
            ObjectAnimator ofFloat3 = ObjectAnimator.ofFloat(this, "alpha", 1.0f, 0.0f);
            ofFloat3.setDuration((long) this.mCurrentDoEndAnimationDuration);
            ValueAnimator ofFloat4 = ValueAnimator.ofFloat(95.0f, 100.0f);
            ofFloat4.setDuration((long) this.mCurrentDoEndAnimationDuration);
            ofFloat4.addUpdateListener(this.mAnimatorUpdateListener);
            AnimatorSet animatorSet2 = new AnimatorSet();
            animatorSet2.playTogether(ofFloat3, ofFloat4);
            if (valueAnimator != null) {
                AnimatorSet animatorSet3 = new AnimatorSet();
                animatorSet3.play(animatorSet2).after(valueAnimator);
                animatorSet2 = animatorSet3;
            }
            animatorSet2.addListener(this.mAnimatorListenerAdapter);
            animatorSet2.start();
            this.mAnimator = animatorSet2;
        }
        this.indicatorStatus = 1;
    }

    public void dispatchDraw(Canvas canvas) {
        canvas.drawRect(0.0f, 0.0f, Float.valueOf((float) getWidth()).floatValue() * (this.mCurrentProgress / 100.0f), (float) getHeight(), this.mPaint);
    }

    @Override // com.just.agentweb.BaseIndicatorSpec, com.just.agentweb.BaseIndicatorView
    public void hide() {
        this.indicatorStatus = 2;
    }

    @Override // com.just.agentweb.LayoutParamsOffer
    public FrameLayout.LayoutParams offerLayoutParams() {
        return new FrameLayout.LayoutParams(-1, this.mWebIndicatorDefaultHeight);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        Animator animator = this.mAnimator;
        if (animator != null && animator.isStarted()) {
            this.mAnimator.cancel();
            this.mAnimator = null;
        }
    }

    public void onDraw(Canvas canvas) {
    }

    public void onMeasure(int i2, int i3) {
        int mode = View.MeasureSpec.getMode(i2);
        int size = View.MeasureSpec.getSize(i2);
        int mode2 = View.MeasureSpec.getMode(i3);
        int size2 = View.MeasureSpec.getSize(i3);
        if (mode == Integer.MIN_VALUE && size > getContext().getResources().getDisplayMetrics().widthPixels) {
            size = getContext().getResources().getDisplayMetrics().widthPixels;
        }
        if (mode2 == Integer.MIN_VALUE) {
            size2 = this.mWebIndicatorDefaultHeight;
        }
        setMeasuredDimension(size, size2);
    }

    public void onSizeChanged(int i2, int i3, int i4, int i5) {
        super.onSizeChanged(i2, i3, i4, i5);
        this.mTargetWidth = getMeasuredWidth();
        int i6 = getContext().getResources().getDisplayMetrics().widthPixels;
        int i7 = this.mTargetWidth;
        if (i7 >= i6) {
            this.mCurrentMaxDecelerateSpeedDuration = MAX_DECELERATE_SPEED_DURATION;
            this.mCurrentMaxUniformSpeedDuration = MAX_UNIFORM_SPEED_DURATION;
            this.mCurrentDoEndAnimationDuration = MAX_DECELERATE_SPEED_DURATION;
        } else {
            float floatValue = ((float) i7) / Float.valueOf((float) i6).floatValue();
            this.mCurrentMaxUniformSpeedDuration = (int) (8000.0f * floatValue);
            this.mCurrentMaxDecelerateSpeedDuration = (int) (450.0f * floatValue);
            this.mCurrentDoEndAnimationDuration = (int) (floatValue * 600.0f);
        }
        StringBuilder B = a.B("CURRENT_MAX_UNIFORM_SPEED_DURATION");
        B.append(this.mCurrentMaxUniformSpeedDuration);
        LogUtils.i("WebProgress", B.toString());
    }

    @Override // com.just.agentweb.BaseIndicatorSpec, com.just.agentweb.BaseIndicatorView
    public void reset() {
        this.mCurrentProgress = 0.0f;
        Animator animator = this.mAnimator;
        if (animator != null && animator.isStarted()) {
            this.mAnimator.cancel();
        }
    }

    public void setColor(int i2) {
        this.mColor = i2;
        this.mPaint.setColor(i2);
    }

    public void setProgress(float f2) {
        if (getVisibility() == 8) {
            setVisibility(0);
        }
        if (f2 >= 95.0f && this.indicatorStatus != 2) {
            startAnim(true);
        }
    }

    @Override // com.just.agentweb.BaseIndicatorSpec, com.just.agentweb.BaseIndicatorView
    public void show() {
        if (getVisibility() == 8) {
            setVisibility(0);
            this.mCurrentProgress = 0.0f;
            startAnim(false);
        }
    }

    public WebIndicator(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public WebIndicator(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mTargetWidth = 0;
        this.mCurrentMaxUniformSpeedDuration = MAX_UNIFORM_SPEED_DURATION;
        this.mCurrentMaxDecelerateSpeedDuration = MAX_DECELERATE_SPEED_DURATION;
        this.mCurrentDoEndAnimationDuration = 600;
        this.indicatorStatus = 0;
        this.mCurrentProgress = 0.0f;
        this.mWebIndicatorDefaultHeight = 3;
        this.mAnimatorUpdateListener = new ValueAnimator.AnimatorUpdateListener() {
            /* class com.just.agentweb.WebIndicator.AnonymousClass1 */

            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                WebIndicator.this.mCurrentProgress = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                WebIndicator.this.invalidate();
            }
        };
        this.mAnimatorListenerAdapter = new AnimatorListenerAdapter() {
            /* class com.just.agentweb.WebIndicator.AnonymousClass2 */

            public void onAnimationEnd(Animator animator) {
                WebIndicator.this.doEnd();
            }
        };
        init(context, attributeSet, i2);
    }

    public void setColor(String str) {
        setColor(Color.parseColor(str));
    }

    @Override // com.just.agentweb.BaseIndicatorSpec, com.just.agentweb.BaseIndicatorView
    public void setProgress(int i2) {
        setProgress(Float.valueOf((float) i2).floatValue());
    }
}
