package com.like;

import android.animation.ArgbEvaluator;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.util.AttributeSet;
import android.util.Property;
import android.view.View;

public class CircleView extends View {
    public static final Property<CircleView, Float> INNER_CIRCLE_RADIUS_PROGRESS = new Property<CircleView, Float>(Float.class, "innerCircleRadiusProgress") {
        /* class com.like.CircleView.AnonymousClass1 */

        public Float get(CircleView circleView) {
            return Float.valueOf(circleView.getInnerCircleRadiusProgress());
        }

        public void set(CircleView circleView, Float f2) {
            circleView.setInnerCircleRadiusProgress(f2.floatValue());
        }
    };
    public static final Property<CircleView, Float> OUTER_CIRCLE_RADIUS_PROGRESS = new Property<CircleView, Float>(Float.class, "outerCircleRadiusProgress") {
        /* class com.like.CircleView.AnonymousClass2 */

        public Float get(CircleView circleView) {
            return Float.valueOf(circleView.getOuterCircleRadiusProgress());
        }

        public void set(CircleView circleView, Float f2) {
            circleView.setOuterCircleRadiusProgress(f2.floatValue());
        }
    };
    private int END_COLOR = -16121;
    private int START_COLOR = -43230;
    private ArgbEvaluator argbEvaluator = new ArgbEvaluator();
    private Paint circlePaint = new Paint();
    private int height = 0;
    private float innerCircleRadiusProgress = 0.0f;
    private Paint maskPaint = new Paint();
    private int maxCircleSize;
    private float outerCircleRadiusProgress = 0.0f;
    private Bitmap tempBitmap;
    private Canvas tempCanvas;
    private int width = 0;

    public CircleView(Context context) {
        super(context);
        init();
    }

    private void init() {
        this.circlePaint.setStyle(Paint.Style.FILL);
        this.maskPaint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.CLEAR));
    }

    private void updateCircleColor() {
        this.circlePaint.setColor(((Integer) this.argbEvaluator.evaluate((float) Utils.mapValueFromRangeToRange((double) ((float) Utils.clamp((double) this.outerCircleRadiusProgress, 0.5d, 1.0d)), 0.5d, 1.0d, 0.0d, 1.0d), Integer.valueOf(this.START_COLOR), Integer.valueOf(this.END_COLOR))).intValue());
    }

    public float getInnerCircleRadiusProgress() {
        return this.innerCircleRadiusProgress;
    }

    public float getOuterCircleRadiusProgress() {
        return this.outerCircleRadiusProgress;
    }

    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        this.tempCanvas.drawColor(16777215, PorterDuff.Mode.CLEAR);
        this.tempCanvas.drawCircle((float) (getWidth() / 2), (float) (getHeight() / 2), this.outerCircleRadiusProgress * ((float) this.maxCircleSize), this.circlePaint);
        this.tempCanvas.drawCircle((float) (getWidth() / 2), (float) (getHeight() / 2), this.innerCircleRadiusProgress * ((float) this.maxCircleSize), this.maskPaint);
        canvas.drawBitmap(this.tempBitmap, 0.0f, 0.0f, (Paint) null);
    }

    public void onMeasure(int i2, int i3) {
        int i4;
        super.onMeasure(i2, i3);
        int i5 = this.width;
        if (i5 != 0 && (i4 = this.height) != 0) {
            setMeasuredDimension(i5, i4);
        }
    }

    public void onSizeChanged(int i2, int i3, int i4, int i5) {
        super.onSizeChanged(i2, i3, i4, i5);
        this.maxCircleSize = i2 / 2;
        this.tempBitmap = Bitmap.createBitmap(getWidth(), getWidth(), Bitmap.Config.ARGB_8888);
        this.tempCanvas = new Canvas(this.tempBitmap);
    }

    public void setEndColor(int i2) {
        this.END_COLOR = i2;
        invalidate();
    }

    public void setInnerCircleRadiusProgress(float f2) {
        this.innerCircleRadiusProgress = f2;
        postInvalidate();
    }

    public void setOuterCircleRadiusProgress(float f2) {
        this.outerCircleRadiusProgress = f2;
        updateCircleColor();
        postInvalidate();
    }

    public void setSize(int i2, int i3) {
        this.width = i2;
        this.height = i3;
        invalidate();
    }

    public void setStartColor(int i2) {
        this.START_COLOR = i2;
        invalidate();
    }

    public CircleView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init();
    }

    public CircleView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        init();
    }
}
