package com.like;

import android.animation.ArgbEvaluator;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.util.Property;
import android.view.View;
import d.a.a.a.a;

public class DotsView extends View {
    private static final int DOTS_COUNT = 7;
    public static final Property<DotsView, Float> DOTS_PROGRESS = new Property<DotsView, Float>(Float.class, "dotsProgress") {
        /* class com.like.DotsView.AnonymousClass1 */

        public Float get(DotsView dotsView) {
            return Float.valueOf(dotsView.getCurrentProgress());
        }

        public void set(DotsView dotsView, Float f2) {
            dotsView.setCurrentProgress(f2.floatValue());
        }
    };
    private static final int OUTER_DOTS_POSITION_ANGLE = 51;
    private int COLOR_1;
    private int COLOR_2;
    private int COLOR_3;
    private int COLOR_4;
    private ArgbEvaluator argbEvaluator;
    private int centerX;
    private int centerY;
    private final Paint[] circlePaints;
    private float currentDotSize1;
    private float currentDotSize2;
    private float currentProgress;
    private float currentRadius1;
    private float currentRadius2;
    private int height;
    private float maxDotSize;
    private float maxInnerDotsRadius;
    private float maxOuterDotsRadius;
    private int width;

    public DotsView(Context context) {
        super(context);
        this.COLOR_1 = -16121;
        this.COLOR_2 = -26624;
        this.COLOR_3 = -43230;
        this.COLOR_4 = -769226;
        this.width = 0;
        this.height = 0;
        this.circlePaints = new Paint[4];
        this.currentProgress = 0.0f;
        this.currentRadius1 = 0.0f;
        this.currentDotSize1 = 0.0f;
        this.currentDotSize2 = 0.0f;
        this.currentRadius2 = 0.0f;
        this.argbEvaluator = new ArgbEvaluator();
        init();
    }

    private void drawInnerDotsFrame(Canvas canvas) {
        int i2 = 0;
        while (i2 < 7) {
            double d2 = (((double) ((i2 * 51) - 10)) * 3.141592653589793d) / 180.0d;
            double cos = Math.cos(d2) * ((double) this.currentRadius2);
            double d3 = (double) this.centerY;
            float f2 = this.currentDotSize2;
            Paint[] paintArr = this.circlePaints;
            i2++;
            canvas.drawCircle((float) ((int) (cos + ((double) this.centerX))), (float) ((int) a.a(d2, (double) this.currentRadius2, d3)), f2, paintArr[i2 % paintArr.length]);
        }
    }

    private void drawOuterDotsFrame(Canvas canvas) {
        for (int i2 = 0; i2 < 7; i2++) {
            double d2 = (((double) (i2 * 51)) * 3.141592653589793d) / 180.0d;
            double cos = Math.cos(d2) * ((double) this.currentRadius1);
            double d3 = (double) this.centerY;
            float f2 = this.currentDotSize1;
            Paint[] paintArr = this.circlePaints;
            canvas.drawCircle((float) ((int) (cos + ((double) this.centerX))), (float) ((int) a.a(d2, (double) this.currentRadius1, d3)), f2, paintArr[i2 % paintArr.length]);
        }
    }

    private void init() {
        int i2 = 0;
        while (true) {
            Paint[] paintArr = this.circlePaints;
            if (i2 < paintArr.length) {
                paintArr[i2] = new Paint();
                this.circlePaints[i2].setStyle(Paint.Style.FILL);
                i2++;
            } else {
                return;
            }
        }
    }

    private void updateDotsAlpha() {
        int mapValueFromRangeToRange = (int) Utils.mapValueFromRangeToRange((double) ((float) Utils.clamp((double) this.currentProgress, 0.6000000238418579d, 1.0d)), 0.6000000238418579d, 1.0d, 255.0d, 0.0d);
        this.circlePaints[0].setAlpha(mapValueFromRangeToRange);
        this.circlePaints[1].setAlpha(mapValueFromRangeToRange);
        this.circlePaints[2].setAlpha(mapValueFromRangeToRange);
        this.circlePaints[3].setAlpha(mapValueFromRangeToRange);
    }

    private void updateDotsPaints() {
        float f2 = this.currentProgress;
        if (f2 < 0.5f) {
            float mapValueFromRangeToRange = (float) Utils.mapValueFromRangeToRange((double) f2, 0.0d, 0.5d, 0.0d, 1.0d);
            this.circlePaints[0].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange, Integer.valueOf(this.COLOR_1), Integer.valueOf(this.COLOR_2))).intValue());
            this.circlePaints[1].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange, Integer.valueOf(this.COLOR_2), Integer.valueOf(this.COLOR_3))).intValue());
            this.circlePaints[2].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange, Integer.valueOf(this.COLOR_3), Integer.valueOf(this.COLOR_4))).intValue());
            this.circlePaints[3].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange, Integer.valueOf(this.COLOR_4), Integer.valueOf(this.COLOR_1))).intValue());
            return;
        }
        float mapValueFromRangeToRange2 = (float) Utils.mapValueFromRangeToRange((double) f2, 0.5d, 1.0d, 0.0d, 1.0d);
        this.circlePaints[0].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange2, Integer.valueOf(this.COLOR_2), Integer.valueOf(this.COLOR_3))).intValue());
        this.circlePaints[1].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange2, Integer.valueOf(this.COLOR_3), Integer.valueOf(this.COLOR_4))).intValue());
        this.circlePaints[2].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange2, Integer.valueOf(this.COLOR_4), Integer.valueOf(this.COLOR_1))).intValue());
        this.circlePaints[3].setColor(((Integer) this.argbEvaluator.evaluate(mapValueFromRangeToRange2, Integer.valueOf(this.COLOR_1), Integer.valueOf(this.COLOR_2))).intValue());
    }

    private void updateInnerDotsPosition() {
        float f2 = this.currentProgress;
        if (f2 < 0.3f) {
            this.currentRadius2 = (float) Utils.mapValueFromRangeToRange((double) f2, 0.0d, 0.30000001192092896d, 0.0d, (double) this.maxInnerDotsRadius);
        } else {
            this.currentRadius2 = this.maxInnerDotsRadius;
        }
        float f3 = this.currentProgress;
        if (f3 == 0.0f) {
            this.currentDotSize2 = 0.0f;
        } else if (((double) f3) < 0.2d) {
            this.currentDotSize2 = this.maxDotSize;
        } else if (((double) f3) < 0.5d) {
            double d2 = (double) f3;
            float f4 = this.maxDotSize;
            this.currentDotSize2 = (float) Utils.mapValueFromRangeToRange(d2, 0.20000000298023224d, 0.5d, (double) f4, ((double) f4) * 0.3d);
        } else {
            this.currentDotSize2 = (float) Utils.mapValueFromRangeToRange((double) f3, 0.5d, 1.0d, (double) (this.maxDotSize * 0.3f), 0.0d);
        }
    }

    private void updateOuterDotsPosition() {
        float f2 = this.currentProgress;
        if (f2 < 0.3f) {
            this.currentRadius1 = (float) Utils.mapValueFromRangeToRange((double) f2, 0.0d, 0.30000001192092896d, 0.0d, (double) (this.maxOuterDotsRadius * 0.8f));
        } else {
            double d2 = (double) f2;
            float f3 = this.maxOuterDotsRadius;
            this.currentRadius1 = (float) Utils.mapValueFromRangeToRange(d2, 0.30000001192092896d, 1.0d, (double) (0.8f * f3), (double) f3);
        }
        float f4 = this.currentProgress;
        if (f4 == 0.0f) {
            this.currentDotSize1 = 0.0f;
        } else if (((double) f4) < 0.7d) {
            this.currentDotSize1 = this.maxDotSize;
        } else {
            this.currentDotSize1 = (float) Utils.mapValueFromRangeToRange((double) f4, 0.699999988079071d, 1.0d, (double) this.maxDotSize, 0.0d);
        }
    }

    public float getCurrentProgress() {
        return this.currentProgress;
    }

    public void onDraw(Canvas canvas) {
        drawOuterDotsFrame(canvas);
        drawInnerDotsFrame(canvas);
    }

    public void onMeasure(int i2, int i3) {
        int i4;
        super.onMeasure(i2, i3);
        int i5 = this.width;
        if (i5 != 0 && (i4 = this.height) != 0) {
            setMeasuredDimension(i5, i4);
        }
    }

    public void onSizeChanged(int i2, int i3, int i4, int i5) {
        super.onSizeChanged(i2, i3, i4, i5);
        int i6 = i2 / 2;
        this.centerX = i6;
        this.centerY = i3 / 2;
        this.maxDotSize = 5.0f;
        float f2 = ((float) i6) - (5.0f * 2.0f);
        this.maxOuterDotsRadius = f2;
        this.maxInnerDotsRadius = f2 * 0.8f;
    }

    public void setColors(int i2, int i3) {
        this.COLOR_1 = i2;
        this.COLOR_2 = i3;
        this.COLOR_3 = i2;
        this.COLOR_4 = i3;
        invalidate();
    }

    public void setCurrentProgress(float f2) {
        this.currentProgress = f2;
        updateInnerDotsPosition();
        updateOuterDotsPosition();
        updateDotsPaints();
        updateDotsAlpha();
        postInvalidate();
    }

    public void setSize(int i2, int i3) {
        this.width = i2;
        this.height = i3;
        invalidate();
    }

    public DotsView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.COLOR_1 = -16121;
        this.COLOR_2 = -26624;
        this.COLOR_3 = -43230;
        this.COLOR_4 = -769226;
        this.width = 0;
        this.height = 0;
        this.circlePaints = new Paint[4];
        this.currentProgress = 0.0f;
        this.currentRadius1 = 0.0f;
        this.currentDotSize1 = 0.0f;
        this.currentDotSize2 = 0.0f;
        this.currentRadius2 = 0.0f;
        this.argbEvaluator = new ArgbEvaluator();
        init();
    }

    public DotsView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.COLOR_1 = -16121;
        this.COLOR_2 = -26624;
        this.COLOR_3 = -43230;
        this.COLOR_4 = -769226;
        this.width = 0;
        this.height = 0;
        this.circlePaints = new Paint[4];
        this.currentProgress = 0.0f;
        this.currentRadius1 = 0.0f;
        this.currentDotSize1 = 0.0f;
        this.currentDotSize2 = 0.0f;
        this.currentRadius2 = 0.0f;
        this.argbEvaluator = new ArgbEvaluator();
        init();
    }
}
