package com.luck.picture.lib.adapter;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.engine.ImageEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import d.k.a.a.d0.i;
import java.util.ArrayList;
import java.util.List;

public class PictureWeChatPreviewGalleryAdapter extends RecyclerView.Adapter<ViewHolder> {
    private final PictureSelectionConfig config;
    private List<LocalMedia> list;
    private OnItemClickListener listener;

    public interface OnItemClickListener {
        void onItemClick(int i2, LocalMedia localMedia, View view);
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public ImageView ivImage;
        public ImageView ivPlay;
        public View viewBorder;

        public ViewHolder(View view) {
            super(view);
            this.ivImage = (ImageView) view.findViewById(R.id.ivImage);
            this.ivPlay = (ImageView) view.findViewById(R.id.ivPlay);
            View findViewById = view.findViewById(R.id.viewBorder);
            this.viewBorder = findViewById;
            PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
            if (pictureSelectorUIStyle != null) {
                findViewById.setBackgroundResource(pictureSelectorUIStyle.picture_bottom_gallery_frameBackground);
            }
        }
    }

    public PictureWeChatPreviewGalleryAdapter(PictureSelectionConfig pictureSelectionConfig) {
        this.config = pictureSelectionConfig;
    }

    public /* synthetic */ void a(ViewHolder viewHolder, int i2, View view) {
        if (this.listener != null && viewHolder.getAdapterPosition() >= 0) {
            this.listener.onItemClick(viewHolder.getAdapterPosition(), getItem(i2), view);
        }
    }

    public void addSingleMediaToData(LocalMedia localMedia) {
        List<LocalMedia> list2 = this.list;
        if (list2 != null) {
            list2.clear();
            this.list.add(localMedia);
            notifyDataSetChanged();
        }
    }

    public LocalMedia getItem(int i2) {
        List<LocalMedia> list2 = this.list;
        if (list2 == null || list2.size() <= 0) {
            return null;
        }
        return this.list.get(i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<LocalMedia> list2 = this.list;
        if (list2 != null) {
            return list2.size();
        }
        return 0;
    }

    public boolean isDataEmpty() {
        List<LocalMedia> list2 = this.list;
        return list2 == null || list2.size() == 0;
    }

    public void removeMediaToData(LocalMedia localMedia) {
        List<LocalMedia> list2 = this.list;
        if (list2 != null && list2.size() > 0) {
            this.list.remove(localMedia);
            notifyDataSetChanged();
        }
    }

    public void setItemClickListener(OnItemClickListener onItemClickListener) {
        this.listener = onItemClickListener;
    }

    public void setNewData(List<LocalMedia> list2) {
        if (list2 == null) {
            list2 = new ArrayList<>();
        }
        this.list = list2;
        notifyDataSetChanged();
    }

    public void onBindViewHolder(ViewHolder viewHolder, int i2) {
        ImageEngine imageEngine;
        LocalMedia item = getItem(i2);
        if (item != null) {
            int i3 = 0;
            viewHolder.viewBorder.setVisibility(item.isChecked() ? 0 : 8);
            if (!(this.config == null || (imageEngine = PictureSelectionConfig.imageEngine) == null)) {
                imageEngine.loadImage(viewHolder.itemView.getContext(), item.getPath(), viewHolder.ivImage);
            }
            ImageView imageView = viewHolder.ivPlay;
            if (!PictureMimeType.isHasVideo(item.getMimeType())) {
                i3 = 8;
            }
            imageView.setVisibility(i3);
            viewHolder.itemView.setOnClickListener(new i(this, viewHolder, i2));
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i2) {
        return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.picture_wechat_preview_gallery, viewGroup, false));
    }
}
