package com.luck.picture.lib.camera;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.SurfaceTexture;
import android.media.MediaPlayer;
import android.net.Uri;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.Surface;
import android.view.TextureView;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.ImageCaptureException;
import androidx.camera.core.VideoCapture;
import androidx.camera.lifecycle.ProcessCameraProvider;
import androidx.camera.view.LifecycleCameraController;
import androidx.camera.view.PreviewView;
import androidx.camera.view.video.OnVideoSavedCallback;
import androidx.lifecycle.LifecycleOwner;
import b.d.a.q1;
import b.d.c.j0.c;
import b.d.c.j0.d;
import b.d.c.j0.e;
import b.d.c.v;
import b.j.b.a;
import com.luck.picture.lib.PictureMediaScannerConnection;
import com.luck.picture.lib.R;
import com.luck.picture.lib.camera.listener.CameraListener;
import com.luck.picture.lib.camera.listener.CaptureListener;
import com.luck.picture.lib.camera.listener.ClickListener;
import com.luck.picture.lib.camera.listener.ImageCallbackListener;
import com.luck.picture.lib.camera.listener.TypeListener;
import com.luck.picture.lib.camera.view.CaptureLayout;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import d.k.a.a.e0.b;
import java.io.File;
import java.io.IOException;
import java.lang.ref.WeakReference;
import java.util.Objects;
import java.util.concurrent.Executor;

public class CustomCameraView extends RelativeLayout {
    public static final int BUTTON_STATE_BOTH = 259;
    public static final int BUTTON_STATE_ONLY_CAPTURE = 257;
    public static final int BUTTON_STATE_ONLY_RECORDER = 258;
    public static final int DEFAULT_MIN_RECORD_VIDEO = 1500;
    private static final int TYPE_FLASH_AUTO = 33;
    private static final int TYPE_FLASH_OFF = 35;
    private static final int TYPE_FLASH_ON = 34;
    private LifecycleCameraController mCameraController;
    private CameraListener mCameraListener;
    private PreviewView mCameraPreviewView;
    private CaptureLayout mCaptureLayout;
    private PictureSelectionConfig mConfig;
    private ImageView mFlashLamp;
    private ImageCallbackListener mImageCallbackListener;
    private ImageView mImagePreview;
    private MediaPlayer mMediaPlayer;
    private ClickListener mOnClickListener;
    private File mOutMediaFile;
    private ImageView mSwitchCamera;
    private TextureView mTextureView;
    private long recordTime = 0;
    private final TextureView.SurfaceTextureListener surfaceTextureListener = new TextureView.SurfaceTextureListener() {
        /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass5 */

        public void onSurfaceTextureAvailable(SurfaceTexture surfaceTexture, int i2, int i3) {
            CustomCameraView customCameraView = CustomCameraView.this;
            customCameraView.startVideoPlay(customCameraView.mOutMediaFile);
        }

        public boolean onSurfaceTextureDestroyed(SurfaceTexture surfaceTexture) {
            return false;
        }

        public void onSurfaceTextureSizeChanged(SurfaceTexture surfaceTexture, int i2, int i3) {
        }

        public void onSurfaceTextureUpdated(SurfaceTexture surfaceTexture) {
        }
    };
    private int type_flash = 35;

    public static class MyImageResultCallback implements ImageCapture.OnImageSavedCallback {
        private final WeakReference<CameraListener> mCameraListenerReference;
        private final WeakReference<CaptureLayout> mCaptureLayoutReference;
        private final WeakReference<File> mFileReference;
        private final WeakReference<ImageCallbackListener> mImageCallbackListenerReference;
        private final WeakReference<ImageView> mImagePreviewReference;

        public MyImageResultCallback(File file, ImageView imageView, CaptureLayout captureLayout, ImageCallbackListener imageCallbackListener, CameraListener cameraListener) {
            this.mFileReference = new WeakReference<>(file);
            this.mImagePreviewReference = new WeakReference<>(imageView);
            this.mCaptureLayoutReference = new WeakReference<>(captureLayout);
            this.mImageCallbackListenerReference = new WeakReference<>(imageCallbackListener);
            this.mCameraListenerReference = new WeakReference<>(cameraListener);
        }

        @Override // androidx.camera.core.ImageCapture.OnImageSavedCallback
        public void onError(ImageCaptureException imageCaptureException) {
            if (this.mCaptureLayoutReference.get() != null) {
                this.mCaptureLayoutReference.get().setButtonCaptureEnabled(true);
            }
            if (this.mCameraListenerReference.get() != null) {
                this.mCameraListenerReference.get().onError(imageCaptureException.getImageCaptureError(), imageCaptureException.getMessage(), imageCaptureException.getCause());
            }
        }

        @Override // androidx.camera.core.ImageCapture.OnImageSavedCallback
        public void onImageSaved(ImageCapture.i iVar) {
            if (this.mCaptureLayoutReference.get() != null) {
                this.mCaptureLayoutReference.get().setButtonCaptureEnabled(true);
            }
            if (!(this.mImageCallbackListenerReference.get() == null || this.mFileReference.get() == null || this.mImagePreviewReference.get() == null)) {
                this.mImageCallbackListenerReference.get().onLoadImage(this.mFileReference.get(), this.mImagePreviewReference.get());
            }
            if (this.mImagePreviewReference.get() != null) {
                this.mImagePreviewReference.get().setVisibility(0);
            }
            if (this.mCaptureLayoutReference.get() != null) {
                this.mCaptureLayoutReference.get().startTypeBtnAnimator();
            }
        }
    }

    public CustomCameraView(Context context) {
        super(context);
        initView();
    }

    private Uri getOutUri(int i2) {
        if (i2 == PictureMimeType.ofVideo()) {
            Context context = getContext();
            PictureSelectionConfig pictureSelectionConfig = this.mConfig;
            return MediaUtils.createVideoUri(context, pictureSelectionConfig.cameraFileName, pictureSelectionConfig.suffixType);
        }
        Context context2 = getContext();
        PictureSelectionConfig pictureSelectionConfig2 = this.mConfig;
        return MediaUtils.createImageUri(context2, pictureSelectionConfig2.cameraFileName, pictureSelectionConfig2.suffixType);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @SuppressLint({"UnsafeOptInUsageError"})
    private void resetState() {
        if (this.mCameraController.f()) {
            this.mImagePreview.setVisibility(4);
        } else {
            LifecycleCameraController lifecycleCameraController = this.mCameraController;
            Objects.requireNonNull(lifecycleCameraController);
            AppCompatDelegateImpl.e.k();
            if (lifecycleCameraController.f2872g.get()) {
                this.mCameraController.n();
            }
        }
        File file = this.mOutMediaFile;
        if (file != null && file.exists()) {
            this.mOutMediaFile.delete();
            if (!SdkVersionUtils.checkedAndroid_Q()) {
                new PictureMediaScannerConnection(getContext(), this.mOutMediaFile.getAbsolutePath());
            }
        }
        this.mSwitchCamera.setVisibility(0);
        this.mFlashLamp.setVisibility(0);
        this.mCameraPreviewView.setVisibility(0);
        this.mCaptureLayout.resetCaptureLayout();
    }

    private void setFlashRes() {
        switch (this.type_flash) {
            case 33:
                this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_auto);
                this.mCameraController.k(0);
                return;
            case 34:
                this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_on);
                this.mCameraController.k(1);
                return;
            case 35:
                this.mFlashLamp.setImageResource(R.drawable.picture_ic_flash_off);
                this.mCameraController.k(2);
                return;
            default:
                return;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startVideoPlay(File file) {
        try {
            if (this.mMediaPlayer == null) {
                this.mMediaPlayer = new MediaPlayer();
            }
            this.mMediaPlayer.setDataSource(file.getAbsolutePath());
            this.mMediaPlayer.setSurface(new Surface(this.mTextureView.getSurfaceTexture()));
            this.mMediaPlayer.setLooping(true);
            this.mMediaPlayer.setOnPreparedListener(new b(this));
            this.mMediaPlayer.prepareAsync();
        } catch (IOException e2) {
            e2.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopVideoPlay() {
        MediaPlayer mediaPlayer = this.mMediaPlayer;
        if (mediaPlayer != null) {
            mediaPlayer.stop();
            this.mMediaPlayer.release();
            this.mMediaPlayer = null;
        }
        this.mTextureView.setVisibility(8);
    }

    public /* synthetic */ void a(View view) {
        int i2 = this.type_flash + 1;
        this.type_flash = i2;
        if (i2 > 35) {
            this.type_flash = 33;
        }
        setFlashRes();
    }

    public /* synthetic */ void b(MediaPlayer mediaPlayer) {
        mediaPlayer.start();
        float videoWidth = (((float) mediaPlayer.getVideoWidth()) * 1.0f) / ((float) mediaPlayer.getVideoHeight());
        int width = this.mTextureView.getWidth();
        ViewGroup.LayoutParams layoutParams = this.mTextureView.getLayoutParams();
        layoutParams.height = (int) (((float) width) / videoWidth);
        this.mTextureView.setLayoutParams(layoutParams);
    }

    public File createImageFile() {
        String str;
        String str2;
        String str3 = ".jpeg";
        if (SdkVersionUtils.checkedAndroid_Q()) {
            File file = new File(PictureFileUtils.getDiskCacheDir(getContext()));
            if (!file.exists()) {
                file.mkdirs();
            }
            boolean isEmpty = TextUtils.isEmpty(this.mConfig.cameraFileName);
            if (this.mConfig.suffixType.startsWith("image/")) {
                str3 = this.mConfig.suffixType.replaceAll("image/", ".");
            }
            if (isEmpty) {
                str2 = DateUtils.getCreateFileName("IMG_") + str3;
            } else {
                str2 = this.mConfig.cameraFileName;
            }
            File file2 = new File(file, str2);
            Uri outUri = getOutUri(PictureMimeType.ofImage());
            if (outUri != null) {
                this.mConfig.cameraPath = outUri.toString();
            }
            return file2;
        }
        if (!TextUtils.isEmpty(this.mConfig.cameraFileName)) {
            boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.mConfig.cameraFileName);
            PictureSelectionConfig pictureSelectionConfig = this.mConfig;
            pictureSelectionConfig.cameraFileName = !isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig.cameraFileName, str3) : pictureSelectionConfig.cameraFileName;
            PictureSelectionConfig pictureSelectionConfig2 = this.mConfig;
            boolean z = pictureSelectionConfig2.camera;
            str = pictureSelectionConfig2.cameraFileName;
            if (!z) {
                str = StringUtils.rename(str);
            }
        } else {
            str = "";
        }
        Context context = getContext();
        int ofImage = PictureMimeType.ofImage();
        PictureSelectionConfig pictureSelectionConfig3 = this.mConfig;
        File createCameraFile = PictureFileUtils.createCameraFile(context, ofImage, str, pictureSelectionConfig3.suffixType, pictureSelectionConfig3.outPutCameraPath);
        this.mConfig.cameraPath = createCameraFile.getAbsolutePath();
        return createCameraFile;
    }

    public File createVideoFile() {
        String str;
        String str2;
        String str3 = ".mp4";
        if (SdkVersionUtils.checkedAndroid_Q()) {
            File file = new File(PictureFileUtils.getVideoDiskCacheDir(getContext()));
            if (!file.exists()) {
                file.mkdirs();
            }
            boolean isEmpty = TextUtils.isEmpty(this.mConfig.cameraFileName);
            if (this.mConfig.suffixType.startsWith("video/")) {
                str3 = this.mConfig.suffixType.replaceAll("video/", ".");
            }
            if (isEmpty) {
                str2 = DateUtils.getCreateFileName("VID_") + str3;
            } else {
                str2 = this.mConfig.cameraFileName;
            }
            File file2 = new File(file, str2);
            Uri outUri = getOutUri(PictureMimeType.ofVideo());
            if (outUri != null) {
                this.mConfig.cameraPath = outUri.toString();
            }
            return file2;
        }
        if (!TextUtils.isEmpty(this.mConfig.cameraFileName)) {
            boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.mConfig.cameraFileName);
            PictureSelectionConfig pictureSelectionConfig = this.mConfig;
            pictureSelectionConfig.cameraFileName = !isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig.cameraFileName, str3) : pictureSelectionConfig.cameraFileName;
            PictureSelectionConfig pictureSelectionConfig2 = this.mConfig;
            boolean z = pictureSelectionConfig2.camera;
            str = pictureSelectionConfig2.cameraFileName;
            if (!z) {
                str = StringUtils.rename(str);
            }
        } else {
            str = "";
        }
        Context context = getContext();
        int ofVideo = PictureMimeType.ofVideo();
        PictureSelectionConfig pictureSelectionConfig3 = this.mConfig;
        File createCameraFile = PictureFileUtils.createCameraFile(context, ofVideo, str, pictureSelectionConfig3.suffixType, pictureSelectionConfig3.outPutCameraPath);
        this.mConfig.cameraPath = createCameraFile.getAbsolutePath();
        return createCameraFile;
    }

    public CaptureLayout getCaptureLayout() {
        return this.mCaptureLayout;
    }

    public void initCamera(PictureSelectionConfig pictureSelectionConfig) {
        this.mConfig = pictureSelectionConfig;
        if (a.a(getContext(), "android.permission.CAMERA") == 0) {
            LifecycleCameraController lifecycleCameraController = new LifecycleCameraController(getContext());
            this.mCameraController = lifecycleCameraController;
            Objects.requireNonNull(lifecycleCameraController);
            AppCompatDelegateImpl.e.k();
            lifecycleCameraController.t = (LifecycleOwner) getContext();
            lifecycleCameraController.m(null);
            this.mCameraController.i(this.mConfig.isCameraAroundState ? q1.f2625a : q1.f2626b);
            this.mCameraPreviewView.setController(this.mCameraController);
        }
        setFlashRes();
    }

    public void initView() {
        RelativeLayout.inflate(getContext(), R.layout.picture_camera_view, this);
        setBackgroundColor(a.b(getContext(), R.color.picture_color_black));
        this.mCameraPreviewView = (PreviewView) findViewById(R.id.cameraPreviewView);
        this.mTextureView = (TextureView) findViewById(R.id.video_play_preview);
        this.mImagePreview = (ImageView) findViewById(R.id.image_preview);
        this.mSwitchCamera = (ImageView) findViewById(R.id.image_switch);
        this.mFlashLamp = (ImageView) findViewById(R.id.image_flash);
        this.mCaptureLayout = (CaptureLayout) findViewById(R.id.capture_layout);
        this.mSwitchCamera.setImageResource(R.drawable.picture_ic_camera);
        this.mFlashLamp.setOnClickListener(new d.k.a.a.e0.a(this));
        this.mCaptureLayout.setDuration(15000);
        this.mSwitchCamera.setOnClickListener(new View.OnClickListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass1 */

            public void onClick(View view) {
                CustomCameraView.this.toggleCamera();
            }
        });
        this.mCaptureLayout.setCaptureListener(new CaptureListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass2 */

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            @SuppressLint({"UnsafeOptInUsageError"})
            public void recordEnd(long j2) {
                CustomCameraView.this.recordTime = j2;
                CustomCameraView.this.mCameraController.n();
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordError() {
                if (CustomCameraView.this.mCameraListener != null) {
                    CustomCameraView.this.mCameraListener.onError(0, "An unknown error", null);
                }
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            @SuppressLint({"UnsafeOptInUsageError"})
            public void recordShort(long j2) {
                CustomCameraView.this.recordTime = j2;
                CustomCameraView.this.mSwitchCamera.setVisibility(0);
                CustomCameraView.this.mFlashLamp.setVisibility(0);
                CustomCameraView.this.mCaptureLayout.resetCaptureLayout();
                CustomCameraView.this.mCaptureLayout.setTextWithAnimation(CustomCameraView.this.getContext().getString(R.string.picture_recording_time_is_short));
                CustomCameraView.this.mCameraController.n();
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            @SuppressLint({"UnsafeOptInUsageError"})
            public void recordStart() {
                VideoCapture.c.a aVar;
                CustomCameraView customCameraView = CustomCameraView.this;
                customCameraView.mOutMediaFile = customCameraView.createVideoFile();
                CustomCameraView.this.mSwitchCamera.setVisibility(4);
                CustomCameraView.this.mFlashLamp.setVisibility(4);
                CustomCameraView.this.mCameraController.j(4);
                File file = CustomCameraView.this.mOutMediaFile;
                c cVar = d.f2849a;
                LifecycleCameraController lifecycleCameraController = CustomCameraView.this.mCameraController;
                Executor c2 = a.c(CustomCameraView.this.getContext());
                AnonymousClass1 r4 = new OnVideoSavedCallback() {
                    /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass2.AnonymousClass1 */

                    @Override // androidx.camera.view.video.OnVideoSavedCallback
                    public void onError(int i2, String str, Throwable th) {
                        if (CustomCameraView.this.mCameraListener != null) {
                            CustomCameraView.this.mCameraListener.onError(i2, str, th);
                        }
                    }

                    @Override // androidx.camera.view.video.OnVideoSavedCallback
                    public void onVideoSaved(e eVar) {
                        if (CustomCameraView.this.recordTime >= (CustomCameraView.this.mConfig.recordVideoMinSecond <= 0 ? 1500 : (long) (CustomCameraView.this.mConfig.recordVideoMinSecond * 1000)) || !CustomCameraView.this.mOutMediaFile.exists() || !CustomCameraView.this.mOutMediaFile.delete()) {
                            CustomCameraView.this.mTextureView.setVisibility(0);
                            CustomCameraView.this.mCameraPreviewView.setVisibility(4);
                            if (CustomCameraView.this.mTextureView.isAvailable()) {
                                CustomCameraView customCameraView = CustomCameraView.this;
                                customCameraView.startVideoPlay(customCameraView.mOutMediaFile);
                                return;
                            }
                            CustomCameraView.this.mTextureView.setSurfaceTextureListener(CustomCameraView.this.surfaceTextureListener);
                        }
                    }
                };
                Objects.requireNonNull(lifecycleCameraController);
                AppCompatDelegateImpl.e.k();
                AppCompatDelegateImpl.e.n(lifecycleCameraController.e(), "Camera not initialized.");
                AppCompatDelegateImpl.e.n(lifecycleCameraController.h(), "VideoCapture disabled.");
                VideoCapture videoCapture = lifecycleCameraController.f2871f;
                if (file != null) {
                    Objects.requireNonNull(file);
                    aVar = new VideoCapture.c.a(file);
                } else {
                    AppCompatDelegateImpl.e.n(false, null);
                    Objects.requireNonNull(null);
                    Objects.requireNonNull(null);
                    Objects.requireNonNull(null);
                    aVar = new VideoCapture.c.a(null, null, null);
                }
                VideoCapture.b bVar = new VideoCapture.b();
                bVar.f624a = cVar.a();
                aVar.f637f = bVar;
                videoCapture.A(new VideoCapture.c(aVar.f632a, aVar.f633b, aVar.f634c, aVar.f635d, aVar.f636e, bVar), c2, new v(lifecycleCameraController, r4));
                lifecycleCameraController.f2872g.set(true);
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void recordZoom(float f2) {
            }

            @Override // com.luck.picture.lib.camera.listener.CaptureListener
            public void takePictures() {
                CustomCameraView customCameraView = CustomCameraView.this;
                customCameraView.mOutMediaFile = customCameraView.createImageFile();
                boolean z = false;
                CustomCameraView.this.mCaptureLayout.setButtonCaptureEnabled(false);
                CustomCameraView.this.mSwitchCamera.setVisibility(4);
                CustomCameraView.this.mFlashLamp.setVisibility(4);
                CustomCameraView.this.mCameraController.j(1);
                ImageCapture.h hVar = new ImageCapture.h(CustomCameraView.this.mOutMediaFile, null, null, null, null, null);
                LifecycleCameraController lifecycleCameraController = CustomCameraView.this.mCameraController;
                Executor c2 = a.c(CustomCameraView.this.getContext());
                MyImageResultCallback myImageResultCallback = new MyImageResultCallback(CustomCameraView.this.mOutMediaFile, CustomCameraView.this.mImagePreview, CustomCameraView.this.mCaptureLayout, CustomCameraView.this.mImageCallbackListener, CustomCameraView.this.mCameraListener);
                Objects.requireNonNull(lifecycleCameraController);
                AppCompatDelegateImpl.e.k();
                AppCompatDelegateImpl.e.n(lifecycleCameraController.e(), "Camera not initialized.");
                AppCompatDelegateImpl.e.n(lifecycleCameraController.f(), "ImageCapture disabled.");
                if (lifecycleCameraController.f2866a.b() != null) {
                    ImageCapture.f fVar = hVar.f572b;
                    if (!fVar.f570b) {
                        if (lifecycleCameraController.f2866a.b().intValue() == 0) {
                            z = true;
                        }
                        fVar.f569a = z;
                        fVar.f570b = true;
                    }
                }
                lifecycleCameraController.f2869d.E(hVar, c2, myImageResultCallback);
            }
        });
        this.mCaptureLayout.setTypeListener(new TypeListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass3 */

            @Override // com.luck.picture.lib.camera.listener.TypeListener
            public void cancel() {
                CustomCameraView.this.stopVideoPlay();
                CustomCameraView.this.resetState();
            }

            @Override // com.luck.picture.lib.camera.listener.TypeListener
            public void confirm() {
                if (CustomCameraView.this.mOutMediaFile != null && CustomCameraView.this.mOutMediaFile.exists()) {
                    if (SdkVersionUtils.checkedAndroid_Q() && PictureMimeType.isContent(CustomCameraView.this.mConfig.cameraPath)) {
                        PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<Boolean>() {
                            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass3.AnonymousClass1 */

                            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                            public Boolean doInBackground() {
                                return Boolean.valueOf(AndroidQTransformUtils.copyPathToDCIM(CustomCameraView.this.getContext(), CustomCameraView.this.mOutMediaFile, Uri.parse(CustomCameraView.this.mConfig.cameraPath)));
                            }

                            public void onSuccess(Boolean bool) {
                                if (CustomCameraView.this.mCameraController.f()) {
                                    CustomCameraView.this.mImagePreview.setVisibility(4);
                                    if (CustomCameraView.this.mCameraListener != null) {
                                        CustomCameraView.this.mCameraListener.onPictureSuccess(CustomCameraView.this.mOutMediaFile);
                                        return;
                                    }
                                    return;
                                }
                                CustomCameraView.this.stopVideoPlay();
                                if (CustomCameraView.this.mCameraListener != null || !CustomCameraView.this.mOutMediaFile.exists()) {
                                    CustomCameraView.this.mCameraListener.onRecordSuccess(CustomCameraView.this.mOutMediaFile);
                                }
                            }
                        });
                    } else if (CustomCameraView.this.mCameraController.f()) {
                        CustomCameraView.this.mImagePreview.setVisibility(4);
                        if (CustomCameraView.this.mCameraListener != null) {
                            CustomCameraView.this.mCameraListener.onPictureSuccess(CustomCameraView.this.mOutMediaFile);
                        }
                    } else {
                        CustomCameraView.this.stopVideoPlay();
                        if (CustomCameraView.this.mCameraListener != null || !CustomCameraView.this.mOutMediaFile.exists()) {
                            CustomCameraView.this.mCameraListener.onRecordSuccess(CustomCameraView.this.mOutMediaFile);
                        }
                    }
                }
            }
        });
        this.mCaptureLayout.setLeftClickListener(new ClickListener() {
            /* class com.luck.picture.lib.camera.CustomCameraView.AnonymousClass4 */

            @Override // com.luck.picture.lib.camera.listener.ClickListener
            public void onClick() {
                if (CustomCameraView.this.mOnClickListener != null) {
                    CustomCameraView.this.mOnClickListener.onClick();
                }
            }
        });
    }

    public void setCameraListener(CameraListener cameraListener) {
        this.mCameraListener = cameraListener;
    }

    public void setCaptureLoadingColor(int i2) {
        this.mCaptureLayout.setCaptureLoadingColor(i2);
    }

    public void setImageCallbackListener(ImageCallbackListener imageCallbackListener) {
        this.mImageCallbackListener = imageCallbackListener;
    }

    public void setOnClickListener(ClickListener clickListener) {
        this.mOnClickListener = clickListener;
    }

    public void setRecordVideoMaxTime(int i2) {
        this.mCaptureLayout.setDuration(i2 * 1000);
    }

    public void setRecordVideoMinTime(int i2) {
        this.mCaptureLayout.setMinDuration(i2 * 1000);
    }

    public void toggleCamera() {
        LifecycleCameraController lifecycleCameraController = this.mCameraController;
        Objects.requireNonNull(lifecycleCameraController);
        AppCompatDelegateImpl.e.k();
        q1 q1Var = lifecycleCameraController.f2866a;
        q1 q1Var2 = q1.f2626b;
        if (q1Var == q1Var2) {
            LifecycleCameraController lifecycleCameraController2 = this.mCameraController;
            q1 q1Var3 = q1.f2625a;
            if (lifecycleCameraController2.c(q1Var3)) {
                this.mCameraController.i(q1Var3);
                return;
            }
        }
        LifecycleCameraController lifecycleCameraController3 = this.mCameraController;
        Objects.requireNonNull(lifecycleCameraController3);
        AppCompatDelegateImpl.e.k();
        if (lifecycleCameraController3.f2866a == q1.f2625a && this.mCameraController.c(q1Var2)) {
            this.mCameraController.i(q1Var2);
        }
    }

    public void unbindCameraController() {
        LifecycleCameraController lifecycleCameraController = this.mCameraController;
        if (lifecycleCameraController != null) {
            Objects.requireNonNull(lifecycleCameraController);
            AppCompatDelegateImpl.e.k();
            lifecycleCameraController.t = null;
            lifecycleCameraController.f2873h = null;
            ProcessCameraProvider processCameraProvider = lifecycleCameraController.f2874i;
            if (processCameraProvider != null) {
                processCameraProvider.unbindAll();
            }
        }
    }

    public CustomCameraView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        initView();
    }

    public CustomCameraView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        initView();
    }
}
