package com.luck.picture.lib.compress;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.text.TextUtils;
import com.luck.picture.lib.tools.BitmapUtils;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;

public class Engine {
    private static final int DEFAULT_QUALITY = 80;
    private int compressQuality;
    private final Context context;
    private final boolean focusAlpha;
    private final boolean isAutoRotating;
    private int srcHeight;
    private final InputStreamProvider srcImg;
    private int srcWidth;
    private final File tagImg;

    public Engine(Context context2, InputStreamProvider inputStreamProvider, File file, boolean z, int i2, boolean z2) {
        this.tagImg = file;
        this.srcImg = inputStreamProvider;
        this.context = context2;
        this.focusAlpha = z;
        this.isAutoRotating = z2;
        this.compressQuality = i2 <= 0 ? 80 : i2;
        if (inputStreamProvider.getMedia().getWidth() <= 0 || inputStreamProvider.getMedia().getHeight() <= 0) {
            BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            options.inSampleSize = 1;
            BitmapFactory.decodeStream(inputStreamProvider.open(), null, options);
            this.srcWidth = options.outWidth;
            this.srcHeight = options.outHeight;
            return;
        }
        this.srcWidth = inputStreamProvider.getMedia().getWidth();
        this.srcHeight = inputStreamProvider.getMedia().getHeight();
    }

    private int computeSize() {
        int i2 = this.srcWidth;
        if (i2 % 2 == 1) {
            i2++;
        }
        this.srcWidth = i2;
        int i3 = this.srcHeight;
        if (i3 % 2 == 1) {
            i3++;
        }
        this.srcHeight = i3;
        int max = Math.max(i2, i3);
        float min = ((float) Math.min(this.srcWidth, this.srcHeight)) / ((float) max);
        if (min > 1.0f || ((double) min) <= 0.5625d) {
            double d2 = (double) min;
            if (d2 > 0.5625d || d2 <= 0.5d) {
                return (int) Math.ceil(((double) max) / (1280.0d / d2));
            }
            int i4 = max / 1280;
            if (i4 == 0) {
                return 1;
            }
            return i4;
        } else if (max < 1664) {
            return 1;
        } else {
            if (max < 4990) {
                return 2;
            }
            if (max <= 4990 || max >= 10240) {
                return max / 1280;
            }
            return 4;
        }
    }

    public File compress() {
        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = computeSize();
        Bitmap decodeStream = BitmapFactory.decodeStream(this.srcImg.open(), null, options);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        if (this.isAutoRotating && Checker.SINGLE.isJPG(this.srcImg.getMedia().getMimeType())) {
            int readPictureDegree = BitmapUtils.readPictureDegree(this.context, this.srcImg.getMedia().isCut() && !TextUtils.isEmpty(this.srcImg.getMedia().getCutPath()) ? this.srcImg.getMedia().getCutPath() : this.srcImg.getMedia().getPath());
            if (readPictureDegree > 0) {
                decodeStream = BitmapUtils.rotatingImage(decodeStream, readPictureDegree);
            }
        }
        if (decodeStream != null) {
            int i2 = this.compressQuality;
            if (i2 <= 0 || i2 > 100) {
                i2 = 80;
            }
            this.compressQuality = i2;
            decodeStream.compress(this.focusAlpha ? Bitmap.CompressFormat.PNG : Bitmap.CompressFormat.JPEG, i2, byteArrayOutputStream);
            decodeStream.recycle();
        }
        FileOutputStream fileOutputStream = new FileOutputStream(this.tagImg);
        fileOutputStream.write(byteArrayOutputStream.toByteArray());
        fileOutputStream.flush();
        fileOutputStream.close();
        byteArrayOutputStream.close();
        return this.tagImg;
    }
}
