package com.luck.picture.lib.compress;

import android.content.Context;
import android.net.Uri;
import android.os.Environment;
import android.text.TextUtils;
import android.util.Log;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import d.a.a.a.a;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class Luban {
    private static final String TAG = "Luban";
    private final int compressQuality;
    private final int dataCount;
    private final boolean focusAlpha;
    private int index;
    private boolean isAutoRotating;
    private final boolean isCamera;
    private final OnCompressListener mCompressListener;
    private final CompressionPredicate mCompressionPredicate;
    private final int mLeastCompressSize;
    private final String mNewFileName;
    private final List<String> mPaths;
    private final OnRenameListener mRenameListener;
    private final List<InputStreamProvider> mStreamProviders;
    private String mTargetDir;
    private final List<LocalMedia> mediaList;

    public static class Builder {
        private int compressQuality;
        private final Context context;
        private int dataCount;
        private boolean focusAlpha;
        private boolean isAutoRotating;
        private boolean isCamera;
        private OnCompressListener mCompressListener;
        private CompressionPredicate mCompressionPredicate;
        private int mLeastCompressSize = 100;
        private String mNewFileName;
        private final List<String> mPaths;
        private OnRenameListener mRenameListener;
        private final List<InputStreamProvider> mStreamProviders;
        private String mTargetDir;
        private List<LocalMedia> mediaList;

        public Builder(Context context2) {
            this.context = context2;
            this.mPaths = new ArrayList();
            this.mediaList = new ArrayList();
            this.mStreamProviders = new ArrayList();
        }

        private Luban build() {
            return new Luban(this);
        }

        public Builder filter(CompressionPredicate compressionPredicate) {
            this.mCompressionPredicate = compressionPredicate;
            return this;
        }

        public File get(final String str) {
            return build().get(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass5 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(str);
                }
            }, this.context);
        }

        public Builder ignoreBy(int i2) {
            this.mLeastCompressSize = i2;
            return this;
        }

        public Builder isAutoRotating(boolean z) {
            this.isAutoRotating = z;
            return this;
        }

        public Builder isCamera(boolean z) {
            this.isCamera = z;
            return this;
        }

        public void launch() {
            build().launch(this.context);
        }

        public Builder load(InputStreamProvider inputStreamProvider) {
            this.mStreamProviders.add(inputStreamProvider);
            return this;
        }

        public <T> Builder loadMediaData(List<LocalMedia> list) {
            this.mediaList = list;
            this.dataCount = list.size();
            for (LocalMedia localMedia : list) {
                load(localMedia);
            }
            return this;
        }

        public Builder putGear(int i2) {
            return this;
        }

        public Builder setCompressListener(OnCompressListener onCompressListener) {
            this.mCompressListener = onCompressListener;
            return this;
        }

        public Builder setCompressQuality(int i2) {
            this.compressQuality = i2;
            return this;
        }

        public Builder setFocusAlpha(boolean z) {
            this.focusAlpha = z;
            return this;
        }

        public Builder setNewCompressFileName(String str) {
            this.mNewFileName = str;
            return this;
        }

        @Deprecated
        public Builder setRenameListener(OnRenameListener onRenameListener) {
            this.mRenameListener = onRenameListener;
            return this;
        }

        public Builder setTargetDir(String str) {
            this.mTargetDir = str;
            return this;
        }

        private Builder load(final LocalMedia localMedia) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass1 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return localMedia;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    if (localMedia.isCut()) {
                        return localMedia.getCutPath();
                    }
                    return TextUtils.isEmpty(localMedia.getAndroidQToPath()) ? localMedia.getPath() : localMedia.getAndroidQToPath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    if (!PictureMimeType.isContent(localMedia.getPath()) || localMedia.isCut()) {
                        if (PictureMimeType.isHasHttp(localMedia.getPath()) && TextUtils.isEmpty(localMedia.getCutPath())) {
                            return null;
                        }
                        return new FileInputStream(localMedia.isCut() ? localMedia.getCutPath() : localMedia.getPath());
                    } else if (TextUtils.isEmpty(localMedia.getAndroidQToPath())) {
                        return Builder.this.context.getContentResolver().openInputStream(Uri.parse(localMedia.getPath()));
                    } else {
                        return new FileInputStream(localMedia.getAndroidQToPath());
                    }
                }
            });
            return this;
        }

        public List<File> get() {
            return build().get(this.context);
        }

        public Builder load(final Uri uri) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass2 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return uri.getPath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return Builder.this.context.getContentResolver().openInputStream(uri);
                }
            });
            return this;
        }

        public Builder load(final File file) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return file.getAbsolutePath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(file);
                }
            });
            return this;
        }

        public Builder load(final String str) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass4 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() {
                    return new FileInputStream(str);
                }
            });
            return this;
        }

        public <T> Builder load(List<T> list) {
            for (T t : list) {
                if (t instanceof String) {
                    load((String) t);
                } else if (t instanceof File) {
                    load((File) t);
                } else if (t instanceof Uri) {
                    load((Uri) t);
                } else {
                    throw new IllegalArgumentException("Incoming data type exception, it must be String, File, Uri or Bitmap");
                }
            }
            return this;
        }
    }

    public static /* synthetic */ int access$1408(Luban luban) {
        int i2 = luban.index;
        luban.index = i2 + 1;
        return i2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File compress(Context context, InputStreamProvider inputStreamProvider) {
        try {
            return compressRealLocalMedia(context, inputStreamProvider);
        } finally {
            inputStreamProvider.close();
        }
    }

    private File compressReal(Context context, InputStreamProvider inputStreamProvider) {
        Checker checker = Checker.SINGLE;
        String extSuffix = checker.extSuffix(inputStreamProvider.getMedia() != null ? inputStreamProvider.getMedia().getMimeType() : "");
        TextUtils.isEmpty(extSuffix);
        File imageCacheFile = getImageCacheFile(context, inputStreamProvider, extSuffix);
        OnRenameListener onRenameListener = this.mRenameListener;
        if (onRenameListener != null) {
            imageCacheFile = getImageCustomFile(context, onRenameListener.rename(inputStreamProvider.getPath()));
        }
        CompressionPredicate compressionPredicate = this.mCompressionPredicate;
        if (compressionPredicate != null) {
            if (!compressionPredicate.apply(inputStreamProvider.getPath()) || !checker.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new File(inputStreamProvider.getPath());
            }
            return new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
        } else if (extSuffix.startsWith(".gif")) {
            return new File(inputStreamProvider.getPath());
        } else {
            if (checker.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
            }
            return new File(inputStreamProvider.getPath());
        }
    }

    private File compressRealLocalMedia(Context context, InputStreamProvider inputStreamProvider) {
        String str;
        String str2;
        String str3;
        File file;
        String str4;
        LocalMedia media = inputStreamProvider.getMedia();
        String realPath = (!media.isCut() || TextUtils.isEmpty(media.getCutPath())) ? media.getRealPath() : media.getCutPath();
        Checker checker = Checker.SINGLE;
        String extSuffix = checker.extSuffix(media.getMimeType());
        File imageCacheFile = getImageCacheFile(context, inputStreamProvider, extSuffix);
        if (!TextUtils.isEmpty(this.mNewFileName)) {
            String rename = (this.isCamera || this.dataCount == 1) ? this.mNewFileName : StringUtils.rename(this.mNewFileName);
            str = rename;
            imageCacheFile = getImageCustomFile(context, rename);
        } else {
            str = "";
        }
        if (imageCacheFile.exists()) {
            return imageCacheFile;
        }
        if (this.mCompressionPredicate != null) {
            if (!extSuffix.startsWith(".gif")) {
                boolean needCompressToLocalMedia = checker.needCompressToLocalMedia(this.mLeastCompressSize, realPath);
                if (this.mCompressionPredicate.apply(realPath) && needCompressToLocalMedia) {
                    file = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
                } else if (needCompressToLocalMedia) {
                    file = new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
                } else if (SdkVersionUtils.checkedAndroid_Q()) {
                    if (media.isCut()) {
                        str4 = media.getCutPath();
                    } else {
                        str4 = AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
                    }
                    if (!TextUtils.isEmpty(str4)) {
                        realPath = str4;
                    }
                    return new File(realPath);
                } else {
                    file = new File(realPath);
                }
                return file;
            } else if (!SdkVersionUtils.checkedAndroid_Q()) {
                return new File(realPath);
            } else {
                if (!media.isCut() || TextUtils.isEmpty(media.getCutPath())) {
                    return new File(AndroidQTransformUtils.copyPathToAndroidQ(context, inputStreamProvider.getMedia().getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str));
                }
                return new File(media.getCutPath());
            }
        } else if (extSuffix.startsWith(".gif")) {
            if (!SdkVersionUtils.checkedAndroid_Q()) {
                return new File(realPath);
            }
            if (media.isCut()) {
                str3 = media.getCutPath();
            } else {
                str3 = AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
            }
            if (!TextUtils.isEmpty(str3)) {
                realPath = str3;
            }
            return new File(realPath);
        } else if (checker.needCompressToLocalMedia(this.mLeastCompressSize, realPath)) {
            return new Engine(context, inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
        } else {
            if (!SdkVersionUtils.checkedAndroid_Q()) {
                return new File(realPath);
            }
            if (media.isCut()) {
                str2 = media.getCutPath();
            } else {
                str2 = AndroidQTransformUtils.copyPathToAndroidQ(context, media.getId(), inputStreamProvider.getPath(), media.getWidth(), media.getHeight(), media.getMimeType(), str);
            }
            if (!TextUtils.isEmpty(str2)) {
                realPath = str2;
            }
            return new File(realPath);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File get(InputStreamProvider inputStreamProvider, Context context) {
        try {
            return new Engine(context, inputStreamProvider, getImageCacheFile(context, inputStreamProvider, Checker.SINGLE.extSuffix(inputStreamProvider.getMedia().getMimeType())), this.focusAlpha, this.compressQuality, this.isAutoRotating).compress();
        } finally {
            inputStreamProvider.close();
        }
    }

    private static File getImageCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        if (externalFilesDir == null) {
            if (Log.isLoggable(TAG, 6)) {
                Log.e(TAG, "default disk cache dir is null");
            }
            return null;
        } else if (externalFilesDir.mkdirs() || (externalFilesDir.exists() && externalFilesDir.isDirectory())) {
            return externalFilesDir;
        } else {
            return null;
        }
    }

    private File getImageCacheFile(Context context, InputStreamProvider inputStreamProvider, String str) {
        String str2;
        File imageCacheDir;
        if (TextUtils.isEmpty(this.mTargetDir) && (imageCacheDir = getImageCacheDir(context)) != null) {
            this.mTargetDir = imageCacheDir.getAbsolutePath();
        }
        try {
            LocalMedia media = inputStreamProvider.getMedia();
            String encryptionValue = StringUtils.getEncryptionValue(media.getId(), media.getWidth(), media.getHeight());
            StringBuilder sb = new StringBuilder();
            sb.append(this.mTargetDir);
            if (TextUtils.isEmpty(encryptionValue) || media.isCut()) {
                String createFileName = DateUtils.getCreateFileName("IMG_CMP_");
                sb.append("/");
                sb.append(createFileName);
                if (TextUtils.isEmpty(str)) {
                    str = ".jpeg";
                }
                sb.append(str);
                str2 = sb.toString();
                return new File(str2);
            }
            sb.append("/IMG_CMP_");
            sb.append(encryptionValue);
            if (TextUtils.isEmpty(str)) {
                str = ".jpeg";
            }
            sb.append(str);
            str2 = sb.toString();
            return new File(str2);
        } catch (Exception e2) {
            e2.printStackTrace();
            str2 = "";
        }
    }

    private File getImageCustomFile(Context context, String str) {
        if (TextUtils.isEmpty(this.mTargetDir)) {
            File imageCacheDir = getImageCacheDir(context);
            this.mTargetDir = imageCacheDir != null ? imageCacheDir.getAbsolutePath() : "";
        }
        return new File(a.z(new StringBuilder(), this.mTargetDir, "/", str));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void launch(final Context context) {
        List<InputStreamProvider> list = this.mStreamProviders;
        if (list == null || this.mPaths == null || (list.size() == 0 && this.mCompressListener != null)) {
            this.mCompressListener.onError(new NullPointerException("image file cannot be null"));
            return;
        }
        final Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        OnCompressListener onCompressListener = this.mCompressListener;
        if (onCompressListener != null) {
            onCompressListener.onStart();
        }
        PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
            /* class com.luck.picture.lib.compress.Luban.AnonymousClass1 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMedia> doInBackground() {
                String str;
                Luban.this.index = -1;
                while (true) {
                    String str2 = null;
                    if (!it.hasNext()) {
                        return null;
                    }
                    try {
                        Luban.access$1408(Luban.this);
                        InputStreamProvider inputStreamProvider = (InputStreamProvider) it.next();
                        boolean z = false;
                        if (inputStreamProvider.getMedia().isCompressed() && !TextUtils.isEmpty(inputStreamProvider.getMedia().getCompressPath())) {
                            str = (!inputStreamProvider.getMedia().isCut() && new File(inputStreamProvider.getMedia().getCompressPath()).exists() ? new File(inputStreamProvider.getMedia().getCompressPath()) : Luban.this.compress(context, inputStreamProvider)).getAbsolutePath();
                        } else if (!PictureMimeType.isHasHttp(inputStreamProvider.getMedia().getPath()) || !TextUtils.isEmpty(inputStreamProvider.getMedia().getCutPath())) {
                            str = (PictureMimeType.isHasVideo(inputStreamProvider.getMedia().getMimeType()) ? new File(inputStreamProvider.getPath()) : Luban.this.compress(context, inputStreamProvider)).getAbsolutePath();
                        } else {
                            str = inputStreamProvider.getMedia().getPath();
                        }
                        if (Luban.this.mediaList != null && Luban.this.mediaList.size() > 0) {
                            LocalMedia localMedia = (LocalMedia) Luban.this.mediaList.get(Luban.this.index);
                            boolean isHasHttp = PictureMimeType.isHasHttp(str);
                            boolean isHasVideo = PictureMimeType.isHasVideo(localMedia.getMimeType());
                            localMedia.setCompressed(!isHasHttp && !isHasVideo);
                            if (isHasHttp || isHasVideo) {
                                str = null;
                            }
                            localMedia.setCompressPath(str);
                            if (SdkVersionUtils.checkedAndroid_Q()) {
                                str2 = localMedia.getCompressPath();
                            }
                            localMedia.setAndroidQToPath(str2);
                            if (Luban.this.index == Luban.this.mediaList.size() - 1) {
                                z = true;
                            }
                            if (z) {
                                return Luban.this.mediaList;
                            }
                        }
                    } catch (Exception e2) {
                        e2.printStackTrace();
                    }
                    it.remove();
                }
            }

            public void onSuccess(List<LocalMedia> list) {
                if (Luban.this.mCompressListener != null) {
                    if (list != null) {
                        Luban.this.mCompressListener.onSuccess(list);
                    } else {
                        Luban.this.mCompressListener.onError(new Throwable("Failed to compress file"));
                    }
                }
            }
        });
    }

    public static Builder with(Context context) {
        return new Builder(context);
    }

    private Luban(Builder builder) {
        this.index = -1;
        this.mPaths = builder.mPaths;
        this.mediaList = builder.mediaList;
        this.dataCount = builder.dataCount;
        this.mTargetDir = builder.mTargetDir;
        this.mNewFileName = builder.mNewFileName;
        this.mRenameListener = builder.mRenameListener;
        this.mStreamProviders = builder.mStreamProviders;
        this.mCompressListener = builder.mCompressListener;
        this.mLeastCompressSize = builder.mLeastCompressSize;
        this.mCompressionPredicate = builder.mCompressionPredicate;
        this.compressQuality = builder.compressQuality;
        this.isAutoRotating = builder.isAutoRotating;
        this.focusAlpha = builder.focusAlpha;
        this.isCamera = builder.isCamera;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private List<File> get(Context context) {
        File file;
        ArrayList arrayList = new ArrayList();
        Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        while (it.hasNext()) {
            InputStreamProvider next = it.next();
            if (next.getMedia() != null) {
                boolean z = true;
                if (!next.getMedia().isCompressed() || TextUtils.isEmpty(next.getMedia().getCompressPath())) {
                    if (!PictureMimeType.isHasHttp(next.getMedia().getPath()) || !TextUtils.isEmpty(next.getMedia().getCutPath())) {
                        z = false;
                    }
                    arrayList.add((z || PictureMimeType.isHasVideo(next.getMedia().getMimeType())) ? new File(next.getMedia().getPath()) : compress(context, next));
                } else {
                    if (next.getMedia().isCut() || !new File(next.getMedia().getCompressPath()).exists()) {
                        z = false;
                    }
                    if (z) {
                        file = new File(next.getMedia().getCompressPath());
                    } else {
                        file = compress(context, next);
                    }
                    arrayList.add(file);
                }
                it.remove();
            }
        }
        return arrayList;
    }
}
