package com.luck.picture.lib.widget;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.PopupWindow;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import b.j.b.a;
import com.luck.picture.lib.R;
import com.luck.picture.lib.adapter.PictureAlbumDirectoryAdapter;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.listener.OnAlbumItemClickListener;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.tools.AnimUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import java.util.List;

public class FolderPopWindow extends PopupWindow {
    private PictureAlbumDirectoryAdapter adapter;
    private int chooseMode;
    private PictureSelectionConfig config;
    private Context context;
    private Drawable drawableDown;
    private Drawable drawableUp;
    private boolean isDismiss = false;
    private ImageView ivArrowView;
    private RecyclerView mRecyclerView;
    private int maxHeight;
    private View rootViewBg;
    private View window;

    public FolderPopWindow(Context context2) {
        this.context = context2;
        PictureSelectionConfig instance = PictureSelectionConfig.getInstance();
        this.config = instance;
        this.chooseMode = instance.chooseMode;
        View inflate = LayoutInflater.from(context2).inflate(R.layout.picture_window_folder, (ViewGroup) null);
        this.window = inflate;
        setContentView(inflate);
        setWidth(-1);
        setHeight(-2);
        setAnimationStyle(R.style.PictureThemeWindowStyle);
        setFocusable(true);
        setOutsideTouchable(true);
        update();
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle != null) {
            int i2 = pictureSelectorUIStyle.picture_top_titleArrowUpDrawable;
            if (i2 != 0) {
                Object obj = a.f3266a;
                this.drawableUp = context2.getDrawable(i2);
            }
            int i3 = PictureSelectionConfig.uiStyle.picture_top_titleArrowDownDrawable;
            if (i3 != 0) {
                Object obj2 = a.f3266a;
                this.drawableDown = context2.getDrawable(i3);
            }
        } else {
            PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
            if (pictureParameterStyle != null) {
                int i4 = pictureParameterStyle.pictureTitleUpResId;
                if (i4 != 0) {
                    Object obj3 = a.f3266a;
                    this.drawableUp = context2.getDrawable(i4);
                }
                int i5 = PictureSelectionConfig.style.pictureTitleDownResId;
                if (i5 != 0) {
                    Object obj4 = a.f3266a;
                    this.drawableDown = context2.getDrawable(i5);
                }
            } else {
                PictureSelectionConfig pictureSelectionConfig = this.config;
                if (pictureSelectionConfig.isWeChatStyle) {
                    int i6 = R.drawable.picture_icon_wechat_up;
                    Object obj5 = a.f3266a;
                    this.drawableUp = context2.getDrawable(i6);
                    this.drawableDown = context2.getDrawable(R.drawable.picture_icon_wechat_down);
                } else {
                    int i7 = pictureSelectionConfig.upResId;
                    if (i7 != 0) {
                        Object obj6 = a.f3266a;
                        this.drawableUp = context2.getDrawable(i7);
                    } else {
                        this.drawableUp = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_up_icon, R.drawable.picture_icon_arrow_up);
                    }
                    int i8 = this.config.downResId;
                    if (i8 != 0) {
                        Object obj7 = a.f3266a;
                        this.drawableDown = context2.getDrawable(i8);
                    } else {
                        this.drawableDown = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_down_icon, R.drawable.picture_icon_arrow_down);
                    }
                }
            }
        }
        this.maxHeight = (int) (((double) ScreenUtils.getScreenHeight(context2)) * 0.6d);
        initView();
    }

    public void bindFolder(List<LocalMediaFolder> list) {
        this.adapter.setChooseMode(this.chooseMode);
        this.adapter.bindFolderData(list);
        this.mRecyclerView.getLayoutParams().height = (list == null || list.size() <= 8) ? -2 : this.maxHeight;
    }

    public void dismiss() {
        if (!this.isDismiss) {
            this.rootViewBg.animate().alpha(0.0f).setDuration(50).start();
            this.ivArrowView.setImageDrawable(this.drawableDown);
            AnimUtils.rotateArrow(this.ivArrowView, false);
            this.isDismiss = true;
            super.dismiss();
            this.isDismiss = false;
        }
    }

    public LocalMediaFolder getFolder(int i2) {
        if (this.adapter.getFolderData().size() <= 0 || i2 >= this.adapter.getFolderData().size()) {
            return null;
        }
        return this.adapter.getFolderData().get(i2);
    }

    public List<LocalMediaFolder> getFolderData() {
        return this.adapter.getFolderData();
    }

    public void initView() {
        this.rootViewBg = this.window.findViewById(R.id.rootViewBg);
        this.adapter = new PictureAlbumDirectoryAdapter(this.config);
        RecyclerView recyclerView = (RecyclerView) this.window.findViewById(R.id.folder_list);
        this.mRecyclerView = recyclerView;
        recyclerView.setLayoutManager(new LinearLayoutManager(this.context));
        this.mRecyclerView.setAdapter(this.adapter);
        this.window.findViewById(R.id.rootView);
        this.rootViewBg.setOnClickListener(new d.k.a.a.g0.a(this));
    }

    public boolean isEmpty() {
        return this.adapter.getFolderData().size() == 0;
    }

    public void setArrowImageView(ImageView imageView) {
        this.ivArrowView = imageView;
    }

    public void setOnAlbumItemClickListener(OnAlbumItemClickListener onAlbumItemClickListener) {
        this.adapter.setOnAlbumItemClickListener(onAlbumItemClickListener);
    }

    public void showAsDropDown(View view) {
        try {
            if (Build.VERSION.SDK_INT == 24) {
                int[] iArr = new int[2];
                view.getLocationInWindow(iArr);
                showAtLocation(view, 0, 0, iArr[1] + view.getHeight());
            } else {
                super.showAsDropDown(view);
            }
            this.isDismiss = false;
            this.ivArrowView.setImageDrawable(this.drawableUp);
            AnimUtils.rotateArrow(this.ivArrowView, true);
            this.rootViewBg.animate().alpha(1.0f).setDuration(250).setStartDelay(250).start();
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0040, code lost:
        r5.setCheckedNum(1);
     */
    public void updateFolderCheckStatus(List<LocalMedia> list) {
        try {
            List<LocalMediaFolder> folderData = this.adapter.getFolderData();
            int size = folderData.size();
            int size2 = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                LocalMediaFolder localMediaFolder = folderData.get(i2);
                localMediaFolder.setCheckedNum(0);
                int i3 = 0;
                while (true) {
                    if (i3 >= size2) {
                        break;
                    } else if (localMediaFolder.getName().equals(list.get(i3).getParentFolderName())) {
                        break;
                    } else if (localMediaFolder.getBucketId() == -1) {
                        break;
                    } else {
                        i3++;
                    }
                }
            }
            this.adapter.bindFolderData(folderData);
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }
}
