package com.lxj.xpopup.widget;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.widget.FrameLayout;
import android.widget.OverScroller;
import androidx.core.view.NestedScrollingParent;
import androidx.core.view.ViewCompat;
import com.lxj.xpopup.enums.LayoutStatus;
import d.l.b.a;
import d.l.b.b.e;
import java.util.concurrent.atomic.AtomicInteger;

public class SmartDragLayout extends FrameLayout implements NestedScrollingParent {
    private static final String TAG = "SmartDragLayout";
    public e bgAnimator;
    private View child;
    public boolean dismissOnTouchOutside;
    public boolean enableDrag;
    public boolean hasShadowBg;
    public boolean isScrollUp;
    public boolean isUserClose;
    public int lastHeight;
    private OnCloseListener listener;
    public int maxY;
    public int minY;
    public OverScroller scroller;
    public LayoutStatus status;
    public float touchX;
    public float touchY;
    public VelocityTracker tracker;

    public interface OnCloseListener {
        void onClose();

        void onOpen();
    }

    public SmartDragLayout(Context context) {
        this(context, null);
    }

    private void finishScroll() {
        if (this.enableDrag) {
            this.scroller.startScroll(getScrollX(), getScrollY(), 0, (getScrollY() > (this.isScrollUp ? this.maxY - this.minY : (this.maxY - this.minY) * 2) / 3 ? this.maxY : this.minY) - getScrollY(), a.f12189b);
            AtomicInteger atomicInteger = ViewCompat.f1365a;
            postInvalidateOnAnimation();
        }
    }

    public void close() {
        this.isUserClose = true;
        this.status = LayoutStatus.Closing;
        post(new Runnable() {
            /* class com.lxj.xpopup.widget.SmartDragLayout.AnonymousClass2 */

            public void run() {
                SmartDragLayout smartDragLayout = SmartDragLayout.this;
                smartDragLayout.smoothScroll(smartDragLayout.minY - smartDragLayout.getScrollY(), false);
            }
        });
    }

    public void computeScroll() {
        super.computeScroll();
        if (this.scroller.computeScrollOffset()) {
            scrollTo(this.scroller.getCurrX(), this.scroller.getCurrY());
            AtomicInteger atomicInteger = ViewCompat.f1365a;
            postInvalidateOnAnimation();
        }
    }

    public void dismissOnTouchOutside(boolean z) {
        this.dismissOnTouchOutside = z;
    }

    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        this.isUserClose = true;
        return super.dispatchTouchEvent(motionEvent);
    }

    public void enableDrag(boolean z) {
        this.enableDrag = z;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public int getNestedScrollAxes() {
        return 2;
    }

    public void hasShadowBg(boolean z) {
        this.hasShadowBg = z;
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.isScrollUp = false;
        this.isUserClose = false;
        setTranslationY(0.0f);
    }

    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        this.maxY = this.child.getMeasuredHeight();
        this.minY = 0;
        int measuredWidth = (getMeasuredWidth() / 2) - (this.child.getMeasuredWidth() / 2);
        if (this.enableDrag) {
            this.child.layout(measuredWidth, getMeasuredHeight(), this.child.getMeasuredWidth() + measuredWidth, getMeasuredHeight() + this.maxY);
            if (this.status == LayoutStatus.Open) {
                scrollTo(getScrollX(), getScrollY() - (this.lastHeight - this.maxY));
            }
        } else {
            this.child.layout(measuredWidth, getMeasuredHeight() - this.child.getMeasuredHeight(), this.child.getMeasuredWidth() + measuredWidth, getMeasuredHeight());
        }
        this.lastHeight = this.maxY;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onNestedFling(View view, float f2, float f3, boolean z) {
        if ((getScrollY() > this.minY && getScrollY() < this.maxY) && f3 < -1500.0f) {
            close();
        }
        return false;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onNestedPreFling(View view, float f2, float f3) {
        return false;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedPreScroll(View view, int i2, int i3, int[] iArr) {
        if (i3 > 0) {
            int scrollY = getScrollY() + i3;
            if (scrollY < this.maxY) {
                iArr[1] = i3;
            }
            scrollTo(getScrollX(), scrollY);
        }
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedScroll(View view, int i2, int i3, int i4, int i5) {
        scrollTo(getScrollX(), getScrollY() + i5);
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedScrollAccepted(View view, View view2, int i2) {
        this.scroller.abortAnimation();
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onStartNestedScroll(View view, View view2, int i2) {
        return i2 == 2 && this.enableDrag;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onStopNestedScroll(View view) {
        finishScroll();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x001c, code lost:
        if (r0 != 3) goto L_0x00d5;
     */
    public boolean onTouchEvent(MotionEvent motionEvent) {
        if (this.scroller.computeScrollOffset()) {
            this.touchX = 0.0f;
            this.touchY = 0.0f;
            return false;
        }
        int action = motionEvent.getAction();
        if (action != 0) {
            if (action != 1) {
                if (action == 2) {
                    if (this.enableDrag) {
                        this.tracker.addMovement(motionEvent);
                        this.tracker.computeCurrentVelocity(1000);
                        scrollTo(getScrollX(), getScrollY() - ((int) (motionEvent.getY() - this.touchY)));
                        this.touchY = motionEvent.getY();
                    }
                }
            }
            Rect rect = new Rect();
            this.child.getGlobalVisibleRect(rect);
            if (!d.l.b.g.e.l(motionEvent.getRawX(), motionEvent.getRawY(), rect) && this.dismissOnTouchOutside) {
                if (((float) Math.sqrt(Math.pow((double) (motionEvent.getY() - this.touchY), 2.0d) + Math.pow((double) (motionEvent.getX() - this.touchX), 2.0d))) < ((float) ViewConfiguration.get(getContext()).getScaledTouchSlop())) {
                    performClick();
                }
            }
            if (this.enableDrag) {
                if (this.tracker.getYVelocity() > 1500.0f) {
                    close();
                } else {
                    finishScroll();
                }
                this.tracker.clear();
                this.tracker.recycle();
            }
        } else {
            if (this.enableDrag) {
                this.tracker = VelocityTracker.obtain();
            }
            this.touchX = motionEvent.getX();
            this.touchY = motionEvent.getY();
        }
        return true;
    }

    public void onViewAdded(View view) {
        super.onViewAdded(view);
        this.child = view;
    }

    public void open() {
        this.status = LayoutStatus.Opening;
        post(new Runnable() {
            /* class com.lxj.xpopup.widget.SmartDragLayout.AnonymousClass1 */

            public void run() {
                SmartDragLayout smartDragLayout = SmartDragLayout.this;
                smartDragLayout.smoothScroll(smartDragLayout.maxY - smartDragLayout.getScrollY(), true);
            }
        });
    }

    public void scrollTo(int i2, int i3) {
        LayoutStatus layoutStatus;
        LayoutStatus layoutStatus2;
        int i4 = this.maxY;
        if (i3 > i4) {
            i3 = i4;
        }
        int i5 = this.minY;
        if (i3 < i5) {
            i3 = i5;
        }
        float f2 = (((float) (i3 - i5)) * 1.0f) / ((float) (i4 - i5));
        this.isScrollUp = i3 > getScrollY();
        if (this.hasShadowBg) {
            setBackgroundColor(this.bgAnimator.d(f2));
        }
        OnCloseListener onCloseListener = this.listener;
        if (onCloseListener != null) {
            if (this.isUserClose && f2 == 0.0f && this.status != (layoutStatus2 = LayoutStatus.Close)) {
                this.status = layoutStatus2;
                onCloseListener.onClose();
            } else if (f2 == 1.0f && this.status != (layoutStatus = LayoutStatus.Open)) {
                this.status = layoutStatus;
                onCloseListener.onOpen();
            }
        }
        super.scrollTo(i2, i3);
    }

    public void setOnCloseListener(OnCloseListener onCloseListener) {
        this.listener = onCloseListener;
    }

    public void smoothScroll(final int i2, final boolean z) {
        post(new Runnable() {
            /* class com.lxj.xpopup.widget.SmartDragLayout.AnonymousClass3 */

            public void run() {
                SmartDragLayout smartDragLayout = SmartDragLayout.this;
                smartDragLayout.scroller.startScroll(smartDragLayout.getScrollX(), SmartDragLayout.this.getScrollY(), 0, i2, (int) (z ? (float) a.f12189b : ((float) a.f12189b) * 0.8f));
                SmartDragLayout smartDragLayout2 = SmartDragLayout.this;
                AtomicInteger atomicInteger = ViewCompat.f1365a;
                smartDragLayout2.postInvalidateOnAnimation();
            }
        });
    }

    public SmartDragLayout(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public SmartDragLayout(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.bgAnimator = new e();
        this.enableDrag = true;
        this.dismissOnTouchOutside = true;
        this.hasShadowBg = true;
        this.isUserClose = false;
        this.status = LayoutStatus.Close;
        this.scroller = new OverScroller(context);
    }
}
