package com.lzy.okgo.model;

import d.a.a.a.a;
import d.l.b.g.g.b;
import java.io.File;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import okhttp3.MediaType;

public class HttpParams implements Serializable {
    public static final boolean IS_REPLACE = true;
    public static final MediaType MEDIA_TYPE_JSON = MediaType.parse("application/json;charset=utf-8");
    public static final MediaType MEDIA_TYPE_PLAIN = MediaType.parse("text/plain;charset=utf-8");
    public static final MediaType MEDIA_TYPE_STREAM = MediaType.parse("application/octet-stream");
    private static final long serialVersionUID = 7369819159227055048L;
    public LinkedHashMap<String, List<FileWrapper>> fileParamsMap;
    public LinkedHashMap<String, List<String>> urlParamsMap;

    public static class FileWrapper implements Serializable {
        private static final long serialVersionUID = -2356139899636767776L;
        public transient MediaType contentType;
        public File file;
        public String fileName;
        public long fileSize;

        public FileWrapper(File file2, String str, MediaType mediaType) {
            this.file = file2;
            this.fileName = str;
            this.contentType = mediaType;
            this.fileSize = file2.length();
        }

        private void readObject(ObjectInputStream objectInputStream) {
            objectInputStream.defaultReadObject();
            this.contentType = MediaType.parse((String) objectInputStream.readObject());
        }

        private void writeObject(ObjectOutputStream objectOutputStream) {
            objectOutputStream.defaultWriteObject();
            objectOutputStream.writeObject(this.contentType.toString());
        }

        public String toString() {
            StringBuilder B = a.B("FileWrapper{file=");
            B.append(this.file);
            B.append(", fileName=");
            B.append(this.fileName);
            B.append(", contentType=");
            B.append(this.contentType);
            B.append(", fileSize=");
            B.append(this.fileSize);
            B.append("}");
            return B.toString();
        }
    }

    public HttpParams() {
        init();
    }

    private void init() {
        this.urlParamsMap = new LinkedHashMap<>();
        this.fileParamsMap = new LinkedHashMap<>();
    }

    public void clear() {
        this.urlParamsMap.clear();
        this.fileParamsMap.clear();
    }

    public void put(HttpParams httpParams) {
        if (httpParams != null) {
            LinkedHashMap<String, List<String>> linkedHashMap = httpParams.urlParamsMap;
            if (linkedHashMap != null && !linkedHashMap.isEmpty()) {
                this.urlParamsMap.putAll(httpParams.urlParamsMap);
            }
            LinkedHashMap<String, List<FileWrapper>> linkedHashMap2 = httpParams.fileParamsMap;
            if (linkedHashMap2 != null && !linkedHashMap2.isEmpty()) {
                this.fileParamsMap.putAll(httpParams.fileParamsMap);
            }
        }
    }

    public void putFileParams(String str, List<File> list) {
        if (!(str == null || list == null || list.isEmpty())) {
            for (File file : list) {
                put(str, file);
            }
        }
    }

    public void putFileWrapperParams(String str, List<FileWrapper> list) {
        if (!(str == null || list == null || list.isEmpty())) {
            for (FileWrapper fileWrapper : list) {
                put(str, fileWrapper);
            }
        }
    }

    public void putUrlParams(String str, List<String> list) {
        if (!(str == null || list == null || list.isEmpty())) {
            for (String str2 : list) {
                put(str, str2, false);
            }
        }
    }

    public void remove(String str) {
        removeUrl(str);
        removeFile(str);
    }

    public void removeFile(String str) {
        this.fileParamsMap.remove(str);
    }

    public void removeUrl(String str) {
        this.urlParamsMap.remove(str);
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, List<String>> entry : this.urlParamsMap.entrySet()) {
            if (sb.length() > 0) {
                sb.append("&");
            }
            sb.append(entry.getKey());
            sb.append("=");
            sb.append(entry.getValue());
        }
        for (Map.Entry<String, List<FileWrapper>> entry2 : this.fileParamsMap.entrySet()) {
            if (sb.length() > 0) {
                sb.append("&");
            }
            sb.append(entry2.getKey());
            sb.append("=");
            sb.append(entry2.getValue());
        }
        return sb.toString();
    }

    public HttpParams(String str, String str2) {
        init();
        put(str, str2, true);
    }

    public void put(Map<String, String> map, boolean... zArr) {
        if (!(map == null || map.isEmpty())) {
            for (Map.Entry<String, String> entry : map.entrySet()) {
                put(entry.getKey(), entry.getValue(), zArr);
            }
        }
    }

    public HttpParams(String str, File file) {
        init();
        put(str, file);
    }

    public void put(String str, String str2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, str2, true);
        } else {
            put(str, str2, zArr[0]);
        }
    }

    public void put(String str, int i2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(i2), true);
        } else {
            put(str, String.valueOf(i2), zArr[0]);
        }
    }

    public void put(String str, long j2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(j2), true);
        } else {
            put(str, String.valueOf(j2), zArr[0]);
        }
    }

    public void put(String str, float f2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(f2), true);
        } else {
            put(str, String.valueOf(f2), zArr[0]);
        }
    }

    public void put(String str, double d2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(d2), true);
        } else {
            put(str, String.valueOf(d2), zArr[0]);
        }
    }

    public void put(String str, char c2, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(c2), true);
        } else {
            put(str, String.valueOf(c2), zArr[0]);
        }
    }

    public void put(String str, boolean z, boolean... zArr) {
        if (zArr == null || zArr.length <= 0) {
            put(str, String.valueOf(z), true);
        } else {
            put(str, String.valueOf(z), zArr[0]);
        }
    }

    private void put(String str, String str2, boolean z) {
        if (str != null && str2 != null) {
            List<String> list = this.urlParamsMap.get(str);
            if (list == null) {
                list = new ArrayList<>();
                this.urlParamsMap.put(str, list);
            }
            if (z) {
                list.clear();
            }
            list.add(str2);
        }
    }

    public void put(String str, File file) {
        put(str, file, file.getName());
    }

    public void put(String str, File file, String str2) {
        put(str, file, str2, b.Q(str2));
    }

    public void put(String str, FileWrapper fileWrapper) {
        if (str != null && fileWrapper != null) {
            put(str, fileWrapper.file, fileWrapper.fileName, fileWrapper.contentType);
        }
    }

    public void put(String str, File file, String str2, MediaType mediaType) {
        if (str != null) {
            List<FileWrapper> list = this.fileParamsMap.get(str);
            if (list == null) {
                list = new ArrayList<>();
                this.fileParamsMap.put(str, list);
            }
            list.add(new FileWrapper(file, str2, mediaType));
        }
    }
}
