package com.lzy.okgo.request.base;

import android.text.TextUtils;
import com.lzy.okgo.model.HttpHeaders;
import com.lzy.okgo.model.HttpParams;
import com.lzy.okgo.request.base.BodyRequest;
import d.l.b.g.g.b;
import java.io.File;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.List;
import java.util.Map;
import okhttp3.FormBody;
import okhttp3.MediaType;
import okhttp3.MultipartBody;
import okhttp3.Request;
import okhttp3.RequestBody;
import org.json.JSONArray;
import org.json.JSONObject;

public abstract class BodyRequest<T, R extends BodyRequest> extends Request<T, R> {
    private static final long serialVersionUID = -6459175248476927501L;
    public byte[] bs;
    public String content;
    public transient File file;
    public boolean isMultipart = false;
    public boolean isSpliceUrl = false;
    public transient MediaType mediaType;
    public RequestBody requestBody;

    public BodyRequest(String str) {
        super(str);
    }

    private void readObject(ObjectInputStream objectInputStream) {
        objectInputStream.defaultReadObject();
        String str = (String) objectInputStream.readObject();
        if (!TextUtils.isEmpty(str)) {
            this.mediaType = MediaType.parse(str);
        }
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.defaultWriteObject();
        MediaType mediaType2 = this.mediaType;
        objectOutputStream.writeObject(mediaType2 == null ? "" : mediaType2.toString());
    }

    @Override // com.lzy.okgo.request.base.Request
    public RequestBody generateRequestBody() {
        MediaType mediaType2;
        MediaType mediaType3;
        MediaType mediaType4;
        if (this.isSpliceUrl) {
            this.url = b.v(this.baseUrl, this.params.urlParamsMap);
        }
        RequestBody requestBody2 = this.requestBody;
        if (requestBody2 != null) {
            return requestBody2;
        }
        String str = this.content;
        if (!(str == null || (mediaType4 = this.mediaType) == null)) {
            return RequestBody.create(mediaType4, str);
        }
        byte[] bArr = this.bs;
        if (!(bArr == null || (mediaType3 = this.mediaType) == null)) {
            return RequestBody.create(mediaType3, bArr);
        }
        File file2 = this.file;
        if (!(file2 == null || (mediaType2 = this.mediaType) == null)) {
            return RequestBody.create(mediaType2, file2);
        }
        HttpParams httpParams = this.params;
        boolean z = this.isMultipart;
        if (!httpParams.fileParamsMap.isEmpty() || z) {
            MultipartBody.Builder type = new MultipartBody.Builder().setType(MultipartBody.FORM);
            if (!httpParams.urlParamsMap.isEmpty()) {
                for (Map.Entry<String, List<String>> entry : httpParams.urlParamsMap.entrySet()) {
                    for (String str2 : entry.getValue()) {
                        type.addFormDataPart(entry.getKey(), str2);
                    }
                }
            }
            for (Map.Entry<String, List<HttpParams.FileWrapper>> entry2 : httpParams.fileParamsMap.entrySet()) {
                for (HttpParams.FileWrapper fileWrapper : entry2.getValue()) {
                    type.addFormDataPart(entry2.getKey(), fileWrapper.fileName, RequestBody.create(fileWrapper.contentType, fileWrapper.file));
                }
            }
            return type.build();
        }
        FormBody.Builder builder = new FormBody.Builder();
        for (String str3 : httpParams.urlParamsMap.keySet()) {
            for (String str4 : httpParams.urlParamsMap.get(str3)) {
                builder.add(str3, str4);
            }
        }
        return builder.build();
    }

    public Request.Builder generateRequestBuilder(RequestBody requestBody2) {
        try {
            headers(HttpHeaders.HEAD_KEY_CONTENT_LENGTH, String.valueOf(requestBody2.contentLength()));
        } catch (IOException e2) {
            e2.printStackTrace();
        }
        return b.f(new Request.Builder(), this.headers);
    }

    public R addFileParams(String str, List<File> list) {
        this.params.putFileParams(str, list);
        return this;
    }

    public R addFileWrapperParams(String str, List<HttpParams.FileWrapper> list) {
        this.params.putFileWrapperParams(str, list);
        return this;
    }

    public R isMultipart(boolean z) {
        this.isMultipart = z;
        return this;
    }

    public R isSpliceUrl(boolean z) {
        this.isSpliceUrl = z;
        return this;
    }

    public R upRequestBody(RequestBody requestBody2) {
        this.requestBody = requestBody2;
        return this;
    }

    public R upBytes(byte[] bArr) {
        this.bs = bArr;
        this.mediaType = HttpParams.MEDIA_TYPE_STREAM;
        return this;
    }

    public R upFile(File file2) {
        this.file = file2;
        this.mediaType = b.Q(file2.getName());
        return this;
    }

    public R upString(String str) {
        this.content = str;
        this.mediaType = HttpParams.MEDIA_TYPE_PLAIN;
        return this;
    }

    public R params(String str, File file2) {
        this.params.put(str, file2);
        return this;
    }

    public R upJson(String str) {
        this.content = str;
        this.mediaType = HttpParams.MEDIA_TYPE_JSON;
        return this;
    }

    public R params(String str, File file2, String str2) {
        this.params.put(str, file2, str2);
        return this;
    }

    public R upBytes(byte[] bArr, MediaType mediaType2) {
        this.bs = bArr;
        this.mediaType = mediaType2;
        return this;
    }

    public R upFile(File file2, MediaType mediaType2) {
        this.file = file2;
        this.mediaType = mediaType2;
        return this;
    }

    public R upString(String str, MediaType mediaType2) {
        this.content = str;
        this.mediaType = mediaType2;
        return this;
    }

    public R params(String str, File file2, String str2, MediaType mediaType2) {
        this.params.put(str, file2, str2, mediaType2);
        return this;
    }

    public R upJson(JSONObject jSONObject) {
        this.content = jSONObject.toString();
        this.mediaType = HttpParams.MEDIA_TYPE_JSON;
        return this;
    }

    public R upJson(JSONArray jSONArray) {
        this.content = jSONArray.toString();
        this.mediaType = HttpParams.MEDIA_TYPE_JSON;
        return this;
    }
}
