package com.maning.updatelibrary;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ProviderInfo;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import androidx.core.content.FileProvider;
import com.maning.updatelibrary.http.AbsFileProgressCallback;
import com.maning.updatelibrary.http.DownloadFileUtils;
import com.maning.updatelibrary.utils.ActForResultCallback;
import com.maning.updatelibrary.utils.ActResultRequest;
import com.maning.updatelibrary.utils.MNUtils;
import d.a.a.a.a;
import java.io.File;

public class InstallUtils {
    private static final String TAG = "InstallUtils";
    private static boolean isDownloading = false;
    private static Context mContext;
    private static DownloadCallBack mDownloadCallBack;
    private static InstallUtils mInstance;
    private String filePath;
    private String httpUrl;

    public interface DownloadCallBack {
        void cancle();

        void onComplete(String str);

        void onFail(Exception exc);

        void onLoading(long j2, long j3);

        void onStart();
    }

    public interface InstallCallBack {
        void onFail(Exception exc);

        void onSuccess();
    }

    public interface InstallPermissionCallBack {
        void onDenied();

        void onGranted();
    }

    private InstallUtils() {
    }

    public static void cancleDownload() {
        DownloadFileUtils.cancle(InstallUtils.class);
    }

    public static void checkInstallPermission(Activity activity, InstallPermissionCallBack installPermissionCallBack) {
        if (!hasInstallPermission(activity)) {
            openInstallPermissionSetting(activity, installPermissionCallBack);
        } else if (installPermissionCallBack != null) {
            installPermissionCallBack.onGranted();
        }
    }

    private static String getFileProviderAuthority(Context context) {
        try {
            ProviderInfo[] providerInfoArr = context.getPackageManager().getPackageInfo(context.getPackageName(), 8).providers;
            for (ProviderInfo providerInfo : providerInfoArr) {
                if (MNUpdateApkFileProvider.class.getName().equals(providerInfo.name) && providerInfo.authority.endsWith(".mn_update_apk.file_provider")) {
                    return providerInfo.authority;
                }
            }
            return null;
        } catch (PackageManager.NameNotFoundException unused) {
            return null;
        }
    }

    public static Intent getInstallIntent(Context context, String str) {
        Uri uri;
        Intent intent = new Intent();
        intent.addFlags(268435456);
        intent.setAction("android.intent.action.VIEW");
        File file = new File(str);
        if (Build.VERSION.SDK_INT >= 24) {
            intent.addFlags(1);
            uri = FileProvider.getUriForFile(context, getFileProviderAuthority(context), file);
            context.grantUriPermission(context.getPackageName(), uri, 1);
            context.grantUriPermission(context.getPackageName(), uri, 64);
            intent.addFlags(1);
            intent.addFlags(64);
        } else {
            uri = Uri.fromFile(file);
        }
        intent.setDataAndType(uri, "application/vnd.android.package-archive");
        return intent;
    }

    public static boolean hasInstallPermission(Context context) {
        if (MNUtils.isAndroid8()) {
            return context.getPackageManager().canRequestPackageInstalls();
        }
        return true;
    }

    public static void installAPK(Activity activity, String str, final InstallCallBack installCallBack) {
        try {
            MNUtils.changeApkFileMode(new File(str));
            new ActResultRequest(activity).startForResult(getInstallIntent(activity, str), new ActForResultCallback() {
                /* class com.maning.updatelibrary.InstallUtils.AnonymousClass2 */

                @Override // com.maning.updatelibrary.utils.ActForResultCallback
                public void onActivityResult(int i2, Intent intent) {
                    InstallCallBack installCallBack = InstallCallBack.this;
                    if (installCallBack != null) {
                        installCallBack.onSuccess();
                    }
                }
            });
        } catch (Exception e2) {
            if (installCallBack != null) {
                installCallBack.onFail(e2);
            }
        }
    }

    public static void installAPKWithBrower(Context context, String str) {
        context.startActivity(new Intent("android.intent.action.VIEW", Uri.parse(str)));
    }

    public static boolean isDownloading() {
        return isDownloading;
    }

    public static void openInstallPermissionSetting(Activity activity, final InstallPermissionCallBack installPermissionCallBack) {
        if (Build.VERSION.SDK_INT >= 26) {
            StringBuilder B = a.B("package:");
            B.append(activity.getPackageName());
            new ActResultRequest(activity).startForResult(new Intent("android.settings.MANAGE_UNKNOWN_APP_SOURCES", Uri.parse(B.toString())), new ActForResultCallback() {
                /* class com.maning.updatelibrary.InstallUtils.AnonymousClass3 */

                @Override // com.maning.updatelibrary.utils.ActForResultCallback
                public void onActivityResult(int i2, Intent intent) {
                    String str = InstallUtils.TAG;
                    Log.i(str, "onActivityResult:" + i2);
                    if (i2 == -1) {
                        InstallPermissionCallBack installPermissionCallBack = InstallPermissionCallBack.this;
                        if (installPermissionCallBack != null) {
                            installPermissionCallBack.onGranted();
                            return;
                        }
                        return;
                    }
                    InstallPermissionCallBack installPermissionCallBack2 = InstallPermissionCallBack.this;
                    if (installPermissionCallBack2 != null) {
                        installPermissionCallBack2.onDenied();
                    }
                }
            });
        } else if (installPermissionCallBack != null) {
            installPermissionCallBack.onGranted();
        }
    }

    public static void setDownloadCallBack(DownloadCallBack downloadCallBack) {
        if (isDownloading) {
            mDownloadCallBack = downloadCallBack;
        }
    }

    public static InstallUtils with(Context context) {
        mContext = context.getApplicationContext();
        if (mInstance == null) {
            mInstance = new InstallUtils();
        }
        return mInstance;
    }

    public InstallUtils setApkPath(String str) {
        this.filePath = str;
        return mInstance;
    }

    public InstallUtils setApkUrl(String str) {
        this.httpUrl = str;
        return mInstance;
    }

    public InstallUtils setCallBack(DownloadCallBack downloadCallBack) {
        mDownloadCallBack = downloadCallBack;
        return mInstance;
    }

    public void startDownload() {
        if (isDownloading) {
            cancleDownload();
        }
        if (TextUtils.isEmpty(this.filePath)) {
            this.filePath = MNUtils.getCachePath(mContext) + "/update.apk";
        }
        MNUtils.changeApkFileMode(new File(this.filePath));
        DownloadFileUtils.with().downloadPath(this.filePath).url(this.httpUrl).tag(InstallUtils.class).execute(new AbsFileProgressCallback() {
            /* class com.maning.updatelibrary.InstallUtils.AnonymousClass1 */
            public int currentProgress = 0;

            @Override // com.maning.updatelibrary.http.AbsFileProgressCallback
            public void onCancle() {
                boolean unused = InstallUtils.isDownloading = false;
                if (InstallUtils.mDownloadCallBack != null) {
                    InstallUtils.mDownloadCallBack.cancle();
                }
            }

            @Override // com.maning.updatelibrary.http.AbsFileProgressCallback
            public void onFailed(String str) {
                boolean unused = InstallUtils.isDownloading = false;
                if (InstallUtils.mDownloadCallBack != null) {
                    InstallUtils.mDownloadCallBack.onFail(new Exception(str));
                }
            }

            @Override // com.maning.updatelibrary.http.AbsFileProgressCallback
            public void onProgress(long j2, long j3, boolean z) {
                boolean unused = InstallUtils.isDownloading = true;
                if (InstallUtils.mDownloadCallBack != null && 0 != j3) {
                    int i2 = (int) ((100 * j2) / j3);
                    if (i2 - this.currentProgress >= 1) {
                        InstallUtils.mDownloadCallBack.onLoading(j3, j2);
                    }
                    this.currentProgress = i2;
                }
            }

            @Override // com.maning.updatelibrary.http.AbsFileProgressCallback
            public void onStart() {
                boolean unused = InstallUtils.isDownloading = true;
                if (InstallUtils.mDownloadCallBack != null) {
                    InstallUtils.mDownloadCallBack.onStart();
                }
            }

            @Override // com.maning.updatelibrary.http.AbsFileProgressCallback
            public void onSuccess(String str) {
                boolean unused = InstallUtils.isDownloading = false;
                if (InstallUtils.mDownloadCallBack != null) {
                    InstallUtils.mDownloadCallBack.onComplete(InstallUtils.this.filePath);
                }
            }
        });
    }
}
