package com.maning.updatelibrary.http;

import android.os.Handler;
import android.os.Looper;
import okhttp3.MediaType;
import okhttp3.ResponseBody;
import okio.Buffer;
import okio.BufferedSource;
import okio.ForwardingSource;
import okio.Okio;
import okio.Source;

public class ProgressResponseBody extends ResponseBody {
    private BufferedSource bufferedSource;
    private Handler mUIHandler = new Handler(Looper.getMainLooper());
    private final AbsFileProgressCallback progressListener;
    private final ResponseBody responseBody;

    public interface ProgressListener {
        void update(long j2, long j3, boolean z);
    }

    public ProgressResponseBody(ResponseBody responseBody2, AbsFileProgressCallback absFileProgressCallback) {
        this.responseBody = responseBody2;
        this.progressListener = absFileProgressCallback;
    }

    @Override // okhttp3.ResponseBody
    public long contentLength() {
        return this.responseBody.contentLength();
    }

    @Override // okhttp3.ResponseBody
    public MediaType contentType() {
        return this.responseBody.contentType();
    }

    @Override // okhttp3.ResponseBody
    public BufferedSource source() {
        if (this.bufferedSource == null) {
            this.bufferedSource = Okio.buffer(source(this.responseBody.source()));
        }
        return this.bufferedSource;
    }

    private Source source(Source source) {
        return new ForwardingSource(source) {
            /* class com.maning.updatelibrary.http.ProgressResponseBody.AnonymousClass1 */
            public long totalBytesRead = 0;

            @Override // okio.Source, okio.ForwardingSource
            public long read(Buffer buffer, long j2) {
                final long read = super.read(buffer, j2);
                this.totalBytesRead += read != -1 ? read : 0;
                ProgressResponseBody.this.mUIHandler.post(new Runnable() {
                    /* class com.maning.updatelibrary.http.ProgressResponseBody.AnonymousClass1.AnonymousClass1 */

                    public void run() {
                        AbsFileProgressCallback absFileProgressCallback = ProgressResponseBody.this.progressListener;
                        AnonymousClass1 r0 = AnonymousClass1.this;
                        absFileProgressCallback.onProgress(r0.totalBytesRead, ProgressResponseBody.this.responseBody.contentLength(), read == -1);
                    }
                });
                return read;
            }
        };
    }
}
