package com.yanzhenjie.recyclerview;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import b.f.h;
import com.yanzhenjie.recyclerview.x.R;
import java.lang.reflect.Field;
import java.util.List;

public class AdapterWrapper extends RecyclerView.Adapter<RecyclerView.ViewHolder> {
    private static final int BASE_ITEM_TYPE_FOOTER = 200000;
    private static final int BASE_ITEM_TYPE_HEADER = 100000;
    private RecyclerView.Adapter mAdapter;
    private h<View> mFootViews = new h<>();
    private h<View> mHeaderViews = new h<>();
    private LayoutInflater mInflater;
    private OnItemClickListener mOnItemClickListener;
    private OnItemLongClickListener mOnItemLongClickListener;
    private OnItemMenuClickListener mOnItemMenuClickListener;
    private SwipeMenuCreator mSwipeMenuCreator;

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public ViewHolder(View view) {
            super(view);
        }
    }

    public AdapterWrapper(Context context, RecyclerView.Adapter adapter) {
        this.mInflater = LayoutInflater.from(context);
        this.mAdapter = adapter;
    }

    private int getContentItemCount() {
        return this.mAdapter.getItemCount();
    }

    private Class<?> getSupperClass(Class<?> cls) {
        Class<? super Object> superclass = cls.getSuperclass();
        return (superclass == null || superclass.equals(Object.class)) ? cls : getSupperClass(superclass);
    }

    public void addFooterView(View view) {
        this.mFootViews.h(getFooterCount() + BASE_ITEM_TYPE_FOOTER, view);
    }

    public void addFooterViewAndNotify(View view) {
        addFooterView(view);
        notifyItemInserted((getFooterCount() + (getHeaderCount() + getContentItemCount())) - 1);
    }

    public void addHeaderView(View view) {
        this.mHeaderViews.h(getHeaderCount() + BASE_ITEM_TYPE_HEADER, view);
    }

    public void addHeaderViewAndNotify(View view) {
        addHeaderView(view);
        notifyItemInserted(getHeaderCount() - 1);
    }

    public int getFooterCount() {
        return this.mFootViews.i();
    }

    public int getHeaderCount() {
        return this.mHeaderViews.i();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        return getFooterCount() + getHeaderCount() + getContentItemCount();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public long getItemId(int i2) {
        if (isHeaderOrFooter(i2)) {
            return (long) ((-i2) - 1);
        }
        return this.mAdapter.getItemId(i2 - getHeaderCount());
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int i2) {
        if (isHeader(i2)) {
            h<View> hVar = this.mHeaderViews;
            if (hVar.f2946h) {
                hVar.c();
            }
            return hVar.f2947j[i2];
        } else if (isFooter(i2)) {
            return this.mFootViews.g((i2 - getHeaderCount()) - getContentItemCount());
        } else {
            return this.mAdapter.getItemViewType(i2 - getHeaderCount());
        }
    }

    public RecyclerView.Adapter getOriginAdapter() {
        return this.mAdapter;
    }

    public boolean isFooter(int i2) {
        return i2 >= getHeaderCount() + getContentItemCount();
    }

    public boolean isHeader(int i2) {
        return i2 >= 0 && i2 < getHeaderCount();
    }

    public boolean isHeaderOrFooter(RecyclerView.ViewHolder viewHolder) {
        if (viewHolder instanceof ViewHolder) {
            return true;
        }
        return isHeaderOrFooter(viewHolder.getAdapterPosition());
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        this.mAdapter.onAttachedToRecyclerView(recyclerView);
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        if (layoutManager instanceof GridLayoutManager) {
            final GridLayoutManager gridLayoutManager = (GridLayoutManager) layoutManager;
            final GridLayoutManager.a spanSizeLookup = gridLayoutManager.getSpanSizeLookup();
            gridLayoutManager.setSpanSizeLookup(new GridLayoutManager.a() {
                /* class com.yanzhenjie.recyclerview.AdapterWrapper.AnonymousClass3 */

                @Override // androidx.recyclerview.widget.GridLayoutManager.a
                public int getSpanSize(int i2) {
                    if (AdapterWrapper.this.isHeaderOrFooter(i2)) {
                        return gridLayoutManager.getSpanCount();
                    }
                    GridLayoutManager.a aVar = spanSizeLookup;
                    if (aVar != null) {
                        return aVar.getSpanSize(i2);
                    }
                    return 1;
                }
            });
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i2) {
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i2, List<Object> list) {
        if (!isHeaderOrFooter(viewHolder)) {
            View view = viewHolder.itemView;
            int headerCount = i2 - getHeaderCount();
            if ((view instanceof SwipeMenuLayout) && this.mSwipeMenuCreator != null) {
                SwipeMenuLayout swipeMenuLayout = (SwipeMenuLayout) view;
                SwipeMenu swipeMenu = new SwipeMenu(swipeMenuLayout);
                SwipeMenu swipeMenu2 = new SwipeMenu(swipeMenuLayout);
                this.mSwipeMenuCreator.onCreateMenu(swipeMenu, swipeMenu2, headerCount);
                SwipeMenuView swipeMenuView = (SwipeMenuView) swipeMenuLayout.getChildAt(0);
                if (swipeMenu.hasMenuItems()) {
                    swipeMenuView.setOrientation(swipeMenu.getOrientation());
                    swipeMenuView.createMenu(viewHolder, swipeMenu, swipeMenuLayout, 1, this.mOnItemMenuClickListener);
                } else if (swipeMenuView.getChildCount() > 0) {
                    swipeMenuView.removeAllViews();
                }
                SwipeMenuView swipeMenuView2 = (SwipeMenuView) swipeMenuLayout.getChildAt(2);
                if (swipeMenu2.hasMenuItems()) {
                    swipeMenuView2.setOrientation(swipeMenu2.getOrientation());
                    swipeMenuView2.createMenu(viewHolder, swipeMenu2, swipeMenuLayout, -1, this.mOnItemMenuClickListener);
                } else if (swipeMenuView2.getChildCount() > 0) {
                    swipeMenuView2.removeAllViews();
                }
            }
            this.mAdapter.onBindViewHolder(viewHolder, headerCount, list);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i2) {
        View e2 = this.mHeaderViews.e(i2, null);
        if (e2 != null) {
            return new ViewHolder(e2);
        }
        View e3 = this.mFootViews.e(i2, null);
        if (e3 != null) {
            return new ViewHolder(e3);
        }
        final RecyclerView.ViewHolder onCreateViewHolder = this.mAdapter.onCreateViewHolder(viewGroup, i2);
        if (this.mOnItemClickListener != null) {
            onCreateViewHolder.itemView.setOnClickListener(new View.OnClickListener() {
                /* class com.yanzhenjie.recyclerview.AdapterWrapper.AnonymousClass1 */

                public void onClick(View view) {
                    AdapterWrapper.this.mOnItemClickListener.onItemClick(view, onCreateViewHolder.getAdapterPosition());
                }
            });
        }
        if (this.mOnItemLongClickListener != null) {
            onCreateViewHolder.itemView.setOnLongClickListener(new View.OnLongClickListener() {
                /* class com.yanzhenjie.recyclerview.AdapterWrapper.AnonymousClass2 */

                public boolean onLongClick(View view) {
                    AdapterWrapper.this.mOnItemLongClickListener.onItemLongClick(view, onCreateViewHolder.getAdapterPosition());
                    return true;
                }
            });
        }
        if (this.mSwipeMenuCreator == null) {
            return onCreateViewHolder;
        }
        View inflate = this.mInflater.inflate(R.layout.x_recycler_view_item, viewGroup, false);
        ((ViewGroup) inflate.findViewById(R.id.swipe_content)).addView(onCreateViewHolder.itemView);
        try {
            Field declaredField = getSupperClass(onCreateViewHolder.getClass()).getDeclaredField("itemView");
            if (!declaredField.isAccessible()) {
                declaredField.setAccessible(true);
            }
            declaredField.set(onCreateViewHolder, inflate);
        } catch (Exception unused) {
        }
        return onCreateViewHolder;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onDetachedFromRecyclerView(RecyclerView recyclerView) {
        this.mAdapter.onDetachedFromRecyclerView(recyclerView);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public boolean onFailedToRecycleView(RecyclerView.ViewHolder viewHolder) {
        if (!isHeaderOrFooter(viewHolder)) {
            return this.mAdapter.onFailedToRecycleView(viewHolder);
        }
        return false;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewAttachedToWindow(RecyclerView.ViewHolder viewHolder) {
        if (isHeaderOrFooter(viewHolder)) {
            ViewGroup.LayoutParams layoutParams = viewHolder.itemView.getLayoutParams();
            if (layoutParams instanceof StaggeredGridLayoutManager.LayoutParams) {
                ((StaggeredGridLayoutManager.LayoutParams) layoutParams).f1923f = true;
                return;
            }
            return;
        }
        this.mAdapter.onViewAttachedToWindow(viewHolder);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewDetachedFromWindow(RecyclerView.ViewHolder viewHolder) {
        if (!isHeaderOrFooter(viewHolder)) {
            this.mAdapter.onViewDetachedFromWindow(viewHolder);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onViewRecycled(RecyclerView.ViewHolder viewHolder) {
        if (!isHeaderOrFooter(viewHolder)) {
            this.mAdapter.onViewRecycled(viewHolder);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void registerAdapterDataObserver(RecyclerView.h hVar) {
        super.registerAdapterDataObserver(hVar);
    }

    public void removeFooterViewAndNotify(View view) {
        int f2 = this.mFootViews.f(view);
        if (f2 != -1) {
            h<View> hVar = this.mFootViews;
            Object[] objArr = hVar.f2948k;
            Object obj = objArr[f2];
            Object obj2 = h.f2945d;
            if (obj != obj2) {
                objArr[f2] = obj2;
                hVar.f2946h = true;
            }
            notifyItemRemoved(getHeaderCount() + getContentItemCount() + f2);
        }
    }

    public void removeHeaderViewAndNotify(View view) {
        int f2 = this.mHeaderViews.f(view);
        if (f2 != -1) {
            h<View> hVar = this.mHeaderViews;
            Object[] objArr = hVar.f2948k;
            Object obj = objArr[f2];
            Object obj2 = h.f2945d;
            if (obj != obj2) {
                objArr[f2] = obj2;
                hVar.f2946h = true;
            }
            notifyItemRemoved(f2);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public final void setHasStableIds(boolean z) {
        super.setHasStableIds(z);
    }

    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.mOnItemClickListener = onItemClickListener;
    }

    public void setOnItemLongClickListener(OnItemLongClickListener onItemLongClickListener) {
        this.mOnItemLongClickListener = onItemLongClickListener;
    }

    public void setOnItemMenuClickListener(OnItemMenuClickListener onItemMenuClickListener) {
        this.mOnItemMenuClickListener = onItemMenuClickListener;
    }

    public void setSwipeMenuCreator(SwipeMenuCreator swipeMenuCreator) {
        this.mSwipeMenuCreator = swipeMenuCreator;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void unregisterAdapterDataObserver(RecyclerView.h hVar) {
        super.unregisterAdapterDataObserver(hVar);
    }

    public boolean isHeaderOrFooter(int i2) {
        return isHeader(i2) || isFooter(i2);
    }
}
