package com.yanzhenjie.recyclerview;

import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.yanzhenjie.recyclerview.touch.DefaultItemTouchHelper;
import com.yanzhenjie.recyclerview.touch.OnItemMoveListener;
import com.yanzhenjie.recyclerview.touch.OnItemMovementListener;
import com.yanzhenjie.recyclerview.touch.OnItemStateChangedListener;
import com.yanzhenjie.recyclerview.widget.DefaultLoadMoreView;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.ArrayList;
import java.util.List;

public class SwipeRecyclerView extends RecyclerView {
    private static final int INVALID_POSITION = -1;
    public static final int LEFT_DIRECTION = 1;
    public static final int RIGHT_DIRECTION = -1;
    private boolean allowSwipeDelete;
    private boolean isAutoLoadMore;
    private boolean isLoadError;
    private boolean isLoadMore;
    private RecyclerView.h mAdapterDataObserver;
    private AdapterWrapper mAdapterWrapper;
    private boolean mDataEmpty;
    private List<Integer> mDisableSwipeItemMenuList;
    private int mDownX;
    private int mDownY;
    private List<View> mFooterViewList;
    private boolean mHasMore;
    private List<View> mHeaderViewList;
    private DefaultItemTouchHelper mItemTouchHelper;
    private LoadMoreListener mLoadMoreListener;
    private LoadMoreView mLoadMoreView;
    public SwipeMenuLayout mOldSwipedLayout;
    public int mOldTouchedPosition;
    private OnItemClickListener mOnItemClickListener;
    private OnItemLongClickListener mOnItemLongClickListener;
    private OnItemMenuClickListener mOnItemMenuClickListener;
    public int mScaleTouchSlop;
    private int mScrollState;
    private boolean mSwipeItemMenuEnable;
    private SwipeMenuCreator mSwipeMenuCreator;

    @Retention(RetentionPolicy.SOURCE)
    public @interface DirectionMode {
    }

    public static class ItemClickListener implements OnItemClickListener {
        private OnItemClickListener mListener;
        private SwipeRecyclerView mRecyclerView;

        public ItemClickListener(SwipeRecyclerView swipeRecyclerView, OnItemClickListener onItemClickListener) {
            this.mRecyclerView = swipeRecyclerView;
            this.mListener = onItemClickListener;
        }

        @Override // com.yanzhenjie.recyclerview.OnItemClickListener
        public void onItemClick(View view, int i2) {
            int headerCount = i2 - this.mRecyclerView.getHeaderCount();
            if (headerCount >= 0) {
                this.mListener.onItemClick(view, headerCount);
            }
        }
    }

    public static class ItemLongClickListener implements OnItemLongClickListener {
        private OnItemLongClickListener mListener;
        private SwipeRecyclerView mRecyclerView;

        public ItemLongClickListener(SwipeRecyclerView swipeRecyclerView, OnItemLongClickListener onItemLongClickListener) {
            this.mRecyclerView = swipeRecyclerView;
            this.mListener = onItemLongClickListener;
        }

        @Override // com.yanzhenjie.recyclerview.OnItemLongClickListener
        public void onItemLongClick(View view, int i2) {
            int headerCount = i2 - this.mRecyclerView.getHeaderCount();
            if (headerCount >= 0) {
                this.mListener.onItemLongClick(view, headerCount);
            }
        }
    }

    public static class ItemMenuClickListener implements OnItemMenuClickListener {
        private OnItemMenuClickListener mListener;
        private SwipeRecyclerView mRecyclerView;

        public ItemMenuClickListener(SwipeRecyclerView swipeRecyclerView, OnItemMenuClickListener onItemMenuClickListener) {
            this.mRecyclerView = swipeRecyclerView;
            this.mListener = onItemMenuClickListener;
        }

        @Override // com.yanzhenjie.recyclerview.OnItemMenuClickListener
        public void onItemClick(SwipeMenuBridge swipeMenuBridge, int i2) {
            int headerCount = i2 - this.mRecyclerView.getHeaderCount();
            if (headerCount >= 0) {
                this.mListener.onItemClick(swipeMenuBridge, headerCount);
            }
        }
    }

    public interface LoadMoreListener {
        void onLoadMore();
    }

    public interface LoadMoreView {
        void onLoadError(int i2, String str);

        void onLoadFinish(boolean z, boolean z2);

        void onLoading();

        void onWaitToLoadMore(LoadMoreListener loadMoreListener);
    }

    public SwipeRecyclerView(Context context) {
        this(context, null);
    }

    private void checkAdapterExist(String str) {
        if (this.mAdapterWrapper != null) {
            throw new IllegalStateException(str);
        }
    }

    private void dispatchLoadMore() {
        if (!this.isLoadError) {
            if (!this.isAutoLoadMore) {
                LoadMoreView loadMoreView = this.mLoadMoreView;
                if (loadMoreView != null) {
                    loadMoreView.onWaitToLoadMore(this.mLoadMoreListener);
                }
            } else if (!this.isLoadMore && !this.mDataEmpty && this.mHasMore) {
                this.isLoadMore = true;
                LoadMoreView loadMoreView2 = this.mLoadMoreView;
                if (loadMoreView2 != null) {
                    loadMoreView2.onLoading();
                }
                LoadMoreListener loadMoreListener = this.mLoadMoreListener;
                if (loadMoreListener != null) {
                    loadMoreListener.onLoadMore();
                }
            }
        }
    }

    private View getSwipeMenuView(View view) {
        if (view instanceof SwipeMenuLayout) {
            return view;
        }
        ArrayList arrayList = new ArrayList();
        arrayList.add(view);
        while (!arrayList.isEmpty()) {
            View view2 = (View) arrayList.remove(0);
            if (view2 instanceof ViewGroup) {
                if (view2 instanceof SwipeMenuLayout) {
                    return view2;
                }
                ViewGroup viewGroup = (ViewGroup) view2;
                int childCount = viewGroup.getChildCount();
                for (int i2 = 0; i2 < childCount; i2++) {
                    arrayList.add(viewGroup.getChildAt(i2));
                }
            }
        }
        return view;
    }

    private boolean handleUnDown(int i2, int i3, boolean z) {
        int i4 = this.mDownX - i2;
        int i5 = this.mDownY - i3;
        if (Math.abs(i4) > this.mScaleTouchSlop && Math.abs(i4) > Math.abs(i5)) {
            return false;
        }
        if (Math.abs(i5) >= this.mScaleTouchSlop || Math.abs(i4) >= this.mScaleTouchSlop) {
            return z;
        }
        return false;
    }

    private void initializeItemTouchHelper() {
        if (this.mItemTouchHelper == null) {
            DefaultItemTouchHelper defaultItemTouchHelper = new DefaultItemTouchHelper();
            this.mItemTouchHelper = defaultItemTouchHelper;
            defaultItemTouchHelper.attachToRecyclerView(this);
        }
    }

    public void addFooterView(View view) {
        this.mFooterViewList.add(view);
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper != null) {
            adapterWrapper.addFooterViewAndNotify(view);
        }
    }

    public void addHeaderView(View view) {
        this.mHeaderViewList.add(view);
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper != null) {
            adapterWrapper.addHeaderViewAndNotify(view);
        }
    }

    public int getFooterCount() {
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper == null) {
            return 0;
        }
        return adapterWrapper.getFooterCount();
    }

    public int getHeaderCount() {
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper == null) {
            return 0;
        }
        return adapterWrapper.getHeaderCount();
    }

    public int getItemViewType(int i2) {
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper == null) {
            return 0;
        }
        return adapterWrapper.getItemViewType(i2);
    }

    public RecyclerView.Adapter getOriginAdapter() {
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper == null) {
            return null;
        }
        return adapterWrapper.getOriginAdapter();
    }

    public boolean isItemViewSwipeEnabled() {
        initializeItemTouchHelper();
        return this.mItemTouchHelper.isItemViewSwipeEnabled();
    }

    public boolean isLongPressDragEnabled() {
        initializeItemTouchHelper();
        return this.mItemTouchHelper.isLongPressDragEnabled();
    }

    public boolean isSwipeItemMenuEnabled() {
        return this.mSwipeItemMenuEnable;
    }

    public void loadMoreError(int i2, String str) {
        this.isLoadMore = false;
        this.isLoadError = true;
        LoadMoreView loadMoreView = this.mLoadMoreView;
        if (loadMoreView != null) {
            loadMoreView.onLoadError(i2, str);
        }
    }

    public final void loadMoreFinish(boolean z, boolean z2) {
        this.isLoadMore = false;
        this.isLoadError = false;
        this.mDataEmpty = z;
        this.mHasMore = z2;
        LoadMoreView loadMoreView = this.mLoadMoreView;
        if (loadMoreView != null) {
            loadMoreView.onLoadFinish(z, z2);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0059  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x005e A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x005f  */
    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
        SwipeMenuLayout swipeMenuLayout;
        boolean z;
        boolean z2;
        SwipeMenuLayout swipeMenuLayout2;
        ViewParent parent;
        boolean onInterceptTouchEvent = super.onInterceptTouchEvent(motionEvent);
        if (this.allowSwipeDelete || this.mSwipeMenuCreator == null) {
            return onInterceptTouchEvent;
        }
        boolean z3 = true;
        if (motionEvent.getPointerCount() > 1) {
            return true;
        }
        int action = motionEvent.getAction();
        int x = (int) motionEvent.getX();
        int y = (int) motionEvent.getY();
        int childAdapterPosition = getChildAdapterPosition(findChildViewUnder((float) x, (float) y));
        RecyclerView.ViewHolder findViewHolderForAdapterPosition = findViewHolderForAdapterPosition(childAdapterPosition);
        if (findViewHolderForAdapterPosition != null) {
            View swipeMenuView = getSwipeMenuView(findViewHolderForAdapterPosition.itemView);
            if (swipeMenuView instanceof SwipeMenuLayout) {
                swipeMenuLayout = (SwipeMenuLayout) swipeMenuView;
                z = !this.mSwipeItemMenuEnable && !this.mDisableSwipeItemMenuList.contains(Integer.valueOf(childAdapterPosition));
                if (swipeMenuLayout != null) {
                    swipeMenuLayout.setSwipeEnable(z);
                }
                if (z) {
                    return onInterceptTouchEvent;
                }
                if (action != 0) {
                    if (action != 1) {
                        if (action == 2) {
                            onInterceptTouchEvent = handleUnDown(x, y, onInterceptTouchEvent);
                            if (this.mOldSwipedLayout == null || (parent = getParent()) == null) {
                                return onInterceptTouchEvent;
                            }
                            int i2 = this.mDownX - x;
                            boolean z4 = i2 > 0 && (this.mOldSwipedLayout.hasRightMenu() || this.mOldSwipedLayout.isLeftCompleteOpen());
                            boolean z5 = i2 < 0 && (this.mOldSwipedLayout.hasLeftMenu() || this.mOldSwipedLayout.isRightCompleteOpen());
                            if (!z4 && !z5) {
                                z3 = false;
                            }
                            parent.requestDisallowInterceptTouchEvent(z3);
                        } else if (action != 3) {
                            return onInterceptTouchEvent;
                        }
                    }
                    return handleUnDown(x, y, onInterceptTouchEvent);
                }
                this.mDownX = x;
                this.mDownY = y;
                if (childAdapterPosition == this.mOldTouchedPosition || (swipeMenuLayout2 = this.mOldSwipedLayout) == null || !swipeMenuLayout2.isMenuOpen()) {
                    z2 = false;
                } else {
                    this.mOldSwipedLayout.smoothCloseMenu();
                    z2 = true;
                }
                if (z2) {
                    this.mOldSwipedLayout = null;
                    this.mOldTouchedPosition = -1;
                    return z2;
                } else if (swipeMenuLayout == null) {
                    return z2;
                } else {
                    this.mOldSwipedLayout = swipeMenuLayout;
                    this.mOldTouchedPosition = childAdapterPosition;
                    return z2;
                }
            }
        }
        swipeMenuLayout = null;
        if (!this.mSwipeItemMenuEnable) {
        }
        if (swipeMenuLayout != null) {
        }
        if (z) {
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void onScrollStateChanged(int i2) {
        this.mScrollState = i2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void onScrolled(int i2, int i3) {
        RecyclerView.LayoutManager layoutManager = getLayoutManager();
        if (layoutManager instanceof LinearLayoutManager) {
            LinearLayoutManager linearLayoutManager = (LinearLayoutManager) layoutManager;
            int itemCount = layoutManager.getItemCount();
            if (itemCount > 0 && itemCount == linearLayoutManager.findLastVisibleItemPosition() + 1) {
                int i4 = this.mScrollState;
                if (i4 == 1 || i4 == 2) {
                    dispatchLoadMore();
                }
            }
        } else if (layoutManager instanceof StaggeredGridLayoutManager) {
            StaggeredGridLayoutManager staggeredGridLayoutManager = (StaggeredGridLayoutManager) layoutManager;
            int itemCount2 = layoutManager.getItemCount();
            if (itemCount2 > 0) {
                int[] f2 = staggeredGridLayoutManager.f(null);
                if (itemCount2 == f2[f2.length - 1] + 1) {
                    int i5 = this.mScrollState;
                    if (i5 == 1 || i5 == 2) {
                        dispatchLoadMore();
                    }
                }
            }
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean onTouchEvent(MotionEvent motionEvent) {
        SwipeMenuLayout swipeMenuLayout;
        if (motionEvent.getAction() == 2 && (swipeMenuLayout = this.mOldSwipedLayout) != null && swipeMenuLayout.isMenuOpen()) {
            this.mOldSwipedLayout.smoothCloseMenu();
        }
        return super.onTouchEvent(motionEvent);
    }

    public void removeFooterView(View view) {
        this.mFooterViewList.remove(view);
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper != null) {
            adapterWrapper.removeFooterViewAndNotify(view);
        }
    }

    public void removeHeaderView(View view) {
        this.mHeaderViewList.remove(view);
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper != null) {
            adapterWrapper.removeHeaderViewAndNotify(view);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void setAdapter(RecyclerView.Adapter adapter) {
        AdapterWrapper adapterWrapper = this.mAdapterWrapper;
        if (adapterWrapper != null) {
            adapterWrapper.getOriginAdapter().unregisterAdapterDataObserver(this.mAdapterDataObserver);
        }
        if (adapter == null) {
            this.mAdapterWrapper = null;
        } else {
            adapter.registerAdapterDataObserver(this.mAdapterDataObserver);
            AdapterWrapper adapterWrapper2 = new AdapterWrapper(getContext(), adapter);
            this.mAdapterWrapper = adapterWrapper2;
            adapterWrapper2.setOnItemClickListener(this.mOnItemClickListener);
            this.mAdapterWrapper.setOnItemLongClickListener(this.mOnItemLongClickListener);
            this.mAdapterWrapper.setSwipeMenuCreator(this.mSwipeMenuCreator);
            this.mAdapterWrapper.setOnItemMenuClickListener(this.mOnItemMenuClickListener);
            if (this.mHeaderViewList.size() > 0) {
                for (View view : this.mHeaderViewList) {
                    this.mAdapterWrapper.addHeaderView(view);
                }
            }
            if (this.mFooterViewList.size() > 0) {
                for (View view2 : this.mFooterViewList) {
                    this.mAdapterWrapper.addFooterView(view2);
                }
            }
        }
        super.setAdapter(this.mAdapterWrapper);
    }

    public void setAutoLoadMore(boolean z) {
        this.isAutoLoadMore = z;
    }

    public void setItemViewSwipeEnabled(boolean z) {
        initializeItemTouchHelper();
        this.allowSwipeDelete = z;
        this.mItemTouchHelper.setItemViewSwipeEnabled(z);
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void setLayoutManager(RecyclerView.LayoutManager layoutManager) {
        if (layoutManager instanceof GridLayoutManager) {
            final GridLayoutManager gridLayoutManager = (GridLayoutManager) layoutManager;
            final GridLayoutManager.a spanSizeLookup = gridLayoutManager.getSpanSizeLookup();
            gridLayoutManager.setSpanSizeLookup(new GridLayoutManager.a() {
                /* class com.yanzhenjie.recyclerview.SwipeRecyclerView.AnonymousClass1 */

                @Override // androidx.recyclerview.widget.GridLayoutManager.a
                public int getSpanSize(int i2) {
                    if (SwipeRecyclerView.this.mAdapterWrapper.isHeader(i2) || SwipeRecyclerView.this.mAdapterWrapper.isFooter(i2)) {
                        return gridLayoutManager.getSpanCount();
                    }
                    GridLayoutManager.a aVar = spanSizeLookup;
                    if (aVar != null) {
                        return aVar.getSpanSize(i2 - SwipeRecyclerView.this.getHeaderCount());
                    }
                    return 1;
                }
            });
        }
        super.setLayoutManager(layoutManager);
    }

    public void setLoadMoreListener(LoadMoreListener loadMoreListener) {
        this.mLoadMoreListener = loadMoreListener;
    }

    public void setLoadMoreView(LoadMoreView loadMoreView) {
        this.mLoadMoreView = loadMoreView;
    }

    public void setLongPressDragEnabled(boolean z) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.setLongPressDragEnabled(z);
    }

    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        if (onItemClickListener != null) {
            checkAdapterExist("Cannot set item click listener, setAdapter has already been called.");
            this.mOnItemClickListener = new ItemClickListener(this, onItemClickListener);
        }
    }

    public void setOnItemLongClickListener(OnItemLongClickListener onItemLongClickListener) {
        if (onItemLongClickListener != null) {
            checkAdapterExist("Cannot set item long click listener, setAdapter has already been called.");
            this.mOnItemLongClickListener = new ItemLongClickListener(this, onItemLongClickListener);
        }
    }

    public void setOnItemMenuClickListener(OnItemMenuClickListener onItemMenuClickListener) {
        if (onItemMenuClickListener != null) {
            checkAdapterExist("Cannot set menu item click listener, setAdapter has already been called.");
            this.mOnItemMenuClickListener = new ItemMenuClickListener(this, onItemMenuClickListener);
        }
    }

    public void setOnItemMoveListener(OnItemMoveListener onItemMoveListener) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.setOnItemMoveListener(onItemMoveListener);
    }

    public void setOnItemMovementListener(OnItemMovementListener onItemMovementListener) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.setOnItemMovementListener(onItemMovementListener);
    }

    public void setOnItemStateChangedListener(OnItemStateChangedListener onItemStateChangedListener) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.setOnItemStateChangedListener(onItemStateChangedListener);
    }

    public void setSwipeItemMenuEnabled(boolean z) {
        this.mSwipeItemMenuEnable = z;
    }

    public void setSwipeMenuCreator(SwipeMenuCreator swipeMenuCreator) {
        if (swipeMenuCreator != null) {
            checkAdapterExist("Cannot set menu creator, setAdapter has already been called.");
            this.mSwipeMenuCreator = swipeMenuCreator;
        }
    }

    public void smoothCloseMenu() {
        SwipeMenuLayout swipeMenuLayout = this.mOldSwipedLayout;
        if (swipeMenuLayout != null && swipeMenuLayout.isMenuOpen()) {
            this.mOldSwipedLayout.smoothCloseMenu();
        }
    }

    public void smoothOpenLeftMenu(int i2) {
        smoothOpenMenu(i2, 1, 200);
    }

    public void smoothOpenMenu(int i2, int i3, int i4) {
        SwipeMenuLayout swipeMenuLayout = this.mOldSwipedLayout;
        if (swipeMenuLayout != null && swipeMenuLayout.isMenuOpen()) {
            this.mOldSwipedLayout.smoothCloseMenu();
        }
        int headerCount = getHeaderCount() + i2;
        RecyclerView.ViewHolder findViewHolderForAdapterPosition = findViewHolderForAdapterPosition(headerCount);
        if (findViewHolderForAdapterPosition != null) {
            View swipeMenuView = getSwipeMenuView(findViewHolderForAdapterPosition.itemView);
            if (swipeMenuView instanceof SwipeMenuLayout) {
                SwipeMenuLayout swipeMenuLayout2 = (SwipeMenuLayout) swipeMenuView;
                this.mOldSwipedLayout = swipeMenuLayout2;
                if (i3 == -1) {
                    this.mOldTouchedPosition = headerCount;
                    swipeMenuLayout2.smoothOpenRightMenu(i4);
                } else if (i3 == 1) {
                    this.mOldTouchedPosition = headerCount;
                    swipeMenuLayout2.smoothOpenLeftMenu(i4);
                }
            }
        }
    }

    public void smoothOpenRightMenu(int i2) {
        smoothOpenMenu(i2, -1, 200);
    }

    public void startDrag(RecyclerView.ViewHolder viewHolder) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.startDrag(viewHolder);
    }

    public void startSwipe(RecyclerView.ViewHolder viewHolder) {
        initializeItemTouchHelper();
        this.mItemTouchHelper.startSwipe(viewHolder);
    }

    public void useDefaultLoadMore() {
        DefaultLoadMoreView defaultLoadMoreView = new DefaultLoadMoreView(getContext());
        addFooterView(defaultLoadMoreView);
        setLoadMoreView(defaultLoadMoreView);
    }

    public SwipeRecyclerView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public boolean isSwipeItemMenuEnabled(int i2) {
        return !this.mDisableSwipeItemMenuList.contains(Integer.valueOf(i2));
    }

    public void setSwipeItemMenuEnabled(int i2, boolean z) {
        if (z) {
            if (this.mDisableSwipeItemMenuList.contains(Integer.valueOf(i2))) {
                this.mDisableSwipeItemMenuList.remove(Integer.valueOf(i2));
            }
        } else if (!this.mDisableSwipeItemMenuList.contains(Integer.valueOf(i2))) {
            this.mDisableSwipeItemMenuList.add(Integer.valueOf(i2));
        }
    }

    public void smoothOpenLeftMenu(int i2, int i3) {
        smoothOpenMenu(i2, 1, i3);
    }

    public void smoothOpenRightMenu(int i2, int i3) {
        smoothOpenMenu(i2, -1, i3);
    }

    public SwipeRecyclerView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mOldTouchedPosition = -1;
        this.mSwipeItemMenuEnable = true;
        this.mDisableSwipeItemMenuList = new ArrayList();
        this.mAdapterDataObserver = new RecyclerView.h() {
            /* class com.yanzhenjie.recyclerview.SwipeRecyclerView.AnonymousClass2 */

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onChanged() {
                SwipeRecyclerView.this.mAdapterWrapper.notifyDataSetChanged();
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeChanged(int i2, int i3) {
                SwipeRecyclerView.this.mAdapterWrapper.notifyItemRangeChanged(SwipeRecyclerView.this.getHeaderCount() + i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeInserted(int i2, int i3) {
                SwipeRecyclerView.this.mAdapterWrapper.notifyItemRangeInserted(SwipeRecyclerView.this.getHeaderCount() + i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeMoved(int i2, int i3, int i4) {
                SwipeRecyclerView.this.mAdapterWrapper.notifyItemMoved(SwipeRecyclerView.this.getHeaderCount() + i2, SwipeRecyclerView.this.getHeaderCount() + i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeRemoved(int i2, int i3) {
                SwipeRecyclerView.this.mAdapterWrapper.notifyItemRangeRemoved(SwipeRecyclerView.this.getHeaderCount() + i2, i3);
            }

            @Override // androidx.recyclerview.widget.RecyclerView.h
            public void onItemRangeChanged(int i2, int i3, Object obj) {
                SwipeRecyclerView.this.mAdapterWrapper.notifyItemRangeChanged(SwipeRecyclerView.this.getHeaderCount() + i2, i3, obj);
            }
        };
        this.mHeaderViewList = new ArrayList();
        this.mFooterViewList = new ArrayList();
        this.mScrollState = -1;
        this.isLoadMore = false;
        this.isAutoLoadMore = true;
        this.isLoadError = false;
        this.mDataEmpty = true;
        this.mHasMore = false;
        this.mScaleTouchSlop = ViewConfiguration.get(getContext()).getScaledTouchSlop();
    }
}
