package com.yanzhenjie.recyclerview.widget;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.widget.NestedScrollView;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class StickyNestedScrollView extends NestedScrollView {
    private static final int DEFAULT_SHADOW_HEIGHT = 10;
    public static final String FLAG_HASTRANSPARENCY = "-hastransparency";
    public static final String FLAG_NONCONSTANT = "-nonconstant";
    public static final String STICKY_TAG = "sticky";
    private boolean clipToPaddingHasBeenSet;
    private boolean clippingToPadding;
    private View currentlyStickingView;
    private boolean hasNotDoneActionDown;
    private final Runnable invalidateRunnable;
    private List<OnViewStickyListener> mOnViewStickyListeners;
    private Drawable mShadowDrawable;
    private int mShadowHeight;
    private boolean redirectTouchesToStickyView;
    private int stickyViewLeftOffset;
    private float stickyViewTopOffset;
    private ArrayList<View> stickyViews;

    public interface OnViewStickyListener {
        void onSticky(View view);

        void onUnSticky(View view);
    }

    public StickyNestedScrollView(Context context) {
        this(context, null);
    }

    private boolean detainStickyView(View view) {
        if (!getStringTagForView(view).contains(STICKY_TAG)) {
            return false;
        }
        this.stickyViews.add(view);
        return true;
    }

    private void doTheStickyThing() {
        float f2;
        int i2;
        Iterator<View> it = this.stickyViews.iterator();
        View view = null;
        View view2 = null;
        while (true) {
            int i3 = 0;
            if (!it.hasNext()) {
                break;
            }
            View next = it.next();
            int topForViewRelativeOnlyChild = (getTopForViewRelativeOnlyChild(next) - getScrollY()) + (this.clippingToPadding ? 0 : getPaddingTop());
            if (topForViewRelativeOnlyChild <= 0) {
                if (view != null) {
                    int topForViewRelativeOnlyChild2 = getTopForViewRelativeOnlyChild(view) - getScrollY();
                    if (!this.clippingToPadding) {
                        i3 = getPaddingTop();
                    }
                    if (topForViewRelativeOnlyChild <= topForViewRelativeOnlyChild2 + i3) {
                    }
                }
                view = next;
            } else {
                if (view2 != null) {
                    int topForViewRelativeOnlyChild3 = getTopForViewRelativeOnlyChild(view2) - getScrollY();
                    if (!this.clippingToPadding) {
                        i3 = getPaddingTop();
                    }
                    if (topForViewRelativeOnlyChild >= topForViewRelativeOnlyChild3 + i3) {
                    }
                }
                view2 = next;
            }
        }
        if (view != null) {
            if (view2 == null) {
                f2 = 0.0f;
            } else {
                int topForViewRelativeOnlyChild4 = getTopForViewRelativeOnlyChild(view2) - getScrollY();
                if (this.clippingToPadding) {
                    i2 = 0;
                } else {
                    i2 = getPaddingTop();
                }
                f2 = (float) Math.min(0, (topForViewRelativeOnlyChild4 + i2) - view.getHeight());
            }
            this.stickyViewTopOffset = f2;
            View view3 = this.currentlyStickingView;
            if (view != view3) {
                if (view3 != null) {
                    List<OnViewStickyListener> list = this.mOnViewStickyListeners;
                    if (list != null) {
                        for (OnViewStickyListener onViewStickyListener : list) {
                            onViewStickyListener.onUnSticky(this.currentlyStickingView);
                        }
                    }
                    stopStickingCurrentlyStickingView();
                }
                this.stickyViewLeftOffset = getLeftForViewRelativeOnlyChild(view);
                startStickingView(view);
                List<OnViewStickyListener> list2 = this.mOnViewStickyListeners;
                if (list2 != null) {
                    for (OnViewStickyListener onViewStickyListener2 : list2) {
                        onViewStickyListener2.onSticky(this.currentlyStickingView);
                    }
                }
            }
        } else if (this.currentlyStickingView != null) {
            List<OnViewStickyListener> list3 = this.mOnViewStickyListeners;
            if (list3 != null) {
                for (OnViewStickyListener onViewStickyListener3 : list3) {
                    onViewStickyListener3.onUnSticky(this.currentlyStickingView);
                }
            }
            stopStickingCurrentlyStickingView();
        }
    }

    private void findStickyViews(View view) {
        if (!detainStickyView(view) && (view instanceof ViewGroup)) {
            ViewGroup viewGroup = (ViewGroup) view;
            for (int i2 = 0; i2 < viewGroup.getChildCount(); i2++) {
                findStickyViews(viewGroup.getChildAt(i2));
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getBottomForViewRelativeOnlyChild(View view) {
        int bottom = view.getBottom();
        while (view.getParent() != null && view.getParent() != getChildAt(0)) {
            view = (View) view.getParent();
            bottom += view.getBottom();
        }
        return bottom;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getLeftForViewRelativeOnlyChild(View view) {
        int left = view.getLeft();
        while (view.getParent() != null && view.getParent() != getChildAt(0)) {
            view = (View) view.getParent();
            left += view.getLeft();
        }
        return left;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getRightForViewRelativeOnlyChild(View view) {
        int right = view.getRight();
        while (view.getParent() != null && view.getParent() != getChildAt(0)) {
            view = (View) view.getParent();
            right += view.getRight();
        }
        return right;
    }

    private String getStringTagForView(View view) {
        return String.valueOf(view.getTag());
    }

    private int getTopForViewRelativeOnlyChild(View view) {
        int top = view.getTop();
        while (view.getParent() != null && view.getParent() != getChildAt(0)) {
            view = (View) view.getParent();
            top += view.getTop();
        }
        return top;
    }

    private void hideView(View view) {
        view.setAlpha(0.0f);
    }

    private void notifyHierarchyChanged() {
        if (this.currentlyStickingView != null) {
            stopStickingCurrentlyStickingView();
        }
        this.stickyViews.clear();
        findStickyViews(getChildAt(0));
        doTheStickyThing();
        invalidate();
    }

    private void showView(View view) {
        view.setAlpha(1.0f);
    }

    private void startStickingView(View view) {
        this.currentlyStickingView = view;
        if (view != null) {
            if (getStringTagForView(view).contains(FLAG_HASTRANSPARENCY)) {
                hideView(this.currentlyStickingView);
            }
            if (getStringTagForView(this.currentlyStickingView).contains(FLAG_NONCONSTANT)) {
                post(this.invalidateRunnable);
            }
        }
    }

    private void stopStickingCurrentlyStickingView() {
        if (getStringTagForView(this.currentlyStickingView).contains(FLAG_HASTRANSPARENCY)) {
            showView(this.currentlyStickingView);
        }
        this.currentlyStickingView = null;
        removeCallbacks(this.invalidateRunnable);
    }

    public void addOnViewStickyListener(OnViewStickyListener onViewStickyListener) {
        if (this.mOnViewStickyListeners == null) {
            this.mOnViewStickyListeners = new ArrayList();
        }
        this.mOnViewStickyListeners.add(onViewStickyListener);
    }

    @Override // androidx.core.widget.NestedScrollView
    public void addView(View view) {
        super.addView(view);
        findStickyViews(view);
    }

    public void clearOnViewStickyListener() {
        List<OnViewStickyListener> list = this.mOnViewStickyListeners;
        if (list != null) {
            list.clear();
        }
    }

    public void dispatchDraw(Canvas canvas) {
        super.dispatchDraw(canvas);
        if (this.currentlyStickingView != null) {
            canvas.save();
            canvas.translate((float) (getPaddingLeft() + this.stickyViewLeftOffset), ((float) getScrollY()) + this.stickyViewTopOffset + ((float) (this.clippingToPadding ? getPaddingTop() : 0)));
            canvas.clipRect(0.0f, this.clippingToPadding ? -this.stickyViewTopOffset : 0.0f, (float) (getWidth() - this.stickyViewLeftOffset), (float) (this.currentlyStickingView.getHeight() + this.mShadowHeight + 1));
            if (this.mShadowDrawable != null) {
                this.mShadowDrawable.setBounds(0, this.currentlyStickingView.getHeight(), this.currentlyStickingView.getWidth(), this.currentlyStickingView.getHeight() + this.mShadowHeight);
                this.mShadowDrawable.draw(canvas);
            }
            canvas.clipRect(0.0f, this.clippingToPadding ? -this.stickyViewTopOffset : 0.0f, (float) getWidth(), (float) this.currentlyStickingView.getHeight());
            if (getStringTagForView(this.currentlyStickingView).contains(FLAG_HASTRANSPARENCY)) {
                showView(this.currentlyStickingView);
                this.currentlyStickingView.draw(canvas);
                hideView(this.currentlyStickingView);
            } else {
                this.currentlyStickingView.draw(canvas);
            }
            canvas.restore();
        }
    }

    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        boolean z = true;
        if (motionEvent.getAction() == 0) {
            this.redirectTouchesToStickyView = true;
        }
        if (this.redirectTouchesToStickyView) {
            boolean z2 = this.currentlyStickingView != null;
            this.redirectTouchesToStickyView = z2;
            if (z2) {
                if (motionEvent.getY() > ((float) this.currentlyStickingView.getHeight()) + this.stickyViewTopOffset || motionEvent.getX() < ((float) getLeftForViewRelativeOnlyChild(this.currentlyStickingView)) || motionEvent.getX() > ((float) getRightForViewRelativeOnlyChild(this.currentlyStickingView))) {
                    z = false;
                }
                this.redirectTouchesToStickyView = z;
            }
        } else if (this.currentlyStickingView == null) {
            this.redirectTouchesToStickyView = false;
        }
        if (this.redirectTouchesToStickyView) {
            motionEvent.offsetLocation(0.0f, ((((float) getScrollY()) + this.stickyViewTopOffset) - ((float) getTopForViewRelativeOnlyChild(this.currentlyStickingView))) * -1.0f);
        }
        return super.dispatchTouchEvent(motionEvent);
    }

    public void notifyStickyAttributeChanged() {
        notifyHierarchyChanged();
    }

    public void onDetachedFromWindow() {
        removeCallbacks(this.invalidateRunnable);
        super.onDetachedFromWindow();
    }

    @Override // androidx.core.widget.NestedScrollView
    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        super.onLayout(z, i2, i3, i4, i5);
        if (!this.clipToPaddingHasBeenSet) {
            this.clippingToPadding = true;
        }
        notifyHierarchyChanged();
    }

    @Override // androidx.core.widget.NestedScrollView
    public void onScrollChanged(int i2, int i3, int i4, int i5) {
        super.onScrollChanged(i2, i3, i4, i5);
        doTheStickyThing();
    }

    @Override // androidx.core.widget.NestedScrollView
    public boolean onTouchEvent(MotionEvent motionEvent) {
        if (this.redirectTouchesToStickyView) {
            motionEvent.offsetLocation(0.0f, (((float) getScrollY()) + this.stickyViewTopOffset) - ((float) getTopForViewRelativeOnlyChild(this.currentlyStickingView)));
        }
        if (motionEvent.getAction() == 0) {
            this.hasNotDoneActionDown = false;
        }
        if (this.hasNotDoneActionDown) {
            MotionEvent obtain = MotionEvent.obtain(motionEvent);
            obtain.setAction(0);
            super.onTouchEvent(obtain);
            this.hasNotDoneActionDown = false;
        }
        if (motionEvent.getAction() == 1 || motionEvent.getAction() == 3) {
            this.hasNotDoneActionDown = true;
        }
        return super.onTouchEvent(motionEvent);
    }

    public void removeOnViewStickyListener(OnViewStickyListener onViewStickyListener) {
        List<OnViewStickyListener> list = this.mOnViewStickyListeners;
        if (list != null) {
            list.remove(onViewStickyListener);
        }
    }

    public void setClipToPadding(boolean z) {
        super.setClipToPadding(z);
        this.clippingToPadding = z;
        this.clipToPaddingHasBeenSet = true;
    }

    public void setShadowDrawable(Drawable drawable) {
        this.mShadowDrawable = drawable;
    }

    public void setShadowHeight(int i2) {
        this.mShadowHeight = i2;
    }

    public void setup() {
        this.stickyViews = new ArrayList<>();
    }

    public StickyNestedScrollView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 16842880);
    }

    public StickyNestedScrollView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.invalidateRunnable = new Runnable() {
            /* class com.yanzhenjie.recyclerview.widget.StickyNestedScrollView.AnonymousClass1 */

            public void run() {
                if (StickyNestedScrollView.this.currentlyStickingView != null) {
                    StickyNestedScrollView stickyNestedScrollView = StickyNestedScrollView.this;
                    int leftForViewRelativeOnlyChild = stickyNestedScrollView.getLeftForViewRelativeOnlyChild(stickyNestedScrollView.currentlyStickingView);
                    StickyNestedScrollView stickyNestedScrollView2 = StickyNestedScrollView.this;
                    int bottomForViewRelativeOnlyChild = stickyNestedScrollView2.getBottomForViewRelativeOnlyChild(stickyNestedScrollView2.currentlyStickingView);
                    StickyNestedScrollView stickyNestedScrollView3 = StickyNestedScrollView.this;
                    int rightForViewRelativeOnlyChild = stickyNestedScrollView3.getRightForViewRelativeOnlyChild(stickyNestedScrollView3.currentlyStickingView);
                    float height = StickyNestedScrollView.this.stickyViewTopOffset + ((float) StickyNestedScrollView.this.currentlyStickingView.getHeight());
                    StickyNestedScrollView.this.invalidate(leftForViewRelativeOnlyChild, bottomForViewRelativeOnlyChild, rightForViewRelativeOnlyChild, (int) (height + ((float) StickyNestedScrollView.this.getScrollY())));
                }
                StickyNestedScrollView.this.postDelayed(this, 16);
            }
        };
        this.mShadowHeight = 10;
        this.hasNotDoneActionDown = true;
        setup();
    }

    @Override // androidx.core.widget.NestedScrollView, android.view.ViewGroup
    public void addView(View view, int i2) {
        super.addView(view, i2);
        findStickyViews(view);
    }

    @Override // androidx.core.widget.NestedScrollView, android.view.ViewGroup
    public void addView(View view, int i2, ViewGroup.LayoutParams layoutParams) {
        super.addView(view, i2, layoutParams);
        findStickyViews(view);
    }

    @Override // android.view.ViewGroup
    public void addView(View view, int i2, int i3) {
        super.addView(view, i2, i3);
        findStickyViews(view);
    }

    @Override // androidx.core.widget.NestedScrollView, android.view.ViewGroup
    public void addView(View view, ViewGroup.LayoutParams layoutParams) {
        super.addView(view, layoutParams);
        findStickyViews(view);
    }
}
