package com.youth.banner.indicator;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.drawable.BitmapDrawable;
import android.util.AttributeSet;
import com.youth.banner.R;

public class DrawableIndicator extends BaseIndicator {
    private Bitmap normalBitmap;
    private Bitmap selectedBitmap;

    public DrawableIndicator(Context context, int i2, int i3) {
        super(context);
        this.normalBitmap = BitmapFactory.decodeResource(getResources(), i2);
        this.selectedBitmap = BitmapFactory.decodeResource(getResources(), i3);
    }

    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        int indicatorSize = this.config.getIndicatorSize();
        if (indicatorSize > 1 && this.normalBitmap != null && this.selectedBitmap != null) {
            int i2 = 0;
            float f2 = 0.0f;
            while (i2 < indicatorSize) {
                canvas.drawBitmap(this.config.getCurrentPosition() == i2 ? this.selectedBitmap : this.normalBitmap, f2, 0.0f, this.mPaint);
                f2 += (float) (this.config.getIndicatorSpace() + this.normalBitmap.getWidth());
                i2++;
            }
        }
    }

    public void onMeasure(int i2, int i3) {
        super.onMeasure(i2, i3);
        int indicatorSize = this.config.getIndicatorSize();
        if (indicatorSize > 1) {
            int i4 = indicatorSize - 1;
            setMeasuredDimension((this.config.getIndicatorSpace() * i4) + this.selectedBitmap.getWidth() + (this.selectedBitmap.getWidth() * i4), Math.max(this.normalBitmap.getHeight(), this.selectedBitmap.getHeight()));
        }
    }

    public DrawableIndicator(Context context) {
        this(context, null);
    }

    public DrawableIndicator(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public DrawableIndicator(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.DrawableIndicator);
        if (obtainStyledAttributes != null) {
            this.normalBitmap = ((BitmapDrawable) obtainStyledAttributes.getDrawable(R.styleable.DrawableIndicator_normal_drawable)).getBitmap();
            this.selectedBitmap = ((BitmapDrawable) obtainStyledAttributes.getDrawable(R.styleable.DrawableIndicator_selected_drawable)).getBitmap();
        }
    }
}
