package freemarker.core;

import d.a.a.a.a;
import e.b.b;
import e.b.d1;
import e.b.l;
import e.b.m;
import e.b.p;
import e.b.u;
import e.b.z0;
import freemarker.template.TemplateException;

public class InvalidReferenceException extends TemplateException {
    public static final InvalidReferenceException FAST_INSTANCE;
    private static final Object[] TIP = {"If the failing expression is known to legally refer to something that's sometimes null or missing, either specify a default value like myOptionalVar!myDefault, or use ", "<#if myOptionalVar??>", "when-present", "<#else>", "when-missing", "</#if>", ". (These only cover the last step of the expression; to cover the whole expression, use parenthesis: (myOptionalVar.foo)!myDefault, (myOptionalVar.foo)??"};
    private static final String TIP_JSP_TAGLIBS = "The \"JspTaglibs\" variable isn't a core FreeMarker feature; it's only available when templates are invoked through freemarker.ext.servlet.FreemarkerServlet (or other custom FreeMarker-JSP integration solution).";
    private static final String TIP_LAST_STEP_DOT = "It's the step after the last dot that caused this error, not those before it.";
    private static final String TIP_LAST_STEP_SQUARE_BRACKET = "It's the final [] step that caused this error, not those before it.";
    private static final Object[] TIP_MISSING_ASSIGNMENT_TARGET = {"If the target variable is known to be legally null or missing sometimes, instead of something like ", "<#assign x += 1>", ", you could write ", "<#if x??>", "<#assign x += 1>", "</#if>", " or ", "<#assign x = (x!0) + 1>"};
    private static final String TIP_NO_DOLLAR = "Variable references must not start with \"$\", unless the \"$\" is really part of the variable name.";

    static {
        Environment e2 = Environment.e();
        try {
            ThreadLocal threadLocal = Environment.O;
            threadLocal.set(null);
            FAST_INSTANCE = new InvalidReferenceException("Invalid reference. Details are unavilable, as this should have been handled by an FTL construct. If it wasn't, that's problably a bug in FreeMarker.", null);
            threadLocal.set(e2);
        } catch (Throwable th) {
            Environment.O.set(e2);
            throw th;
        }
    }

    public InvalidReferenceException(Environment environment) {
        super("Invalid reference: The expression has evaluated to null or refers to something that doesn't exist.", environment);
    }

    private static boolean endsWithDollarVariable(p pVar) {
        return ((pVar instanceof u) && ((u) pVar).m.startsWith("$")) || ((pVar instanceof l) && ((l) pVar).n.startsWith("$"));
    }

    public static InvalidReferenceException getInstance(int i2, String str, String str2, Environment environment) {
        String str3;
        if (environment != null && environment.X) {
            return FAST_INSTANCE;
        }
        Object[] objArr = new Object[5];
        objArr[0] = "The target variable of the assignment, ";
        objArr[1] = new z0(str);
        StringBuilder B = a.B(", was null or missing in the ");
        Number number = b.q;
        if (i2 == 1) {
            str3 = "template namespace";
        } else if (i2 == 2) {
            str3 = "local scope";
        } else if (i2 == 3) {
            str3 = "global scope";
        } else {
            throw new AssertionError(a.k("Unsupported scope: ", i2));
        }
        objArr[2] = a.y(B, str3, ", and the \"");
        objArr[3] = str2;
        objArr[4] = "\" operator must get its value from there before assigning to it.";
        d1 d1Var = new d1(objArr);
        if (str.startsWith("$")) {
            d1Var.e(TIP_NO_DOLLAR, TIP_MISSING_ASSIGNMENT_TARGET);
        } else {
            d1Var.d(TIP_MISSING_ASSIGNMENT_TARGET);
        }
        return new InvalidReferenceException(d1Var, environment, null);
    }

    public InvalidReferenceException(String str, Environment environment) {
        super(str, environment);
    }

    public InvalidReferenceException(d1 d1Var, Environment environment, p pVar) {
        super(null, environment, pVar, d1Var);
    }

    public static InvalidReferenceException getInstance(p pVar, Environment environment) {
        Object[] objArr;
        if (environment != null && environment.X) {
            return FAST_INSTANCE;
        }
        if (pVar == null) {
            return new InvalidReferenceException(environment);
        }
        d1 d1Var = new d1("The following has evaluated to null or missing:");
        d1Var.f12672d = pVar;
        if (endsWithDollarVariable(pVar)) {
            d1Var.e(TIP_NO_DOLLAR, TIP);
        } else if (pVar instanceof l) {
            String str = ((l) pVar).n;
            String str2 = null;
            if ("size".equals(str)) {
                str2 = "To query the size of a collection or map use ?size, like myList?size";
            } else if ("length".equals(str)) {
                str2 = "To query the length of a string use ?length, like myString?size";
            }
            if (str2 == null) {
                objArr = new Object[]{TIP_LAST_STEP_DOT, TIP};
            } else {
                objArr = new Object[]{TIP_LAST_STEP_DOT, str2, TIP};
            }
            d1Var.e(objArr);
        } else if (pVar instanceof m) {
            d1Var.e(TIP_LAST_STEP_SQUARE_BRACKET, TIP);
        } else if (!(pVar instanceof u) || !((u) pVar).m.equals("JspTaglibs")) {
            d1Var.d(TIP);
        } else {
            d1Var.e(TIP_JSP_TAGLIBS, TIP);
        }
        return new InvalidReferenceException(d1Var, environment, pVar);
    }
}
