package freemarker.core;

import e.b.d1;
import e.b.p;
import e.d.d.c;
import e.f.b0;
import e.f.i0;
import e.f.q;

public class NonSequenceOrCollectionException extends UnexpectedTypeException {
    private static final Class[] EXPECTED_TYPES = {i0.class, q.class};
    private static final String ITERABLE_SUPPORT_HINT = "The problematic value is a java.lang.Iterable. Using DefaultObjectWrapper(..., iterableSupport=true) as the object_wrapper setting of the FreeMarker configuration should solve this.";

    public NonSequenceOrCollectionException(Environment environment) {
        super(environment, "Expecting sequence or collection value here");
    }

    private static Object[] extendTipsIfIterable(b0 b0Var, Object[] objArr) {
        if (!isWrappedIterable(b0Var)) {
            return objArr;
        }
        int length = objArr != null ? objArr.length : 0;
        Object[] objArr2 = new Object[(length + 1)];
        for (int i2 = 0; i2 < length; i2++) {
            objArr2[i2] = objArr[i2];
        }
        objArr2[length] = ITERABLE_SUPPORT_HINT;
        return objArr2;
    }

    public static boolean isWrappedIterable(b0 b0Var) {
        return (b0Var instanceof c) && (((c) b0Var).getWrappedObject() instanceof Iterable);
    }

    public NonSequenceOrCollectionException(String str, Environment environment) {
        super(environment, str);
    }

    public NonSequenceOrCollectionException(Environment environment, d1 d1Var) {
        super(environment, d1Var);
    }

    public NonSequenceOrCollectionException(p pVar, b0 b0Var, Environment environment) {
        this(pVar, b0Var, e.f.m0.c.f12913a, environment);
    }

    public NonSequenceOrCollectionException(p pVar, b0 b0Var, String str, Environment environment) {
        this(pVar, b0Var, new Object[]{str}, environment);
    }

    public NonSequenceOrCollectionException(p pVar, b0 b0Var, Object[] objArr, Environment environment) {
        super(pVar, b0Var, "sequence or collection", EXPECTED_TYPES, extendTipsIfIterable(b0Var, objArr), environment);
    }
}
