package freemarker.core;

import d.a.a.a.a;
import freemarker.template.Template;

public class TokenMgrError extends Error {
    public static final int INVALID_LEXICAL_STATE = 2;
    public static final int LEXICAL_ERROR = 0;
    public static final int LOOP_DETECTED = 3;
    public static final int STATIC_LEXER_ERROR = 1;
    private Integer columnNumber;
    private String detail;
    private Integer endColumnNumber;
    private Integer endLineNumber;
    public int errorCode;
    private Integer lineNumber;

    public TokenMgrError() {
    }

    public static String LexicalError(boolean z, int i2, int i3, int i4, String str, char c2) {
        String str2;
        StringBuilder B = a.B("Lexical error: encountered ");
        if (z) {
            str2 = "<EOF> ";
        } else {
            StringBuilder B2 = a.B("\"");
            B2.append(addEscapes(String.valueOf(c2)));
            B2.append("\"");
            B2.append(" (");
            B2.append((int) c2);
            B2.append("), ");
            str2 = B2.toString();
        }
        B.append(str2);
        B.append("after \"");
        B.append(addEscapes(str));
        B.append("\".");
        return B.toString();
    }

    public static final String addEscapes(String str) {
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            if (charAt != 0) {
                if (charAt == '\"') {
                    sb.append("\\\"");
                } else if (charAt == '\'') {
                    sb.append("\\'");
                } else if (charAt == '\\') {
                    sb.append("\\\\");
                } else if (charAt == '\f') {
                    sb.append("\\f");
                } else if (charAt != '\r') {
                    switch (charAt) {
                        case '\b':
                            sb.append("\\b");
                            continue;
                        case '\t':
                            sb.append("\\t");
                            continue;
                        case '\n':
                            sb.append("\\n");
                            continue;
                        default:
                            char charAt2 = str.charAt(i2);
                            if (charAt2 < ' ' || charAt2 > '~') {
                                StringBuilder B = a.B("0000");
                                B.append(Integer.toString(charAt2, 16));
                                String sb2 = B.toString();
                                StringBuilder B2 = a.B("\\u");
                                B2.append(sb2.substring(sb2.length() - 4, sb2.length()));
                                sb.append(B2.toString());
                                break;
                            } else {
                                sb.append(charAt2);
                                continue;
                            }
                    }
                } else {
                    sb.append("\\r");
                }
            }
        }
        return sb.toString();
    }

    public Integer getColumnNumber() {
        return this.columnNumber;
    }

    public String getDetail() {
        return this.detail;
    }

    public Integer getEndColumnNumber() {
        return this.endColumnNumber;
    }

    public Integer getEndLineNumber() {
        return this.endLineNumber;
    }

    public Integer getLineNumber() {
        return this.lineNumber;
    }

    public String getMessage() {
        return super.getMessage();
    }

    public ParseException toParseException(Template template) {
        return new ParseException(getDetail(), template, getLineNumber() != null ? getLineNumber().intValue() : 0, getColumnNumber() != null ? getColumnNumber().intValue() : 0, getEndLineNumber() != null ? getEndLineNumber().intValue() : 0, getEndColumnNumber() != null ? getEndColumnNumber().intValue() : 0);
    }

    public TokenMgrError(String str, int i2) {
        super(str);
        this.detail = str;
        this.errorCode = i2;
    }

    @Deprecated
    public TokenMgrError(String str, int i2, int i3, int i4) {
        this(str, i2, i3, i4, 0, 0);
        this.endLineNumber = null;
        this.endColumnNumber = null;
    }

    public TokenMgrError(String str, int i2, int i3, int i4, int i5, int i6) {
        super(str);
        this.detail = str;
        this.errorCode = i2;
        this.lineNumber = Integer.valueOf(i3);
        this.columnNumber = Integer.valueOf(i4);
        this.endLineNumber = Integer.valueOf(i5);
        this.endColumnNumber = Integer.valueOf(i6);
    }

    public TokenMgrError(boolean z, int i2, int i3, int i4, String str, int i5, int i6) {
        this(z, i2, i3, i4, str, (char) i5, i6);
    }

    public TokenMgrError(boolean z, int i2, int i3, int i4, String str, char c2, int i5) {
        this(LexicalError(z, i2, i3, i4, str, c2), i5);
        this.lineNumber = Integer.valueOf(i3);
        Integer valueOf = Integer.valueOf(i4);
        this.columnNumber = valueOf;
        this.endLineNumber = this.lineNumber;
        this.endColumnNumber = valueOf;
    }
}
