package freemarker.template;

import e.d.d.c;
import e.f.b0;
import e.f.i0;
import e.f.k0;
import e.f.l;
import e.f.m;
import java.io.Serializable;
import java.lang.reflect.Array;

public abstract class DefaultArrayAdapter extends k0 implements i0, e.f.a, c, Serializable {

    public static class BooleanArrayAdapter extends DefaultArrayAdapter {
        private final boolean[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                boolean[] zArr = this.array;
                if (i2 < zArr.length) {
                    return wrap(Boolean.valueOf(zArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private BooleanArrayAdapter(boolean[] zArr, l lVar) {
            super(lVar);
            this.array = zArr;
        }
    }

    public static class ByteArrayAdapter extends DefaultArrayAdapter {
        private final byte[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                byte[] bArr = this.array;
                if (i2 < bArr.length) {
                    return wrap(Byte.valueOf(bArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private ByteArrayAdapter(byte[] bArr, l lVar) {
            super(lVar);
            this.array = bArr;
        }
    }

    public static class CharArrayAdapter extends DefaultArrayAdapter {
        private final char[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                char[] cArr = this.array;
                if (i2 < cArr.length) {
                    return wrap(Character.valueOf(cArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private CharArrayAdapter(char[] cArr, l lVar) {
            super(lVar);
            this.array = cArr;
        }
    }

    public static class DoubleArrayAdapter extends DefaultArrayAdapter {
        private final double[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                double[] dArr = this.array;
                if (i2 < dArr.length) {
                    return wrap(Double.valueOf(dArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private DoubleArrayAdapter(double[] dArr, l lVar) {
            super(lVar);
            this.array = dArr;
        }
    }

    public static class FloatArrayAdapter extends DefaultArrayAdapter {
        private final float[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                float[] fArr = this.array;
                if (i2 < fArr.length) {
                    return wrap(Float.valueOf(fArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private FloatArrayAdapter(float[] fArr, l lVar) {
            super(lVar);
            this.array = fArr;
        }
    }

    public static class GenericPrimitiveArrayAdapter extends DefaultArrayAdapter {
        private final Object array;
        private final int length;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 < 0 || i2 >= this.length) {
                return null;
            }
            return wrap(Array.get(this.array, i2));
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.length;
        }

        private GenericPrimitiveArrayAdapter(Object obj, l lVar) {
            super(lVar);
            this.array = obj;
            this.length = Array.getLength(obj);
        }
    }

    public static class IntArrayAdapter extends DefaultArrayAdapter {
        private final int[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                int[] iArr = this.array;
                if (i2 < iArr.length) {
                    return wrap(Integer.valueOf(iArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private IntArrayAdapter(int[] iArr, l lVar) {
            super(lVar);
            this.array = iArr;
        }
    }

    public static class LongArrayAdapter extends DefaultArrayAdapter {
        private final long[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                long[] jArr = this.array;
                if (i2 < jArr.length) {
                    return wrap(Long.valueOf(jArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private LongArrayAdapter(long[] jArr, l lVar) {
            super(lVar);
            this.array = jArr;
        }
    }

    public static class ObjectArrayAdapter extends DefaultArrayAdapter {
        private final Object[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                Object[] objArr = this.array;
                if (i2 < objArr.length) {
                    return wrap(objArr[i2]);
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private ObjectArrayAdapter(Object[] objArr, l lVar) {
            super(lVar);
            this.array = objArr;
        }
    }

    public static class ShortArrayAdapter extends DefaultArrayAdapter {
        private final short[] array;

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public b0 get(int i2) {
            if (i2 >= 0) {
                short[] sArr = this.array;
                if (i2 < sArr.length) {
                    return wrap(Short.valueOf(sArr[i2]));
                }
            }
            return null;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.d.d.c
        public Object getWrappedObject() {
            return this.array;
        }

        @Override // freemarker.template.DefaultArrayAdapter, e.f.i0
        public int size() {
            return this.array.length;
        }

        private ShortArrayAdapter(short[] sArr, l lVar) {
            super(lVar);
            this.array = sArr;
        }
    }

    public static DefaultArrayAdapter adapt(Object obj, m mVar) {
        Class<?> componentType = obj.getClass().getComponentType();
        if (componentType == null) {
            throw new IllegalArgumentException("Not an array");
        } else if (!componentType.isPrimitive()) {
            return new ObjectArrayAdapter((Object[]) obj, mVar);
        } else {
            if (componentType == Integer.TYPE) {
                return new IntArrayAdapter((int[]) obj, mVar);
            }
            if (componentType == Double.TYPE) {
                return new DoubleArrayAdapter((double[]) obj, mVar);
            }
            if (componentType == Long.TYPE) {
                return new LongArrayAdapter((long[]) obj, mVar);
            }
            if (componentType == Boolean.TYPE) {
                return new BooleanArrayAdapter((boolean[]) obj, mVar);
            }
            if (componentType == Float.TYPE) {
                return new FloatArrayAdapter((float[]) obj, mVar);
            }
            if (componentType == Character.TYPE) {
                return new CharArrayAdapter((char[]) obj, mVar);
            }
            if (componentType == Short.TYPE) {
                return new ShortArrayAdapter((short[]) obj, mVar);
            }
            if (componentType == Byte.TYPE) {
                return new ByteArrayAdapter((byte[]) obj, mVar);
            }
            return new GenericPrimitiveArrayAdapter(obj, mVar);
        }
    }

    @Override // e.f.i0
    public abstract /* synthetic */ b0 get(int i2);

    @Override // e.f.a
    public final Object getAdaptedObject(Class cls) {
        return getWrappedObject();
    }

    @Override // e.d.d.c
    public abstract /* synthetic */ Object getWrappedObject();

    @Override // e.f.i0
    public abstract /* synthetic */ int size();

    private DefaultArrayAdapter(l lVar) {
        super(lVar);
    }
}
