package freemarker.template;

import d.a.a.a.a;
import e.f.m0.l;
import java.io.Serializable;
import java.util.Date;

public final class Version implements Serializable {
    private final Date buildDate;
    private volatile String calculatedStringValue;
    private final String extraInfo;
    private final Boolean gaeCompliant;
    private int hashCode;
    private final int intValue;
    private final int major;
    private final int micro;
    private final int minor;
    private final String originalStringValue;

    public Version(String str) {
        this(str, (Boolean) null, (Date) null);
    }

    private int calculateIntValue() {
        return intValueFor(this.major, this.minor, this.micro);
    }

    private String getStringValue() {
        String str = this.originalStringValue;
        if (str != null) {
            return str;
        }
        String str2 = this.calculatedStringValue;
        if (str2 == null) {
            synchronized (this) {
                str2 = this.calculatedStringValue;
                if (str2 == null) {
                    str2 = this.major + "." + this.minor + "." + this.micro;
                    if (this.extraInfo != null) {
                        str2 = str2 + "-" + this.extraInfo;
                    }
                    this.calculatedStringValue = str2;
                }
            }
        }
        return str2;
    }

    public static int intValueFor(int i2, int i3, int i4) {
        return (i3 * 1000) + (i2 * 1000000) + i4;
    }

    private boolean isNumber(char c2) {
        return c2 >= '0' && c2 <= '9';
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || Version.class != obj.getClass()) {
            return false;
        }
        Version version = (Version) obj;
        if (this.intValue != version.intValue || version.hashCode() != hashCode()) {
            return false;
        }
        Date date = this.buildDate;
        if (date == null) {
            if (version.buildDate != null) {
                return false;
            }
        } else if (!date.equals(version.buildDate)) {
            return false;
        }
        String str = this.extraInfo;
        if (str == null) {
            if (version.extraInfo != null) {
                return false;
            }
        } else if (!str.equals(version.extraInfo)) {
            return false;
        }
        Boolean bool = this.gaeCompliant;
        if (bool == null) {
            if (version.gaeCompliant != null) {
                return false;
            }
        } else if (!bool.equals(version.gaeCompliant)) {
            return false;
        }
        return true;
    }

    public Date getBuildDate() {
        return this.buildDate;
    }

    public String getExtraInfo() {
        return this.extraInfo;
    }

    public int getMajor() {
        return this.major;
    }

    public int getMicro() {
        return this.micro;
    }

    public int getMinor() {
        return this.minor;
    }

    public int hashCode() {
        int i2;
        int i3 = this.hashCode;
        if (i3 != 0) {
            return i3;
        }
        synchronized (this) {
            if (this.hashCode == 0) {
                Date date = this.buildDate;
                int i4 = 0;
                int hashCode2 = ((date == null ? 0 : date.hashCode()) + 31) * 31;
                String str = this.extraInfo;
                int hashCode3 = (hashCode2 + (str == null ? 0 : str.hashCode())) * 31;
                Boolean bool = this.gaeCompliant;
                if (bool != null) {
                    i4 = bool.hashCode();
                }
                int i5 = ((hashCode3 + i4) * 31) + this.intValue;
                if (i5 == 0) {
                    i5 = -1;
                }
                this.hashCode = i5;
            }
            i2 = this.hashCode;
        }
        return i2;
    }

    public int intValue() {
        return this.intValue;
    }

    public Boolean isGAECompliant() {
        return this.gaeCompliant;
    }

    public String toString() {
        return getStringValue();
    }

    public Version(String str, Boolean bool, Date date) {
        String str2;
        char charAt;
        String trim = str.trim();
        this.originalStringValue = trim;
        int[] iArr = new int[3];
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i2 >= trim.length()) {
                str2 = null;
                break;
            }
            char charAt2 = trim.charAt(i2);
            if (isNumber(charAt2)) {
                iArr[i3] = (charAt2 - '0') + (iArr[i3] * 10);
            } else if (i2 != 0) {
                if (charAt2 != '.') {
                    str2 = trim.substring(i2);
                    break;
                }
                int i4 = i2 + 1;
                char charAt3 = i4 >= trim.length() ? 0 : trim.charAt(i4);
                if (charAt3 == '.') {
                    StringBuilder B = a.B("The version number string ");
                    B.append(l.i(trim));
                    B.append(" contains multiple dots after a number.");
                    throw new IllegalArgumentException(B.toString());
                } else if (i3 == 2 || !isNumber(charAt3)) {
                    str2 = trim.substring(i2);
                } else {
                    i3++;
                }
            } else {
                StringBuilder B2 = a.B("The version number string ");
                B2.append(l.i(trim));
                B2.append(" doesn't start with a number.");
                throw new IllegalArgumentException(B2.toString());
            }
            i2++;
        }
        if (str2 != null && ((charAt = str2.charAt(0)) == '.' || charAt == '-' || charAt == '_')) {
            str2 = str2.substring(1);
            if (str2.length() == 0) {
                StringBuilder B3 = a.B("The version number string ");
                B3.append(l.i(trim));
                B3.append(" has an extra info section opened with \"");
                B3.append(charAt);
                B3.append("\", but it's empty.");
                throw new IllegalArgumentException(B3.toString());
            }
        }
        this.extraInfo = str2;
        this.major = iArr[0];
        this.minor = iArr[1];
        this.micro = iArr[2];
        this.intValue = calculateIntValue();
        this.gaeCompliant = bool;
        this.buildDate = date;
    }

    public Version(int i2, int i3, int i4) {
        this(i2, i3, i4, null, null, null);
    }

    public Version(int i2) {
        this.intValue = i2;
        this.micro = i2 % 1000;
        this.minor = (i2 / 1000) % 1000;
        this.major = i2 / 1000000;
        this.extraInfo = null;
        this.gaeCompliant = null;
        this.buildDate = null;
        this.originalStringValue = null;
    }

    public Version(int i2, int i3, int i4, String str, Boolean bool, Date date) {
        this.major = i2;
        this.minor = i3;
        this.micro = i4;
        this.extraInfo = str;
        this.gaeCompliant = bool;
        this.buildDate = date;
        this.intValue = calculateIntValue();
        this.originalStringValue = null;
    }
}
