package io.reactivex.internal.operators.flowable;

import d.l.b.g.g.b;
import f.a.b0.a;
import f.a.c0.c.f;
import f.a.j;
import io.reactivex.exceptions.MissingBackpressureException;
import io.reactivex.internal.queue.SpscArrayQueue;
import io.reactivex.internal.subscriptions.BasicIntQueueSubscription;
import io.reactivex.internal.subscriptions.SubscriptionHelper;
import java.util.concurrent.atomic.AtomicLong;
import k.c.c;
import k.c.d;

public final class FlowableOnBackpressureBuffer$BackpressureBufferSubscriber<T> extends BasicIntQueueSubscription<T> implements j<T> {
    private static final long serialVersionUID = -2514538129242366402L;
    public volatile boolean cancelled;
    public final boolean delayError;
    public volatile boolean done;
    public final c<? super T> downstream;
    public Throwable error;
    public final a onOverflow;
    public boolean outputFused;
    public final f<T> queue;
    public final AtomicLong requested = new AtomicLong();
    public d upstream;

    public FlowableOnBackpressureBuffer$BackpressureBufferSubscriber(c<? super T> cVar, int i2, boolean z, boolean z2, a aVar) {
        f<T> fVar;
        this.downstream = cVar;
        this.onOverflow = aVar;
        this.delayError = z2;
        if (z) {
            fVar = new f.a.c0.f.a<>(i2);
        } else {
            fVar = new SpscArrayQueue<>(i2);
        }
        this.queue = fVar;
    }

    @Override // k.c.d, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public void cancel() {
        if (!this.cancelled) {
            this.cancelled = true;
            this.upstream.cancel();
            if (getAndIncrement() == 0) {
                this.queue.clear();
            }
        }
    }

    public boolean checkTerminated(boolean z, boolean z2, c<? super T> cVar) {
        if (this.cancelled) {
            this.queue.clear();
            return true;
        } else if (!z) {
            return false;
        } else {
            if (!this.delayError) {
                Throwable th = this.error;
                if (th != null) {
                    this.queue.clear();
                    cVar.onError(th);
                    return true;
                } else if (!z2) {
                    return false;
                } else {
                    cVar.onComplete();
                    return true;
                }
            } else if (!z2) {
                return false;
            } else {
                Throwable th2 = this.error;
                if (th2 != null) {
                    cVar.onError(th2);
                } else {
                    cVar.onComplete();
                }
                return true;
            }
        }
    }

    @Override // f.a.c0.c.g, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public void clear() {
        this.queue.clear();
    }

    public void drain() {
        int i2;
        if (getAndIncrement() == 0) {
            f<T> fVar = this.queue;
            c<? super T> cVar = this.downstream;
            int i3 = 1;
            while (!checkTerminated(this.done, fVar.isEmpty(), cVar)) {
                long j2 = this.requested.get();
                long j3 = 0;
                while (true) {
                    i2 = (j3 > j2 ? 1 : (j3 == j2 ? 0 : -1));
                    if (i2 == 0) {
                        break;
                    }
                    boolean z = this.done;
                    T poll = fVar.poll();
                    boolean z2 = poll == null;
                    if (!checkTerminated(z, z2, cVar)) {
                        if (z2) {
                            break;
                        }
                        cVar.onNext(poll);
                        j3++;
                    } else {
                        return;
                    }
                }
                if (i2 != 0 || !checkTerminated(this.done, fVar.isEmpty(), cVar)) {
                    if (!(j3 == 0 || j2 == Long.MAX_VALUE)) {
                        this.requested.addAndGet(-j3);
                    }
                    i3 = addAndGet(-i3);
                    if (i3 == 0) {
                        return;
                    }
                } else {
                    return;
                }
            }
        }
    }

    @Override // f.a.c0.c.g, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public boolean isEmpty() {
        return this.queue.isEmpty();
    }

    @Override // k.c.c
    public void onComplete() {
        this.done = true;
        if (this.outputFused) {
            this.downstream.onComplete();
        } else {
            drain();
        }
    }

    @Override // k.c.c
    public void onError(Throwable th) {
        this.error = th;
        this.done = true;
        if (this.outputFused) {
            this.downstream.onError(th);
        } else {
            drain();
        }
    }

    @Override // k.c.c
    public void onNext(T t) {
        if (!this.queue.offer(t)) {
            this.upstream.cancel();
            MissingBackpressureException missingBackpressureException = new MissingBackpressureException("Buffer is full");
            try {
                this.onOverflow.run();
            } catch (Throwable th) {
                b.D0(th);
                missingBackpressureException.initCause(th);
            }
            onError(missingBackpressureException);
        } else if (this.outputFused) {
            this.downstream.onNext(null);
        } else {
            drain();
        }
    }

    @Override // f.a.j, k.c.c
    public void onSubscribe(d dVar) {
        if (SubscriptionHelper.validate(this.upstream, dVar)) {
            this.upstream = dVar;
            this.downstream.onSubscribe(this);
            dVar.request(Long.MAX_VALUE);
        }
    }

    @Override // f.a.c0.c.g, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public T poll() {
        return this.queue.poll();
    }

    @Override // k.c.d, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public void request(long j2) {
        if (!this.outputFused && SubscriptionHelper.validate(j2)) {
            b.b(this.requested, j2);
            drain();
        }
    }

    @Override // f.a.c0.c.c, io.reactivex.internal.subscriptions.BasicIntQueueSubscription
    public int requestFusion(int i2) {
        if ((i2 & 2) == 0) {
            return 0;
        }
        this.outputFused = true;
        return 2;
    }
}
