package io.reactivex.internal.operators.flowable;

import d.l.b.g.g.b;
import f.a.b0.a;
import f.a.j;
import io.reactivex.BackpressureOverflowStrategy;
import io.reactivex.exceptions.MissingBackpressureException;
import io.reactivex.internal.subscriptions.SubscriptionHelper;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
import k.c.c;
import k.c.d;

public final class FlowableOnBackpressureBufferStrategy$OnBackpressureBufferStrategySubscriber<T> extends AtomicInteger implements j<T>, d {
    private static final long serialVersionUID = 3240706908776709697L;
    public final long bufferSize;
    public volatile boolean cancelled;
    public final Deque<T> deque = new ArrayDeque();
    public volatile boolean done;
    public final c<? super T> downstream;
    public Throwable error;
    public final a onOverflow;
    public final AtomicLong requested = new AtomicLong();
    public final BackpressureOverflowStrategy strategy;
    public d upstream;

    public FlowableOnBackpressureBufferStrategy$OnBackpressureBufferStrategySubscriber(c<? super T> cVar, a aVar, BackpressureOverflowStrategy backpressureOverflowStrategy, long j2) {
        this.downstream = cVar;
        this.onOverflow = aVar;
        this.strategy = backpressureOverflowStrategy;
        this.bufferSize = j2;
    }

    @Override // k.c.d
    public void cancel() {
        this.cancelled = true;
        this.upstream.cancel();
        if (getAndIncrement() == 0) {
            clear(this.deque);
        }
    }

    public void clear(Deque<T> deque2) {
        synchronized (deque2) {
            deque2.clear();
        }
    }

    public void drain() {
        int i2;
        boolean isEmpty;
        T poll;
        if (getAndIncrement() == 0) {
            Deque<T> deque2 = this.deque;
            c<? super T> cVar = this.downstream;
            int i3 = 1;
            do {
                long j2 = this.requested.get();
                long j3 = 0;
                while (true) {
                    i2 = (j3 > j2 ? 1 : (j3 == j2 ? 0 : -1));
                    if (i2 == 0) {
                        break;
                    } else if (this.cancelled) {
                        clear(deque2);
                        return;
                    } else {
                        boolean z = this.done;
                        synchronized (deque2) {
                            poll = deque2.poll();
                        }
                        boolean z2 = poll == null;
                        if (z) {
                            Throwable th = this.error;
                            if (th != null) {
                                clear(deque2);
                                cVar.onError(th);
                                return;
                            } else if (z2) {
                                cVar.onComplete();
                                return;
                            }
                        }
                        if (z2) {
                            break;
                        }
                        cVar.onNext(poll);
                        j3++;
                    }
                }
                if (i2 == 0) {
                    if (this.cancelled) {
                        clear(deque2);
                        return;
                    }
                    boolean z3 = this.done;
                    synchronized (deque2) {
                        isEmpty = deque2.isEmpty();
                    }
                    if (z3) {
                        Throwable th2 = this.error;
                        if (th2 != null) {
                            clear(deque2);
                            cVar.onError(th2);
                            return;
                        } else if (isEmpty) {
                            cVar.onComplete();
                            return;
                        }
                    }
                }
                if (j3 != 0) {
                    b.v0(this.requested, j3);
                }
                i3 = addAndGet(-i3);
            } while (i3 != 0);
        }
    }

    @Override // k.c.c
    public void onComplete() {
        this.done = true;
        drain();
    }

    @Override // k.c.c
    public void onError(Throwable th) {
        if (this.done) {
            b.q0(th);
            return;
        }
        this.error = th;
        this.done = true;
        drain();
    }

    @Override // k.c.c
    public void onNext(T t) {
        boolean z;
        boolean z2;
        if (!this.done) {
            Deque<T> deque2 = this.deque;
            synchronized (deque2) {
                z = false;
                z2 = true;
                if (((long) deque2.size()) == this.bufferSize) {
                    int ordinal = this.strategy.ordinal();
                    if (ordinal == 1) {
                        deque2.poll();
                        deque2.offer(t);
                    } else if (ordinal == 2) {
                        deque2.pollLast();
                        deque2.offer(t);
                    }
                    z = true;
                } else {
                    deque2.offer(t);
                }
                z2 = false;
            }
            if (z) {
                a aVar = this.onOverflow;
                if (aVar != null) {
                    try {
                        aVar.run();
                    } catch (Throwable th) {
                        b.D0(th);
                        this.upstream.cancel();
                        onError(th);
                    }
                }
            } else if (z2) {
                this.upstream.cancel();
                onError(new MissingBackpressureException());
            } else {
                drain();
            }
        }
    }

    @Override // f.a.j, k.c.c
    public void onSubscribe(d dVar) {
        if (SubscriptionHelper.validate(this.upstream, dVar)) {
            this.upstream = dVar;
            this.downstream.onSubscribe(this);
            dVar.request(Long.MAX_VALUE);
        }
    }

    @Override // k.c.d
    public void request(long j2) {
        if (SubscriptionHelper.validate(j2)) {
            b.b(this.requested, j2);
            drain();
        }
    }
}
