package io.reactivex.internal.operators.mixed;

import f.a.b0.h;
import f.a.c;
import f.a.c0.c.f;
import f.a.e;
import f.a.j;
import f.a.z.b;
import io.reactivex.exceptions.MissingBackpressureException;
import io.reactivex.internal.disposables.DisposableHelper;
import io.reactivex.internal.queue.SpscArrayQueue;
import io.reactivex.internal.subscriptions.SubscriptionHelper;
import io.reactivex.internal.util.AtomicThrowable;
import io.reactivex.internal.util.ErrorMode;
import io.reactivex.internal.util.ExceptionHelper;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;
import k.c.d;

public final class FlowableConcatMapCompletable$ConcatMapCompletableObserver<T> extends AtomicInteger implements j<T>, b {
    private static final long serialVersionUID = 3610901111000061034L;
    public volatile boolean active;
    public int consumed;
    public volatile boolean disposed;
    public volatile boolean done;
    public final c downstream;
    public final ErrorMode errorMode;
    public final AtomicThrowable errors = new AtomicThrowable();
    public final ConcatMapInnerObserver inner = new ConcatMapInnerObserver(this);
    public final h<? super T, ? extends e> mapper;
    public final int prefetch;
    public final f<T> queue;
    public d upstream;

    public static final class ConcatMapInnerObserver extends AtomicReference<b> implements c {
        private static final long serialVersionUID = 5638352172918776687L;
        public final FlowableConcatMapCompletable$ConcatMapCompletableObserver<?> parent;

        public ConcatMapInnerObserver(FlowableConcatMapCompletable$ConcatMapCompletableObserver<?> flowableConcatMapCompletable$ConcatMapCompletableObserver) {
            this.parent = flowableConcatMapCompletable$ConcatMapCompletableObserver;
        }

        public void dispose() {
            DisposableHelper.dispose(this);
        }

        @Override // f.a.c
        public void onComplete() {
            this.parent.innerComplete();
        }

        @Override // f.a.c
        public void onError(Throwable th) {
            this.parent.innerError(th);
        }

        @Override // f.a.c
        public void onSubscribe(b bVar) {
            DisposableHelper.replace(this, bVar);
        }
    }

    public FlowableConcatMapCompletable$ConcatMapCompletableObserver(c cVar, h<? super T, ? extends e> hVar, ErrorMode errorMode2, int i2) {
        this.downstream = cVar;
        this.mapper = hVar;
        this.errorMode = errorMode2;
        this.prefetch = i2;
        this.queue = new SpscArrayQueue(i2);
    }

    @Override // f.a.z.b
    public void dispose() {
        this.disposed = true;
        this.upstream.cancel();
        this.inner.dispose();
        if (getAndIncrement() == 0) {
            this.queue.clear();
        }
    }

    public void drain() {
        if (getAndIncrement() == 0) {
            while (!this.disposed) {
                if (!this.active) {
                    if (this.errorMode != ErrorMode.BOUNDARY || this.errors.get() == null) {
                        boolean z = this.done;
                        T poll = this.queue.poll();
                        boolean z2 = poll == null;
                        if (z && z2) {
                            Throwable terminate = this.errors.terminate();
                            if (terminate != null) {
                                this.downstream.onError(terminate);
                                return;
                            } else {
                                this.downstream.onComplete();
                                return;
                            }
                        } else if (!z2) {
                            int i2 = this.prefetch;
                            int i3 = i2 - (i2 >> 1);
                            int i4 = this.consumed + 1;
                            if (i4 == i3) {
                                this.consumed = 0;
                                this.upstream.request((long) i3);
                            } else {
                                this.consumed = i4;
                            }
                            try {
                                Object apply = this.mapper.apply(poll);
                                Objects.requireNonNull(apply, "The mapper returned a null CompletableSource");
                                e eVar = (e) apply;
                                this.active = true;
                                eVar.a(this.inner);
                            } catch (Throwable th) {
                                d.l.b.g.g.b.D0(th);
                                this.queue.clear();
                                this.upstream.cancel();
                                this.errors.addThrowable(th);
                                this.downstream.onError(this.errors.terminate());
                                return;
                            }
                        }
                    } else {
                        this.queue.clear();
                        this.downstream.onError(this.errors.terminate());
                        return;
                    }
                }
                if (decrementAndGet() == 0) {
                    return;
                }
            }
            this.queue.clear();
        }
    }

    public void innerComplete() {
        this.active = false;
        drain();
    }

    public void innerError(Throwable th) {
        if (!this.errors.addThrowable(th)) {
            d.l.b.g.g.b.q0(th);
        } else if (this.errorMode == ErrorMode.IMMEDIATE) {
            this.upstream.cancel();
            Throwable terminate = this.errors.terminate();
            if (terminate != ExceptionHelper.f13426a) {
                this.downstream.onError(terminate);
            }
            if (getAndIncrement() == 0) {
                this.queue.clear();
            }
        } else {
            this.active = false;
            drain();
        }
    }

    @Override // f.a.z.b
    public boolean isDisposed() {
        return this.disposed;
    }

    @Override // k.c.c
    public void onComplete() {
        this.done = true;
        drain();
    }

    @Override // k.c.c
    public void onError(Throwable th) {
        if (!this.errors.addThrowable(th)) {
            d.l.b.g.g.b.q0(th);
        } else if (this.errorMode == ErrorMode.IMMEDIATE) {
            this.inner.dispose();
            Throwable terminate = this.errors.terminate();
            if (terminate != ExceptionHelper.f13426a) {
                this.downstream.onError(terminate);
            }
            if (getAndIncrement() == 0) {
                this.queue.clear();
            }
        } else {
            this.done = true;
            drain();
        }
    }

    @Override // k.c.c
    public void onNext(T t) {
        if (this.queue.offer(t)) {
            drain();
            return;
        }
        this.upstream.cancel();
        onError(new MissingBackpressureException("Queue full?!"));
    }

    @Override // f.a.j, k.c.c
    public void onSubscribe(d dVar) {
        if (SubscriptionHelper.validate(this.upstream, dVar)) {
            this.upstream = dVar;
            this.downstream.onSubscribe(this);
            dVar.request((long) this.prefetch);
        }
    }
}
