package kotlin.jvm.internal;

import h.p.b.p;
import h.p.b.q;
import h.s.b;
import h.s.d;
import h.s.n;
import java.io.Serializable;
import java.lang.annotation.Annotation;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import kotlin.jvm.KotlinReflectionNotSupportedError;
import kotlin.reflect.KVisibility;

public abstract class CallableReference implements b, Serializable {
    public static final Object NO_RECEIVER = NoReceiver.INSTANCE;
    private final boolean isTopLevel;
    private final String name;
    private final Class owner;
    public final Object receiver;
    private transient b reflected;
    private final String signature;

    public static class NoReceiver implements Serializable {
        private static final NoReceiver INSTANCE = new NoReceiver();

        private NoReceiver() {
        }

        private Object readResolve() {
            return INSTANCE;
        }
    }

    public CallableReference() {
        this(NO_RECEIVER);
    }

    @Override // h.s.b
    public Object call(Object... objArr) {
        return getReflected().call(objArr);
    }

    @Override // h.s.b
    public Object callBy(Map map) {
        return getReflected().callBy(map);
    }

    public b compute() {
        b bVar = this.reflected;
        if (bVar != null) {
            return bVar;
        }
        b computeReflected = computeReflected();
        this.reflected = computeReflected;
        return computeReflected;
    }

    public abstract b computeReflected();

    @Override // h.s.a
    public List<Annotation> getAnnotations() {
        return getReflected().getAnnotations();
    }

    public Object getBoundReceiver() {
        return this.receiver;
    }

    public String getName() {
        return this.name;
    }

    public d getOwner() {
        Class cls = this.owner;
        if (cls == null) {
            return null;
        }
        if (!this.isTopLevel) {
            return q.a(cls);
        }
        Objects.requireNonNull(q.f13316a);
        return new p(cls, "");
    }

    @Override // h.s.b
    public List<?> getParameters() {
        return getReflected().getParameters();
    }

    public b getReflected() {
        b compute = compute();
        if (compute != this) {
            return compute;
        }
        throw new KotlinReflectionNotSupportedError();
    }

    @Override // h.s.b
    public n getReturnType() {
        return getReflected().getReturnType();
    }

    public String getSignature() {
        return this.signature;
    }

    @Override // h.s.b
    public List<?> getTypeParameters() {
        return getReflected().getTypeParameters();
    }

    @Override // h.s.b
    public KVisibility getVisibility() {
        return getReflected().getVisibility();
    }

    @Override // h.s.b
    public boolean isAbstract() {
        return getReflected().isAbstract();
    }

    @Override // h.s.b
    public boolean isFinal() {
        return getReflected().isFinal();
    }

    @Override // h.s.b
    public boolean isOpen() {
        return getReflected().isOpen();
    }

    @Override // h.s.b
    public boolean isSuspend() {
        return getReflected().isSuspend();
    }

    public CallableReference(Object obj) {
        this(obj, null, null, null, false);
    }

    public CallableReference(Object obj, Class cls, String str, String str2, boolean z) {
        this.receiver = obj;
        this.owner = cls;
        this.name = str;
        this.signature = str2;
        this.isTopLevel = z;
    }
}
