package okio;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import d.l.b.g.g.b;
import h.p.b.o;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import okio.Path;

@ExperimentalFileSystem
/* compiled from: JvmSystemFileSystem.kt */
public class JvmSystemFileSystem extends FileSystem {
    @Override // okio.FileSystem
    public Sink appendingSink(Path path) {
        o.e(path, "file");
        return Okio.sink(path.toFile(), true);
    }

    @Override // okio.FileSystem
    public void atomicMove(Path path, Path path2) {
        o.e(path, "source");
        o.e(path2, TypedValues.Attributes.S_TARGET);
        if (!path.toFile().renameTo(path2.toFile())) {
            throw new IOException("failed to move " + path + " to " + path2);
        }
    }

    @Override // okio.FileSystem
    public Path canonicalize(Path path) {
        o.e(path, "path");
        File canonicalFile = path.toFile().getCanonicalFile();
        if (canonicalFile.exists()) {
            Path.Companion companion = Path.Companion;
            o.d(canonicalFile, "canonicalFile");
            return companion.get(canonicalFile);
        }
        throw new FileNotFoundException("no such file");
    }

    @Override // okio.FileSystem
    public void createDirectory(Path path) {
        o.e(path, "dir");
        if (!path.toFile().mkdir()) {
            throw new IOException("failed to create directory: " + path);
        }
    }

    @Override // okio.FileSystem
    public void delete(Path path) {
        o.e(path, "path");
        File file = path.toFile();
        if (file.delete()) {
            return;
        }
        if (!file.exists()) {
            throw new FileNotFoundException("no such file: " + path);
        }
        throw new IOException("failed to delete " + path);
    }

    @Override // okio.FileSystem
    public List<Path> list(Path path) {
        o.e(path, "dir");
        File file = path.toFile();
        String[] list = file.list();
        if (list != null) {
            ArrayList arrayList = new ArrayList();
            for (String str : list) {
                o.d(str, "it");
                arrayList.add(path.resolve(str));
            }
            b.C0(arrayList);
            return arrayList;
        } else if (!file.exists()) {
            throw new FileNotFoundException("no such file: " + path);
        } else {
            throw new IOException("failed to list " + path);
        }
    }

    @Override // okio.FileSystem
    public FileMetadata metadataOrNull(Path path) {
        o.e(path, "path");
        File file = path.toFile();
        boolean isFile = file.isFile();
        boolean isDirectory = file.isDirectory();
        long lastModified = file.lastModified();
        long length = file.length();
        if (isFile || isDirectory || lastModified != 0 || length != 0 || file.exists()) {
            return new FileMetadata(isFile, isDirectory, Long.valueOf(length), null, Long.valueOf(lastModified), null);
        }
        return null;
    }

    @Override // okio.FileSystem
    public FileHandle open(Path path) {
        o.e(path, "file");
        throw new UnsupportedOperationException("not implemented yet!");
    }

    @Override // okio.FileSystem
    public Sink sink(Path path) {
        o.e(path, "file");
        return Okio__JvmOkioKt.sink$default(path.toFile(), false, 1, null);
    }

    @Override // okio.FileSystem
    public Source source(Path path) {
        o.e(path, "file");
        return Okio.source(path.toFile());
    }

    public String toString() {
        return "JvmSystemFileSystem";
    }
}
