package okio;

import d.a.a.a.a;
import d.l.b.g.g.b;
import h.p.b.o;
import java.io.EOFException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import okio.internal.BufferedSourceCursor;
import okio.internal._BufferKt;

/* compiled from: RealBufferedSource.kt */
public final class RealBufferedSource implements BufferedSource {
    public final Buffer bufferField;
    public boolean closed;
    private final Cursor cursor;
    public final Source source;

    public RealBufferedSource(Source source2) {
        o.e(source2, "source");
        this.source = source2;
        Buffer buffer = new Buffer();
        this.bufferField = buffer;
        Cursor cursor2 = source2.cursor();
        this.cursor = cursor2 != null ? new BufferedSourceCursor(buffer, cursor2) : null;
    }

    public static /* synthetic */ void getBuffer$annotations() {
    }

    @Override // okio.BufferedSource
    public Buffer buffer() {
        return this.bufferField;
    }

    @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable, java.nio.channels.Channel
    public void close() {
        if (!this.closed) {
            this.closed = true;
            this.source.close();
            this.bufferField.clear();
        }
    }

    @Override // okio.Source
    public Cursor cursor() {
        return this.cursor;
    }

    @Override // okio.BufferedSource
    public boolean exhausted() {
        if (!(!this.closed)) {
            throw new IllegalStateException("closed".toString());
        } else if (!this.bufferField.exhausted() || this.source.read(this.bufferField, (long) 8192) != -1) {
            return false;
        } else {
            return true;
        }
    }

    @Override // okio.BufferedSource
    public Buffer getBuffer() {
        return this.bufferField;
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2) {
        return indexOf(b2, 0, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString) {
        o.e(byteString, "targetBytes");
        return indexOfElement(byteString, 0);
    }

    @Override // okio.BufferedSource
    public InputStream inputStream() {
        return new RealBufferedSource$inputStream$1(this);
    }

    public boolean isOpen() {
        return !this.closed;
    }

    @Override // okio.BufferedSource
    public BufferedSource peek() {
        return Okio.buffer(new PeekSource(this));
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j2, ByteString byteString) {
        o.e(byteString, "bytes");
        return rangeEquals(j2, byteString, 0, byteString.size());
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr) {
        o.e(bArr, "sink");
        return read(bArr, 0, bArr.length);
    }

    @Override // okio.BufferedSource
    public long readAll(Sink sink) {
        o.e(sink, "sink");
        long j2 = 0;
        while (this.source.read(this.bufferField, (long) 8192) != -1) {
            long completeSegmentByteCount = this.bufferField.completeSegmentByteCount();
            if (completeSegmentByteCount > 0) {
                j2 += completeSegmentByteCount;
                sink.write(this.bufferField, completeSegmentByteCount);
            }
        }
        if (this.bufferField.size() <= 0) {
            return j2;
        }
        long size = j2 + this.bufferField.size();
        Buffer buffer = this.bufferField;
        sink.write(buffer, buffer.size());
        return size;
    }

    @Override // okio.BufferedSource
    public byte readByte() {
        require(1);
        return this.bufferField.readByte();
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray() {
        this.bufferField.writeAll(this.source);
        return this.bufferField.readByteArray();
    }

    @Override // okio.BufferedSource
    public ByteString readByteString() {
        this.bufferField.writeAll(this.source);
        return this.bufferField.readByteString();
    }

    @Override // okio.BufferedSource
    public long readDecimalLong() {
        int i2;
        require(1);
        long j2 = 0;
        while (true) {
            long j3 = j2 + 1;
            if (!request(j3)) {
                break;
            }
            byte b2 = this.bufferField.getByte(j2);
            if ((b2 >= ((byte) 48) && b2 <= ((byte) 57)) || (j2 == 0 && b2 == ((byte) 45))) {
                j2 = j3;
            } else if (i2 == 0) {
                StringBuilder sb = new StringBuilder();
                sb.append("Expected leading [0-9] or '-' character but was 0x");
                b.n(16);
                b.n(16);
                String num = Integer.toString(b2, 16);
                o.d(num, "java.lang.Integer.toStri…(this, checkRadix(radix))");
                sb.append(num);
                throw new NumberFormatException(sb.toString());
            }
        }
        return this.bufferField.readDecimalLong();
    }

    @Override // okio.BufferedSource
    public void readFully(byte[] bArr) {
        o.e(bArr, "sink");
        try {
            require((long) bArr.length);
            this.bufferField.readFully(bArr);
        } catch (EOFException e2) {
            int i2 = 0;
            while (this.bufferField.size() > 0) {
                Buffer buffer = this.bufferField;
                int read = buffer.read(bArr, i2, (int) buffer.size());
                if (read != -1) {
                    i2 += read;
                } else {
                    throw new AssertionError();
                }
            }
            throw e2;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x003a  */
    @Override // okio.BufferedSource
    public long readHexadecimalUnsignedLong() {
        require(1);
        int i2 = 0;
        while (true) {
            int i3 = i2 + 1;
            if (!request((long) i3)) {
                break;
            }
            byte b2 = this.bufferField.getByte((long) i2);
            if ((b2 >= ((byte) 48) && b2 <= ((byte) 57)) || ((b2 >= ((byte) 97) && b2 <= ((byte) 102)) || (b2 >= ((byte) 65) && b2 <= ((byte) 70)))) {
                i2 = i3;
            } else if (i2 == 0) {
                StringBuilder sb = new StringBuilder();
                sb.append("Expected leading [0-9a-fA-F] character but was 0x");
                b.n(16);
                b.n(16);
                String num = Integer.toString(b2, 16);
                o.d(num, "java.lang.Integer.toStri…(this, checkRadix(radix))");
                sb.append(num);
                throw new NumberFormatException(sb.toString());
            }
        }
        if (i2 == 0) {
        }
        return this.bufferField.readHexadecimalUnsignedLong();
    }

    @Override // okio.BufferedSource
    public int readInt() {
        require(4);
        return this.bufferField.readInt();
    }

    @Override // okio.BufferedSource
    public int readIntLe() {
        require(4);
        return this.bufferField.readIntLe();
    }

    @Override // okio.BufferedSource
    public long readLong() {
        require(8);
        return this.bufferField.readLong();
    }

    @Override // okio.BufferedSource
    public long readLongLe() {
        require(8);
        return this.bufferField.readLongLe();
    }

    @Override // okio.BufferedSource
    public short readShort() {
        require(2);
        return this.bufferField.readShort();
    }

    @Override // okio.BufferedSource
    public short readShortLe() {
        require(2);
        return this.bufferField.readShortLe();
    }

    @Override // okio.BufferedSource
    public String readString(long j2, Charset charset) {
        o.e(charset, "charset");
        require(j2);
        return this.bufferField.readString(j2, charset);
    }

    @Override // okio.BufferedSource
    public String readUtf8() {
        this.bufferField.writeAll(this.source);
        return this.bufferField.readUtf8();
    }

    @Override // okio.BufferedSource
    public int readUtf8CodePoint() {
        require(1);
        byte b2 = this.bufferField.getByte(0);
        if ((b2 & 224) == 192) {
            require(2);
        } else if ((b2 & 240) == 224) {
            require(3);
        } else if ((b2 & 248) == 240) {
            require(4);
        }
        return this.bufferField.readUtf8CodePoint();
    }

    @Override // okio.BufferedSource
    public String readUtf8Line() {
        long indexOf = indexOf((byte) 10);
        if (indexOf != -1) {
            return _BufferKt.readUtf8Line(this.bufferField, indexOf);
        }
        if (this.bufferField.size() != 0) {
            return readUtf8(this.bufferField.size());
        }
        return null;
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict() {
        return readUtf8LineStrict(Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public boolean request(long j2) {
        if (!(j2 >= 0)) {
            throw new IllegalArgumentException(a.o("byteCount < 0: ", j2).toString());
        } else if (!this.closed) {
            while (this.bufferField.size() < j2) {
                if (this.source.read(this.bufferField, (long) 8192) == -1) {
                    return false;
                }
            }
            return true;
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSource
    public void require(long j2) {
        if (!request(j2)) {
            throw new EOFException();
        }
    }

    @Override // okio.BufferedSource
    public int select(Options options) {
        o.e(options, "options");
        if (!this.closed) {
            while (true) {
                int selectPrefix = _BufferKt.selectPrefix(this.bufferField, options, true);
                if (selectPrefix == -2) {
                    if (this.source.read(this.bufferField, (long) 8192) == -1) {
                        break;
                    }
                } else if (selectPrefix != -1) {
                    this.bufferField.skip((long) options.getByteStrings$okio()[selectPrefix].size());
                    return selectPrefix;
                }
            }
            return -1;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSource
    public void skip(long j2) {
        if (!this.closed) {
            while (j2 > 0) {
                if (this.bufferField.size() == 0 && this.source.read(this.bufferField, (long) 8192) == -1) {
                    throw new EOFException();
                }
                long min = Math.min(j2, this.bufferField.size());
                this.bufferField.skip(min);
                j2 -= min;
            }
            return;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.Source
    public Timeout timeout() {
        return this.source.timeout();
    }

    public String toString() {
        StringBuilder B = a.B("buffer(");
        B.append(this.source);
        B.append(')');
        return B.toString();
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2, long j2) {
        return indexOf(b2, j2, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString, long j2) {
        o.e(byteString, "targetBytes");
        if (!this.closed) {
            while (true) {
                long indexOfElement = this.bufferField.indexOfElement(byteString, j2);
                if (indexOfElement != -1) {
                    return indexOfElement;
                }
                long size = this.bufferField.size();
                if (this.source.read(this.bufferField, (long) 8192) == -1) {
                    return -1;
                }
                j2 = Math.max(j2, size);
            }
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.Source
    public long read(Buffer buffer, long j2) {
        o.e(buffer, "sink");
        if (!(j2 >= 0)) {
            throw new IllegalArgumentException(a.o("byteCount < 0: ", j2).toString());
        } else if (!(!this.closed)) {
            throw new IllegalStateException("closed".toString());
        } else if (this.bufferField.size() == 0 && this.source.read(this.bufferField, (long) 8192) == -1) {
            return -1;
        } else {
            return this.bufferField.read(buffer, Math.min(j2, this.bufferField.size()));
        }
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict(long j2) {
        if (j2 >= 0) {
            long j3 = j2 == Long.MAX_VALUE ? Long.MAX_VALUE : j2 + 1;
            byte b2 = (byte) 10;
            long indexOf = indexOf(b2, 0, j3);
            if (indexOf != -1) {
                return _BufferKt.readUtf8Line(this.bufferField, indexOf);
            }
            if (j3 < Long.MAX_VALUE && request(j3) && this.bufferField.getByte(j3 - 1) == ((byte) 13) && request(1 + j3) && this.bufferField.getByte(j3) == b2) {
                return _BufferKt.readUtf8Line(this.bufferField, j3);
            }
            Buffer buffer = new Buffer();
            Buffer buffer2 = this.bufferField;
            buffer2.copyTo(buffer, 0, Math.min((long) 32, buffer2.size()));
            StringBuilder B = a.B("\\n not found: limit=");
            B.append(Math.min(this.bufferField.size(), j2));
            B.append(" content=");
            B.append(buffer.readByteString().hex());
            B.append("…");
            throw new EOFException(B.toString());
        }
        throw new IllegalArgumentException(a.o("limit < 0: ", j2).toString());
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString) {
        o.e(byteString, "bytes");
        return indexOf(byteString, 0);
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j2, ByteString byteString, int i2, int i3) {
        o.e(byteString, "bytes");
        if (!this.closed) {
            if (j2 >= 0 && i2 >= 0 && i3 >= 0 && byteString.size() - i2 >= i3) {
                for (int i4 = 0; i4 < i3; i4++) {
                    long j3 = ((long) i4) + j2;
                    if (request(1 + j3) && this.bufferField.getByte(j3) == byteString.getByte(i2 + i4)) {
                    }
                }
                return true;
            }
            return false;
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2, long j2, long j3) {
        boolean z = true;
        if (!this.closed) {
            if (0 > j2 || j3 < j2) {
                z = false;
            }
            if (z) {
                while (j2 < j3) {
                    long indexOf = this.bufferField.indexOf(b2, j2, j3);
                    if (indexOf != -1) {
                        return indexOf;
                    }
                    long size = this.bufferField.size();
                    if (size >= j3 || this.source.read(this.bufferField, (long) 8192) == -1) {
                        return -1;
                    }
                    j2 = Math.max(j2, size);
                }
                return -1;
            }
            StringBuilder E = a.E("fromIndex=", j2, " toIndex=");
            E.append(j3);
            throw new IllegalArgumentException(E.toString().toString());
        }
        throw new IllegalStateException("closed".toString());
    }

    @Override // okio.BufferedSource
    public String readString(Charset charset) {
        o.e(charset, "charset");
        this.bufferField.writeAll(this.source);
        return this.bufferField.readString(charset);
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray(long j2) {
        require(j2);
        return this.bufferField.readByteArray(j2);
    }

    @Override // okio.BufferedSource
    public ByteString readByteString(long j2) {
        require(j2);
        return this.bufferField.readByteString(j2);
    }

    @Override // okio.BufferedSource
    public String readUtf8(long j2) {
        require(j2);
        return this.bufferField.readUtf8(j2);
    }

    @Override // okio.BufferedSource
    public void readFully(Buffer buffer, long j2) {
        o.e(buffer, "sink");
        try {
            require(j2);
            this.bufferField.readFully(buffer, j2);
        } catch (EOFException e2) {
            buffer.writeAll(this.bufferField);
            throw e2;
        }
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString, long j2) {
        o.e(byteString, "bytes");
        if (!this.closed) {
            while (true) {
                long indexOf = this.bufferField.indexOf(byteString, j2);
                if (indexOf != -1) {
                    return indexOf;
                }
                long size = this.bufferField.size();
                if (this.source.read(this.bufferField, (long) 8192) == -1) {
                    return -1;
                }
                j2 = Math.max(j2, (size - ((long) byteString.size())) + 1);
            }
        } else {
            throw new IllegalStateException("closed".toString());
        }
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr, int i2, int i3) {
        o.e(bArr, "sink");
        long j2 = (long) i3;
        _UtilKt.checkOffsetAndCount((long) bArr.length, (long) i2, j2);
        if (this.bufferField.size() == 0 && this.source.read(this.bufferField, (long) 8192) == -1) {
            return -1;
        }
        return this.bufferField.read(bArr, i2, (int) Math.min(j2, this.bufferField.size()));
    }

    @Override // java.nio.channels.ReadableByteChannel
    public int read(ByteBuffer byteBuffer) {
        o.e(byteBuffer, "sink");
        if (this.bufferField.size() == 0 && this.source.read(this.bufferField, (long) 8192) == -1) {
            return -1;
        }
        return this.bufferField.read(byteBuffer);
    }
}
