package okio.internal;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.shuyu.gsyvideoplayer.utils.NeuQuant;
import d.a.a.a.a;
import h.l.h;
import h.p.a.p;
import h.p.b.o;
import java.io.EOFException;
import okio.Buffer;
import okio.ByteString;
import okio.Options;
import okio.Segment;
import okio.SegmentPool;
import okio.SegmentedByteString;
import okio.Sink;
import okio.Source;
import okio.Utf8;
import okio._JvmPlatformKt;
import okio._UtilKt;
import org.dsq.library.widget.bigImage.SubsamplingScaleImageView;

public final class _BufferKt {
    private static final byte[] HEX_DIGIT_BYTES = _JvmPlatformKt.asUtf8ToByteArray("0123456789abcdef");
    public static final long OVERFLOW_DIGIT_START;
    public static final long OVERFLOW_ZONE;
    public static final int SEGMENTING_THRESHOLD;

    public static final void commonClear(Buffer buffer) {
        o.e(buffer, "$this$commonClear");
        buffer.skip(buffer.size());
    }

    public static final void commonClose(Buffer.UnsafeCursor unsafeCursor) {
        o.e(unsafeCursor, "$this$commonClose");
        if (unsafeCursor.buffer != null) {
            unsafeCursor.buffer = null;
            unsafeCursor.setSegment$okio(null);
            unsafeCursor.offset = -1;
            unsafeCursor.data = null;
            unsafeCursor.start = -1;
            unsafeCursor.end = -1;
            return;
        }
        throw new IllegalStateException("not attached to a buffer".toString());
    }

    public static final long commonCompleteSegmentByteCount(Buffer buffer) {
        o.e(buffer, "$this$commonCompleteSegmentByteCount");
        long size = buffer.size();
        if (size == 0) {
            return 0;
        }
        Segment segment = buffer.head;
        o.c(segment);
        Segment segment2 = segment.prev;
        o.c(segment2);
        int i2 = segment2.limit;
        return (i2 >= 8192 || !segment2.owner) ? size : size - ((long) (i2 - segment2.pos));
    }

    public static final Buffer commonCopy(Buffer buffer) {
        o.e(buffer, "$this$commonCopy");
        Buffer buffer2 = new Buffer();
        if (buffer.size() == 0) {
            return buffer2;
        }
        Segment segment = buffer.head;
        o.c(segment);
        Segment sharedCopy = segment.sharedCopy();
        buffer2.head = sharedCopy;
        sharedCopy.prev = sharedCopy;
        sharedCopy.next = sharedCopy;
        for (Segment segment2 = segment.next; segment2 != segment; segment2 = segment2.next) {
            Segment segment3 = sharedCopy.prev;
            o.c(segment3);
            o.c(segment2);
            segment3.push(segment2.sharedCopy());
        }
        buffer2.setSize$okio(buffer.size());
        return buffer2;
    }

    public static final Buffer commonCopyTo(Buffer buffer, Buffer buffer2, long j2, long j3) {
        o.e(buffer, "$this$commonCopyTo");
        o.e(buffer2, "out");
        _UtilKt.checkOffsetAndCount(buffer.size(), j2, j3);
        if (j3 == 0) {
            return buffer;
        }
        buffer2.setSize$okio(buffer2.size() + j3);
        Segment segment = buffer.head;
        while (true) {
            o.c(segment);
            int i2 = segment.limit;
            int i3 = segment.pos;
            if (j2 < ((long) (i2 - i3))) {
                break;
            }
            j2 -= (long) (i2 - i3);
            segment = segment.next;
        }
        while (j3 > 0) {
            o.c(segment);
            Segment sharedCopy = segment.sharedCopy();
            int i4 = sharedCopy.pos + ((int) j2);
            sharedCopy.pos = i4;
            sharedCopy.limit = Math.min(i4 + ((int) j3), sharedCopy.limit);
            Segment segment2 = buffer2.head;
            if (segment2 == null) {
                sharedCopy.prev = sharedCopy;
                sharedCopy.next = sharedCopy;
                buffer2.head = sharedCopy;
            } else {
                o.c(segment2);
                Segment segment3 = segment2.prev;
                o.c(segment3);
                segment3.push(sharedCopy);
            }
            j3 -= (long) (sharedCopy.limit - sharedCopy.pos);
            segment = segment.next;
            j2 = 0;
        }
        return buffer;
    }

    public static final boolean commonEquals(Buffer buffer, Object obj) {
        o.e(buffer, "$this$commonEquals");
        if (buffer == obj) {
            return true;
        }
        if (!(obj instanceof Buffer)) {
            return false;
        }
        Buffer buffer2 = (Buffer) obj;
        if (buffer.size() != buffer2.size()) {
            return false;
        }
        if (buffer.size() == 0) {
            return true;
        }
        Segment segment = buffer.head;
        o.c(segment);
        Segment segment2 = buffer2.head;
        o.c(segment2);
        int i2 = segment.pos;
        int i3 = segment2.pos;
        long j2 = 0;
        while (j2 < buffer.size()) {
            long min = (long) Math.min(segment.limit - i2, segment2.limit - i3);
            long j3 = 0;
            while (j3 < min) {
                int i4 = i2 + 1;
                int i5 = i3 + 1;
                if (segment.data[i2] != segment2.data[i3]) {
                    return false;
                }
                j3++;
                i2 = i4;
                i3 = i5;
            }
            if (i2 == segment.limit) {
                segment = segment.next;
                o.c(segment);
                i2 = segment.pos;
            }
            if (i3 == segment2.limit) {
                segment2 = segment2.next;
                o.c(segment2);
                i3 = segment2.pos;
            }
            j2 += min;
        }
        return true;
    }

    public static final long commonExpandBuffer(Buffer.UnsafeCursor unsafeCursor, int i2) {
        o.e(unsafeCursor, "$this$commonExpandBuffer");
        boolean z = true;
        if (i2 > 0) {
            if (i2 > 8192) {
                z = false;
            }
            if (z) {
                Buffer buffer = unsafeCursor.buffer;
                if (buffer == null) {
                    throw new IllegalStateException("not attached to a buffer".toString());
                } else if (unsafeCursor.readWrite) {
                    long size = buffer.size();
                    Segment writableSegment$okio = buffer.writableSegment$okio(i2);
                    int i3 = 8192 - writableSegment$okio.limit;
                    writableSegment$okio.limit = 8192;
                    long j2 = (long) i3;
                    buffer.setSize$okio(size + j2);
                    unsafeCursor.setSegment$okio(writableSegment$okio);
                    unsafeCursor.offset = size;
                    unsafeCursor.data = writableSegment$okio.data;
                    unsafeCursor.start = 8192 - i3;
                    unsafeCursor.end = 8192;
                    return j2;
                } else {
                    throw new IllegalStateException("expandBuffer() only permitted for read/write buffers".toString());
                }
            } else {
                throw new IllegalArgumentException(a.k("minByteCount > Segment.SIZE: ", i2).toString());
            }
        } else {
            throw new IllegalArgumentException(a.k("minByteCount <= 0: ", i2).toString());
        }
    }

    public static final byte commonGet(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonGet");
        _UtilKt.checkOffsetAndCount(buffer.size(), j2, 1);
        Segment segment = buffer.head;
        if (segment == null) {
            Segment segment2 = null;
            o.c(null);
            return segment2.data[(int) ((((long) segment2.pos) + j2) - -1)];
        } else if (buffer.size() - j2 < j2) {
            long size = buffer.size();
            while (size > j2) {
                segment = segment.prev;
                o.c(segment);
                size -= (long) (segment.limit - segment.pos);
            }
            o.c(segment);
            return segment.data[(int) ((((long) segment.pos) + j2) - size)];
        } else {
            long j3 = 0;
            while (true) {
                long j4 = ((long) (segment.limit - segment.pos)) + j3;
                if (j4 > j2) {
                    o.c(segment);
                    return segment.data[(int) ((((long) segment.pos) + j2) - j3)];
                }
                segment = segment.next;
                o.c(segment);
                j3 = j4;
            }
        }
    }

    public static final int commonHashCode(Buffer buffer) {
        o.e(buffer, "$this$commonHashCode");
        Segment segment = buffer.head;
        if (segment == null) {
            return 0;
        }
        int i2 = 1;
        do {
            int i3 = segment.limit;
            for (int i4 = segment.pos; i4 < i3; i4++) {
                i2 = (i2 * 31) + segment.data[i4];
            }
            segment = segment.next;
            o.c(segment);
        } while (segment != buffer.head);
        return i2;
    }

    public static final long commonIndexOf(Buffer buffer, byte b2, long j2, long j3) {
        Segment segment;
        int i2;
        o.e(buffer, "$this$commonIndexOf");
        long j4 = 0;
        if (0 <= j2 && j3 >= j2) {
            if (j3 > buffer.size()) {
                j3 = buffer.size();
            }
            if (j2 == j3 || (segment = buffer.head) == null) {
                return -1;
            }
            if (buffer.size() - j2 < j2) {
                j4 = buffer.size();
                while (j4 > j2) {
                    segment = segment.prev;
                    o.c(segment);
                    j4 -= (long) (segment.limit - segment.pos);
                }
                while (j4 < j3) {
                    byte[] bArr = segment.data;
                    int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + j3) - j4);
                    i2 = (int) ((((long) segment.pos) + j2) - j4);
                    while (i2 < min) {
                        if (bArr[i2] != b2) {
                            i2++;
                        }
                    }
                    j4 += (long) (segment.limit - segment.pos);
                    segment = segment.next;
                    o.c(segment);
                    j2 = j4;
                }
                return -1;
            }
            while (true) {
                long j5 = ((long) (segment.limit - segment.pos)) + j4;
                if (j5 > j2) {
                    break;
                }
                segment = segment.next;
                o.c(segment);
                j4 = j5;
            }
            while (j4 < j3) {
                byte[] bArr2 = segment.data;
                int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + j3) - j4);
                i2 = (int) ((((long) segment.pos) + j2) - j4);
                while (i2 < min2) {
                    if (bArr2[i2] != b2) {
                        i2++;
                    }
                }
                j4 += (long) (segment.limit - segment.pos);
                segment = segment.next;
                o.c(segment);
                j2 = j4;
            }
            return -1;
            return ((long) (i2 - segment.pos)) + j4;
        }
        StringBuilder B = a.B("size=");
        B.append(buffer.size());
        B.append(" fromIndex=");
        B.append(j2);
        B.append(" toIndex=");
        B.append(j3);
        throw new IllegalArgumentException(B.toString().toString());
    }

    public static final long commonIndexOfElement(Buffer buffer, ByteString byteString, long j2) {
        int i2;
        int i3;
        o.e(buffer, "$this$commonIndexOfElement");
        o.e(byteString, "targetBytes");
        long j3 = 0;
        if (j2 >= 0) {
            Segment segment = buffer.head;
            if (segment == null) {
                return -1;
            }
            if (buffer.size() - j2 < j2) {
                j3 = buffer.size();
                while (j3 > j2) {
                    segment = segment.prev;
                    o.c(segment);
                    j3 -= (long) (segment.limit - segment.pos);
                }
                if (byteString.size() == 2) {
                    byte b2 = byteString.getByte(0);
                    byte b3 = byteString.getByte(1);
                    while (j3 < buffer.size()) {
                        byte[] bArr = segment.data;
                        i2 = (int) ((((long) segment.pos) + j2) - j3);
                        int i4 = segment.limit;
                        while (i2 < i4) {
                            byte b4 = bArr[i2];
                            if (!(b4 == b2 || b4 == b3)) {
                                i2++;
                            }
                        }
                        j3 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        o.c(segment);
                        j2 = j3;
                    }
                } else {
                    byte[] internalArray$okio = byteString.internalArray$okio();
                    while (j3 < buffer.size()) {
                        byte[] bArr2 = segment.data;
                        i2 = (int) ((((long) segment.pos) + j2) - j3);
                        int i5 = segment.limit;
                        while (i2 < i5) {
                            byte b5 = bArr2[i2];
                            for (byte b6 : internalArray$okio) {
                                if (b5 == b6) {
                                    i3 = segment.pos;
                                    return ((long) (i2 - i3)) + j3;
                                }
                            }
                            i2++;
                        }
                        j3 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        o.c(segment);
                        j2 = j3;
                    }
                }
                return -1;
            }
            while (true) {
                long j4 = ((long) (segment.limit - segment.pos)) + j3;
                if (j4 > j2) {
                    break;
                }
                segment = segment.next;
                o.c(segment);
                j3 = j4;
            }
            if (byteString.size() == 2) {
                byte b7 = byteString.getByte(0);
                byte b8 = byteString.getByte(1);
                while (j3 < buffer.size()) {
                    byte[] bArr3 = segment.data;
                    i2 = (int) ((((long) segment.pos) + j2) - j3);
                    int i6 = segment.limit;
                    while (i2 < i6) {
                        byte b9 = bArr3[i2];
                        if (!(b9 == b7 || b9 == b8)) {
                            i2++;
                        }
                    }
                    j3 += (long) (segment.limit - segment.pos);
                    segment = segment.next;
                    o.c(segment);
                    j2 = j3;
                }
            } else {
                byte[] internalArray$okio2 = byteString.internalArray$okio();
                while (j3 < buffer.size()) {
                    byte[] bArr4 = segment.data;
                    i2 = (int) ((((long) segment.pos) + j2) - j3);
                    int i7 = segment.limit;
                    while (i2 < i7) {
                        byte b10 = bArr4[i2];
                        for (byte b11 : internalArray$okio2) {
                            if (b10 == b11) {
                                i3 = segment.pos;
                                return ((long) (i2 - i3)) + j3;
                            }
                        }
                        i2++;
                    }
                    j3 += (long) (segment.limit - segment.pos);
                    segment = segment.next;
                    o.c(segment);
                    j2 = j3;
                }
            }
            return -1;
            i3 = segment.pos;
            return ((long) (i2 - i3)) + j3;
        }
        throw new IllegalArgumentException(a.o("fromIndex < 0: ", j2).toString());
    }

    public static final int commonNext(Buffer.UnsafeCursor unsafeCursor) {
        o.e(unsafeCursor, "$this$commonNext");
        long j2 = unsafeCursor.offset;
        Buffer buffer = unsafeCursor.buffer;
        o.c(buffer);
        if (j2 != buffer.size()) {
            long j3 = unsafeCursor.offset;
            return unsafeCursor.seek(j3 == -1 ? 0 : j3 + ((long) (unsafeCursor.end - unsafeCursor.start)));
        }
        throw new IllegalStateException("no more bytes".toString());
    }

    public static final boolean commonRangeEquals(Buffer buffer, long j2, ByteString byteString, int i2, int i3) {
        o.e(buffer, "$this$commonRangeEquals");
        o.e(byteString, "bytes");
        if (j2 < 0 || i2 < 0 || i3 < 0 || buffer.size() - j2 < ((long) i3) || byteString.size() - i2 < i3) {
            return false;
        }
        for (int i4 = 0; i4 < i3; i4++) {
            if (buffer.getByte(((long) i4) + j2) != byteString.getByte(i2 + i4)) {
                return false;
            }
        }
        return true;
    }

    public static final int commonRead(Buffer buffer, byte[] bArr) {
        o.e(buffer, "$this$commonRead");
        o.e(bArr, "sink");
        return buffer.read(bArr, 0, bArr.length);
    }

    public static final long commonReadAll(Buffer buffer, Sink sink) {
        o.e(buffer, "$this$commonReadAll");
        o.e(sink, "sink");
        long size = buffer.size();
        if (size > 0) {
            sink.write(buffer, size);
        }
        return size;
    }

    public static final Buffer.UnsafeCursor commonReadAndWriteUnsafe(Buffer buffer, Buffer.UnsafeCursor unsafeCursor) {
        o.e(buffer, "$this$commonReadAndWriteUnsafe");
        o.e(unsafeCursor, "unsafeCursor");
        if (unsafeCursor.buffer == null) {
            unsafeCursor.buffer = buffer;
            unsafeCursor.readWrite = true;
            return unsafeCursor;
        }
        throw new IllegalStateException("already attached to a buffer".toString());
    }

    public static final byte commonReadByte(Buffer buffer) {
        o.e(buffer, "$this$commonReadByte");
        if (buffer.size() != 0) {
            Segment segment = buffer.head;
            o.c(segment);
            int i2 = segment.pos;
            int i3 = segment.limit;
            int i4 = i2 + 1;
            byte b2 = segment.data[i2];
            buffer.setSize$okio(buffer.size() - 1);
            if (i4 == i3) {
                buffer.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i4;
            }
            return b2;
        }
        throw new EOFException();
    }

    public static final byte[] commonReadByteArray(Buffer buffer) {
        o.e(buffer, "$this$commonReadByteArray");
        return buffer.readByteArray(buffer.size());
    }

    public static final ByteString commonReadByteString(Buffer buffer) {
        o.e(buffer, "$this$commonReadByteString");
        return buffer.readByteString(buffer.size());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:29:0x009c, code lost:
        if (r10 != r11) goto L_0x00a8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x009e, code lost:
        r17.head = r8.pop();
        okio.SegmentPool.recycle(r8);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x00a8, code lost:
        r8.pos = r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x00aa, code lost:
        if (r7 != false) goto L_0x00b0;
     */
    public static final long commonReadDecimalLong(Buffer buffer) {
        byte b2;
        o.e(buffer, "$this$commonReadDecimalLong");
        long j2 = 0;
        if (buffer.size() != 0) {
            long j3 = -7;
            int i2 = 0;
            boolean z = false;
            boolean z2 = false;
            loop0:
            do {
                Segment segment = buffer.head;
                o.c(segment);
                byte[] bArr = segment.data;
                int i3 = segment.pos;
                int i4 = segment.limit;
                while (true) {
                    if (i3 >= i4) {
                        break;
                    }
                    b2 = bArr[i3];
                    byte b3 = (byte) 48;
                    if (b2 >= b3 && b2 <= ((byte) 57)) {
                        int i5 = b3 - b2;
                        int i6 = (j2 > OVERFLOW_ZONE ? 1 : (j2 == OVERFLOW_ZONE ? 0 : -1));
                        if (i6 < 0 || (i6 == 0 && ((long) i5) < j3)) {
                            Buffer writeByte = new Buffer().writeDecimalLong(j2).writeByte((int) b2);
                        } else {
                            j2 = (j2 * 10) + ((long) i5);
                        }
                    } else if (b2 == ((byte) 45) && i2 == 0) {
                        j3--;
                        z = true;
                    } else if (i2 != 0) {
                        z2 = true;
                    } else {
                        StringBuilder B = a.B("Expected leading [0-9] or '-' character but was 0x");
                        B.append(_UtilKt.toHexString(b2));
                        throw new NumberFormatException(B.toString());
                    }
                    i3++;
                    i2++;
                }
                Buffer writeByte2 = new Buffer().writeDecimalLong(j2).writeByte((int) b2);
                if (!z) {
                    writeByte2.readByte();
                }
                StringBuilder B2 = a.B("Number too large: ");
                B2.append(writeByte2.readUtf8());
                throw new NumberFormatException(B2.toString());
            } while (buffer.head != null);
            buffer.setSize$okio(buffer.size() - ((long) i2));
            return z ? j2 : -j2;
        }
        throw new EOFException();
    }

    public static final void commonReadFully(Buffer buffer, byte[] bArr) {
        o.e(buffer, "$this$commonReadFully");
        o.e(bArr, "sink");
        int i2 = 0;
        while (i2 < bArr.length) {
            int read = buffer.read(bArr, i2, bArr.length - i2);
            if (read != -1) {
                i2 += read;
            } else {
                throw new EOFException();
            }
        }
    }

    public static final long commonReadHexadecimalUnsignedLong(Buffer buffer) {
        int i2;
        o.e(buffer, "$this$commonReadHexadecimalUnsignedLong");
        if (buffer.size() != 0) {
            int i3 = 0;
            boolean z = false;
            long j2 = 0;
            do {
                Segment segment = buffer.head;
                o.c(segment);
                byte[] bArr = segment.data;
                int i4 = segment.pos;
                int i5 = segment.limit;
                while (true) {
                    if (i4 >= i5) {
                        break;
                    }
                    byte b2 = bArr[i4];
                    byte b3 = (byte) 48;
                    if (b2 < b3 || b2 > ((byte) 57)) {
                        byte b4 = (byte) 97;
                        if ((b2 >= b4 && b2 <= ((byte) 102)) || (b2 >= (b4 = (byte) 65) && b2 <= ((byte) 70))) {
                            i2 = (b2 - b4) + 10;
                        } else if (i3 != 0) {
                            z = true;
                        } else {
                            StringBuilder B = a.B("Expected leading [0-9a-fA-F] character but was 0x");
                            B.append(_UtilKt.toHexString(b2));
                            throw new NumberFormatException(B.toString());
                        }
                    } else {
                        i2 = b2 - b3;
                    }
                    if ((-1152921504606846976L & j2) == 0) {
                        j2 = (j2 << 4) | ((long) i2);
                        i4++;
                        i3++;
                    } else {
                        Buffer writeByte = new Buffer().writeHexadecimalUnsignedLong(j2).writeByte((int) b2);
                        StringBuilder B2 = a.B("Number too large: ");
                        B2.append(writeByte.readUtf8());
                        throw new NumberFormatException(B2.toString());
                    }
                }
                if (i4 == i5) {
                    buffer.head = segment.pop();
                    SegmentPool.recycle(segment);
                } else {
                    segment.pos = i4;
                }
                if (z) {
                    break;
                }
            } while (buffer.head != null);
            buffer.setSize$okio(buffer.size() - ((long) i3));
            return j2;
        }
        throw new EOFException();
    }

    public static final int commonReadInt(Buffer buffer) {
        o.e(buffer, "$this$commonReadInt");
        if (buffer.size() >= 4) {
            Segment segment = buffer.head;
            o.c(segment);
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (((long) (i3 - i2)) < 4) {
                return (buffer.readByte() & 255) | ((buffer.readByte() & 255) << 24) | ((buffer.readByte() & 255) << 16) | ((buffer.readByte() & 255) << 8);
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            int i6 = ((bArr[i2] & 255) << 24) | ((bArr[i4] & 255) << 16);
            int i7 = i5 + 1;
            int i8 = i6 | ((bArr[i5] & 255) << 8);
            int i9 = i7 + 1;
            int i10 = i8 | (bArr[i7] & 255);
            buffer.setSize$okio(buffer.size() - 4);
            if (i9 == i3) {
                buffer.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i9;
            }
            return i10;
        }
        throw new EOFException();
    }

    public static final long commonReadLong(Buffer buffer) {
        o.e(buffer, "$this$commonReadLong");
        if (buffer.size() >= 8) {
            Segment segment = buffer.head;
            o.c(segment);
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (((long) (i3 - i2)) < 8) {
                return ((((long) buffer.readInt()) & 4294967295L) << 32) | (4294967295L & ((long) buffer.readInt()));
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            int i6 = i5 + 1;
            long j2 = ((((long) bArr[i2]) & 255) << 56) | ((((long) bArr[i4]) & 255) << 48) | ((((long) bArr[i5]) & 255) << 40);
            int i7 = i6 + 1;
            long j3 = ((((long) bArr[i6]) & 255) << 32) | j2;
            int i8 = i7 + 1;
            int i9 = i8 + 1;
            long j4 = j3 | ((((long) bArr[i7]) & 255) << 24) | ((((long) bArr[i8]) & 255) << 16);
            int i10 = i9 + 1;
            int i11 = i10 + 1;
            long j5 = j4 | ((((long) bArr[i9]) & 255) << 8) | (((long) bArr[i10]) & 255);
            buffer.setSize$okio(buffer.size() - 8);
            if (i11 == i3) {
                buffer.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i11;
            }
            return j5;
        }
        throw new EOFException();
    }

    public static final short commonReadShort(Buffer buffer) {
        o.e(buffer, "$this$commonReadShort");
        if (buffer.size() >= 2) {
            Segment segment = buffer.head;
            o.c(segment);
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (i3 - i2 < 2) {
                return (short) ((buffer.readByte() & 255) | ((buffer.readByte() & 255) << 8));
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            int i6 = ((bArr[i2] & 255) << 8) | (bArr[i4] & 255);
            buffer.setSize$okio(buffer.size() - 2);
            if (i5 == i3) {
                buffer.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i5;
            }
            return (short) i6;
        }
        throw new EOFException();
    }

    public static final Buffer.UnsafeCursor commonReadUnsafe(Buffer buffer, Buffer.UnsafeCursor unsafeCursor) {
        o.e(buffer, "$this$commonReadUnsafe");
        o.e(unsafeCursor, "unsafeCursor");
        if (unsafeCursor.buffer == null) {
            unsafeCursor.buffer = buffer;
            unsafeCursor.readWrite = false;
            return unsafeCursor;
        }
        throw new IllegalStateException("already attached to a buffer".toString());
    }

    public static final String commonReadUtf8(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonReadUtf8");
        int i2 = (j2 > 0 ? 1 : (j2 == 0 ? 0 : -1));
        if (!(i2 >= 0 && j2 <= ((long) SubsamplingScaleImageView.TILE_SIZE_AUTO))) {
            throw new IllegalArgumentException(a.o("byteCount: ", j2).toString());
        } else if (buffer.size() < j2) {
            throw new EOFException();
        } else if (i2 == 0) {
            return "";
        } else {
            Segment segment = buffer.head;
            o.c(segment);
            int i3 = segment.pos;
            if (((long) i3) + j2 > ((long) segment.limit)) {
                return _Utf8Kt.commonToUtf8String$default(buffer.readByteArray(j2), 0, 0, 3, null);
            }
            int i4 = (int) j2;
            String commonToUtf8String = _Utf8Kt.commonToUtf8String(segment.data, i3, i3 + i4);
            segment.pos += i4;
            buffer.setSize$okio(buffer.size() - j2);
            if (segment.pos == segment.limit) {
                buffer.head = segment.pop();
                SegmentPool.recycle(segment);
            }
            return commonToUtf8String;
        }
    }

    public static final int commonReadUtf8CodePoint(Buffer buffer) {
        int i2;
        int i3;
        int i4;
        o.e(buffer, "$this$commonReadUtf8CodePoint");
        if (buffer.size() != 0) {
            byte b2 = buffer.getByte(0);
            if ((b2 & 128) == 0) {
                i4 = b2 & Byte.MAX_VALUE;
                i3 = 1;
                i2 = 0;
            } else if ((b2 & 224) == 192) {
                i4 = b2 & 31;
                i3 = 2;
                i2 = 128;
            } else if ((b2 & 240) == 224) {
                i4 = b2 & 15;
                i3 = 3;
                i2 = 2048;
            } else if ((b2 & 248) == 240) {
                i4 = b2 & 7;
                i3 = 4;
                i2 = 65536;
            } else {
                buffer.skip(1);
                return Utf8.REPLACEMENT_CODE_POINT;
            }
            long j2 = (long) i3;
            if (buffer.size() >= j2) {
                for (int i5 = 1; i5 < i3; i5++) {
                    long j3 = (long) i5;
                    byte b3 = buffer.getByte(j3);
                    if ((b3 & 192) == 128) {
                        i4 = (i4 << 6) | (b3 & Utf8.REPLACEMENT_BYTE);
                    } else {
                        buffer.skip(j3);
                        return Utf8.REPLACEMENT_CODE_POINT;
                    }
                }
                buffer.skip(j2);
                if (i4 > 1114111) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                if ((55296 <= i4 && 57343 >= i4) || i4 < i2) {
                    return Utf8.REPLACEMENT_CODE_POINT;
                }
                return i4;
            }
            StringBuilder C = a.C("size < ", i3, ": ");
            C.append(buffer.size());
            C.append(" (to read code point prefixed 0x");
            C.append(_UtilKt.toHexString(b2));
            C.append(')');
            throw new EOFException(C.toString());
        }
        throw new EOFException();
    }

    public static final String commonReadUtf8Line(Buffer buffer) {
        o.e(buffer, "$this$commonReadUtf8Line");
        long indexOf = buffer.indexOf((byte) 10);
        if (indexOf != -1) {
            return readUtf8Line(buffer, indexOf);
        }
        if (buffer.size() != 0) {
            return buffer.readUtf8(buffer.size());
        }
        return null;
    }

    public static final String commonReadUtf8LineStrict(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonReadUtf8LineStrict");
        if (j2 >= 0) {
            long j3 = Long.MAX_VALUE;
            if (j2 != Long.MAX_VALUE) {
                j3 = j2 + 1;
            }
            byte b2 = (byte) 10;
            long indexOf = buffer.indexOf(b2, 0, j3);
            if (indexOf != -1) {
                return readUtf8Line(buffer, indexOf);
            }
            if (j3 < buffer.size() && buffer.getByte(j3 - 1) == ((byte) 13) && buffer.getByte(j3) == b2) {
                return readUtf8Line(buffer, j3);
            }
            Buffer buffer2 = new Buffer();
            buffer.copyTo(buffer2, 0, Math.min((long) 32, buffer.size()));
            StringBuilder B = a.B("\\n not found: limit=");
            B.append(Math.min(buffer.size(), j2));
            B.append(" content=");
            B.append(buffer2.readByteString().hex());
            B.append((char) 8230);
            throw new EOFException(B.toString());
        }
        throw new IllegalArgumentException(a.o("limit < 0: ", j2).toString());
    }

    public static final long commonResizeBuffer(Buffer.UnsafeCursor unsafeCursor, long j2) {
        o.e(unsafeCursor, "$this$commonResizeBuffer");
        Buffer buffer = unsafeCursor.buffer;
        if (buffer == null) {
            throw new IllegalStateException("not attached to a buffer".toString());
        } else if (unsafeCursor.readWrite) {
            long size = buffer.size();
            int i2 = 1;
            int i3 = (j2 > size ? 1 : (j2 == size ? 0 : -1));
            if (i3 <= 0) {
                if (j2 >= 0) {
                    long j3 = size - j2;
                    while (true) {
                        if (j3 <= 0) {
                            break;
                        }
                        Segment segment = buffer.head;
                        o.c(segment);
                        Segment segment2 = segment.prev;
                        o.c(segment2);
                        int i4 = segment2.limit;
                        long j4 = (long) (i4 - segment2.pos);
                        if (j4 > j3) {
                            segment2.limit = i4 - ((int) j3);
                            break;
                        }
                        buffer.head = segment2.pop();
                        SegmentPool.recycle(segment2);
                        j3 -= j4;
                    }
                    unsafeCursor.setSegment$okio(null);
                    unsafeCursor.offset = j2;
                    unsafeCursor.data = null;
                    unsafeCursor.start = -1;
                    unsafeCursor.end = -1;
                } else {
                    throw new IllegalArgumentException(a.o("newSize < 0: ", j2).toString());
                }
            } else if (i3 > 0) {
                long j5 = j2 - size;
                boolean z = true;
                while (j5 > 0) {
                    Segment writableSegment$okio = buffer.writableSegment$okio(i2);
                    int min = (int) Math.min(j5, (long) (8192 - writableSegment$okio.limit));
                    writableSegment$okio.limit += min;
                    j5 -= (long) min;
                    if (z) {
                        unsafeCursor.setSegment$okio(writableSegment$okio);
                        unsafeCursor.offset = size;
                        unsafeCursor.data = writableSegment$okio.data;
                        int i5 = writableSegment$okio.limit;
                        unsafeCursor.start = i5 - min;
                        unsafeCursor.end = i5;
                        z = false;
                    }
                    i2 = 1;
                }
            }
            buffer.setSize$okio(j2);
            return size;
        } else {
            throw new IllegalStateException("resizeBuffer() only permitted for read/write buffers".toString());
        }
    }

    public static final int commonSeek(Buffer.UnsafeCursor unsafeCursor, long j2) {
        Segment segment;
        o.e(unsafeCursor, "$this$commonSeek");
        Buffer buffer = unsafeCursor.buffer;
        if (buffer == null) {
            throw new IllegalStateException("not attached to a buffer".toString());
        } else if (j2 < ((long) -1) || j2 > buffer.size()) {
            StringBuilder E = a.E("offset=", j2, " > size=");
            E.append(buffer.size());
            throw new ArrayIndexOutOfBoundsException(E.toString());
        } else if (j2 == -1 || j2 == buffer.size()) {
            unsafeCursor.setSegment$okio(null);
            unsafeCursor.offset = j2;
            unsafeCursor.data = null;
            unsafeCursor.start = -1;
            unsafeCursor.end = -1;
            return -1;
        } else {
            long j3 = 0;
            long size = buffer.size();
            Segment segment2 = buffer.head;
            if (unsafeCursor.getSegment$okio() != null) {
                long j4 = unsafeCursor.offset;
                int i2 = unsafeCursor.start;
                Segment segment$okio = unsafeCursor.getSegment$okio();
                o.c(segment$okio);
                long j5 = j4 - ((long) (i2 - segment$okio.pos));
                if (j5 > j2) {
                    segment = unsafeCursor.getSegment$okio();
                    size = j5;
                } else {
                    segment2 = unsafeCursor.getSegment$okio();
                    j3 = j5;
                    segment = segment2;
                }
            } else {
                segment = segment2;
            }
            if (size - j2 > j2 - j3) {
                while (true) {
                    o.c(segment2);
                    int i3 = segment2.limit;
                    int i4 = segment2.pos;
                    if (j2 < ((long) (i3 - i4)) + j3) {
                        break;
                    }
                    j3 += (long) (i3 - i4);
                    segment2 = segment2.next;
                }
            } else {
                while (size > j2) {
                    o.c(segment);
                    segment = segment.prev;
                    o.c(segment);
                    size -= (long) (segment.limit - segment.pos);
                }
                j3 = size;
                segment2 = segment;
            }
            if (unsafeCursor.readWrite) {
                o.c(segment2);
                if (segment2.shared) {
                    Segment unsharedCopy = segment2.unsharedCopy();
                    if (buffer.head == segment2) {
                        buffer.head = unsharedCopy;
                    }
                    segment2 = segment2.push(unsharedCopy);
                    Segment segment3 = segment2.prev;
                    o.c(segment3);
                    segment3.pop();
                }
            }
            unsafeCursor.setSegment$okio(segment2);
            unsafeCursor.offset = j2;
            o.c(segment2);
            unsafeCursor.data = segment2.data;
            int i5 = segment2.pos + ((int) (j2 - j3));
            unsafeCursor.start = i5;
            int i6 = segment2.limit;
            unsafeCursor.end = i6;
            return i6 - i5;
        }
    }

    public static final int commonSelect(Buffer buffer, Options options) {
        o.e(buffer, "$this$commonSelect");
        o.e(options, "options");
        int selectPrefix$default = selectPrefix$default(buffer, options, false, 2, null);
        if (selectPrefix$default == -1) {
            return -1;
        }
        buffer.skip((long) options.getByteStrings$okio()[selectPrefix$default].size());
        return selectPrefix$default;
    }

    public static final void commonSkip(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonSkip");
        while (j2 > 0) {
            Segment segment = buffer.head;
            if (segment != null) {
                int min = (int) Math.min(j2, (long) (segment.limit - segment.pos));
                long j3 = (long) min;
                buffer.setSize$okio(buffer.size() - j3);
                j2 -= j3;
                int i2 = segment.pos + min;
                segment.pos = i2;
                if (i2 == segment.limit) {
                    buffer.head = segment.pop();
                    SegmentPool.recycle(segment);
                }
            } else {
                throw new EOFException();
            }
        }
    }

    public static final ByteString commonSnapshot(Buffer buffer) {
        o.e(buffer, "$this$commonSnapshot");
        if (buffer.size() <= ((long) SubsamplingScaleImageView.TILE_SIZE_AUTO)) {
            return buffer.snapshot((int) buffer.size());
        }
        StringBuilder B = a.B("size > Int.MAX_VALUE: ");
        B.append(buffer.size());
        throw new IllegalStateException(B.toString().toString());
    }

    public static final Segment commonWritableSegment(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonWritableSegment");
        boolean z = true;
        if (i2 < 1 || i2 > 8192) {
            z = false;
        }
        if (z) {
            Segment segment = buffer.head;
            if (segment == null) {
                Segment take = SegmentPool.take();
                buffer.head = take;
                take.prev = take;
                take.next = take;
                return take;
            }
            o.c(segment);
            Segment segment2 = segment.prev;
            o.c(segment2);
            return (segment2.limit + i2 > 8192 || !segment2.owner) ? segment2.push(SegmentPool.take()) : segment2;
        }
        throw new IllegalArgumentException("unexpected capacity".toString());
    }

    public static final Buffer commonWrite(Buffer buffer, ByteString byteString, int i2, int i3) {
        o.e(buffer, "$this$commonWrite");
        o.e(byteString, "byteString");
        byteString.write$okio(buffer, i2, i3);
        return buffer;
    }

    public static /* synthetic */ Buffer commonWrite$default(Buffer buffer, ByteString byteString, int i2, int i3, int i4, Object obj) {
        if ((i4 & 2) != 0) {
            i2 = 0;
        }
        if ((i4 & 4) != 0) {
            i3 = byteString.size();
        }
        o.e(buffer, "$this$commonWrite");
        o.e(byteString, "byteString");
        byteString.write$okio(buffer, i2, i3);
        return buffer;
    }

    public static final long commonWriteAll(Buffer buffer, Source source) {
        o.e(buffer, "$this$commonWriteAll");
        o.e(source, "source");
        long j2 = 0;
        while (true) {
            long read = source.read(buffer, (long) 8192);
            if (read == -1) {
                return j2;
            }
            j2 += read;
        }
    }

    public static final Buffer commonWriteByte(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonWriteByte");
        Segment writableSegment$okio = buffer.writableSegment$okio(1);
        byte[] bArr = writableSegment$okio.data;
        int i3 = writableSegment$okio.limit;
        writableSegment$okio.limit = i3 + 1;
        bArr[i3] = (byte) i2;
        buffer.setSize$okio(buffer.size() + 1);
        return buffer;
    }

    public static final Buffer commonWriteDecimalLong(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonWriteDecimalLong");
        int i2 = (j2 > 0 ? 1 : (j2 == 0 ? 0 : -1));
        if (i2 == 0) {
            return buffer.writeByte(48);
        }
        boolean z = false;
        int i3 = 1;
        if (i2 < 0) {
            j2 = -j2;
            if (j2 < 0) {
                return buffer.writeUtf8("-9223372036854775808");
            }
            z = true;
        }
        if (j2 >= 100000000) {
            i3 = j2 < 1000000000000L ? j2 < 10000000000L ? j2 < 1000000000 ? 9 : 10 : j2 < 100000000000L ? 11 : 12 : j2 < 1000000000000000L ? j2 < 10000000000000L ? 13 : j2 < 100000000000000L ? 14 : 15 : j2 < 100000000000000000L ? j2 < 10000000000000000L ? 16 : 17 : j2 < 1000000000000000000L ? 18 : 19;
        } else if (j2 >= 10000) {
            i3 = j2 < 1000000 ? j2 < 100000 ? 5 : 6 : j2 < 10000000 ? 7 : 8;
        } else if (j2 >= 100) {
            i3 = j2 < 1000 ? 3 : 4;
        } else if (j2 >= 10) {
            i3 = 2;
        }
        if (z) {
            i3++;
        }
        Segment writableSegment$okio = buffer.writableSegment$okio(i3);
        byte[] bArr = writableSegment$okio.data;
        int i4 = writableSegment$okio.limit + i3;
        while (j2 != 0) {
            long j3 = (long) 10;
            i4--;
            bArr[i4] = getHEX_DIGIT_BYTES()[(int) (j2 % j3)];
            j2 /= j3;
        }
        if (z) {
            bArr[i4 - 1] = (byte) 45;
        }
        writableSegment$okio.limit += i3;
        buffer.setSize$okio(buffer.size() + ((long) i3));
        return buffer;
    }

    public static final Buffer commonWriteHexadecimalUnsignedLong(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonWriteHexadecimalUnsignedLong");
        if (j2 == 0) {
            return buffer.writeByte(48);
        }
        long j3 = (j2 >>> 1) | j2;
        long j4 = j3 | (j3 >>> 2);
        long j5 = j4 | (j4 >>> 4);
        long j6 = j5 | (j5 >>> 8);
        long j7 = j6 | (j6 >>> 16);
        long j8 = j7 | (j7 >>> 32);
        long j9 = j8 - ((j8 >>> 1) & 6148914691236517205L);
        long j10 = ((j9 >>> 2) & 3689348814741910323L) + (j9 & 3689348814741910323L);
        long j11 = ((j10 >>> 4) + j10) & 1085102592571150095L;
        long j12 = j11 + (j11 >>> 8);
        long j13 = j12 + (j12 >>> 16);
        int i2 = (int) ((((j13 & 63) + ((j13 >>> 32) & 63)) + ((long) 3)) / ((long) 4));
        Segment writableSegment$okio = buffer.writableSegment$okio(i2);
        byte[] bArr = writableSegment$okio.data;
        int i3 = writableSegment$okio.limit;
        for (int i4 = (i3 + i2) - 1; i4 >= i3; i4--) {
            bArr[i4] = getHEX_DIGIT_BYTES()[(int) (15 & j2)];
            j2 >>>= 4;
        }
        writableSegment$okio.limit += i2;
        buffer.setSize$okio(buffer.size() + ((long) i2));
        return buffer;
    }

    public static final Buffer commonWriteInt(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonWriteInt");
        Segment writableSegment$okio = buffer.writableSegment$okio(4);
        byte[] bArr = writableSegment$okio.data;
        int i3 = writableSegment$okio.limit;
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((i2 >>> 24) & NeuQuant.maxnetpos);
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((i2 >>> 16) & NeuQuant.maxnetpos);
        int i6 = i5 + 1;
        bArr[i5] = (byte) ((i2 >>> 8) & NeuQuant.maxnetpos);
        bArr[i6] = (byte) (i2 & NeuQuant.maxnetpos);
        writableSegment$okio.limit = i6 + 1;
        buffer.setSize$okio(buffer.size() + 4);
        return buffer;
    }

    public static final Buffer commonWriteLong(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonWriteLong");
        Segment writableSegment$okio = buffer.writableSegment$okio(8);
        byte[] bArr = writableSegment$okio.data;
        int i2 = writableSegment$okio.limit;
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((int) ((j2 >>> 56) & 255));
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((int) ((j2 >>> 48) & 255));
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((int) ((j2 >>> 40) & 255));
        int i6 = i5 + 1;
        bArr[i5] = (byte) ((int) ((j2 >>> 32) & 255));
        int i7 = i6 + 1;
        bArr[i6] = (byte) ((int) ((j2 >>> 24) & 255));
        int i8 = i7 + 1;
        bArr[i7] = (byte) ((int) ((j2 >>> 16) & 255));
        int i9 = i8 + 1;
        bArr[i8] = (byte) ((int) ((j2 >>> 8) & 255));
        bArr[i9] = (byte) ((int) (j2 & 255));
        writableSegment$okio.limit = i9 + 1;
        buffer.setSize$okio(buffer.size() + 8);
        return buffer;
    }

    public static final Buffer commonWriteShort(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonWriteShort");
        Segment writableSegment$okio = buffer.writableSegment$okio(2);
        byte[] bArr = writableSegment$okio.data;
        int i3 = writableSegment$okio.limit;
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((i2 >>> 8) & NeuQuant.maxnetpos);
        bArr[i4] = (byte) (i2 & NeuQuant.maxnetpos);
        writableSegment$okio.limit = i4 + 1;
        buffer.setSize$okio(buffer.size() + 2);
        return buffer;
    }

    public static final Buffer commonWriteUtf8(Buffer buffer, String str, int i2, int i3) {
        char charAt;
        o.e(buffer, "$this$commonWriteUtf8");
        o.e(str, TypedValues.Custom.S_STRING);
        if (i2 >= 0) {
            if (i3 >= i2) {
                if (i3 <= str.length()) {
                    while (i2 < i3) {
                        char charAt2 = str.charAt(i2);
                        if (charAt2 < 128) {
                            Segment writableSegment$okio = buffer.writableSegment$okio(1);
                            byte[] bArr = writableSegment$okio.data;
                            int i4 = writableSegment$okio.limit - i2;
                            int min = Math.min(i3, 8192 - i4);
                            int i5 = i2 + 1;
                            bArr[i2 + i4] = (byte) charAt2;
                            while (true) {
                                i2 = i5;
                                if (i2 >= min || (charAt = str.charAt(i2)) >= 128) {
                                    int i6 = writableSegment$okio.limit;
                                    int i7 = (i4 + i2) - i6;
                                    writableSegment$okio.limit = i6 + i7;
                                    buffer.setSize$okio(buffer.size() + ((long) i7));
                                } else {
                                    i5 = i2 + 1;
                                    bArr[i2 + i4] = (byte) charAt;
                                }
                            }
                            int i62 = writableSegment$okio.limit;
                            int i72 = (i4 + i2) - i62;
                            writableSegment$okio.limit = i62 + i72;
                            buffer.setSize$okio(buffer.size() + ((long) i72));
                        } else {
                            if (charAt2 < 2048) {
                                Segment writableSegment$okio2 = buffer.writableSegment$okio(2);
                                byte[] bArr2 = writableSegment$okio2.data;
                                int i8 = writableSegment$okio2.limit;
                                bArr2[i8] = (byte) ((charAt2 >> 6) | 192);
                                bArr2[i8 + 1] = (byte) ((charAt2 & '?') | 128);
                                writableSegment$okio2.limit = i8 + 2;
                                buffer.setSize$okio(buffer.size() + 2);
                            } else if (charAt2 < 55296 || charAt2 > 57343) {
                                Segment writableSegment$okio3 = buffer.writableSegment$okio(3);
                                byte[] bArr3 = writableSegment$okio3.data;
                                int i9 = writableSegment$okio3.limit;
                                bArr3[i9] = (byte) ((charAt2 >> '\f') | 224);
                                bArr3[i9 + 1] = (byte) ((63 & (charAt2 >> 6)) | 128);
                                bArr3[i9 + 2] = (byte) ((charAt2 & '?') | 128);
                                writableSegment$okio3.limit = i9 + 3;
                                buffer.setSize$okio(buffer.size() + 3);
                            } else {
                                int i10 = i2 + 1;
                                char charAt3 = i10 < i3 ? str.charAt(i10) : 0;
                                if (charAt2 > 56319 || 56320 > charAt3 || 57343 < charAt3) {
                                    buffer.writeByte(63);
                                    i2 = i10;
                                } else {
                                    int i11 = (((charAt2 & 1023) << 10) | (charAt3 & 1023)) + 65536;
                                    Segment writableSegment$okio4 = buffer.writableSegment$okio(4);
                                    byte[] bArr4 = writableSegment$okio4.data;
                                    int i12 = writableSegment$okio4.limit;
                                    bArr4[i12] = (byte) ((i11 >> 18) | 240);
                                    bArr4[i12 + 1] = (byte) (((i11 >> 12) & 63) | 128);
                                    bArr4[i12 + 2] = (byte) (((i11 >> 6) & 63) | 128);
                                    bArr4[i12 + 3] = (byte) ((i11 & 63) | 128);
                                    writableSegment$okio4.limit = i12 + 4;
                                    buffer.setSize$okio(buffer.size() + 4);
                                    i2 += 2;
                                }
                            }
                            i2++;
                        }
                    }
                    return buffer;
                }
                StringBuilder C = a.C("endIndex > string.length: ", i3, " > ");
                C.append(str.length());
                throw new IllegalArgumentException(C.toString().toString());
            }
            throw new IllegalArgumentException(("endIndex < beginIndex: " + i3 + " < " + i2).toString());
        }
        throw new IllegalArgumentException(a.k("beginIndex < 0: ", i2).toString());
    }

    public static final Buffer commonWriteUtf8CodePoint(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonWriteUtf8CodePoint");
        if (i2 < 128) {
            buffer.writeByte(i2);
        } else if (i2 < 2048) {
            Segment writableSegment$okio = buffer.writableSegment$okio(2);
            byte[] bArr = writableSegment$okio.data;
            int i3 = writableSegment$okio.limit;
            bArr[i3] = (byte) ((i2 >> 6) | 192);
            bArr[i3 + 1] = (byte) ((i2 & 63) | 128);
            writableSegment$okio.limit = i3 + 2;
            buffer.setSize$okio(buffer.size() + 2);
        } else if (55296 <= i2 && 57343 >= i2) {
            buffer.writeByte(63);
        } else if (i2 < 65536) {
            Segment writableSegment$okio2 = buffer.writableSegment$okio(3);
            byte[] bArr2 = writableSegment$okio2.data;
            int i4 = writableSegment$okio2.limit;
            bArr2[i4] = (byte) ((i2 >> 12) | 224);
            bArr2[i4 + 1] = (byte) (((i2 >> 6) & 63) | 128);
            bArr2[i4 + 2] = (byte) ((i2 & 63) | 128);
            writableSegment$okio2.limit = i4 + 3;
            buffer.setSize$okio(buffer.size() + 3);
        } else if (i2 <= 1114111) {
            Segment writableSegment$okio3 = buffer.writableSegment$okio(4);
            byte[] bArr3 = writableSegment$okio3.data;
            int i5 = writableSegment$okio3.limit;
            bArr3[i5] = (byte) ((i2 >> 18) | 240);
            bArr3[i5 + 1] = (byte) (((i2 >> 12) & 63) | 128);
            bArr3[i5 + 2] = (byte) (((i2 >> 6) & 63) | 128);
            bArr3[i5 + 3] = (byte) ((i2 & 63) | 128);
            writableSegment$okio3.limit = i5 + 4;
            buffer.setSize$okio(buffer.size() + 4);
        } else {
            StringBuilder B = a.B("Unexpected code point: 0x");
            B.append(_UtilKt.toHexString(i2));
            throw new IllegalArgumentException(B.toString());
        }
        return buffer;
    }

    public static final byte[] getHEX_DIGIT_BYTES() {
        return HEX_DIGIT_BYTES;
    }

    public static final boolean rangeEquals(Segment segment, int i2, byte[] bArr, int i3, int i4) {
        o.e(segment, "segment");
        o.e(bArr, "bytes");
        int i5 = segment.limit;
        byte[] bArr2 = segment.data;
        while (i3 < i4) {
            if (i2 == i5) {
                segment = segment.next;
                o.c(segment);
                byte[] bArr3 = segment.data;
                bArr2 = bArr3;
                i2 = segment.pos;
                i5 = segment.limit;
            }
            if (bArr2[i2] != bArr[i3]) {
                return false;
            }
            i2++;
            i3++;
        }
        return true;
    }

    public static final String readUtf8Line(Buffer buffer, long j2) {
        o.e(buffer, "$this$readUtf8Line");
        if (j2 > 0) {
            long j3 = j2 - 1;
            if (buffer.getByte(j3) == ((byte) 13)) {
                String readUtf8 = buffer.readUtf8(j3);
                buffer.skip(2);
                return readUtf8;
            }
        }
        String readUtf82 = buffer.readUtf8(j2);
        buffer.skip(1);
        return readUtf82;
    }

    public static final <T> T seek(Buffer buffer, long j2, p<? super Segment, ? super Long, ? extends T> pVar) {
        o.e(buffer, "$this$seek");
        o.e(pVar, "lambda");
        Segment segment = buffer.head;
        if (segment == null) {
            return (T) pVar.invoke(null, -1L);
        }
        if (buffer.size() - j2 < j2) {
            long size = buffer.size();
            while (size > j2) {
                segment = segment.prev;
                o.c(segment);
                size -= (long) (segment.limit - segment.pos);
            }
            return (T) pVar.invoke(segment, Long.valueOf(size));
        }
        long j3 = 0;
        while (true) {
            long j4 = ((long) (segment.limit - segment.pos)) + j3;
            if (j4 > j2) {
                return (T) pVar.invoke(segment, Long.valueOf(j3));
            }
            segment = segment.next;
            o.c(segment);
            j3 = j4;
        }
    }

    public static final int selectPrefix(Buffer buffer, Options options, boolean z) {
        int i2;
        int i3;
        int i4;
        Segment segment;
        int i5;
        o.e(buffer, "$this$selectPrefix");
        o.e(options, "options");
        Segment segment2 = buffer.head;
        if (segment2 != null) {
            byte[] bArr = segment2.data;
            int i6 = segment2.pos;
            int i7 = segment2.limit;
            int[] trie$okio = options.getTrie$okio();
            Segment segment3 = segment2;
            int i8 = 0;
            int i9 = -1;
            loop0:
            while (true) {
                int i10 = i8 + 1;
                int i11 = trie$okio[i8];
                int i12 = i10 + 1;
                int i13 = trie$okio[i10];
                if (i13 != -1) {
                    i9 = i13;
                }
                if (segment3 == null) {
                    break;
                }
                if (i11 < 0) {
                    int i14 = (i11 * -1) + i12;
                    while (true) {
                        int i15 = i6 + 1;
                        int i16 = i12 + 1;
                        if ((bArr[i6] & 255) != trie$okio[i12]) {
                            return i9;
                        }
                        boolean z2 = i16 == i14;
                        if (i15 == i7) {
                            o.c(segment3);
                            Segment segment4 = segment3.next;
                            o.c(segment4);
                            i5 = segment4.pos;
                            byte[] bArr2 = segment4.data;
                            i4 = segment4.limit;
                            if (segment4 != segment2) {
                                segment = segment4;
                                bArr = bArr2;
                            } else if (!z2) {
                                break loop0;
                            } else {
                                bArr = bArr2;
                                segment = null;
                            }
                        } else {
                            i4 = i7;
                            i5 = i15;
                            segment = segment3;
                        }
                        if (z2) {
                            i3 = trie$okio[i16];
                            i2 = i5;
                            i7 = i4;
                            segment3 = segment;
                            break;
                        }
                        i6 = i5;
                        i7 = i4;
                        i12 = i16;
                        segment3 = segment;
                    }
                } else {
                    i2 = i6 + 1;
                    int i17 = bArr[i6] & 255;
                    int i18 = i12 + i11;
                    while (i12 != i18) {
                        if (i17 == trie$okio[i12]) {
                            i3 = trie$okio[i12 + i11];
                            if (i2 == i7) {
                                segment3 = segment3.next;
                                o.c(segment3);
                                i2 = segment3.pos;
                                bArr = segment3.data;
                                i7 = segment3.limit;
                                if (segment3 == segment2) {
                                    segment3 = null;
                                }
                            }
                        } else {
                            i12++;
                        }
                    }
                    return i9;
                }
                if (i3 >= 0) {
                    return i3;
                }
                i8 = -i3;
                i6 = i2;
            }
            if (z) {
                return -2;
            }
            return i9;
        } else if (z) {
            return -2;
        } else {
            return -1;
        }
    }

    public static /* synthetic */ int selectPrefix$default(Buffer buffer, Options options, boolean z, int i2, Object obj) {
        if ((i2 & 2) != 0) {
            z = false;
        }
        return selectPrefix(buffer, options, z);
    }

    public static final int commonRead(Buffer buffer, byte[] bArr, int i2, int i3) {
        o.e(buffer, "$this$commonRead");
        o.e(bArr, "sink");
        _UtilKt.checkOffsetAndCount((long) bArr.length, (long) i2, (long) i3);
        Segment segment = buffer.head;
        if (segment == null) {
            return -1;
        }
        int min = Math.min(i3, segment.limit - segment.pos);
        byte[] bArr2 = segment.data;
        int i4 = segment.pos;
        h.a(bArr2, bArr, i2, i4, i4 + min);
        segment.pos += min;
        buffer.setSize$okio(buffer.size() - ((long) min));
        if (segment.pos == segment.limit) {
            buffer.head = segment.pop();
            SegmentPool.recycle(segment);
        }
        return min;
    }

    public static final byte[] commonReadByteArray(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonReadByteArray");
        if (!(j2 >= 0 && j2 <= ((long) SubsamplingScaleImageView.TILE_SIZE_AUTO))) {
            throw new IllegalArgumentException(a.o("byteCount: ", j2).toString());
        } else if (buffer.size() >= j2) {
            byte[] bArr = new byte[((int) j2)];
            buffer.readFully(bArr);
            return bArr;
        } else {
            throw new EOFException();
        }
    }

    public static final ByteString commonReadByteString(Buffer buffer, long j2) {
        o.e(buffer, "$this$commonReadByteString");
        if (!(j2 >= 0 && j2 <= ((long) SubsamplingScaleImageView.TILE_SIZE_AUTO))) {
            throw new IllegalArgumentException(a.o("byteCount: ", j2).toString());
        } else if (buffer.size() < j2) {
            throw new EOFException();
        } else if (j2 < ((long) 4096)) {
            return new ByteString(buffer.readByteArray(j2));
        } else {
            ByteString snapshot = buffer.snapshot((int) j2);
            buffer.skip(j2);
            return snapshot;
        }
    }

    public static final Buffer commonWrite(Buffer buffer, byte[] bArr) {
        o.e(buffer, "$this$commonWrite");
        o.e(bArr, "source");
        return buffer.write(bArr, 0, bArr.length);
    }

    public static final Buffer commonWrite(Buffer buffer, byte[] bArr, int i2, int i3) {
        o.e(buffer, "$this$commonWrite");
        o.e(bArr, "source");
        long j2 = (long) i3;
        _UtilKt.checkOffsetAndCount((long) bArr.length, (long) i2, j2);
        int i4 = i3 + i2;
        while (i2 < i4) {
            Segment writableSegment$okio = buffer.writableSegment$okio(1);
            int min = Math.min(i4 - i2, 8192 - writableSegment$okio.limit);
            int i5 = i2 + min;
            h.a(bArr, writableSegment$okio.data, writableSegment$okio.limit, i2, i5);
            writableSegment$okio.limit += min;
            i2 = i5;
        }
        buffer.setSize$okio(buffer.size() + j2);
        return buffer;
    }

    public static final void commonReadFully(Buffer buffer, Buffer buffer2, long j2) {
        o.e(buffer, "$this$commonReadFully");
        o.e(buffer2, "sink");
        if (buffer.size() >= j2) {
            buffer2.write(buffer, j2);
        } else {
            buffer2.write(buffer, buffer.size());
            throw new EOFException();
        }
    }

    public static final ByteString commonSnapshot(Buffer buffer, int i2) {
        o.e(buffer, "$this$commonSnapshot");
        if (i2 == 0) {
            return ByteString.EMPTY;
        }
        _UtilKt.checkOffsetAndCount(buffer.size(), 0, (long) i2);
        Segment segment = buffer.head;
        int i3 = 0;
        int i4 = 0;
        int i5 = 0;
        while (i4 < i2) {
            o.c(segment);
            int i6 = segment.limit;
            int i7 = segment.pos;
            if (i6 != i7) {
                i4 += i6 - i7;
                i5++;
                segment = segment.next;
            } else {
                throw new AssertionError("s.limit == s.pos");
            }
        }
        byte[][] bArr = new byte[i5][];
        int[] iArr = new int[(i5 * 2)];
        Segment segment2 = buffer.head;
        int i8 = 0;
        while (i3 < i2) {
            o.c(segment2);
            bArr[i8] = segment2.data;
            i3 += segment2.limit - segment2.pos;
            iArr[i8] = Math.min(i3, i2);
            iArr[i8 + i5] = segment2.pos;
            segment2.shared = true;
            i8++;
            segment2 = segment2.next;
        }
        return new SegmentedByteString(bArr, iArr);
    }

    public static final Buffer commonWrite(Buffer buffer, Source source, long j2) {
        o.e(buffer, "$this$commonWrite");
        o.e(source, "source");
        while (j2 > 0) {
            long read = source.read(buffer, j2);
            if (read != -1) {
                j2 -= read;
            } else {
                throw new EOFException();
            }
        }
        return buffer;
    }

    public static final long commonRead(Buffer buffer, Buffer buffer2, long j2) {
        o.e(buffer, "$this$commonRead");
        o.e(buffer2, "sink");
        if (!(j2 >= 0)) {
            throw new IllegalArgumentException(a.o("byteCount < 0: ", j2).toString());
        } else if (buffer.size() == 0) {
            return -1;
        } else {
            if (j2 > buffer.size()) {
                j2 = buffer.size();
            }
            buffer2.write(buffer, j2);
            return j2;
        }
    }

    public static final void commonWrite(Buffer buffer, Buffer buffer2, long j2) {
        Segment segment;
        o.e(buffer, "$this$commonWrite");
        o.e(buffer2, "source");
        if (buffer2 != buffer) {
            _UtilKt.checkOffsetAndCount(buffer2.size(), 0, j2);
            while (j2 > 0) {
                Segment segment2 = buffer2.head;
                o.c(segment2);
                int i2 = segment2.limit;
                Segment segment3 = buffer2.head;
                o.c(segment3);
                if (j2 < ((long) (i2 - segment3.pos))) {
                    Segment segment4 = buffer.head;
                    if (segment4 != null) {
                        o.c(segment4);
                        segment = segment4.prev;
                    } else {
                        segment = null;
                    }
                    if (segment != null && segment.owner) {
                        if ((((long) segment.limit) + j2) - ((long) (segment.shared ? 0 : segment.pos)) <= ((long) 8192)) {
                            Segment segment5 = buffer2.head;
                            o.c(segment5);
                            segment5.writeTo(segment, (int) j2);
                            buffer2.setSize$okio(buffer2.size() - j2);
                            buffer.setSize$okio(buffer.size() + j2);
                            return;
                        }
                    }
                    Segment segment6 = buffer2.head;
                    o.c(segment6);
                    buffer2.head = segment6.split((int) j2);
                }
                Segment segment7 = buffer2.head;
                o.c(segment7);
                long j3 = (long) (segment7.limit - segment7.pos);
                buffer2.head = segment7.pop();
                Segment segment8 = buffer.head;
                if (segment8 == null) {
                    buffer.head = segment7;
                    segment7.prev = segment7;
                    segment7.next = segment7;
                } else {
                    o.c(segment8);
                    Segment segment9 = segment8.prev;
                    o.c(segment9);
                    segment9.push(segment7).compact();
                }
                buffer2.setSize$okio(buffer2.size() - j3);
                buffer.setSize$okio(buffer.size() + j3);
                j2 -= j3;
            }
            return;
        }
        throw new IllegalArgumentException("source == this".toString());
    }

    public static final long commonIndexOf(Buffer buffer, ByteString byteString, long j2) {
        int i2;
        long j3 = j2;
        o.e(buffer, "$this$commonIndexOf");
        o.e(byteString, "bytes");
        if (byteString.size() > 0) {
            long j4 = 0;
            if (j3 >= 0) {
                Segment segment = buffer.head;
                if (segment == null) {
                    return -1;
                }
                if (buffer.size() - j3 < j3) {
                    long size = buffer.size();
                    while (size > j3) {
                        segment = segment.prev;
                        o.c(segment);
                        size -= (long) (segment.limit - segment.pos);
                    }
                    byte[] internalArray$okio = byteString.internalArray$okio();
                    byte b2 = internalArray$okio[0];
                    int size2 = byteString.size();
                    long size3 = (buffer.size() - ((long) size2)) + 1;
                    j4 = size;
                    while (j4 < size3) {
                        byte[] bArr = segment.data;
                        int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + size3) - j4);
                        i2 = (int) ((((long) segment.pos) + j3) - j4);
                        while (i2 < min) {
                            if (bArr[i2] == b2) {
                                if (rangeEquals(segment, i2 + 1, internalArray$okio, 1, size2)) {
                                }
                            }
                            i2++;
                        }
                        j4 += (long) (segment.limit - segment.pos);
                        segment = segment.next;
                        o.c(segment);
                        size3 = size3;
                        j3 = j4;
                    }
                    return -1;
                }
                while (true) {
                    long j5 = ((long) (segment.limit - segment.pos)) + j4;
                    if (j5 > j3) {
                        break;
                    }
                    segment = segment.next;
                    o.c(segment);
                    j4 = j5;
                }
                byte[] internalArray$okio2 = byteString.internalArray$okio();
                byte b3 = internalArray$okio2[0];
                int size4 = byteString.size();
                long size5 = (buffer.size() - ((long) size4)) + 1;
                while (j4 < size5) {
                    byte[] bArr2 = segment.data;
                    int min2 = (int) Math.min((long) segment.limit, (((long) segment.pos) + size5) - j4);
                    i2 = (int) ((((long) segment.pos) + j3) - j4);
                    while (i2 < min2) {
                        if (bArr2[i2] != b3 || !rangeEquals(segment, i2 + 1, internalArray$okio2, 1, size4)) {
                            i2++;
                        }
                    }
                    j4 += (long) (segment.limit - segment.pos);
                    segment = segment.next;
                    o.c(segment);
                    j3 = j4;
                }
                return -1;
                return ((long) (i2 - segment.pos)) + j4;
            }
            throw new IllegalArgumentException(a.o("fromIndex < 0: ", j3).toString());
        }
        throw new IllegalArgumentException("bytes is empty".toString());
    }
}
