package org.dsq.library.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.SparseArray;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.TextView;
import org.dsq.library.R;

public class LoadStatusLayout extends FrameLayout {
    public static final int SHOW_EMPTY = 4;
    public static final int SHOW_ERROR = 1;
    public static final int SHOW_LOADING = 2;
    public static final int SHOW_NORMAL = 0;
    public static final int SHOW_NO_NET = 3;
    public int contentViewId;
    public int currentStatus;
    public TextView currentText;
    public View currentView;
    private int emptyViewId;
    private int errorViewId;
    private LayoutInflater inflater;
    private int loadingViewId;
    private Context mContext;
    private int noNetworkViewId;
    private View.OnClickListener onRetryListener;
    private FrameLayout.LayoutParams params;
    private SparseArray<View> views;

    public LoadStatusLayout(Context context) {
        this(context, null);
    }

    private int getLayoutId(String str) {
        return getResources().getIdentifier(str, "layout", this.mContext.getPackageName());
    }

    public View ViewFactory(int i2) {
        View view = this.views.get(i2);
        if (view != null) {
            return view;
        }
        View inflate = this.inflater.inflate(i2, (ViewGroup) null);
        this.views.put(i2, inflate);
        return inflate;
    }

    public void hideLoading() {
        this.currentStatus = 0;
        if (this.currentView != null && getChildCount() > 0) {
            removeAllViews();
        }
    }

    public void setOnRetryListener(View.OnClickListener onClickListener) {
        this.onRetryListener = onClickListener;
    }

    public void setText(String str) {
        if (this.currentText != null && !TextUtils.isEmpty(str)) {
            this.currentText.setText(str);
        }
    }

    public void showEmpty() {
        this.currentStatus = 4;
        showView(this.emptyViewId);
    }

    public void showError() {
        this.currentStatus = 1;
        showView(this.errorViewId);
    }

    public void showLoading() {
        this.currentStatus = 2;
        showView(this.loadingViewId);
    }

    public void showNoNet() {
        this.currentStatus = 3;
        showView(this.noNetworkViewId);
    }

    public void showStatusView(int i2) {
        if (i2 == 1) {
            showError();
        } else if (i2 == 2) {
            showLoading();
        } else if (i2 == 3) {
            showNoNet();
        } else if (i2 != 4) {
            hideLoading();
        } else {
            showEmpty();
        }
    }

    public void showView(int i2) {
        View ViewFactory = ViewFactory(i2);
        this.currentView = ViewFactory;
        if (ViewFactory != null) {
            if (getChildCount() > 0) {
                removeAllViews();
            }
            addView(this.currentView, this.params);
        }
    }

    public LoadStatusLayout(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public LoadStatusLayout(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.params = new FrameLayout.LayoutParams(-1, -1);
        this.currentStatus = 0;
        this.views = new SparseArray<>();
        this.mContext = context;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.LoadStatusLayout);
        this.contentViewId = obtainStyledAttributes.getResourceId(R.styleable.LoadStatusLayout_contentView, -1);
        this.emptyViewId = obtainStyledAttributes.getResourceId(R.styleable.LoadStatusLayout_emptyView, getLayoutId("base_control_layout_empty_view"));
        this.errorViewId = obtainStyledAttributes.getResourceId(R.styleable.LoadStatusLayout_errorView, getLayoutId("base_control_layout_error_view"));
        this.loadingViewId = obtainStyledAttributes.getResourceId(R.styleable.LoadStatusLayout_loadingView, getLayoutId("base_control_layout_loading_view"));
        this.noNetworkViewId = obtainStyledAttributes.getResourceId(R.styleable.LoadStatusLayout_noNetworkView, getLayoutId("base_control_layout_no_network_view"));
        this.inflater = LayoutInflater.from(context);
        obtainStyledAttributes.recycle();
    }
}
