package org.dsq.library.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.StateListDrawable;
import android.text.TextUtils;
import android.util.AttributeSet;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.core.view.ViewCompat;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.concurrent.atomic.AtomicInteger;
import org.dsq.library.R;
import org.dsq.library.expand.ViewHelp;
import org.dsq.library.util.ResouUtils;

public class ShapeTextView extends AppCompatTextView {
    public static final int BOTTOM = 3;
    public static final int LEFT = 0;
    public static final int RIGHT = 2;
    public static final int TOP = 1;
    private float cornersBottomLeftRadius;
    private float cornersBottomRightRadius;
    private float cornersRadius;
    private float cornersTopLeftRadius;
    private float cornersTopRightRadius;
    private int defaultColor;
    private int defaultSelectorColor;
    private GradientDrawable drawable;
    private Drawable[] drawables;
    private int endColor;
    private int[] heights;
    private int selectorDisableColor;
    private int selectorPressedColor;
    private int solidColor;
    private int startColor;
    private int strokeColor;
    private float strokeDashGap;
    private float strokeDashWidth;
    private int strokeWidth;
    private int[] widths;

    @Retention(RetentionPolicy.SOURCE)
    public @interface DrawGravity {
    }

    public ShapeTextView(Context context) {
        this(context, null);
    }

    private int dip2px(float f2) {
        return (int) ((f2 * getResources().getDisplayMetrics().density) + 0.5f);
    }

    private Drawable getDrawable(int i2) {
        GradientDrawable gradientDrawable = new GradientDrawable();
        this.drawable = gradientDrawable;
        int i3 = this.startColor;
        if (i3 != 0) {
            setGradientColor(i3, this.endColor);
        } else {
            gradientDrawable.setColor(this.solidColor);
        }
        int i4 = this.strokeWidth;
        if (i4 > 0) {
            this.drawable.setStroke(i4, this.strokeColor, this.strokeDashWidth, this.strokeDashGap);
        }
        float f2 = this.cornersRadius;
        if (f2 > 0.0f) {
            this.drawable.setCornerRadius(f2);
        } else {
            float f3 = this.cornersTopLeftRadius;
            if (f3 > 0.0f || this.cornersTopRightRadius > 0.0f || this.cornersBottomRightRadius > 0.0f || this.cornersBottomLeftRadius > 0.0f) {
                GradientDrawable gradientDrawable2 = this.drawable;
                float f4 = this.cornersTopRightRadius;
                float f5 = this.cornersBottomRightRadius;
                float f6 = this.cornersBottomLeftRadius;
                gradientDrawable2.setCornerRadii(new float[]{f3, f3, f4, f4, f5, f5, f6, f6});
            }
        }
        if (i2 == -16842910) {
            this.drawable.setColor(this.selectorDisableColor);
        } else if (i2 == 16842910) {
            this.drawable.setColor(this.solidColor);
        } else if (i2 == 16842919) {
            this.drawable.setColor(this.selectorPressedColor);
        }
        return this.drawable;
    }

    private StateListDrawable getListDrawable() {
        StateListDrawable stateListDrawable = new StateListDrawable();
        stateListDrawable.addState(new int[]{16842919, 16842910}, getDrawable(16842919));
        stateListDrawable.addState(new int[]{-16842910}, getDrawable(-16842910));
        stateListDrawable.addState(new int[0], getDrawable(16842910));
        return stateListDrawable;
    }

    private void initShape() {
        if (this.selectorPressedColor != this.defaultSelectorColor) {
            setClickable(true);
        }
        float f2 = this.strokeDashWidth;
        if (f2 > 0.0f && this.strokeDashGap == 0.0f) {
            this.strokeDashGap = (float) dip2px(1.0f);
        } else if (f2 == 0.0f && this.strokeDashGap > 0.0f) {
            this.strokeDashWidth = (float) dip2px(1.0f);
        }
        StateListDrawable listDrawable = getListDrawable();
        AtomicInteger atomicInteger = ViewCompat.f1365a;
        setBackground(listDrawable);
    }

    private void translateText(Canvas canvas, int i2) {
        int i3;
        Drawable[] drawableArr = this.drawables;
        int i4 = 0;
        if (drawableArr[0] != null && drawableArr[2] != null) {
            int[] iArr = this.widths;
            i3 = (iArr[0] - iArr[2]) / 2;
        } else if (drawableArr[0] != null) {
            i3 = (this.widths[0] + i2) / 2;
        } else {
            i3 = drawableArr[2] != null ? (-(this.widths[2] + i2)) / 2 : 0;
        }
        if (drawableArr[1] != null && drawableArr[3] != null) {
            int[] iArr2 = this.heights;
            i4 = (iArr2[1] - iArr2[3]) / 2;
        } else if (drawableArr[1] != null) {
            i4 = (this.heights[1] + i2) / 2;
        } else if (drawableArr[3] != null) {
            i4 = (-(this.heights[3] - i2)) / 2;
        }
        canvas.translate((float) i3, (float) i4);
    }

    public void onDraw(Canvas canvas) {
        int compoundDrawablePadding = getCompoundDrawablePadding();
        translateText(canvas, compoundDrawablePadding);
        super.onDraw(canvas);
        CharSequence text = getText();
        CharSequence hint = getHint();
        if (TextUtils.isEmpty(text)) {
            text = "";
        }
        if (TextUtils.isEmpty(hint)) {
            hint = "";
        }
        float paddingLeft = (float) (((getPaddingLeft() + getWidth()) - getPaddingRight()) / 2);
        float paddingTop = (float) (((getPaddingTop() + getHeight()) - getPaddingBottom()) / 2);
        float measureText = getPaint().measureText(text.toString().isEmpty() ? hint.toString() : text.toString()) / 2.0f;
        Paint.FontMetrics fontMetrics = getPaint().getFontMetrics();
        float f2 = (fontMetrics.descent - fontMetrics.ascent) / 2.0f;
        Drawable[] drawableArr = this.drawables;
        if (drawableArr[0] != null) {
            int[] iArr = this.widths;
            int i2 = (int) (((paddingLeft - ((float) compoundDrawablePadding)) - measureText) - ((float) iArr[0]));
            int[] iArr2 = this.heights;
            int i3 = (int) (paddingTop - ((float) (iArr2[0] / 2)));
            drawableArr[0].setBounds(i2, i3, iArr[0] + i2, iArr2[0] + i3);
            canvas.save();
            this.drawables[0].draw(canvas);
            canvas.restore();
        }
        Drawable[] drawableArr2 = this.drawables;
        if (drawableArr2[2] != null) {
            int i4 = (int) (measureText + paddingLeft + ((float) compoundDrawablePadding));
            int[] iArr3 = this.heights;
            int i5 = (int) (paddingTop - ((float) (iArr3[2] / 2)));
            drawableArr2[2].setBounds(i4, i5, this.widths[2] + i4, iArr3[2] + i5);
            canvas.save();
            this.drawables[2].draw(canvas);
            canvas.restore();
        }
        Drawable[] drawableArr3 = this.drawables;
        if (drawableArr3[1] != null) {
            int[] iArr4 = this.widths;
            int i6 = (int) (paddingLeft - ((float) (iArr4[1] / 2)));
            int i7 = (int) ((paddingTop - f2) - ((float) compoundDrawablePadding));
            drawableArr3[1].setBounds(i6, i7 - this.heights[1], iArr4[1] + i6, i7);
            canvas.save();
            this.drawables[1].draw(canvas);
            canvas.restore();
        }
        Drawable[] drawableArr4 = this.drawables;
        if (drawableArr4[3] != null) {
            int[] iArr5 = this.widths;
            int i8 = (int) (paddingLeft - ((float) (iArr5[3] / 2)));
            int i9 = (int) (paddingTop + f2 + ((float) compoundDrawablePadding));
            drawableArr4[3].setBounds(i8, i9, iArr5[3] + i8, this.heights[3] + i9);
            canvas.save();
            this.drawables[3].draw(canvas);
            canvas.restore();
        }
    }

    public void setCornersRadius(int i2) {
        float dp2px = (float) ViewHelp.dp2px(i2);
        this.cornersRadius = dp2px;
        if (dp2px > 0.0f) {
            this.drawable.setCornerRadius(ViewHelp.dp2px(dp2px));
        } else {
            this.drawable.setCornerRadius(0.0f);
        }
    }

    public void setDrawable(int i2, int i3) {
        if (i3 != 0) {
            Drawable drawable2 = ResouUtils.getDrawable(i3);
            if (drawable2 != null) {
                setDrawable(i2, drawable2, drawable2.getMinimumWidth(), drawable2.getMinimumHeight());
                return;
            }
            return;
        }
        this.drawables[i2] = null;
        this.widths[i2] = 0;
        this.heights[i2] = 0;
        invalidate();
    }

    public void setDrawables(Drawable[] drawableArr, int[] iArr, int[] iArr2) {
        if (drawableArr != null && drawableArr.length >= 4 && iArr != null && iArr.length >= 4 && iArr2 != null && iArr2.length >= 4) {
            this.drawables = drawableArr;
            this.widths = iArr;
            this.heights = iArr2;
            invalidate();
        }
    }

    public void setGradientColor(int i2, int i3) {
        this.startColor = i2;
        int[] iArr = {ResouUtils.getColor(i2), ResouUtils.getColor(i3)};
        if (this.drawable == null) {
            this.drawable = new GradientDrawable();
        }
        this.drawable.setOrientation(GradientDrawable.Orientation.LEFT_RIGHT);
        this.drawable.setColors(iArr);
    }

    public void setSolidColor(int i2) {
        if (i2 != 0) {
            this.solidColor = getResources().getColor(i2);
        }
        if (i2 == 0) {
            this.drawable.setColor(0);
        } else if (this.startColor != 0) {
            initShape();
            this.startColor = 0;
        } else {
            this.drawable.setColor(this.solidColor);
        }
    }

    public void setStrokeColor(int i2) {
        if (i2 != -1) {
            if (this.strokeWidth == 0) {
                this.strokeWidth = ViewHelp.dp2px(1);
            }
            this.drawable.setStroke(this.strokeWidth, getResources().getColor(i2), this.strokeDashWidth, this.strokeDashGap);
        }
    }

    public ShapeTextView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public ShapeTextView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.defaultColor = 536870912;
        this.defaultSelectorColor = 536870912;
        this.startColor = 0;
        this.endColor = 0;
        this.drawables = new Drawable[4];
        this.widths = new int[4];
        this.heights = new int[4];
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.ShapeTextView);
        this.startColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_start_color, 0);
        this.endColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_end_color, 0);
        this.solidColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_solid_color, this.defaultColor);
        this.selectorDisableColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_disable_color, this.defaultSelectorColor);
        this.selectorPressedColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_pressed_color, this.solidColor);
        this.cornersRadius = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_corners_radius, 0);
        this.cornersTopLeftRadius = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_top_left_radius, 0);
        this.cornersTopRightRadius = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_top_right_radius, 0);
        this.cornersBottomLeftRadius = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_bottom_left_radius, 0);
        this.cornersBottomRightRadius = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_bottom_right_radius, 0);
        this.strokeColor = obtainStyledAttributes.getColor(R.styleable.ShapeTextView_stroke_color, this.defaultColor);
        this.strokeWidth = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_stroke_width, 0);
        this.strokeDashGap = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_stroke_dash_gap, 0);
        this.strokeDashWidth = (float) obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_stroke_dash_width, 0);
        this.drawables[0] = obtainStyledAttributes.getDrawable(R.styleable.ShapeTextView_leftDrawable);
        this.drawables[1] = obtainStyledAttributes.getDrawable(R.styleable.ShapeTextView_topDrawable);
        this.drawables[2] = obtainStyledAttributes.getDrawable(R.styleable.ShapeTextView_rightDrawable);
        this.drawables[3] = obtainStyledAttributes.getDrawable(R.styleable.ShapeTextView_bottomDrawable);
        this.widths[0] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_leftDrawableWidth, 0);
        this.widths[1] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_topDrawableWidth, 0);
        this.widths[2] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_rightDrawableWidth, 0);
        this.widths[3] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_bottomDrawableWidth, 0);
        this.heights[0] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_leftDrawableHeight, 0);
        this.heights[1] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_topDrawableHeight, 0);
        this.heights[2] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_rightDrawableHeight, 0);
        this.heights[3] = obtainStyledAttributes.getDimensionPixelSize(R.styleable.ShapeTextView_bottomDrawableHeight, 0);
        obtainStyledAttributes.recycle();
        Drawable[] drawableArr = this.drawables;
        if (drawableArr[0] != null) {
            int[] iArr = this.widths;
            if (iArr[0] < 1) {
                iArr[0] = drawableArr[0].getMinimumWidth();
                this.heights[0] = this.drawables[0].getMinimumHeight();
            }
        }
        Drawable[] drawableArr2 = this.drawables;
        if (drawableArr2[1] != null) {
            int[] iArr2 = this.widths;
            if (iArr2[1] < 1) {
                iArr2[1] = drawableArr2[1].getMinimumWidth();
                this.heights[1] = this.drawables[1].getMinimumHeight();
            }
        }
        Drawable[] drawableArr3 = this.drawables;
        if (drawableArr3[2] != null) {
            int[] iArr3 = this.widths;
            if (iArr3[2] < 1) {
                iArr3[2] = drawableArr3[2].getMinimumWidth();
                this.heights[2] = this.drawables[2].getMinimumHeight();
            }
        }
        Drawable[] drawableArr4 = this.drawables;
        if (drawableArr4[3] != null) {
            int[] iArr4 = this.widths;
            if (iArr4[3] < 1) {
                iArr4[3] = drawableArr4[3].getMinimumWidth();
                this.heights[3] = this.drawables[3].getMinimumHeight();
            }
        }
        initShape();
    }

    public void setDrawable(int i2, Drawable drawable2) {
        if (drawable2 != null) {
            setDrawable(i2, drawable2, drawable2.getMinimumWidth(), drawable2.getMinimumHeight());
            return;
        }
        this.drawables[i2] = null;
        this.widths[i2] = 0;
        this.heights[i2] = 0;
        invalidate();
    }

    public void setGradientColor(int i2, int i3, int i4) {
        this.startColor = i2;
        this.endColor = i4;
        int[] iArr = {ResouUtils.getColor(i2), ResouUtils.getColor(i3), ResouUtils.getColor(i4)};
        this.drawable.setOrientation(GradientDrawable.Orientation.LEFT_RIGHT);
        this.drawable.setColors(iArr);
    }

    public void setDrawable(int i2, Drawable drawable2, int i3, int i4) {
        this.drawables[i2] = drawable2;
        this.widths[i2] = i3;
        this.heights[i2] = i4;
        invalidate();
    }
}
