package org.dsq.library.widget.circularmenu;

import android.app.Activity;
import android.content.Context;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.RectF;
import android.view.Display;
import android.view.LayoutInflater;
import android.view.OrientationEventListener;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.FrameLayout;
import com.gyf.immersionbar.Constants;
import java.util.ArrayList;
import java.util.List;
import org.dsq.library.R;
import org.dsq.library.widget.circularmenu.anim.DefaultAnimationHandler;
import org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler;

public class FloatingActionMenu {
    private boolean animated;
    private MenuAnimationHandler animationHandler;
    private int endAngle;
    private boolean isVip = false;
    private View mainActionView;
    private boolean open;
    private OrientationEventListener orientationListener;
    private FrameLayout overlayContainer;
    private int radius;
    private int startAngle;
    private MenuStateChangeListener stateChangeListener;
    private List<Item> subActionItems;
    private boolean systemOverlay;

    public class ActionViewClickListener implements View.OnClickListener {
        public ActionViewClickListener() {
        }

        public void onClick(View view) {
            FloatingActionMenu floatingActionMenu = FloatingActionMenu.this;
            floatingActionMenu.toggle(floatingActionMenu.animated);
        }
    }

    public static class Builder {
        private View actionView;
        private boolean animated;
        private MenuAnimationHandler animationHandler;
        private int endAngle;
        private boolean isVip;
        private int radius;
        private int startAngle;
        private MenuStateChangeListener stateChangeListener;
        private List<Item> subActionItems;
        private boolean systemOverlay;

        public Builder(Context context, boolean z) {
            this.subActionItems = new ArrayList();
            this.radius = context.getResources().getDimensionPixelSize(R.dimen.action_menu_radius);
            this.startAngle = 180;
            this.endAngle = 270;
            this.animationHandler = new DefaultAnimationHandler();
            this.animated = true;
            this.systemOverlay = z;
        }

        public Builder addSubActionView(View view, int i2, int i3) {
            this.subActionItems.add(new Item(view, i2, i3));
            return this;
        }

        public Builder attachTo(View view) {
            this.actionView = view;
            return this;
        }

        public FloatingActionMenu build() {
            return new FloatingActionMenu(this.actionView, this.startAngle, this.endAngle, this.radius, this.isVip, this.subActionItems, this.animationHandler, this.animated, this.stateChangeListener, this.systemOverlay);
        }

        public Builder disableAnimations() {
            this.animated = false;
            return this;
        }

        public Builder enableAnimations() {
            this.animated = true;
            return this;
        }

        public Builder isVIP(boolean z) {
            this.isVip = z;
            return this;
        }

        public Builder setAnimationHandler(MenuAnimationHandler menuAnimationHandler) {
            this.animationHandler = menuAnimationHandler;
            return this;
        }

        public Builder setEndAngle(int i2) {
            this.endAngle = i2;
            return this;
        }

        public Builder setRadius(int i2) {
            this.radius = i2;
            return this;
        }

        public Builder setStartAngle(int i2) {
            this.startAngle = i2;
            return this;
        }

        public Builder setStateChangeListener(MenuStateChangeListener menuStateChangeListener) {
            this.stateChangeListener = menuStateChangeListener;
            return this;
        }

        public Builder setSystemOverlay(boolean z) {
            this.systemOverlay = z;
            return this;
        }

        public Builder addSubActionView(View view) {
            if (!this.systemOverlay) {
                return addSubActionView(view, 0, 0);
            }
            throw new RuntimeException("Sub action views cannot be added without definite width and height. Please use other methods named addSubActionView");
        }

        public Builder addSubActionView(int i2, Context context) {
            View inflate = ((LayoutInflater) context.getSystemService("layout_inflater")).inflate(i2, (ViewGroup) null, false);
            inflate.measure(0, 0);
            return addSubActionView(inflate, inflate.getMeasuredWidth(), inflate.getMeasuredHeight());
        }

        public Builder(Context context) {
            this(context, false);
        }
    }

    public static class Item {
        public float alpha;
        public int height;
        public View view;
        public int width;
        public int x = 0;
        public int y = 0;

        public Item(View view2, int i2, int i3) {
            this.view = view2;
            this.width = i2;
            this.height = i3;
            this.alpha = view2.getAlpha();
        }
    }

    public class ItemViewQueueListener implements Runnable {
        private static final int MAX_TRIES = 10;
        private Item item;
        private int tries = 0;

        public ItemViewQueueListener(Item item2) {
            this.item = item2;
        }

        public void run() {
            if (this.item.view.getMeasuredWidth() != 0 || this.tries >= 10) {
                Item item2 = this.item;
                item2.width = item2.view.getMeasuredWidth();
                Item item3 = this.item;
                item3.height = item3.view.getMeasuredHeight();
                Item item4 = this.item;
                item4.view.setAlpha(item4.alpha);
                FloatingActionMenu.this.removeViewFromCurrentContainer(this.item.view);
                return;
            }
            this.item.view.post(this);
        }
    }

    public interface MenuStateChangeListener {
        void notVip();

        void onMenuClosed(FloatingActionMenu floatingActionMenu);

        void onMenuOpened(FloatingActionMenu floatingActionMenu);
    }

    public FloatingActionMenu(View view, int i2, int i3, int i4, boolean z, List<Item> list, MenuAnimationHandler menuAnimationHandler, boolean z2, MenuStateChangeListener menuStateChangeListener, boolean z3) {
        this.mainActionView = view;
        this.startAngle = i2;
        this.endAngle = i3;
        this.radius = i4;
        this.subActionItems = list;
        this.animationHandler = menuAnimationHandler;
        this.animated = z2;
        this.systemOverlay = z3;
        this.open = false;
        this.isVip = z;
        this.stateChangeListener = menuStateChangeListener;
        view.setClickable(true);
        this.mainActionView.setOnClickListener(new ActionViewClickListener());
        if (menuAnimationHandler != null) {
            menuAnimationHandler.setMenu(this);
        }
        if (z3) {
            this.overlayContainer = new FrameLayout(view.getContext());
        } else {
            this.overlayContainer = null;
        }
        for (Item item : list) {
            if (item.width == 0 || item.height == 0) {
                if (!z3) {
                    addViewToCurrentContainer(item.view);
                    item.view.setAlpha(0.0f);
                    item.view.post(new ItemViewQueueListener(item));
                } else {
                    throw new RuntimeException("Sub action views cannot be added without definite width and height.");
                }
            }
        }
        if (z3) {
            AnonymousClass1 r3 = new OrientationEventListener(view.getContext(), 2) {
                /* class org.dsq.library.widget.circularmenu.FloatingActionMenu.AnonymousClass1 */
                private int lastState = -1;

                public void onOrientationChanged(int i2) {
                    Display defaultDisplay = FloatingActionMenu.this.getWindowManager().getDefaultDisplay();
                    if (defaultDisplay.getRotation() != this.lastState) {
                        this.lastState = defaultDisplay.getRotation();
                        if (FloatingActionMenu.this.isOpen()) {
                            FloatingActionMenu.this.close(false);
                        }
                    }
                }
            };
            this.orientationListener = r3;
            r3.enable();
        }
    }

    private void addViewToCurrentContainer(View view, ViewGroup.LayoutParams layoutParams) {
        if (this.systemOverlay) {
            this.overlayContainer.addView(view, layoutParams);
        } else if (layoutParams != null) {
            try {
                ((ViewGroup) getActivityContentView()).addView(view, (FrameLayout.LayoutParams) layoutParams);
            } catch (ClassCastException unused) {
                throw new ClassCastException("layoutParams must be an instance of FrameLayout.LayoutParams.");
            }
        } else {
            ((ViewGroup) getActivityContentView()).addView(view);
        }
    }

    private Point calculateItemPositions() {
        int i2;
        Point actionViewCenter = getActionViewCenter();
        int i3 = actionViewCenter.x;
        int i4 = this.radius;
        int i5 = actionViewCenter.y;
        RectF rectF = new RectF((float) (i3 - i4), (float) (i5 - i4), (float) (i3 + i4), (float) (i5 + i4));
        Path path = new Path();
        int i6 = this.startAngle;
        path.addArc(rectF, (float) i6, (float) (this.endAngle - i6));
        PathMeasure pathMeasure = new PathMeasure(path, false);
        if (Math.abs(this.endAngle - this.startAngle) >= 360 || this.subActionItems.size() <= 1) {
            i2 = this.subActionItems.size();
        } else {
            i2 = this.subActionItems.size() - 1;
        }
        for (int i7 = 0; i7 < this.subActionItems.size(); i7++) {
            float[] fArr = {0.0f, 0.0f};
            pathMeasure.getPosTan((pathMeasure.getLength() * ((float) i7)) / ((float) i2), fArr, null);
            this.subActionItems.get(i7).x = ((int) fArr[0]) - (this.subActionItems.get(i7).width / 2);
            this.subActionItems.get(i7).y = ((int) fArr[1]) - (this.subActionItems.get(i7).height / 2);
        }
        return actionViewCenter;
    }

    private WindowManager.LayoutParams calculateOverlayContainerParams() {
        WindowManager.LayoutParams defaultSystemWindowParams = getDefaultSystemWindowParams();
        int i2 = 9999;
        int i3 = 9999;
        int i4 = 0;
        int i5 = 0;
        for (int i6 = 0; i6 < this.subActionItems.size(); i6++) {
            int i7 = this.subActionItems.get(i6).x;
            int i8 = this.subActionItems.get(i6).y;
            if (i7 < i2) {
                i2 = i7;
            }
            if (i8 < i3) {
                i3 = i8;
            }
            if (this.subActionItems.get(i6).width + i7 > i4) {
                i4 = i7 + this.subActionItems.get(i6).width;
            }
            if (this.subActionItems.get(i6).height + i8 > i5) {
                i5 = i8 + this.subActionItems.get(i6).height;
            }
        }
        defaultSystemWindowParams.width = i4 - i2;
        defaultSystemWindowParams.height = i5 - i3;
        defaultSystemWindowParams.x = i2;
        defaultSystemWindowParams.y = i3;
        defaultSystemWindowParams.gravity = 51;
        return defaultSystemWindowParams;
    }

    private Point getActionViewCoordinates() {
        int[] iArr = new int[2];
        this.mainActionView.getLocationOnScreen(iArr);
        if (this.systemOverlay) {
            iArr[1] = iArr[1] - getStatusBarHeight();
        } else {
            Rect rect = new Rect();
            getActivityContentView().getWindowVisibleDisplayFrame(rect);
            iArr[0] = iArr[0] - (getScreenSize().x - getActivityContentView().getMeasuredWidth());
            iArr[1] = iArr[1] - ((rect.height() + rect.top) - getActivityContentView().getMeasuredHeight());
        }
        return new Point(iArr[0], iArr[1]);
    }

    public static WindowManager.LayoutParams getDefaultSystemWindowParams() {
        WindowManager.LayoutParams layoutParams = new WindowManager.LayoutParams(-2, -2, 2002, 40, -3);
        layoutParams.format = 1;
        layoutParams.gravity = 51;
        return layoutParams;
    }

    private Point getScreenSize() {
        Point point = new Point();
        getWindowManager().getDefaultDisplay().getSize(point);
        return point;
    }

    public void attachOverlayContainer() {
        try {
            WindowManager.LayoutParams calculateOverlayContainerParams = calculateOverlayContainerParams();
            this.overlayContainer.setLayoutParams(calculateOverlayContainerParams);
            if (this.overlayContainer.getParent() == null) {
                getWindowManager().addView(this.overlayContainer, calculateOverlayContainerParams);
            }
            WindowManager windowManager = getWindowManager();
            View view = this.mainActionView;
            windowManager.updateViewLayout(view, view.getLayoutParams());
        } catch (SecurityException unused) {
            throw new SecurityException("Your application must have SYSTEM_ALERT_WINDOW permission to create a system window.");
        }
    }

    public void close(boolean z) {
        MenuAnimationHandler menuAnimationHandler;
        if (!z || (menuAnimationHandler = this.animationHandler) == null) {
            for (int i2 = 0; i2 < this.subActionItems.size(); i2++) {
                removeViewFromCurrentContainer(this.subActionItems.get(i2).view);
            }
            detachOverlayContainer();
        } else if (!menuAnimationHandler.isAnimating()) {
            this.animationHandler.animateMenuClosing(getActionViewCenter());
        } else {
            return;
        }
        this.open = false;
        MenuStateChangeListener menuStateChangeListener = this.stateChangeListener;
        if (menuStateChangeListener != null) {
            menuStateChangeListener.onMenuClosed(this);
        }
    }

    public void detachOverlayContainer() {
        getWindowManager().removeView(this.overlayContainer);
    }

    public Point getActionViewCenter() {
        Point actionViewCoordinates = getActionViewCoordinates();
        actionViewCoordinates.x = (this.mainActionView.getMeasuredWidth() / 2) + actionViewCoordinates.x;
        actionViewCoordinates.y = (this.mainActionView.getMeasuredHeight() / 2) + actionViewCoordinates.y;
        return actionViewCoordinates;
    }

    public View getActivityContentView() {
        try {
            return ((Activity) this.mainActionView.getContext()).getWindow().getDecorView().findViewById(16908290);
        } catch (ClassCastException unused) {
            throw new ClassCastException("Please provide an Activity context for this FloatingActionMenu.");
        }
    }

    public FrameLayout getOverlayContainer() {
        return this.overlayContainer;
    }

    public int getRadius() {
        return this.radius;
    }

    public int getStatusBarHeight() {
        int identifier = this.mainActionView.getContext().getResources().getIdentifier(Constants.IMMERSION_STATUS_BAR_HEIGHT, "dimen", "android");
        if (identifier > 0) {
            return this.mainActionView.getContext().getResources().getDimensionPixelSize(identifier);
        }
        return 0;
    }

    public List<Item> getSubActionItems() {
        return this.subActionItems;
    }

    public WindowManager getWindowManager() {
        return (WindowManager) this.mainActionView.getContext().getSystemService("window");
    }

    public boolean isOpen() {
        return this.open;
    }

    public boolean isSystemOverlay() {
        return this.systemOverlay;
    }

    public void open(boolean z) {
        MenuAnimationHandler menuAnimationHandler;
        if (!this.isVip) {
            MenuStateChangeListener menuStateChangeListener = this.stateChangeListener;
            if (menuStateChangeListener != null) {
                menuStateChangeListener.notVip();
                return;
            }
            return;
        }
        Point calculateItemPositions = calculateItemPositions();
        WindowManager.LayoutParams layoutParams = null;
        if (this.systemOverlay) {
            attachOverlayContainer();
            layoutParams = (WindowManager.LayoutParams) this.overlayContainer.getLayoutParams();
        }
        if (!z || (menuAnimationHandler = this.animationHandler) == null) {
            for (int i2 = 0; i2 < this.subActionItems.size(); i2++) {
                FrameLayout.LayoutParams layoutParams2 = new FrameLayout.LayoutParams(this.subActionItems.get(i2).width, this.subActionItems.get(i2).height, 51);
                if (this.systemOverlay) {
                    layoutParams2.setMargins(this.subActionItems.get(i2).x - layoutParams.x, this.subActionItems.get(i2).y - layoutParams.y, 0, 0);
                    this.subActionItems.get(i2).view.setLayoutParams(layoutParams2);
                } else {
                    layoutParams2.setMargins(this.subActionItems.get(i2).x, this.subActionItems.get(i2).y, 0, 0);
                    this.subActionItems.get(i2).view.setLayoutParams(layoutParams2);
                }
                addViewToCurrentContainer(this.subActionItems.get(i2).view, layoutParams2);
            }
        } else if (!menuAnimationHandler.isAnimating()) {
            for (int i3 = 0; i3 < this.subActionItems.size(); i3++) {
                if (this.subActionItems.get(i3).view.getParent() == null) {
                    FrameLayout.LayoutParams layoutParams3 = new FrameLayout.LayoutParams(this.subActionItems.get(i3).width, this.subActionItems.get(i3).height, 51);
                    if (this.systemOverlay) {
                        layoutParams3.setMargins((calculateItemPositions.x - layoutParams.x) - (this.subActionItems.get(i3).width / 2), (calculateItemPositions.y - layoutParams.y) - (this.subActionItems.get(i3).height / 2), 0, 0);
                    } else {
                        layoutParams3.setMargins(calculateItemPositions.x - (this.subActionItems.get(i3).width / 2), calculateItemPositions.y - (this.subActionItems.get(i3).height / 2), 0, 0);
                    }
                    addViewToCurrentContainer(this.subActionItems.get(i3).view, layoutParams3);
                } else {
                    throw new RuntimeException("All of the sub action items have to be independent from a parent.");
                }
            }
            this.animationHandler.animateMenuOpening(calculateItemPositions);
        } else {
            return;
        }
        this.open = true;
        MenuStateChangeListener menuStateChangeListener2 = this.stateChangeListener;
        if (menuStateChangeListener2 != null) {
            menuStateChangeListener2.onMenuOpened(this);
        }
    }

    public void removeViewFromCurrentContainer(View view) {
        if (this.systemOverlay) {
            this.overlayContainer.removeView(view);
        } else {
            ((ViewGroup) getActivityContentView()).removeView(view);
        }
    }

    public void setStateChangeListener(MenuStateChangeListener menuStateChangeListener) {
        this.stateChangeListener = menuStateChangeListener;
    }

    public void toggle(boolean z) {
        if (this.open) {
            close(z);
        } else {
            open(z);
        }
    }

    public void updateItemPositions() {
        if (isOpen()) {
            calculateItemPositions();
            for (int i2 = 0; i2 < this.subActionItems.size(); i2++) {
                FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(this.subActionItems.get(i2).width, this.subActionItems.get(i2).height, 51);
                layoutParams.setMargins(this.subActionItems.get(i2).x, this.subActionItems.get(i2).y, 0, 0);
                this.subActionItems.get(i2).view.setLayoutParams(layoutParams);
            }
        }
    }

    public void updateVip(boolean z) {
        this.isVip = z;
    }

    public void addViewToCurrentContainer(View view) {
        addViewToCurrentContainer(view, null);
    }
}
