package org.dsq.library.widget.circularmenu.anim;

import android.animation.Animator;
import android.animation.ObjectAnimator;
import android.animation.PropertyValuesHolder;
import android.graphics.Point;
import android.view.View;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.view.animation.OvershootInterpolator;
import org.dsq.library.widget.circularmenu.FloatingActionMenu;
import org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler;

public class DefaultAnimationHandler extends MenuAnimationHandler {
    public static final int DURATION = 500;
    public static final int LAG_BETWEEN_ITEMS = 20;
    private boolean animating;

    public class SubActionItemAnimationListener implements Animator.AnimatorListener {
        private MenuAnimationHandler.ActionType actionType;
        private FloatingActionMenu.Item subActionItem;

        public SubActionItemAnimationListener(FloatingActionMenu.Item item, MenuAnimationHandler.ActionType actionType2) {
            this.subActionItem = item;
            this.actionType = actionType2;
        }

        public void onAnimationCancel(Animator animator) {
            DefaultAnimationHandler.this.restoreSubActionViewAfterAnimation(this.subActionItem, this.actionType);
        }

        public void onAnimationEnd(Animator animator) {
            DefaultAnimationHandler.this.restoreSubActionViewAfterAnimation(this.subActionItem, this.actionType);
        }

        public void onAnimationRepeat(Animator animator) {
        }

        public void onAnimationStart(Animator animator) {
        }
    }

    public DefaultAnimationHandler() {
        setAnimating(false);
    }

    @Override // org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler
    public void animateMenuClosing(Point point) {
        super.animateMenuOpening(point);
        setAnimating(true);
        ObjectAnimator objectAnimator = null;
        for (int i2 = 0; i2 < this.menu.getSubActionItems().size(); i2++) {
            PropertyValuesHolder ofFloat = PropertyValuesHolder.ofFloat(View.TRANSLATION_X, (float) (-((this.menu.getSubActionItems().get(i2).width / 2) + (this.menu.getSubActionItems().get(i2).x - point.x))));
            PropertyValuesHolder ofFloat2 = PropertyValuesHolder.ofFloat(View.TRANSLATION_Y, (float) (-((this.menu.getSubActionItems().get(i2).height / 2) + (this.menu.getSubActionItems().get(i2).y - point.y))));
            PropertyValuesHolder ofFloat3 = PropertyValuesHolder.ofFloat(View.ROTATION, -720.0f);
            PropertyValuesHolder ofFloat4 = PropertyValuesHolder.ofFloat(View.SCALE_X, 0.0f);
            PropertyValuesHolder ofFloat5 = PropertyValuesHolder.ofFloat(View.SCALE_Y, 0.0f);
            PropertyValuesHolder ofFloat6 = PropertyValuesHolder.ofFloat(View.ALPHA, 0.0f);
            ObjectAnimator ofPropertyValuesHolder = ObjectAnimator.ofPropertyValuesHolder(this.menu.getSubActionItems().get(i2).view, ofFloat, ofFloat2, ofFloat3, ofFloat4, ofFloat5, ofFloat6);
            ofPropertyValuesHolder.setDuration(500L);
            ofPropertyValuesHolder.setInterpolator(new AccelerateDecelerateInterpolator());
            ofPropertyValuesHolder.addListener(new SubActionItemAnimationListener(this.menu.getSubActionItems().get(i2), MenuAnimationHandler.ActionType.CLOSING));
            if (i2 == 0) {
                objectAnimator = ofPropertyValuesHolder;
            }
            ofPropertyValuesHolder.setStartDelay((long) ((this.menu.getSubActionItems().size() - i2) * 20));
            ofPropertyValuesHolder.start();
        }
        if (objectAnimator != null) {
            objectAnimator.addListener(new MenuAnimationHandler.LastAnimationListener());
        }
    }

    @Override // org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler
    public void animateMenuOpening(Point point) {
        super.animateMenuOpening(point);
        setAnimating(true);
        ObjectAnimator objectAnimator = null;
        for (int i2 = 0; i2 < this.menu.getSubActionItems().size(); i2++) {
            this.menu.getSubActionItems().get(i2).view.setScaleX(0.0f);
            this.menu.getSubActionItems().get(i2).view.setScaleY(0.0f);
            this.menu.getSubActionItems().get(i2).view.setAlpha(0.0f);
            PropertyValuesHolder ofFloat = PropertyValuesHolder.ofFloat(View.TRANSLATION_X, (float) ((this.menu.getSubActionItems().get(i2).width / 2) + (this.menu.getSubActionItems().get(i2).x - point.x)));
            PropertyValuesHolder ofFloat2 = PropertyValuesHolder.ofFloat(View.TRANSLATION_Y, (float) ((this.menu.getSubActionItems().get(i2).height / 2) + (this.menu.getSubActionItems().get(i2).y - point.y)));
            PropertyValuesHolder ofFloat3 = PropertyValuesHolder.ofFloat(View.ROTATION, 720.0f);
            PropertyValuesHolder ofFloat4 = PropertyValuesHolder.ofFloat(View.SCALE_X, 1.0f);
            PropertyValuesHolder ofFloat5 = PropertyValuesHolder.ofFloat(View.SCALE_Y, 1.0f);
            PropertyValuesHolder ofFloat6 = PropertyValuesHolder.ofFloat(View.ALPHA, 1.0f);
            ObjectAnimator ofPropertyValuesHolder = ObjectAnimator.ofPropertyValuesHolder(this.menu.getSubActionItems().get(i2).view, ofFloat, ofFloat2, ofFloat3, ofFloat4, ofFloat5, ofFloat6);
            ofPropertyValuesHolder.setDuration(500L);
            ofPropertyValuesHolder.setInterpolator(new OvershootInterpolator(0.9f));
            ofPropertyValuesHolder.addListener(new SubActionItemAnimationListener(this.menu.getSubActionItems().get(i2), MenuAnimationHandler.ActionType.OPENING));
            if (i2 == 0) {
                objectAnimator = ofPropertyValuesHolder;
            }
            ofPropertyValuesHolder.setStartDelay((long) ((this.menu.getSubActionItems().size() - i2) * 20));
            ofPropertyValuesHolder.start();
        }
        if (objectAnimator != null) {
            objectAnimator.addListener(new MenuAnimationHandler.LastAnimationListener());
        }
    }

    @Override // org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler
    public boolean isAnimating() {
        return this.animating;
    }

    @Override // org.dsq.library.widget.circularmenu.anim.MenuAnimationHandler
    public void setAnimating(boolean z) {
        this.animating = z;
    }
}
