package org.dsq.library.widget.tablayout;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.SparseArray;
import android.view.View;
import android.view.ViewGroup;
import android.widget.HorizontalScrollView;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;
import androidx.viewpager2.adapter.FragmentStateAdapter;
import androidx.viewpager2.widget.ViewPager2;
import d.a.a.a.a;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.dsq.library.R;
import org.dsq.library.widget.tablayout.listener.OnTabSelectListener;
import org.dsq.library.widget.tablayout.utils.UnreadMsgUtils;

public class SlidingTabLayout extends HorizontalScrollView {
    private static final int STYLE_BLOCK = 2;
    private static final int STYLE_NORMAL = 0;
    private static final int STYLE_TRIANGLE = 1;
    private static final int TEXT_BOLD_BOTH = 2;
    private static final int TEXT_BOLD_NONE = 0;
    private static final int TEXT_BOLD_WHEN_SELECT = 1;
    private ViewPager2.OnPageChangeCallback changeCallback;
    private Drawable indicatorDrawable;
    private boolean isIncrease;
    private Context mContext;
    private float mCurrentPositionOffset;
    private int mCurrentTab;
    private int mDividerColor;
    private float mDividerPadding;
    private Paint mDividerPaint;
    private float mDividerWidth;
    private int mHeight;
    private int mIndicatorColor;
    private float mIndicatorCornerRadius;
    private int mIndicatorGravity;
    private float mIndicatorHeight;
    private float mIndicatorMarginBottom;
    private float mIndicatorMarginLeft;
    private float mIndicatorMarginRight;
    private float mIndicatorMarginTop;
    private Rect mIndicatorRect;
    private int mIndicatorStyle;
    private float mIndicatorWidth;
    private boolean mIndicatorWidthEqualTitle;
    private SparseArray<Boolean> mInitSetMap;
    private int mLastScrollX;
    private OnTabSelectListener mListener;
    private Paint mRectPaint;
    private int mTabCount;
    private float mTabPadding;
    private Rect mTabRect;
    private boolean mTabSpaceEqual;
    private float mTabWidth;
    private LinearLayout mTabsContainer;
    private boolean mTextAllCaps;
    private int mTextBold;
    private Paint mTextPaint;
    private int mTextSelectColor;
    private int mTextUnselectColor;
    private float mTextsize;
    private ArrayList<String> mTitles;
    private Paint mTrianglePaint;
    private Path mTrianglePath;
    private int mUnderlineColor;
    private int mUnderlineGravity;
    private float mUnderlineHeight;
    private ViewPager2 mViewPager;
    private float margin;
    private Drawable markerDrawable;
    private boolean selestedBold;
    private float tabMargin;

    public SlidingTabLayout(Context context) {
        this(context, null, 0);
    }

    private void addTab(int i2, String str, View view) {
        final TextView textView = (TextView) view.findViewById(R.id.tv_tab_title);
        textView.setText(str);
        view.setOnClickListener(new View.OnClickListener() {
            /* class org.dsq.library.widget.tablayout.SlidingTabLayout.AnonymousClass1 */

            public void onClick(View view) {
                int indexOfChild = SlidingTabLayout.this.mTabsContainer.indexOfChild(view);
                if (indexOfChild == -1) {
                    return;
                }
                if (SlidingTabLayout.this.mViewPager.getCurrentItem() != indexOfChild) {
                    SlidingTabLayout.this.mViewPager.setCurrentItem(indexOfChild);
                    if (SlidingTabLayout.this.mListener != null) {
                        SlidingTabLayout.this.mListener.onTabSelect(indexOfChild, textView);
                    }
                } else if (SlidingTabLayout.this.mListener != null) {
                    SlidingTabLayout.this.mListener.onTabReselect(indexOfChild, textView);
                }
            }
        });
        LinearLayout.LayoutParams layoutParams = this.mTabSpaceEqual ? new LinearLayout.LayoutParams(0, -1, 1.0f) : new LinearLayout.LayoutParams(-2, -2);
        float f2 = this.mTabWidth;
        if (f2 > 0.0f) {
            Drawable drawable = this.markerDrawable;
            if (drawable != null) {
                this.mTabWidth = f2 + ((float) (drawable.getIntrinsicWidth() * 2));
            }
            layoutParams = new LinearLayout.LayoutParams((int) this.mTabWidth, -1);
        } else {
            Drawable drawable2 = this.markerDrawable;
            if (drawable2 != null) {
                view.setPadding(drawable2.getIntrinsicWidth(), 0, this.markerDrawable.getIntrinsicWidth(), 0);
            }
        }
        float f3 = this.tabMargin;
        if (f3 > 0.0f) {
            layoutParams.rightMargin = (int) f3;
        }
        this.mTabsContainer.addView(view, i2, layoutParams);
    }

    private void calcIndicatorRect() {
        View childAt = this.mTabsContainer.getChildAt(this.mCurrentTab);
        float left = (float) childAt.getLeft();
        float right = (float) childAt.getRight();
        if (this.mIndicatorStyle == 0 && this.mIndicatorWidthEqualTitle) {
            this.mTextPaint.setTextSize(this.mTextsize);
            this.margin = ((right - left) - this.mTextPaint.measureText(((TextView) childAt.findViewById(R.id.tv_tab_title)).getText().toString())) / 2.0f;
        }
        int i2 = this.mCurrentTab;
        if (i2 < this.mTabCount - 1) {
            View childAt2 = this.mTabsContainer.getChildAt(i2 + 1);
            float left2 = (float) childAt2.getLeft();
            float right2 = (float) childAt2.getRight();
            float f2 = this.mCurrentPositionOffset;
            left = a.b(left2, left, f2, left);
            right = a.b(right2, right, f2, right);
            if (this.mIndicatorStyle == 0 && this.mIndicatorWidthEqualTitle) {
                this.mTextPaint.setTextSize(this.mTextsize);
                float f3 = this.margin;
                this.margin = a.b(((right2 - left2) - this.mTextPaint.measureText(((TextView) childAt2.findViewById(R.id.tv_tab_title)).getText().toString())) / 2.0f, f3, this.mCurrentPositionOffset, f3);
            }
        }
        Rect rect = this.mIndicatorRect;
        int i3 = (int) left;
        rect.left = i3;
        int i4 = (int) right;
        rect.right = i4;
        if (this.mIndicatorStyle == 0 && this.mIndicatorWidthEqualTitle) {
            float f4 = this.margin;
            rect.left = (int) ((left + f4) - 1.0f);
            rect.right = (int) ((right - f4) - 1.0f);
        }
        Rect rect2 = this.mTabRect;
        rect2.left = i3;
        rect2.right = i4;
        if (this.mIndicatorWidth >= 0.0f) {
            float width = ((((float) childAt.getWidth()) - this.mIndicatorWidth) / 2.0f) + ((float) childAt.getLeft());
            int i5 = this.mCurrentTab;
            if (i5 < this.mTabCount - 1) {
                View childAt3 = this.mTabsContainer.getChildAt(i5 + 1);
                width += this.mCurrentPositionOffset * ((float) ((childAt3.getWidth() / 2) + (childAt.getWidth() / 2)));
            }
            Rect rect3 = this.mIndicatorRect;
            int i6 = (int) width;
            rect3.left = i6;
            rect3.right = (int) (((float) i6) + this.mIndicatorWidth);
        }
    }

    private void obtainAttributes(Context context, AttributeSet attributeSet) {
        float f2;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.SlidingTabLayout);
        this.markerDrawable = obtainStyledAttributes.getDrawable(R.styleable.SlidingTabLayout_tl_tab_marker);
        this.indicatorDrawable = obtainStyledAttributes.getDrawable(R.styleable.SlidingTabLayout_tl_indicator_drawable);
        this.mIndicatorStyle = obtainStyledAttributes.getInt(R.styleable.SlidingTabLayout_tl_indicator_style, 0);
        this.mIndicatorColor = obtainStyledAttributes.getColor(R.styleable.SlidingTabLayout_tl_indicator_color, 0);
        int i2 = R.styleable.SlidingTabLayout_tl_indicator_height;
        int i3 = this.mIndicatorStyle;
        if (i3 == 1) {
            f2 = 4.0f;
        } else {
            f2 = (float) (i3 == 2 ? -1 : 2);
        }
        this.mIndicatorHeight = obtainStyledAttributes.getDimension(i2, (float) dp2px(f2));
        this.mIndicatorWidth = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_indicator_width, (float) dp2px(this.mIndicatorStyle == 1 ? 10.0f : -1.0f));
        this.mIndicatorCornerRadius = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_indicator_corner_radius, (float) dp2px(this.mIndicatorStyle == 2 ? -1.0f : 0.0f));
        this.tabMargin = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_tab_margin, 0.0f);
        this.mIndicatorMarginLeft = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_indicator_margin_left, (float) dp2px(0.0f));
        float f3 = 7.0f;
        this.mIndicatorMarginTop = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_indicator_margin_top, (float) dp2px(this.mIndicatorStyle == 2 ? 7.0f : 0.0f));
        this.mIndicatorMarginRight = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_indicator_margin_right, (float) dp2px(0.0f));
        int i4 = R.styleable.SlidingTabLayout_tl_indicator_margin_bottom;
        if (this.mIndicatorStyle != 2) {
            f3 = 0.0f;
        }
        this.mIndicatorMarginBottom = obtainStyledAttributes.getDimension(i4, (float) dp2px(f3));
        this.mIndicatorGravity = obtainStyledAttributes.getInt(R.styleable.SlidingTabLayout_tl_indicator_gravity, 80);
        this.mIndicatorWidthEqualTitle = obtainStyledAttributes.getBoolean(R.styleable.SlidingTabLayout_tl_indicator_width_equal_title, false);
        this.mUnderlineColor = obtainStyledAttributes.getColor(R.styleable.SlidingTabLayout_tl_underline_color, Color.parseColor("#ffffff"));
        this.mUnderlineHeight = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_underline_height, (float) dp2px(0.0f));
        this.mUnderlineGravity = obtainStyledAttributes.getInt(R.styleable.SlidingTabLayout_tl_underline_gravity, 80);
        this.mDividerColor = obtainStyledAttributes.getColor(R.styleable.SlidingTabLayout_tl_divider_color, Color.parseColor("#ffffff"));
        this.mDividerWidth = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_divider_width, (float) dp2px(0.0f));
        this.mDividerPadding = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_divider_padding, (float) dp2px(12.0f));
        this.mTextsize = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_textsize, (float) sp2px(14.0f));
        this.mTextSelectColor = obtainStyledAttributes.getColor(R.styleable.SlidingTabLayout_tl_textSelectColor, Color.parseColor("#ffffff"));
        this.mTextUnselectColor = obtainStyledAttributes.getColor(R.styleable.SlidingTabLayout_tl_textUnselectColor, Color.parseColor("#AAffffff"));
        this.mTextBold = obtainStyledAttributes.getInt(R.styleable.SlidingTabLayout_tl_textBold, 0);
        this.selestedBold = obtainStyledAttributes.getBoolean(R.styleable.SlidingTabLayout_tl_selestedBold, false);
        this.mTextAllCaps = obtainStyledAttributes.getBoolean(R.styleable.SlidingTabLayout_tl_textAllCaps, false);
        this.mTabSpaceEqual = obtainStyledAttributes.getBoolean(R.styleable.SlidingTabLayout_tl_tab_space_equal, false);
        float dimension = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_tab_width, (float) dp2px(-1.0f));
        this.mTabWidth = dimension;
        this.mTabPadding = obtainStyledAttributes.getDimension(R.styleable.SlidingTabLayout_tl_tab_padding, (float) ((this.mTabSpaceEqual || dimension > 0.0f) ? dp2px(0.0f) : dp2px(20.0f)));
        this.isIncrease = obtainStyledAttributes.getBoolean(R.styleable.SlidingTabLayout_tl_isIncrease, false);
        obtainStyledAttributes.recycle();
        if (this.indicatorDrawable == null) {
            this.indicatorDrawable = new GradientDrawable();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void scrollToCurrentTab() {
        if (this.mTabCount > 0) {
            int width = (int) (this.mCurrentPositionOffset * ((float) this.mTabsContainer.getChildAt(this.mCurrentTab).getWidth()));
            int left = this.mTabsContainer.getChildAt(this.mCurrentTab).getLeft() + width;
            if (this.mCurrentTab > 0 || width > 0) {
                int width2 = left - ((getWidth() / 2) - getPaddingLeft());
                calcIndicatorRect();
                Rect rect = this.mTabRect;
                left = width2 + ((rect.right - rect.left) / 2);
            }
            if (left != this.mLastScrollX) {
                this.mLastScrollX = left;
                scrollTo(left, 0);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateTabSelection(int i2) {
        OnTabSelectListener onTabSelectListener;
        int i3 = 0;
        while (i3 < this.mTabCount) {
            View childAt = this.mTabsContainer.getChildAt(i3);
            boolean z = i3 == i2;
            TextView textView = (TextView) childAt.findViewById(R.id.tv_tab_title);
            ImageView imageView = (ImageView) childAt.findViewById(R.id.markerView);
            textView.setTextColor(z ? this.mTextSelectColor : this.mTextUnselectColor);
            if (this.mTextBold == 1) {
                textView.getPaint().setFakeBoldText(z);
            }
            if (z && (onTabSelectListener = this.mListener) != null) {
                onTabSelectListener.onTabSelect(i2, textView);
            }
            Drawable drawable = this.markerDrawable;
            if (drawable != null) {
                if (z) {
                    imageView.setImageDrawable(drawable);
                } else {
                    imageView.setImageDrawable(null);
                }
            }
            i3++;
        }
    }

    private void updateTabStyles() {
        int i2 = 0;
        while (i2 < this.mTabCount) {
            TextView textView = (TextView) this.mTabsContainer.getChildAt(i2).findViewById(R.id.tv_tab_title);
            textView.setTextColor(i2 == this.mCurrentTab ? this.mTextSelectColor : this.mTextUnselectColor);
            float f2 = this.mTabPadding;
            textView.setPadding((int) f2, 0, (int) f2, 0);
            if (this.mTextAllCaps) {
                textView.setText(textView.getText().toString().toUpperCase());
            }
            if (this.mTextBold == 2 || (this.selestedBold && i2 == this.mCurrentTab)) {
                textView.getPaint().setFakeBoldText(true);
            } else {
                textView.getPaint().setFakeBoldText(false);
            }
            if (this.isIncrease) {
                textView.setTextSize(0, this.mTextsize + ((float) sp2px(2.0f)));
            } else {
                textView.setTextSize(0, this.mTextsize);
            }
            i2++;
        }
    }

    public void addNewTab(String str) {
        View inflate = View.inflate(this.mContext, R.layout.layout_tab, null);
        ArrayList<String> arrayList = this.mTitles;
        if (arrayList != null) {
            arrayList.add(str);
        }
        addTab(this.mTabCount, this.mTitles.get(this.mTabCount).toString(), inflate);
        this.mTabCount = this.mTitles.size();
        updateTabStyles();
    }

    public int dp2px(float f2) {
        return (int) ((f2 * this.mContext.getResources().getDisplayMetrics().density) + 0.5f);
    }

    public int getCurrentTab() {
        return this.mCurrentTab;
    }

    public int getDividerColor() {
        return this.mDividerColor;
    }

    public float getDividerPadding() {
        return this.mDividerPadding;
    }

    public float getDividerWidth() {
        return this.mDividerWidth;
    }

    public int getIndicatorColor() {
        return this.mIndicatorColor;
    }

    public float getIndicatorCornerRadius() {
        return this.mIndicatorCornerRadius;
    }

    public float getIndicatorHeight() {
        return this.mIndicatorHeight;
    }

    public float getIndicatorMarginBottom() {
        return this.mIndicatorMarginBottom;
    }

    public float getIndicatorMarginLeft() {
        return this.mIndicatorMarginLeft;
    }

    public float getIndicatorMarginRight() {
        return this.mIndicatorMarginRight;
    }

    public float getIndicatorMarginTop() {
        return this.mIndicatorMarginTop;
    }

    public int getIndicatorStyle() {
        return this.mIndicatorStyle;
    }

    public float getIndicatorWidth() {
        return this.mIndicatorWidth;
    }

    public MsgView getMsgView(int i2) {
        int i3 = this.mTabCount;
        if (i2 >= i3) {
            i2 = i3 - 1;
        }
        return (MsgView) this.mTabsContainer.getChildAt(i2).findViewById(R.id.rtv_msg_tip);
    }

    public int getTabCount() {
        return this.mTabCount;
    }

    public float getTabPadding() {
        return this.mTabPadding;
    }

    public float getTabWidth() {
        return this.mTabWidth;
    }

    public int getTextBold() {
        return this.mTextBold;
    }

    public int getTextSelectColor() {
        return this.mTextSelectColor;
    }

    public int getTextUnselectColor() {
        return this.mTextUnselectColor;
    }

    public float getTextsize() {
        return this.mTextsize;
    }

    public TextView getTitleView(int i2) {
        return (TextView) this.mTabsContainer.getChildAt(i2).findViewById(R.id.tv_tab_title);
    }

    public int getUnderlineColor() {
        return this.mUnderlineColor;
    }

    public float getUnderlineHeight() {
        return this.mUnderlineHeight;
    }

    public void hideMsg(int i2) {
        int i3 = this.mTabCount;
        if (i2 >= i3) {
            i2 = i3 - 1;
        }
        MsgView msgView = (MsgView) this.mTabsContainer.getChildAt(i2).findViewById(R.id.rtv_msg_tip);
        if (msgView != null) {
            msgView.setVisibility(8);
        }
    }

    public boolean isTabSpaceEqual() {
        return this.mTabSpaceEqual;
    }

    public boolean isTextAllCaps() {
        return this.mTextAllCaps;
    }

    public void notifyDataSetChanged() {
        this.mTabsContainer.removeAllViews();
        this.mTabCount = this.mTitles.size();
        for (int i2 = 0; i2 < this.mTabCount; i2++) {
            addTab(i2, this.mTitles.get(i2).toString(), View.inflate(this.mContext, R.layout.layout_tab, null));
        }
        updateTabStyles();
    }

    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (!isInEditMode() && this.mTabCount > 0) {
            int height = getHeight();
            int paddingLeft = getPaddingLeft();
            float f2 = this.mDividerWidth;
            if (f2 > 0.0f) {
                this.mDividerPaint.setStrokeWidth(f2);
                this.mDividerPaint.setColor(this.mDividerColor);
                for (int i2 = 0; i2 < this.mTabCount - 1; i2++) {
                    View childAt = this.mTabsContainer.getChildAt(i2);
                    canvas.drawLine((float) (childAt.getRight() + paddingLeft), this.mDividerPadding, (float) (childAt.getRight() + paddingLeft), ((float) height) - this.mDividerPadding, this.mDividerPaint);
                }
            }
            if (this.mUnderlineHeight > 0.0f) {
                this.mRectPaint.setColor(this.mUnderlineColor);
                if (this.mUnderlineGravity == 80) {
                    float f3 = (float) height;
                    canvas.drawRect((float) paddingLeft, f3 - this.mUnderlineHeight, (float) (this.mTabsContainer.getWidth() + paddingLeft), f3, this.mRectPaint);
                } else {
                    canvas.drawRect((float) paddingLeft, 0.0f, (float) (this.mTabsContainer.getWidth() + paddingLeft), this.mUnderlineHeight, this.mRectPaint);
                }
            }
            calcIndicatorRect();
            Drawable drawable = this.indicatorDrawable;
            if (drawable instanceof GradientDrawable) {
                ((GradientDrawable) drawable).setColor(this.mIndicatorColor);
            }
            int i3 = this.mIndicatorStyle;
            if (i3 == 1) {
                if (this.mIndicatorHeight > 0.0f) {
                    this.mTrianglePaint.setColor(this.mIndicatorColor);
                    this.mTrianglePath.reset();
                    float f4 = (float) height;
                    this.mTrianglePath.moveTo((float) (this.mIndicatorRect.left + paddingLeft), f4);
                    Path path = this.mTrianglePath;
                    Rect rect = this.mIndicatorRect;
                    path.lineTo((float) ((rect.right / 2) + (rect.left / 2) + paddingLeft), f4 - this.mIndicatorHeight);
                    this.mTrianglePath.lineTo((float) (paddingLeft + this.mIndicatorRect.right), f4);
                    this.mTrianglePath.close();
                    canvas.drawPath(this.mTrianglePath, this.mTrianglePaint);
                }
            } else if (i3 == 2) {
                if (this.mIndicatorHeight < 0.0f) {
                    this.mIndicatorHeight = (((float) height) - this.mIndicatorMarginTop) - this.mIndicatorMarginBottom;
                }
                float f5 = this.mIndicatorHeight;
                if (f5 > 0.0f) {
                    float f6 = this.mIndicatorCornerRadius;
                    if (f6 < 0.0f || f6 > f5 / 2.0f) {
                        this.mIndicatorCornerRadius = f5 / 2.0f;
                    }
                    Drawable drawable2 = this.indicatorDrawable;
                    Rect rect2 = this.mIndicatorRect;
                    int i4 = ((int) this.mIndicatorMarginLeft) + paddingLeft + rect2.left;
                    float f7 = this.mIndicatorMarginTop;
                    drawable2.setBounds(i4, (int) f7, (int) (((float) (paddingLeft + rect2.right)) - this.mIndicatorMarginRight), (int) (f7 + f5));
                    Drawable drawable3 = this.indicatorDrawable;
                    if (drawable3 instanceof GradientDrawable) {
                        ((GradientDrawable) drawable3).setCornerRadius(this.mIndicatorCornerRadius);
                    }
                    this.indicatorDrawable.draw(canvas);
                }
            } else if (this.mIndicatorHeight > 0.0f) {
                Drawable drawable4 = this.indicatorDrawable;
                if (drawable4 instanceof GradientDrawable) {
                    ((GradientDrawable) drawable4).setColor(this.mIndicatorColor);
                }
                if (this.mIndicatorGravity == 80) {
                    Drawable drawable5 = this.indicatorDrawable;
                    Rect rect3 = this.mIndicatorRect;
                    float f8 = this.mIndicatorMarginBottom;
                    drawable5.setBounds(((int) this.mIndicatorMarginLeft) + paddingLeft + rect3.left, (height - ((int) this.mIndicatorHeight)) - ((int) f8), (paddingLeft + rect3.right) - ((int) this.mIndicatorMarginRight), height - ((int) f8));
                } else {
                    Drawable drawable6 = this.indicatorDrawable;
                    Rect rect4 = this.mIndicatorRect;
                    int i5 = ((int) this.mIndicatorMarginLeft) + paddingLeft + rect4.left;
                    float f9 = this.mIndicatorMarginTop;
                    drawable6.setBounds(i5, (int) f9, (paddingLeft + rect4.right) - ((int) this.mIndicatorMarginRight), ((int) this.mIndicatorHeight) + ((int) f9));
                }
                Drawable drawable7 = this.indicatorDrawable;
                if (drawable7 instanceof GradientDrawable) {
                    ((GradientDrawable) drawable7).setCornerRadius(this.mIndicatorCornerRadius);
                }
                this.indicatorDrawable.draw(canvas);
            }
        }
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof Bundle) {
            Bundle bundle = (Bundle) parcelable;
            this.mCurrentTab = bundle.getInt("mCurrentTab");
            parcelable = bundle.getParcelable("instanceState");
            if (this.mCurrentTab != 0 && this.mTabsContainer.getChildCount() > 0) {
                updateTabSelection(this.mCurrentTab);
                scrollToCurrentTab();
            }
        }
        super.onRestoreInstanceState(parcelable);
    }

    public Parcelable onSaveInstanceState() {
        Bundle bundle = new Bundle();
        bundle.putParcelable("instanceState", super.onSaveInstanceState());
        bundle.putInt("mCurrentTab", this.mCurrentTab);
        return bundle;
    }

    public void setCurrentTab(int i2) {
        this.mCurrentTab = i2;
        this.mViewPager.setCurrentItem(i2);
    }

    public void setDividerColor(int i2) {
        this.mDividerColor = i2;
        invalidate();
    }

    public void setDividerPadding(float f2) {
        this.mDividerPadding = (float) dp2px(f2);
        invalidate();
    }

    public void setDividerWidth(float f2) {
        this.mDividerWidth = (float) dp2px(f2);
        invalidate();
    }

    public void setIndicatorColor(int i2) {
        this.mIndicatorColor = i2;
        invalidate();
    }

    public void setIndicatorCornerRadius(float f2) {
        this.mIndicatorCornerRadius = (float) dp2px(f2);
        invalidate();
    }

    public void setIndicatorGravity(int i2) {
        this.mIndicatorGravity = i2;
        invalidate();
    }

    public void setIndicatorHeight(float f2) {
        this.mIndicatorHeight = (float) dp2px(f2);
        invalidate();
    }

    public void setIndicatorMargin(float f2, float f3, float f4, float f5) {
        this.mIndicatorMarginLeft = (float) dp2px(f2);
        this.mIndicatorMarginTop = (float) dp2px(f3);
        this.mIndicatorMarginRight = (float) dp2px(f4);
        this.mIndicatorMarginBottom = (float) dp2px(f5);
        invalidate();
    }

    public void setIndicatorStyle(int i2) {
        this.mIndicatorStyle = i2;
        invalidate();
    }

    public void setIndicatorWidth(float f2) {
        this.mIndicatorWidth = (float) dp2px(f2);
        invalidate();
    }

    public void setIndicatorWidthEqualTitle(boolean z) {
        this.mIndicatorWidthEqualTitle = z;
        invalidate();
    }

    public void setMsgMargin(int i2, float f2, float f3) {
        int i3 = this.mTabCount;
        if (i2 >= i3) {
            i2 = i3 - 1;
        }
        View childAt = this.mTabsContainer.getChildAt(i2);
        MsgView msgView = (MsgView) childAt.findViewById(R.id.rtv_msg_tip);
        if (msgView != null) {
            this.mTextPaint.setTextSize(this.mTextsize);
            float measureText = this.mTextPaint.measureText(((TextView) childAt.findViewById(R.id.tv_tab_title)).getText().toString());
            float descent = this.mTextPaint.descent() - this.mTextPaint.ascent();
            ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) msgView.getLayoutParams();
            float f4 = this.mTabWidth;
            marginLayoutParams.leftMargin = f4 >= 0.0f ? (int) ((measureText / 2.0f) + (f4 / 2.0f) + ((float) dp2px(f2))) : (int) (this.mTabPadding + measureText + ((float) dp2px(f2)));
            int i4 = this.mHeight;
            marginLayoutParams.topMargin = i4 > 0 ? (((int) (((float) i4) - descent)) / 2) - dp2px(f3) : 0;
            msgView.setLayoutParams(marginLayoutParams);
        }
    }

    public void setOnTabSelectListener(OnTabSelectListener onTabSelectListener) {
        this.mListener = onTabSelectListener;
    }

    public void setTabPadding(float f2) {
        this.mTabPadding = (float) dp2px(f2);
        updateTabStyles();
    }

    public void setTabSpaceEqual(boolean z) {
        this.mTabSpaceEqual = z;
        updateTabStyles();
    }

    public void setTabWidth(float f2) {
        this.mTabWidth = (float) dp2px(f2);
        updateTabStyles();
    }

    public void setTextAllCaps(boolean z) {
        this.mTextAllCaps = z;
        updateTabStyles();
    }

    public void setTextBold(int i2) {
        this.mTextBold = i2;
        updateTabStyles();
    }

    public void setTextSelectColor(int i2) {
        this.mTextSelectColor = i2;
        updateTabStyles();
    }

    public void setTextUnselectColor(int i2) {
        this.mTextUnselectColor = i2;
        updateTabStyles();
    }

    public void setTextsize(float f2) {
        this.mTextsize = (float) sp2px(f2);
        updateTabStyles();
    }

    public void setUnderlineColor(int i2) {
        this.mUnderlineColor = i2;
        invalidate();
    }

    public void setUnderlineGravity(int i2) {
        this.mUnderlineGravity = i2;
        invalidate();
    }

    public void setUnderlineHeight(float f2) {
        this.mUnderlineHeight = (float) dp2px(f2);
        invalidate();
    }

    public void setViewPager(FragmentActivity fragmentActivity, ViewPager2 viewPager2, String[] strArr, List<Fragment> list) {
        this.mTitles.clear();
        this.mTitles.addAll(Arrays.asList(strArr));
        this.mViewPager = viewPager2;
        viewPager2.setAdapter(new InnerPagerAdapter(fragmentActivity, list));
        this.mViewPager.unregisterOnPageChangeCallback(this.changeCallback);
        this.mViewPager.registerOnPageChangeCallback(this.changeCallback);
        notifyDataSetChanged();
    }

    public void showDot(int i2) {
        int i3 = this.mTabCount;
        if (i2 >= i3) {
            i2 = i3 - 1;
        }
        showMsg(i2, 0);
    }

    public void showMsg(int i2, int i3) {
        int i4 = this.mTabCount;
        if (i2 >= i4) {
            i2 = i4 - 1;
        }
        MsgView msgView = (MsgView) this.mTabsContainer.getChildAt(i2).findViewById(R.id.rtv_msg_tip);
        if (msgView != null) {
            UnreadMsgUtils.show(msgView, i3);
            if (this.mInitSetMap.get(i2) == null || !this.mInitSetMap.get(i2).booleanValue()) {
                setMsgMargin(i2, 4.0f, 2.0f);
                this.mInitSetMap.put(i2, Boolean.TRUE);
            }
        }
    }

    public int sp2px(float f2) {
        return (int) ((f2 * this.mContext.getResources().getDisplayMetrics().scaledDensity) + 0.5f);
    }

    public static class InnerPagerAdapter extends FragmentStateAdapter {
        private List<Fragment> fragments;

        public InnerPagerAdapter(FragmentActivity fragmentActivity, List<Fragment> list) {
            super(fragmentActivity);
            this.fragments = list;
        }

        @Override // androidx.viewpager2.adapter.FragmentStateAdapter
        public Fragment createFragment(int i2) {
            return this.fragments.get(i2);
        }

        @Override // androidx.recyclerview.widget.RecyclerView.Adapter
        public int getItemCount() {
            return this.fragments.size();
        }

        public InnerPagerAdapter(Fragment fragment, List<Fragment> list) {
            super(fragment);
            this.fragments = list;
        }
    }

    public SlidingTabLayout(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public SlidingTabLayout(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mTitles = new ArrayList<>();
        this.mIndicatorRect = new Rect();
        this.mTabRect = new Rect();
        this.mRectPaint = new Paint(1);
        this.mDividerPaint = new Paint(1);
        this.mTrianglePaint = new Paint(1);
        this.mTrianglePath = new Path();
        this.mIndicatorStyle = 0;
        this.mTextPaint = new Paint(1);
        this.mInitSetMap = new SparseArray<>();
        this.changeCallback = new ViewPager2.OnPageChangeCallback() {
            /* class org.dsq.library.widget.tablayout.SlidingTabLayout.AnonymousClass2 */

            @Override // androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
            public void onPageScrolled(int i2, float f2, int i3) {
                super.onPageScrolled(i2, f2, i3);
                SlidingTabLayout.this.mCurrentTab = i2;
                SlidingTabLayout.this.mCurrentPositionOffset = f2;
                SlidingTabLayout.this.scrollToCurrentTab();
                SlidingTabLayout.this.invalidate();
            }

            @Override // androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
            public void onPageSelected(int i2) {
                super.onPageSelected(i2);
                SlidingTabLayout.this.updateTabSelection(i2);
            }
        };
        setFillViewport(true);
        setWillNotDraw(false);
        setClipChildren(false);
        setClipToPadding(false);
        this.mContext = context;
        LinearLayout linearLayout = new LinearLayout(context);
        this.mTabsContainer = linearLayout;
        addView(linearLayout);
        obtainAttributes(context, attributeSet);
        String attributeValue = attributeSet.getAttributeValue("http://schemas.android.com/apk/res/android", "layout_height");
        if (!attributeValue.equals("-1") || !attributeValue.equals("-2")) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, new int[]{16842997});
            this.mHeight = obtainStyledAttributes.getDimensionPixelSize(0, -2);
            obtainStyledAttributes.recycle();
        }
    }

    public void setCurrentTab(int i2, boolean z) {
        this.mCurrentTab = i2;
        this.mViewPager.setCurrentItem(i2, z);
    }

    public void setViewPager(FragmentActivity fragmentActivity, ViewPager2 viewPager2, List<String> list, List<Fragment> list2) {
        this.mTitles.clear();
        this.mTitles.addAll(list);
        this.mViewPager = viewPager2;
        viewPager2.setAdapter(new InnerPagerAdapter(fragmentActivity, list2));
        this.mViewPager.unregisterOnPageChangeCallback(this.changeCallback);
        this.mViewPager.registerOnPageChangeCallback(this.changeCallback);
        notifyDataSetChanged();
    }

    public void setViewPager(Fragment fragment, ViewPager2 viewPager2, String[] strArr, List<Fragment> list) {
        this.mTitles.clear();
        this.mTitles.addAll(Arrays.asList(strArr));
        this.mViewPager = viewPager2;
        viewPager2.setAdapter(new InnerPagerAdapter(fragment, list));
        this.mViewPager.unregisterOnPageChangeCallback(this.changeCallback);
        this.mViewPager.registerOnPageChangeCallback(this.changeCallback);
        this.mViewPager.setOffscreenPageLimit(list.size() - 1);
        notifyDataSetChanged();
    }

    public void setViewPager(Fragment fragment, ViewPager2 viewPager2, List<String> list, List<Fragment> list2) {
        this.mTitles.clear();
        this.mTitles.addAll(list);
        this.mViewPager = viewPager2;
        viewPager2.setAdapter(new InnerPagerAdapter(fragment, list2));
        this.mViewPager.unregisterOnPageChangeCallback(this.changeCallback);
        this.mViewPager.registerOnPageChangeCallback(this.changeCallback);
        this.mViewPager.setOffscreenPageLimit(list2.size() - 1);
        notifyDataSetChanged();
    }
}
