package tv.danmaku.ijk.media.exo.demo;

import android.media.MediaCodec;
import android.os.SystemClock;
import android.util.Log;
import com.google.android.exoplayer.MediaCodecTrackRenderer;
import com.google.android.exoplayer.audio.AudioTrack;
import d.a.a.a.a;
import d.h.a.a.d0.m;
import d.h.a.a.z;
import java.io.IOException;
import java.text.NumberFormat;
import java.util.Locale;
import tv.danmaku.ijk.media.exo.demo.player.DemoPlayer;

public class EventLogger implements DemoPlayer.Listener, DemoPlayer.InfoListener, DemoPlayer.InternalErrorListener {
    private static final String TAG = "EventLogger";
    private static final NumberFormat TIME_FORMAT;
    private long[] availableRangeValuesUs;
    private long[] loadStartTimeMs = new long[4];
    private long sessionStartTimeMs;

    static {
        NumberFormat instance = NumberFormat.getInstance(Locale.US);
        TIME_FORMAT = instance;
        instance.setMinimumFractionDigits(2);
        instance.setMaximumFractionDigits(2);
    }

    private String getSessionTimeString() {
        return getTimeString(SystemClock.elapsedRealtime() - this.sessionStartTimeMs);
    }

    private String getStateString(int i2) {
        return i2 != 1 ? i2 != 2 ? i2 != 3 ? i2 != 4 ? i2 != 5 ? "?" : "E" : "R" : "B" : "P" : "I";
    }

    private String getTimeString(long j2) {
        return TIME_FORMAT.format((double) (((float) j2) / 1000.0f));
    }

    private void printInternalError(String str, Exception exc) {
        StringBuilder B = a.B("internalError [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(str);
        B.append("]");
        Log.e(TAG, B.toString(), exc);
    }

    public void endSession() {
        StringBuilder B = a.B("end [");
        B.append(getSessionTimeString());
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onAudioFormatEnabled(m mVar, int i2, long j2) {
        StringBuilder B = a.B("audioFormat [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(mVar.f9066a);
        B.append(", ");
        B.append(Integer.toString(i2));
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onAudioTrackInitializationError(AudioTrack.InitializationException initializationException) {
        printInternalError("audioTrackInitializationError", initializationException);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onAudioTrackUnderrun(int i2, long j2, long j3) {
        printInternalError("audioTrackUnderrun [" + i2 + ", " + j2 + ", " + j3 + "]", null);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onAudioTrackWriteError(AudioTrack.WriteException writeException) {
        printInternalError("audioTrackWriteError", writeException);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onAvailableRangeChanged(int i2, z zVar) {
        this.availableRangeValuesUs = zVar.a(this.availableRangeValuesUs);
        StringBuilder B = a.B("availableRange [");
        B.append(zVar.b());
        B.append(", ");
        B.append(this.availableRangeValuesUs[0]);
        B.append(", ");
        B.append(this.availableRangeValuesUs[1]);
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onBandwidthSample(int i2, long j2, long j3) {
        StringBuilder B = a.B("bandwidth [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(j2);
        B.append(", ");
        B.append(getTimeString((long) i2));
        B.append(", ");
        B.append(j3);
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onCryptoError(MediaCodec.CryptoException cryptoException) {
        printInternalError("cryptoError", cryptoException);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onDecoderInitializationError(MediaCodecTrackRenderer.DecoderInitializationException decoderInitializationException) {
        printInternalError("decoderInitializationError", decoderInitializationException);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onDecoderInitialized(String str, long j2, long j3) {
        StringBuilder B = a.B("decoderInitialized [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(str);
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onDrmSessionManagerError(Exception exc) {
        printInternalError("drmSessionManagerError", exc);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onDroppedFrames(int i2, long j2) {
        StringBuilder B = a.B("droppedFrames [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(i2);
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.Listener
    public void onError(Exception exc) {
        StringBuilder B = a.B("playerFailed [");
        B.append(getSessionTimeString());
        B.append("]");
        Log.e(TAG, B.toString(), exc);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onLoadCompleted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4, long j5, long j6) {
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onLoadError(int i2, IOException iOException) {
        printInternalError("loadError", iOException);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onLoadStarted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4) {
        this.loadStartTimeMs[i2] = SystemClock.elapsedRealtime();
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InternalErrorListener
    public void onRendererInitializationError(Exception exc) {
        printInternalError("rendererInitError", exc);
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.Listener
    public void onStateChanged(boolean z, int i2) {
        StringBuilder B = a.B("state [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(z);
        B.append(", ");
        B.append(getStateString(i2));
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.InfoListener
    public void onVideoFormatEnabled(m mVar, int i2, long j2) {
        StringBuilder B = a.B("videoFormat [");
        B.append(getSessionTimeString());
        B.append(", ");
        B.append(mVar.f9066a);
        B.append(", ");
        B.append(Integer.toString(i2));
        B.append("]");
        Log.d(TAG, B.toString());
    }

    @Override // tv.danmaku.ijk.media.exo.demo.player.DemoPlayer.Listener
    public void onVideoSizeChanged(int i2, int i3, int i4, float f2) {
        StringBuilder D = a.D("videoSizeChanged [", i2, ", ", i3, ", ");
        D.append(i4);
        D.append(", ");
        D.append(f2);
        D.append("]");
        Log.d(TAG, D.toString());
    }

    public void startSession() {
        this.sessionStartTimeMs = SystemClock.elapsedRealtime();
        Log.d(TAG, "start [0]");
    }
}
