package tv.danmaku.ijk.media.exo.demo.player;

import android.media.MediaCodec;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.util.Pair;
import android.view.Surface;
import com.google.android.exoplayer.ExoPlaybackException;
import com.google.android.exoplayer.MediaCodecTrackRenderer;
import com.google.android.exoplayer.MediaFormat;
import com.google.android.exoplayer.audio.AudioTrack;
import com.google.android.exoplayer.dash.DashChunkSource;
import com.google.android.exoplayer.extractor.ExtractorSampleSource;
import d.h.a.a.a0;
import d.h.a.a.d0.f;
import d.h.a.a.d0.m;
import d.h.a.a.f0.l;
import d.h.a.a.g;
import d.h.a.a.h0.j;
import d.h.a.a.i;
import d.h.a.a.i0.b;
import d.h.a.a.i0.c.d;
import d.h.a.a.k0.h;
import d.h.a.a.l0.c;
import d.h.a.a.o;
import d.h.a.a.t;
import d.h.a.a.z;
import java.io.IOException;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

public class DemoPlayer implements g.b, f.d, j.c, ExtractorSampleSource.b, c.a, t.d, o.a, l.b, DashChunkSource.a, h, b.a<List<d>> {
    private static final int RENDERER_BUILDING_STATE_BUILDING = 2;
    private static final int RENDERER_BUILDING_STATE_BUILT = 3;
    private static final int RENDERER_BUILDING_STATE_IDLE = 1;
    public static final int RENDERER_COUNT = 4;
    public static final int STATE_BUFFERING = 3;
    public static final int STATE_ENDED = 5;
    public static final int STATE_IDLE = 1;
    public static final int STATE_PREPARING = 2;
    public static final int STATE_READY = 4;
    public static final int TRACK_DEFAULT = 0;
    public static final int TRACK_DISABLED = -1;
    public static final int TYPE_AUDIO = 1;
    public static final int TYPE_METADATA = 3;
    public static final int TYPE_TEXT = 2;
    public static final int TYPE_VIDEO = 0;
    private boolean backgrounded;
    private c bandwidthMeter;
    private CaptionListener captionListener;
    private d.h.a.a.b codecCounters;
    private Id3MetadataListener id3MetadataListener;
    private InfoListener infoListener;
    private InternalErrorListener internalErrorListener;
    private boolean lastReportedPlayWhenReady;
    private int lastReportedPlaybackState = 1;
    private final CopyOnWriteArrayList<Listener> listeners = new CopyOnWriteArrayList<>();
    private final Handler mainHandler = new Handler();
    private final g player;
    private final d.h.a.a.m0.l playerControl;
    private final RendererBuilder rendererBuilder;
    private int rendererBuildingState = 1;
    private Surface surface;
    private m videoFormat;
    private a0 videoRenderer;
    private int videoTrackToRestore;

    public interface CaptionListener {
        void onCues(List<d.h.a.a.k0.b> list);
    }

    public interface Id3MetadataListener {
        void onId3Metadata(List<d> list);
    }

    public interface InfoListener {
        void onAudioFormatEnabled(m mVar, int i2, long j2);

        void onAvailableRangeChanged(int i2, z zVar);

        void onBandwidthSample(int i2, long j2, long j3);

        void onDecoderInitialized(String str, long j2, long j3);

        void onDroppedFrames(int i2, long j2);

        void onLoadCompleted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4, long j5, long j6);

        void onLoadStarted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4);

        void onVideoFormatEnabled(m mVar, int i2, long j2);
    }

    public interface InternalErrorListener {
        void onAudioTrackInitializationError(AudioTrack.InitializationException initializationException);

        void onAudioTrackUnderrun(int i2, long j2, long j3);

        void onAudioTrackWriteError(AudioTrack.WriteException writeException);

        void onCryptoError(MediaCodec.CryptoException cryptoException);

        void onDecoderInitializationError(MediaCodecTrackRenderer.DecoderInitializationException decoderInitializationException);

        void onDrmSessionManagerError(Exception exc);

        void onLoadError(int i2, IOException iOException);

        void onRendererInitializationError(Exception exc);
    }

    public interface Listener {
        void onError(Exception exc);

        void onStateChanged(boolean z, int i2);

        void onVideoSizeChanged(int i2, int i3, int i4, float f2);
    }

    public interface RendererBuilder {
        void buildRenderers(DemoPlayer demoPlayer);

        void cancel();
    }

    public DemoPlayer(RendererBuilder rendererBuilder2) {
        this.rendererBuilder = rendererBuilder2;
        d.h.a.a.h hVar = new d.h.a.a.h(4, 1000, 5000);
        this.player = hVar;
        hVar.f9674c.add(this);
        this.playerControl = new d.h.a.a.m0.l(hVar);
        hVar.f(2, -1);
    }

    private void maybeReportPlayerState() {
        boolean z = ((d.h.a.a.h) this.player).f9677f;
        int playbackState = getPlaybackState();
        if (this.lastReportedPlayWhenReady != z || this.lastReportedPlaybackState != playbackState) {
            Iterator<Listener> it = this.listeners.iterator();
            while (it.hasNext()) {
                it.next().onStateChanged(z, playbackState);
            }
            this.lastReportedPlayWhenReady = z;
            this.lastReportedPlaybackState = playbackState;
        }
    }

    private void pushSurface(boolean z) {
        a0 a0Var = this.videoRenderer;
        if (a0Var != null) {
            if (z) {
                g gVar = this.player;
                Surface surface2 = this.surface;
                i iVar = ((d.h.a.a.h) gVar).f9673b;
                synchronized (iVar) {
                    if (iVar.u) {
                        Log.w("ExoPlayerImplInternal", "Sent message(1) after release. Message ignored.");
                        return;
                    }
                    int i2 = iVar.y;
                    iVar.y = i2 + 1;
                    iVar.f9797d.obtainMessage(9, 1, 0, Pair.create(a0Var, surface2)).sendToTarget();
                    while (iVar.z <= i2) {
                        try {
                            iVar.wait();
                        } catch (InterruptedException unused) {
                            Thread.currentThread().interrupt();
                        }
                    }
                    return;
                }
            }
            g gVar2 = this.player;
            Surface surface3 = this.surface;
            i iVar2 = ((d.h.a.a.h) gVar2).f9673b;
            iVar2.y++;
            iVar2.f9797d.obtainMessage(9, 1, 0, Pair.create(a0Var, surface3)).sendToTarget();
        }
    }

    public void addListener(Listener listener) {
        this.listeners.add(listener);
    }

    public void blockingClearSurface() {
        this.surface = null;
        pushSurface(true);
    }

    public boolean getBackgrounded() {
        return this.backgrounded;
    }

    public c getBandwidthMeter() {
        return this.bandwidthMeter;
    }

    public int getBufferedPercentage() {
        return ((d.h.a.a.h) this.player).a();
    }

    public d.h.a.a.b getCodecCounters() {
        return this.codecCounters;
    }

    public long getCurrentPosition() {
        return ((d.h.a.a.h) this.player).b();
    }

    public long getDuration() {
        return ((d.h.a.a.h) this.player).c();
    }

    public m getFormat() {
        return this.videoFormat;
    }

    public Handler getMainHandler() {
        return this.mainHandler;
    }

    public boolean getPlayWhenReady() {
        return ((d.h.a.a.h) this.player).f9677f;
    }

    public Looper getPlaybackLooper() {
        return ((d.h.a.a.h) this.player).f9673b.f9798h.getLooper();
    }

    public int getPlaybackState() {
        int i2 = this.rendererBuildingState;
        if (i2 == 2) {
            return 2;
        }
        int i3 = ((d.h.a.a.h) this.player).f9678g;
        if (i2 == 3 && i3 == 1) {
            return 2;
        }
        return i3;
    }

    public d.h.a.a.m0.l getPlayerControl() {
        return this.playerControl;
    }

    public int getSelectedTrack(int i2) {
        return ((d.h.a.a.h) this.player).f9676e[i2];
    }

    public Surface getSurface() {
        return this.surface;
    }

    public int getTrackCount(int i2) {
        MediaFormat[][] mediaFormatArr = ((d.h.a.a.h) this.player).f9675d;
        if (mediaFormatArr[i2] != null) {
            return mediaFormatArr[i2].length;
        }
        return 0;
    }

    public MediaFormat getTrackFormat(int i2, int i3) {
        return ((d.h.a.a.h) this.player).f9675d[i2][i3];
    }

    @Override // d.h.a.a.o.a
    public void onAudioTrackInitializationError(AudioTrack.InitializationException initializationException) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onAudioTrackInitializationError(initializationException);
        }
    }

    @Override // d.h.a.a.o.a
    public void onAudioTrackUnderrun(int i2, long j2, long j3) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onAudioTrackUnderrun(i2, j2, j3);
        }
    }

    @Override // d.h.a.a.o.a
    public void onAudioTrackWriteError(AudioTrack.WriteException writeException) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onAudioTrackWriteError(writeException);
        }
    }

    @Override // com.google.android.exoplayer.dash.DashChunkSource.a
    public void onAvailableRangeChanged(int i2, z zVar) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onAvailableRangeChanged(i2, zVar);
        }
    }

    @Override // d.h.a.a.l0.c.a
    public void onBandwidthSample(int i2, long j2, long j3) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onBandwidthSample(i2, j2, j3);
        }
    }

    @Override // com.google.android.exoplayer.MediaCodecTrackRenderer.a
    public void onCryptoError(MediaCodec.CryptoException cryptoException) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onCryptoError(cryptoException);
        }
    }

    @Override // d.h.a.a.k0.h
    public void onCues(List<d.h.a.a.k0.b> list) {
        if (this.captionListener != null && getSelectedTrack(2) != -1) {
            this.captionListener.onCues(list);
        }
    }

    @Override // com.google.android.exoplayer.MediaCodecTrackRenderer.a
    public void onDecoderInitializationError(MediaCodecTrackRenderer.DecoderInitializationException decoderInitializationException) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onDecoderInitializationError(decoderInitializationException);
        }
    }

    @Override // com.google.android.exoplayer.MediaCodecTrackRenderer.a
    public void onDecoderInitialized(String str, long j2, long j3) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onDecoderInitialized(str, j2, j3);
        }
    }

    @Override // d.h.a.a.d0.a
    public void onDownstreamFormatChanged(int i2, m mVar, int i3, long j2) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            if (i2 == 0) {
                this.videoFormat = mVar;
                infoListener2.onVideoFormatEnabled(mVar, i3, j2);
            } else if (i2 == 1) {
                infoListener2.onAudioFormatEnabled(mVar, i3, j2);
            }
        }
    }

    @Override // d.h.a.a.t.d
    public void onDrawnToSurface(Surface surface2) {
    }

    @Override // d.h.a.a.f0.l.b
    public void onDrmKeysLoaded() {
    }

    @Override // d.h.a.a.f0.l.b
    public void onDrmSessionManagerError(Exception exc) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onDrmSessionManagerError(exc);
        }
    }

    @Override // d.h.a.a.t.d
    public void onDroppedFrames(int i2, long j2) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onDroppedFrames(i2, j2);
        }
    }

    @Override // d.h.a.a.d0.a
    public void onLoadCanceled(int i2, long j2) {
    }

    @Override // d.h.a.a.d0.a
    public void onLoadCompleted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4, long j5, long j6) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onLoadCompleted(i2, j2, i3, i4, mVar, j3, j4, j5, j6);
        }
    }

    @Override // d.h.a.a.d0.a, com.google.android.exoplayer.extractor.ExtractorSampleSource.b
    public void onLoadError(int i2, IOException iOException) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onLoadError(i2, iOException);
        }
    }

    @Override // d.h.a.a.d0.a
    public void onLoadStarted(int i2, long j2, int i3, int i4, m mVar, long j3, long j4) {
        InfoListener infoListener2 = this.infoListener;
        if (infoListener2 != null) {
            infoListener2.onLoadStarted(i2, j2, i3, i4, mVar, j3, j4);
        }
    }

    @Override // d.h.a.a.g.b
    public void onPlayWhenReadyCommitted() {
    }

    @Override // d.h.a.a.g.b
    public void onPlayerError(ExoPlaybackException exoPlaybackException) {
        this.rendererBuildingState = 1;
        Iterator<Listener> it = this.listeners.iterator();
        while (it.hasNext()) {
            it.next().onError(exoPlaybackException);
        }
    }

    @Override // d.h.a.a.g.b
    public void onPlayerStateChanged(boolean z, int i2) {
        maybeReportPlayerState();
    }

    public void onRenderers(a0[] a0VarArr, c cVar) {
        d.h.a.a.b bVar;
        for (int i2 = 0; i2 < 4; i2++) {
            if (a0VarArr[i2] == null) {
                a0VarArr[i2] = new d.h.a.a.f();
            }
        }
        a0 a0Var = a0VarArr[0];
        this.videoRenderer = a0Var;
        if (!(a0Var instanceof MediaCodecTrackRenderer)) {
            if (a0VarArr[1] instanceof MediaCodecTrackRenderer) {
                a0Var = a0VarArr[1];
            } else {
                bVar = null;
                this.codecCounters = bVar;
                this.bandwidthMeter = cVar;
                pushSurface(false);
                d.h.a.a.h hVar = (d.h.a.a.h) this.player;
                Arrays.fill(hVar.f9675d, (Object) null);
                hVar.f9673b.f9797d.obtainMessage(1, a0VarArr).sendToTarget();
                this.rendererBuildingState = 3;
            }
        }
        bVar = ((MediaCodecTrackRenderer) a0Var).p;
        this.codecCounters = bVar;
        this.bandwidthMeter = cVar;
        pushSurface(false);
        d.h.a.a.h hVar2 = (d.h.a.a.h) this.player;
        Arrays.fill(hVar2.f9675d, (Object) null);
        hVar2.f9673b.f9797d.obtainMessage(1, a0VarArr).sendToTarget();
        this.rendererBuildingState = 3;
    }

    public void onRenderersError(Exception exc) {
        InternalErrorListener internalErrorListener2 = this.internalErrorListener;
        if (internalErrorListener2 != null) {
            internalErrorListener2.onRendererInitializationError(exc);
        }
        Iterator<Listener> it = this.listeners.iterator();
        while (it.hasNext()) {
            it.next().onError(exc);
        }
        this.rendererBuildingState = 1;
        maybeReportPlayerState();
    }

    @Override // d.h.a.a.d0.a
    public void onUpstreamDiscarded(int i2, long j2, long j3) {
    }

    @Override // d.h.a.a.t.d
    public void onVideoSizeChanged(int i2, int i3, int i4, float f2) {
        Iterator<Listener> it = this.listeners.iterator();
        while (it.hasNext()) {
            it.next().onVideoSizeChanged(i2, i3, i4, f2);
        }
    }

    public void prepare() {
        if (this.rendererBuildingState == 3) {
            ((d.h.a.a.h) this.player).f9673b.f9797d.sendEmptyMessage(4);
        }
        this.rendererBuilder.cancel();
        this.videoFormat = null;
        this.videoRenderer = null;
        this.rendererBuildingState = 2;
        maybeReportPlayerState();
        this.rendererBuilder.buildRenderers(this);
    }

    public void release() {
        this.rendererBuilder.cancel();
        this.rendererBuildingState = 1;
        this.surface = null;
        d.h.a.a.h hVar = (d.h.a.a.h) this.player;
        i iVar = hVar.f9673b;
        synchronized (iVar) {
            if (!iVar.u) {
                iVar.f9797d.sendEmptyMessage(5);
                while (!iVar.u) {
                    try {
                        iVar.wait();
                    } catch (InterruptedException unused) {
                        Thread.currentThread().interrupt();
                    }
                }
                iVar.f9798h.quit();
            }
        }
        hVar.f9672a.removeCallbacksAndMessages(null);
    }

    public void removeListener(Listener listener) {
        this.listeners.remove(listener);
    }

    public void seekTo(long j2) {
        ((d.h.a.a.h) this.player).d(j2);
    }

    public void setBackgrounded(boolean z) {
        if (this.backgrounded != z) {
            this.backgrounded = z;
            if (z) {
                this.videoTrackToRestore = getSelectedTrack(0);
                setSelectedTrack(0, -1);
                blockingClearSurface();
                return;
            }
            setSelectedTrack(0, this.videoTrackToRestore);
        }
    }

    public void setCaptionListener(CaptionListener captionListener2) {
        this.captionListener = captionListener2;
    }

    public void setInfoListener(InfoListener infoListener2) {
        this.infoListener = infoListener2;
    }

    public void setInternalErrorListener(InternalErrorListener internalErrorListener2) {
        this.internalErrorListener = internalErrorListener2;
    }

    public void setMetadataListener(Id3MetadataListener id3MetadataListener2) {
        this.id3MetadataListener = id3MetadataListener2;
    }

    public void setPlayWhenReady(boolean z) {
        ((d.h.a.a.h) this.player).e(z);
    }

    public void setSelectedTrack(int i2, int i3) {
        CaptionListener captionListener2;
        ((d.h.a.a.h) this.player).f(i2, i3);
        if (i2 == 2 && i3 < 0 && (captionListener2 = this.captionListener) != null) {
            captionListener2.onCues(Collections.emptyList());
        }
    }

    public void setSurface(Surface surface2) {
        this.surface = surface2;
        pushSurface(false);
    }

    public void onMetadata(List<d> list) {
        if (this.id3MetadataListener != null && getSelectedTrack(3) != -1) {
            this.id3MetadataListener.onId3Metadata(list);
        }
    }
}
