package androidx.appcompat.widget;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.XmlResourceParser;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffColorFilter;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.util.TypedValue;
import android.util.Xml;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.appcompat.graphics.drawable.AnimatedStateListDrawableCompat;
import androidx.appcompat.resources.R$drawable;
import androidx.vectordrawable.graphics.drawable.AnimatedVectorDrawableCompat;
import androidx.vectordrawable.graphics.drawable.VectorDrawableCompat;
import b.b.f.o;
import b.f.g;
import b.f.h;
import java.lang.ref.WeakReference;
import java.util.Objects;
import java.util.WeakHashMap;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

public final class ResourceManagerInternal {

    /* renamed from: a  reason: collision with root package name */
    public static final PorterDuff.Mode f415a = PorterDuff.Mode.SRC_IN;

    /* renamed from: b  reason: collision with root package name */
    public static ResourceManagerInternal f416b;

    /* renamed from: c  reason: collision with root package name */
    public static final c f417c = new c(6);

    /* renamed from: d  reason: collision with root package name */
    public WeakHashMap<Context, h<ColorStateList>> f418d;

    /* renamed from: e  reason: collision with root package name */
    public g<String, InflateDelegate> f419e;

    /* renamed from: f  reason: collision with root package name */
    public h<String> f420f;

    /* renamed from: g  reason: collision with root package name */
    public final WeakHashMap<Context, b.f.d<WeakReference<Drawable.ConstantState>>> f421g = new WeakHashMap<>(0);

    /* renamed from: h  reason: collision with root package name */
    public TypedValue f422h;

    /* renamed from: i  reason: collision with root package name */
    public boolean f423i;

    /* renamed from: j  reason: collision with root package name */
    public ResourceManagerHooks f424j;

    public interface InflateDelegate {
        Drawable createFromXmlInner(Context context, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme);
    }

    public interface ResourceManagerHooks {
        Drawable createDrawableFor(ResourceManagerInternal resourceManagerInternal, Context context, int i2);

        ColorStateList getTintListForDrawableRes(Context context, int i2);

        PorterDuff.Mode getTintModeForDrawableRes(int i2);

        boolean tintDrawable(Context context, int i2, Drawable drawable);

        boolean tintDrawableUsingColorFilter(Context context, int i2, Drawable drawable);
    }

    public static class a implements InflateDelegate {
        @Override // androidx.appcompat.widget.ResourceManagerInternal.InflateDelegate
        public Drawable createFromXmlInner(Context context, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
            try {
                return AnimatedStateListDrawableCompat.g(context, context.getResources(), xmlPullParser, attributeSet, theme);
            } catch (Exception e2) {
                Log.e("AsldcInflateDelegate", "Exception while inflating <animated-selector>", e2);
                return null;
            }
        }
    }

    public static class b implements InflateDelegate {
        @Override // androidx.appcompat.widget.ResourceManagerInternal.InflateDelegate
        public Drawable createFromXmlInner(Context context, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
            try {
                Resources resources = context.getResources();
                AnimatedVectorDrawableCompat animatedVectorDrawableCompat = new AnimatedVectorDrawableCompat(context, null, null);
                animatedVectorDrawableCompat.inflate(resources, xmlPullParser, attributeSet, theme);
                return animatedVectorDrawableCompat;
            } catch (Exception e2) {
                Log.e("AvdcInflateDelegate", "Exception while inflating <animated-vector>", e2);
                return null;
            }
        }
    }

    public static class c extends b.f.e<Integer, PorterDuffColorFilter> {
        public c(int i2) {
            super(i2);
        }
    }

    public static class d implements InflateDelegate {
        @Override // androidx.appcompat.widget.ResourceManagerInternal.InflateDelegate
        public Drawable createFromXmlInner(Context context, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
            String classAttribute = attributeSet.getClassAttribute();
            if (classAttribute == null) {
                return null;
            }
            try {
                Drawable drawable = (Drawable) d.class.getClassLoader().loadClass(classAttribute).asSubclass(Drawable.class).getDeclaredConstructor(new Class[0]).newInstance(new Object[0]);
                drawable.inflate(context.getResources(), xmlPullParser, attributeSet, theme);
                return drawable;
            } catch (Exception e2) {
                Log.e("DrawableDelegate", "Exception while inflating <drawable>", e2);
                return null;
            }
        }
    }

    public static class e implements InflateDelegate {
        @Override // androidx.appcompat.widget.ResourceManagerInternal.InflateDelegate
        public Drawable createFromXmlInner(Context context, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
            try {
                return VectorDrawableCompat.a(context.getResources(), xmlPullParser, attributeSet, theme);
            } catch (Exception e2) {
                Log.e("VdcInflateDelegate", "Exception while inflating <vector>", e2);
                return null;
            }
        }
    }

    public static synchronized ResourceManagerInternal d() {
        ResourceManagerInternal resourceManagerInternal;
        synchronized (ResourceManagerInternal.class) {
            if (f416b == null) {
                ResourceManagerInternal resourceManagerInternal2 = new ResourceManagerInternal();
                f416b = resourceManagerInternal2;
                j(resourceManagerInternal2);
            }
            resourceManagerInternal = f416b;
        }
        return resourceManagerInternal;
    }

    public static synchronized PorterDuffColorFilter h(int i2, PorterDuff.Mode mode) {
        PorterDuffColorFilter porterDuffColorFilter;
        synchronized (ResourceManagerInternal.class) {
            c cVar = f417c;
            Objects.requireNonNull(cVar);
            int i3 = (i2 + 31) * 31;
            porterDuffColorFilter = (PorterDuffColorFilter) cVar.a(Integer.valueOf(mode.hashCode() + i3));
            if (porterDuffColorFilter == null) {
                porterDuffColorFilter = new PorterDuffColorFilter(i2, mode);
                Objects.requireNonNull(cVar);
                PorterDuffColorFilter porterDuffColorFilter2 = (PorterDuffColorFilter) cVar.b(Integer.valueOf(mode.hashCode() + i3), porterDuffColorFilter);
            }
        }
        return porterDuffColorFilter;
    }

    public static void j(ResourceManagerInternal resourceManagerInternal) {
        if (Build.VERSION.SDK_INT < 24) {
            resourceManagerInternal.a("vector", new e());
            resourceManagerInternal.a("animated-vector", new b());
            resourceManagerInternal.a("animated-selector", new a());
            resourceManagerInternal.a("drawable", new d());
        }
    }

    public final void a(String str, InflateDelegate inflateDelegate) {
        if (this.f419e == null) {
            this.f419e = new g<>();
        }
        this.f419e.put(str, inflateDelegate);
    }

    public final synchronized boolean b(Context context, long j2, Drawable drawable) {
        Drawable.ConstantState constantState = drawable.getConstantState();
        if (constantState == null) {
            return false;
        }
        b.f.d<WeakReference<Drawable.ConstantState>> dVar = this.f421g.get(context);
        if (dVar == null) {
            dVar = new b.f.d<>();
            this.f421g.put(context, dVar);
        }
        dVar.j(j2, new WeakReference<>(constantState));
        return true;
    }

    public final Drawable c(Context context, int i2) {
        Drawable drawable;
        if (this.f422h == null) {
            this.f422h = new TypedValue();
        }
        TypedValue typedValue = this.f422h;
        context.getResources().getValue(i2, typedValue, true);
        long j2 = (((long) typedValue.assetCookie) << 32) | ((long) typedValue.data);
        Drawable e2 = e(context, j2);
        if (e2 != null) {
            return e2;
        }
        ResourceManagerHooks resourceManagerHooks = this.f424j;
        if (resourceManagerHooks == null) {
            drawable = null;
        } else {
            drawable = resourceManagerHooks.createDrawableFor(this, context, i2);
        }
        if (drawable != null) {
            drawable.setChangingConfigurations(typedValue.changingConfigurations);
            b(context, j2, drawable);
        }
        return drawable;
    }

    public final synchronized Drawable e(Context context, long j2) {
        b.f.d<WeakReference<Drawable.ConstantState>> dVar = this.f421g.get(context);
        if (dVar == null) {
            return null;
        }
        WeakReference<Drawable.ConstantState> g2 = dVar.g(j2, null);
        if (g2 != null) {
            Drawable.ConstantState constantState = g2.get();
            if (constantState != null) {
                return constantState.newDrawable(context.getResources());
            }
            dVar.k(j2);
        }
        return null;
    }

    public synchronized Drawable f(Context context, int i2) {
        return g(context, i2, false);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0028, code lost:
        if (r0 != false) goto L_0x002a;
     */
    public synchronized Drawable g(Context context, int i2, boolean z) {
        Drawable k2;
        if (!this.f423i) {
            boolean z2 = true;
            this.f423i = true;
            Drawable f2 = f(context, R$drawable.abc_vector_test);
            if (f2 != null) {
                if (!(f2 instanceof VectorDrawableCompat)) {
                    if (!"android.graphics.drawable.VectorDrawable".equals(f2.getClass().getName())) {
                        z2 = false;
                    }
                }
            }
            this.f423i = false;
            throw new IllegalStateException("This app has been built with an incorrect configuration. Please configure your build for VectorDrawableCompat.");
        }
        k2 = k(context, i2);
        if (k2 == null) {
            k2 = c(context, i2);
        }
        if (k2 == null) {
            Object obj = b.j.b.a.f3266a;
            k2 = context.getDrawable(i2);
        }
        if (k2 != null) {
            k2 = l(context, i2, z, k2);
        }
        if (k2 != null) {
            int[] iArr = o.f2407a;
        }
        return k2;
    }

    public synchronized ColorStateList i(Context context, int i2) {
        ColorStateList colorStateList;
        h<ColorStateList> hVar;
        WeakHashMap<Context, h<ColorStateList>> weakHashMap = this.f418d;
        ColorStateList colorStateList2 = null;
        if (weakHashMap == null || (hVar = weakHashMap.get(context)) == null) {
            colorStateList = null;
        } else {
            colorStateList = hVar.e(i2, null);
        }
        if (colorStateList == null) {
            ResourceManagerHooks resourceManagerHooks = this.f424j;
            if (resourceManagerHooks != null) {
                colorStateList2 = resourceManagerHooks.getTintListForDrawableRes(context, i2);
            }
            if (colorStateList2 != null) {
                if (this.f418d == null) {
                    this.f418d = new WeakHashMap<>();
                }
                h<ColorStateList> hVar2 = this.f418d.get(context);
                if (hVar2 == null) {
                    hVar2 = new h<>();
                    this.f418d.put(context, hVar2);
                }
                hVar2.a(i2, colorStateList2);
            }
            colorStateList = colorStateList2;
        }
        return colorStateList;
    }

    /* JADX WARNING: Removed duplicated region for block: B:30:0x0079 A[Catch:{ Exception -> 0x00a7 }] */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x009f A[Catch:{ Exception -> 0x00a7 }] */
    public final Drawable k(Context context, int i2) {
        int next;
        g<String, InflateDelegate> gVar = this.f419e;
        if (gVar == null || gVar.isEmpty()) {
            return null;
        }
        h<String> hVar = this.f420f;
        if (hVar != null) {
            String e2 = hVar.e(i2, null);
            if ("appcompat_skip_skip".equals(e2) || (e2 != null && this.f419e.get(e2) == null)) {
                return null;
            }
        } else {
            this.f420f = new h<>();
        }
        if (this.f422h == null) {
            this.f422h = new TypedValue();
        }
        TypedValue typedValue = this.f422h;
        Resources resources = context.getResources();
        resources.getValue(i2, typedValue, true);
        long j2 = (((long) typedValue.assetCookie) << 32) | ((long) typedValue.data);
        Drawable e3 = e(context, j2);
        if (e3 != null) {
            return e3;
        }
        CharSequence charSequence = typedValue.string;
        if (charSequence != null && charSequence.toString().endsWith(".xml")) {
            try {
                XmlResourceParser xml = resources.getXml(i2);
                AttributeSet asAttributeSet = Xml.asAttributeSet(xml);
                while (true) {
                    next = xml.next();
                    if (next == 2 || next == 1) {
                        if (next != 2) {
                            String name = xml.getName();
                            this.f420f.a(i2, name);
                            InflateDelegate inflateDelegate = this.f419e.get(name);
                            if (inflateDelegate != null) {
                                e3 = inflateDelegate.createFromXmlInner(context, xml, asAttributeSet, context.getTheme());
                            }
                            if (e3 != null) {
                                e3.setChangingConfigurations(typedValue.changingConfigurations);
                                b(context, j2, e3);
                            }
                        } else {
                            throw new XmlPullParserException("No start tag found");
                        }
                    }
                }
                if (next != 2) {
                }
            } catch (Exception e4) {
                Log.e("ResourceManagerInternal", "Exception while inflating drawable", e4);
            }
        }
        if (e3 == null) {
            this.f420f.a(i2, "appcompat_skip_skip");
        }
        return e3;
    }

    public final Drawable l(Context context, int i2, boolean z, Drawable drawable) {
        ColorStateList i3 = i(context, i2);
        PorterDuff.Mode mode = null;
        if (i3 != null) {
            if (o.a(drawable)) {
                drawable = drawable.mutate();
            }
            Drawable L0 = AppCompatDelegateImpl.e.L0(drawable);
            L0.setTintList(i3);
            ResourceManagerHooks resourceManagerHooks = this.f424j;
            if (resourceManagerHooks != null) {
                mode = resourceManagerHooks.getTintModeForDrawableRes(i2);
            }
            if (mode == null) {
                return L0;
            }
            L0.setTintMode(mode);
            return L0;
        }
        ResourceManagerHooks resourceManagerHooks2 = this.f424j;
        if (resourceManagerHooks2 != null && resourceManagerHooks2.tintDrawable(context, i2, drawable)) {
            return drawable;
        }
        ResourceManagerHooks resourceManagerHooks3 = this.f424j;
        if ((resourceManagerHooks3 != null && resourceManagerHooks3.tintDrawableUsingColorFilter(context, i2, drawable)) || !z) {
            return drawable;
        }
        return null;
    }
}
