package androidx.camera.core;

import android.media.ImageReader;
import android.util.Size;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.core.impl.CaptureConfig;
import androidx.camera.core.impl.Config;
import androidx.camera.core.impl.ConfigProvider;
import androidx.camera.core.impl.DeferrableSurface;
import androidx.camera.core.impl.ImageAnalysisConfig;
import androidx.camera.core.impl.ImageOutputConfig;
import androidx.camera.core.impl.ImmediateSurface;
import androidx.camera.core.impl.MutableConfig;
import androidx.camera.core.impl.MutableOptionsBundle;
import androidx.camera.core.impl.OptionsBundle;
import androidx.camera.core.impl.SessionConfig;
import androidx.camera.core.impl.UseCaseConfig;
import androidx.camera.core.impl.UseCaseConfigFactory;
import androidx.camera.core.internal.TargetConfig;
import androidx.camera.core.internal.ThreadConfig;
import androidx.camera.core.internal.UseCaseEventConfig;
import androidx.core.util.Consumer;
import b.d.a.d;
import b.d.a.i1;
import b.d.a.k2;
import b.d.a.l1;
import b.d.a.q1;
import b.d.a.q2.u;
import b.d.a.v1;
import b.d.a.w1;
import b.d.a.x1;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.List;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.Executor;

public final class ImageAnalysis extends UseCase {

    /* renamed from: k  reason: collision with root package name */
    public static final Defaults f535k = new Defaults();

    /* renamed from: l  reason: collision with root package name */
    public final v1 f536l;
    public DeferrableSurface m;

    public interface Analyzer {
        void analyze(ImageProxy imageProxy);
    }

    public static final class Builder implements ImageOutputConfig.Builder<Builder>, ThreadConfig.Builder<Builder>, UseCaseConfig.Builder<ImageAnalysis, ImageAnalysisConfig, Builder> {

        /* renamed from: a  reason: collision with root package name */
        public final MutableOptionsBundle f537a;

        public Builder() {
            this(MutableOptionsBundle.b());
        }

        /* renamed from: a */
        public ImageAnalysis build() {
            if (this.f537a.retrieveOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, null) == null || this.f537a.retrieveOption(ImageOutputConfig.OPTION_TARGET_RESOLUTION, null) == null) {
                return new ImageAnalysis(getUseCaseConfig());
            }
            throw new IllegalArgumentException("Cannot use both setTargetResolution and setTargetAspectRatio on the same config.");
        }

        /* renamed from: b */
        public ImageAnalysisConfig getUseCaseConfig() {
            return new ImageAnalysisConfig(OptionsBundle.a(this.f537a));
        }

        public Builder c(Class<ImageAnalysis> cls) {
            MutableOptionsBundle mutableOptionsBundle = this.f537a;
            Config.a<Class<?>> aVar = TargetConfig.OPTION_TARGET_CLASS;
            Config.OptionPriority optionPriority = MutableOptionsBundle.f681c;
            mutableOptionsBundle.insertOption(aVar, optionPriority, cls);
            MutableOptionsBundle mutableOptionsBundle2 = this.f537a;
            Config.a<String> aVar2 = TargetConfig.OPTION_TARGET_NAME;
            if (mutableOptionsBundle2.retrieveOption(aVar2, null) == null) {
                this.f537a.insertOption(aVar2, optionPriority, cls.getCanonicalName() + "-" + UUID.randomUUID());
            }
            return this;
        }

        @Override // androidx.camera.core.ExtendableBuilder
        public MutableConfig getMutableConfig() {
            return this.f537a;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setAttachedUseCasesUpdateListener(Consumer consumer) {
            this.f537a.insertOption(UseCaseConfig.OPTION_ATTACHED_USE_CASES_UPDATE_LISTENER, MutableOptionsBundle.f681c, consumer);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.internal.ThreadConfig.Builder
        public Builder setBackgroundExecutor(Executor executor) {
            this.f537a.insertOption(ThreadConfig.OPTION_BACKGROUND_EXECUTOR, MutableOptionsBundle.f681c, executor);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setCameraSelector(q1 q1Var) {
            this.f537a.insertOption(UseCaseConfig.OPTION_CAMERA_SELECTOR, MutableOptionsBundle.f681c, q1Var);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setCaptureOptionUnpacker(CaptureConfig.OptionUnpacker optionUnpacker) {
            this.f537a.insertOption(UseCaseConfig.OPTION_CAPTURE_CONFIG_UNPACKER, MutableOptionsBundle.f681c, optionUnpacker);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setDefaultCaptureConfig(CaptureConfig captureConfig) {
            this.f537a.insertOption(UseCaseConfig.OPTION_DEFAULT_CAPTURE_CONFIG, MutableOptionsBundle.f681c, captureConfig);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setDefaultResolution(Size size) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_DEFAULT_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setDefaultSessionConfig(SessionConfig sessionConfig) {
            this.f537a.insertOption(UseCaseConfig.OPTION_DEFAULT_SESSION_CONFIG, MutableOptionsBundle.f681c, sessionConfig);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setMaxResolution(Size size) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_MAX_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setSessionOptionUnpacker(SessionConfig.OptionUnpacker optionUnpacker) {
            this.f537a.insertOption(UseCaseConfig.OPTION_SESSION_CONFIG_UNPACKER, MutableOptionsBundle.f681c, optionUnpacker);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setSupportedResolutions(List list) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_SUPPORTED_RESOLUTIONS, MutableOptionsBundle.f681c, list);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setSurfaceOccupancyPriority(int i2) {
            this.f537a.insertOption(UseCaseConfig.OPTION_SURFACE_OCCUPANCY_PRIORITY, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetAspectRatio(int i2) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        @Override // androidx.camera.core.internal.TargetConfig.Builder
        public /* bridge */ /* synthetic */ Object setTargetClass(Class cls) {
            c(cls);
            return this;
        }

        @Override // androidx.camera.core.internal.TargetConfig.Builder
        public Object setTargetName(String str) {
            this.f537a.insertOption(TargetConfig.OPTION_TARGET_NAME, MutableOptionsBundle.f681c, str);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetResolution(Size size) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_TARGET_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetRotation(int i2) {
            this.f537a.insertOption(ImageOutputConfig.OPTION_TARGET_ROTATION, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        @Override // androidx.camera.core.internal.UseCaseEventConfig.Builder
        public Object setUseCaseEventCallback(UseCase.EventCallback eventCallback) {
            this.f537a.insertOption(UseCaseEventConfig.OPTION_USE_CASE_EVENT_CALLBACK, MutableOptionsBundle.f681c, eventCallback);
            return this;
        }

        public Builder(MutableOptionsBundle mutableOptionsBundle) {
            this.f537a = mutableOptionsBundle;
            Class cls = (Class) mutableOptionsBundle.retrieveOption(TargetConfig.OPTION_TARGET_CLASS, null);
            if (cls == null || cls.equals(ImageAnalysis.class)) {
                c(ImageAnalysis.class);
                return;
            }
            throw new IllegalArgumentException("Invalid target class configuration for " + this + ": " + cls);
        }
    }

    public static final class Defaults implements ConfigProvider<ImageAnalysisConfig> {

        /* renamed from: a  reason: collision with root package name */
        public static final Size f538a;

        /* renamed from: b  reason: collision with root package name */
        public static final Size f539b;

        /* renamed from: c  reason: collision with root package name */
        public static final ImageAnalysisConfig f540c;

        static {
            Size size = new Size(640, 480);
            f538a = size;
            Size size2 = new Size(1920, 1080);
            f539b = size2;
            Builder builder = new Builder();
            MutableOptionsBundle mutableOptionsBundle = builder.f537a;
            Config.a<Size> aVar = ImageOutputConfig.OPTION_DEFAULT_RESOLUTION;
            Config.OptionPriority optionPriority = MutableOptionsBundle.f681c;
            mutableOptionsBundle.insertOption(aVar, optionPriority, size);
            builder.f537a.insertOption(ImageOutputConfig.OPTION_MAX_RESOLUTION, optionPriority, size2);
            builder.f537a.insertOption(UseCaseConfig.OPTION_SURFACE_OCCUPANCY_PRIORITY, optionPriority, 1);
            builder.f537a.insertOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, optionPriority, 0);
            f540c = builder.getUseCaseConfig();
        }

        /* Return type fixed from 'androidx.camera.core.impl.Config' to match base method */
        @Override // androidx.camera.core.impl.ConfigProvider
        public ImageAnalysisConfig getConfig() {
            return f540c;
        }
    }

    @Retention(RetentionPolicy.SOURCE)
    public @interface a {
    }

    public ImageAnalysis(ImageAnalysisConfig imageAnalysisConfig) {
        super(imageAnalysisConfig);
        if (((Integer) ((ImageAnalysisConfig) this.f611f).retrieveOption(ImageAnalysisConfig.f661a, 0)).intValue() == 1) {
            this.f536l = new w1();
        } else {
            this.f536l = new x1(imageAnalysisConfig.getBackgroundExecutor(AppCompatDelegateImpl.e.V()));
        }
    }

    @Override // androidx.camera.core.UseCase
    public UseCaseConfig<?> d(boolean z, UseCaseConfigFactory useCaseConfigFactory) {
        Config config = useCaseConfigFactory.getConfig(UseCaseConfigFactory.CaptureType.IMAGE_ANALYSIS);
        if (z) {
            Objects.requireNonNull(f535k);
            config = u.a(config, Defaults.f540c);
        }
        if (config == null) {
            return null;
        }
        return ((Builder) i(config)).getUseCaseConfig();
    }

    @Override // androidx.camera.core.UseCase
    public UseCaseConfig.Builder<?, ?, ?> i(Config config) {
        return new Builder(MutableOptionsBundle.c(config));
    }

    @Override // androidx.camera.core.UseCase
    public void p() {
        this.f536l.f2767c = true;
    }

    @Override // androidx.camera.core.UseCase
    public void r() {
        AppCompatDelegateImpl.e.k();
        DeferrableSurface deferrableSurface = this.m;
        if (deferrableSurface != null) {
            deferrableSurface.a();
            this.m = null;
        }
        v1 v1Var = this.f536l;
        v1Var.f2767c = false;
        v1Var.c();
    }

    @Override // androidx.camera.core.UseCase
    public Size t(Size size) {
        w(c(), (ImageAnalysisConfig) this.f611f, size).b();
        return size;
    }

    public String toString() {
        StringBuilder B = d.a.a.a.a.B("ImageAnalysis:");
        B.append(f());
        return B.toString();
    }

    public SessionConfig.Builder w(String str, ImageAnalysisConfig imageAnalysisConfig, Size size) {
        k2 k2Var;
        AppCompatDelegateImpl.e.k();
        Executor backgroundExecutor = imageAnalysisConfig.getBackgroundExecutor(AppCompatDelegateImpl.e.V());
        Objects.requireNonNull(backgroundExecutor);
        int intValue = ((Integer) ((ImageAnalysisConfig) this.f611f).retrieveOption(ImageAnalysisConfig.f661a, 0)).intValue() == 1 ? ((Integer) ((ImageAnalysisConfig) this.f611f).retrieveOption(ImageAnalysisConfig.f662b, 6)).intValue() : 4;
        Config.a<ImageReaderProxyProvider> aVar = ImageAnalysisConfig.f663c;
        if (((ImageReaderProxyProvider) imageAnalysisConfig.retrieveOption(aVar, null)) != null) {
            k2Var = new k2(((ImageReaderProxyProvider) imageAnalysisConfig.retrieveOption(aVar, null)).newInstance(size.getWidth(), size.getHeight(), e(), intValue, 0));
        } else {
            k2Var = new k2(new l1(ImageReader.newInstance(size.getWidth(), size.getHeight(), e(), intValue)));
        }
        CameraInternal a2 = a();
        if (a2 != null) {
            this.f536l.f2765a = g(a2);
        }
        k2Var.setOnImageAvailableListener(this.f536l, backgroundExecutor);
        SessionConfig.Builder c2 = SessionConfig.Builder.c(imageAnalysisConfig);
        DeferrableSurface deferrableSurface = this.m;
        if (deferrableSurface != null) {
            deferrableSurface.a();
        }
        ImmediateSurface immediateSurface = new ImmediateSurface(k2Var.getSurface());
        this.m = immediateSurface;
        immediateSurface.b().a(new i1(k2Var), AppCompatDelegateImpl.e.a0());
        c2.a(this.m);
        c2.f696e.add(new d(this, str, imageAnalysisConfig, size));
        return c2;
    }
}
