package androidx.camera.core;

import android.content.ContentResolver;
import android.content.ContentValues;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.RectF;
import android.net.Uri;
import android.os.Build;
import android.os.Looper;
import android.os.SystemClock;
import android.util.Rational;
import android.util.Size;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.camera.core.ForwardingImageProxy;
import androidx.camera.core.ImageSaver;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CameraCaptureResult;
import androidx.camera.core.impl.CameraControlInternal;
import androidx.camera.core.impl.CameraInfoInternal;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.core.impl.CaptureBundle;
import androidx.camera.core.impl.CaptureConfig;
import androidx.camera.core.impl.CaptureProcessor;
import androidx.camera.core.impl.CaptureStage;
import androidx.camera.core.impl.Config;
import androidx.camera.core.impl.ConfigProvider;
import androidx.camera.core.impl.DeferrableSurface;
import androidx.camera.core.impl.ImageCaptureConfig;
import androidx.camera.core.impl.ImageInputConfig;
import androidx.camera.core.impl.ImageOutputConfig;
import androidx.camera.core.impl.ImageReaderProxy;
import androidx.camera.core.impl.ImmediateSurface;
import androidx.camera.core.impl.MutableConfig;
import androidx.camera.core.impl.MutableOptionsBundle;
import androidx.camera.core.impl.OptionsBundle;
import androidx.camera.core.impl.Quirk;
import androidx.camera.core.impl.SessionConfig;
import androidx.camera.core.impl.UseCaseConfig;
import androidx.camera.core.impl.UseCaseConfigFactory;
import androidx.camera.core.impl.utils.executor.SequentialExecutor;
import androidx.camera.core.impl.utils.futures.FutureCallback;
import androidx.camera.core.internal.IoConfig;
import androidx.camera.core.internal.TargetConfig;
import androidx.camera.core.internal.UseCaseEventConfig;
import androidx.camera.core.internal.YuvToJpegProcessor;
import androidx.camera.core.internal.compat.quirk.ImageCaptureRotationOptionQuirk;
import androidx.camera.core.internal.compat.quirk.ImageCaptureWashedOutImageQuirk;
import androidx.camera.core.internal.compat.quirk.SoftwareJpegEncodingPreferredQuirk;
import androidx.core.util.Consumer;
import b.d.a.e2;
import b.d.a.f2;
import b.d.a.i1;
import b.d.a.i2;
import b.d.a.k;
import b.d.a.k2;
import b.d.a.l;
import b.d.a.l0;
import b.d.a.l2;
import b.d.a.n1;
import b.d.a.n2;
import b.d.a.o;
import b.d.a.q;
import b.d.a.q1;
import b.d.a.q2.d0.j.e;
import b.d.a.q2.m;
import b.d.a.q2.u;
import b.d.a.r1;
import b.d.a.s1;
import b.d.a.w;
import b.d.a.y;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Deque;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.CancellationException;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;

public final class ImageCapture extends UseCase {

    /* renamed from: k  reason: collision with root package name */
    public static final Defaults f541k = new Defaults();
    public SessionConfig.Builder A;
    public k2 B;
    public i2 C;
    public m D;
    public DeferrableSurface E;
    public ImageCaptureRequestProcessor F;
    public final Executor G;

    /* renamed from: l  reason: collision with root package name */
    public final CaptureCallbackChecker f542l = new CaptureCallbackChecker();
    public final ImageReaderProxy.OnImageAvailableListener m = w.f2768a;
    public final Executor n;
    public final int o;
    public final boolean p;
    public final AtomicReference<Integer> q = new AtomicReference<>(null);
    public int r = -1;
    public Rational s = null;
    public ExecutorService t;
    public CaptureConfig u;
    public CaptureBundle v;
    public int w;
    public CaptureProcessor x;
    public boolean y;
    public final boolean z;

    public static final class Builder implements UseCaseConfig.Builder<ImageCapture, ImageCaptureConfig, Builder>, ImageOutputConfig.Builder<Builder>, IoConfig.Builder<Builder> {

        /* renamed from: a  reason: collision with root package name */
        public final MutableOptionsBundle f543a;

        public Builder() {
            this(MutableOptionsBundle.b());
        }

        /* renamed from: a */
        public ImageCapture build() {
            int intValue;
            if (this.f543a.retrieveOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, null) == null || this.f543a.retrieveOption(ImageOutputConfig.OPTION_TARGET_RESOLUTION, null) == null) {
                Integer num = (Integer) this.f543a.retrieveOption(ImageCaptureConfig.f669e, null);
                boolean z = false;
                if (num != null) {
                    AppCompatDelegateImpl.e.h(this.f543a.retrieveOption(ImageCaptureConfig.f668d, null) == null, "Cannot set buffer format with CaptureProcessor defined.");
                    this.f543a.insertOption(ImageInputConfig.OPTION_INPUT_FORMAT, MutableOptionsBundle.f681c, num);
                } else if (this.f543a.retrieveOption(ImageCaptureConfig.f668d, null) != null) {
                    this.f543a.insertOption(ImageInputConfig.OPTION_INPUT_FORMAT, MutableOptionsBundle.f681c, 35);
                } else {
                    this.f543a.insertOption(ImageInputConfig.OPTION_INPUT_FORMAT, MutableOptionsBundle.f681c, 256);
                }
                ImageCapture imageCapture = new ImageCapture(getUseCaseConfig());
                Size size = (Size) this.f543a.retrieveOption(ImageOutputConfig.OPTION_TARGET_RESOLUTION, null);
                if (size != null) {
                    imageCapture.s = new Rational(size.getWidth(), size.getHeight());
                }
                if (((Integer) this.f543a.retrieveOption(ImageCaptureConfig.f670f, 2)).intValue() >= 1) {
                    z = true;
                }
                AppCompatDelegateImpl.e.h(z, "Maximum outstanding image count must be at least 1");
                AppCompatDelegateImpl.e.l((Executor) this.f543a.retrieveOption(IoConfig.OPTION_IO_EXECUTOR, AppCompatDelegateImpl.e.X()), "The IO executor can't be null");
                MutableOptionsBundle mutableOptionsBundle = this.f543a;
                Config.a<Integer> aVar = ImageCaptureConfig.f666b;
                if (!mutableOptionsBundle.containsOption(aVar) || (intValue = ((Integer) this.f543a.retrieveOption(aVar)).intValue()) == 0 || intValue == 1 || intValue == 2) {
                    return imageCapture;
                }
                throw new IllegalArgumentException(d.a.a.a.a.k("The flash mode is not allowed to set: ", intValue));
            }
            throw new IllegalArgumentException("Cannot use both setTargetResolution and setTargetAspectRatio on the same config.");
        }

        /* renamed from: b */
        public ImageCaptureConfig getUseCaseConfig() {
            return new ImageCaptureConfig(OptionsBundle.a(this.f543a));
        }

        public Builder c(int i2) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        public Builder d(Class<ImageCapture> cls) {
            this.f543a.insertOption(TargetConfig.OPTION_TARGET_CLASS, MutableOptionsBundle.f681c, cls);
            if (this.f543a.retrieveOption(TargetConfig.OPTION_TARGET_NAME, null) == null) {
                e(cls.getCanonicalName() + "-" + UUID.randomUUID());
            }
            return this;
        }

        public Builder e(String str) {
            this.f543a.insertOption(TargetConfig.OPTION_TARGET_NAME, MutableOptionsBundle.f681c, str);
            return this;
        }

        @Override // androidx.camera.core.ExtendableBuilder
        public MutableConfig getMutableConfig() {
            return this.f543a;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setAttachedUseCasesUpdateListener(Consumer consumer) {
            this.f543a.insertOption(UseCaseConfig.OPTION_ATTACHED_USE_CASES_UPDATE_LISTENER, MutableOptionsBundle.f681c, consumer);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setCameraSelector(q1 q1Var) {
            this.f543a.insertOption(UseCaseConfig.OPTION_CAMERA_SELECTOR, MutableOptionsBundle.f681c, q1Var);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setCaptureOptionUnpacker(CaptureConfig.OptionUnpacker optionUnpacker) {
            this.f543a.insertOption(UseCaseConfig.OPTION_CAPTURE_CONFIG_UNPACKER, MutableOptionsBundle.f681c, optionUnpacker);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setDefaultCaptureConfig(CaptureConfig captureConfig) {
            this.f543a.insertOption(UseCaseConfig.OPTION_DEFAULT_CAPTURE_CONFIG, MutableOptionsBundle.f681c, captureConfig);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setDefaultResolution(Size size) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_DEFAULT_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setDefaultSessionConfig(SessionConfig sessionConfig) {
            this.f543a.insertOption(UseCaseConfig.OPTION_DEFAULT_SESSION_CONFIG, MutableOptionsBundle.f681c, sessionConfig);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.internal.IoConfig.Builder
        public Builder setIoExecutor(Executor executor) {
            this.f543a.insertOption(IoConfig.OPTION_IO_EXECUTOR, MutableOptionsBundle.f681c, executor);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setMaxResolution(Size size) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_MAX_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setSessionOptionUnpacker(SessionConfig.OptionUnpacker optionUnpacker) {
            this.f543a.insertOption(UseCaseConfig.OPTION_SESSION_CONFIG_UNPACKER, MutableOptionsBundle.f681c, optionUnpacker);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setSupportedResolutions(List list) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_SUPPORTED_RESOLUTIONS, MutableOptionsBundle.f681c, list);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.UseCaseConfig.Builder
        public Builder setSurfaceOccupancyPriority(int i2) {
            this.f543a.insertOption(UseCaseConfig.OPTION_SURFACE_OCCUPANCY_PRIORITY, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetAspectRatio(int i2) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_TARGET_ASPECT_RATIO, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        @Override // androidx.camera.core.internal.TargetConfig.Builder
        public /* bridge */ /* synthetic */ Object setTargetClass(Class cls) {
            d(cls);
            return this;
        }

        @Override // androidx.camera.core.internal.TargetConfig.Builder
        public Object setTargetName(String str) {
            this.f543a.insertOption(TargetConfig.OPTION_TARGET_NAME, MutableOptionsBundle.f681c, str);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetResolution(Size size) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_TARGET_RESOLUTION, MutableOptionsBundle.f681c, size);
            return this;
        }

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // androidx.camera.core.impl.ImageOutputConfig.Builder
        public Builder setTargetRotation(int i2) {
            this.f543a.insertOption(ImageOutputConfig.OPTION_TARGET_ROTATION, MutableOptionsBundle.f681c, Integer.valueOf(i2));
            return this;
        }

        @Override // androidx.camera.core.internal.UseCaseEventConfig.Builder
        public Object setUseCaseEventCallback(UseCase.EventCallback eventCallback) {
            this.f543a.insertOption(UseCaseEventConfig.OPTION_USE_CASE_EVENT_CALLBACK, MutableOptionsBundle.f681c, eventCallback);
            return this;
        }

        public Builder(MutableOptionsBundle mutableOptionsBundle) {
            this.f543a = mutableOptionsBundle;
            Class cls = (Class) mutableOptionsBundle.retrieveOption(TargetConfig.OPTION_TARGET_CLASS, null);
            if (cls == null || cls.equals(ImageCapture.class)) {
                d(ImageCapture.class);
                return;
            }
            throw new IllegalArgumentException("Invalid target class configuration for " + this + ": " + cls);
        }
    }

    public static final class CaptureCallbackChecker extends m {

        /* renamed from: a  reason: collision with root package name */
        public final Set<CaptureResultListener> f544a = new HashSet();

        public interface CaptureResultChecker<T> {
            T check(CameraCaptureResult cameraCaptureResult);
        }

        public interface CaptureResultListener {
            boolean onCaptureResult(CameraCaptureResult cameraCaptureResult);
        }

        public <T> d.h.b.a.a.a<T> a(CaptureResultChecker<T> captureResultChecker, long j2, T t) {
            long j3 = 0;
            int i2 = (j2 > 0 ? 1 : (j2 == 0 ? 0 : -1));
            if (i2 >= 0) {
                if (i2 != 0) {
                    j3 = SystemClock.elapsedRealtime();
                }
                return AppCompatDelegateImpl.e.H(new b.d.a.h(this, captureResultChecker, j3, j2, t));
            }
            throw new IllegalArgumentException(d.a.a.a.a.o("Invalid timeout value: ", j2));
        }
    }

    public static final class CaptureFailedException extends RuntimeException {
        public CaptureFailedException(String str, Throwable th) {
            super(str, th);
        }

        public CaptureFailedException(String str) {
            super(str);
        }
    }

    public static final class Defaults implements ConfigProvider<ImageCaptureConfig> {

        /* renamed from: a  reason: collision with root package name */
        public static final ImageCaptureConfig f545a;

        static {
            Builder builder = new Builder();
            builder.f543a.insertOption(UseCaseConfig.OPTION_SURFACE_OCCUPANCY_PRIORITY, MutableOptionsBundle.f681c, 4);
            builder.c(0);
            f545a = builder.getUseCaseConfig();
        }

        /* Return type fixed from 'androidx.camera.core.impl.Config' to match base method */
        @Override // androidx.camera.core.impl.ConfigProvider
        public ImageCaptureConfig getConfig() {
            return f545a;
        }
    }

    public static class ImageCaptureRequestProcessor implements ForwardingImageProxy.OnImageCloseListener {

        /* renamed from: a  reason: collision with root package name */
        public final Deque<e> f546a = new ArrayDeque();

        /* renamed from: b  reason: collision with root package name */
        public e f547b = null;

        /* renamed from: c  reason: collision with root package name */
        public d.h.b.a.a.a<ImageProxy> f548c = null;

        /* renamed from: d  reason: collision with root package name */
        public int f549d = 0;

        /* renamed from: e  reason: collision with root package name */
        public final ImageCaptor f550e;

        /* renamed from: f  reason: collision with root package name */
        public final int f551f;

        /* renamed from: g  reason: collision with root package name */
        public final Object f552g = new Object();

        public interface ImageCaptor {
            d.h.b.a.a.a<ImageProxy> capture(e eVar);
        }

        public class a implements FutureCallback<ImageProxy> {

            /* renamed from: a  reason: collision with root package name */
            public final /* synthetic */ e f553a;

            public a(e eVar) {
                this.f553a = eVar;
            }

            @Override // androidx.camera.core.impl.utils.futures.FutureCallback
            public void onFailure(Throwable th) {
                synchronized (ImageCaptureRequestProcessor.this.f552g) {
                    if (!(th instanceof CancellationException)) {
                        this.f553a.b(ImageCapture.y(th), th != null ? th.getMessage() : "Unknown error", th);
                    }
                    ImageCaptureRequestProcessor imageCaptureRequestProcessor = ImageCaptureRequestProcessor.this;
                    imageCaptureRequestProcessor.f547b = null;
                    imageCaptureRequestProcessor.f548c = null;
                    imageCaptureRequestProcessor.a();
                }
            }

            /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
            @Override // androidx.camera.core.impl.utils.futures.FutureCallback
            public void onSuccess(ImageProxy imageProxy) {
                ImageProxy imageProxy2 = imageProxy;
                synchronized (ImageCaptureRequestProcessor.this.f552g) {
                    Objects.requireNonNull(imageProxy2);
                    n2 n2Var = new n2(imageProxy2);
                    n2Var.a(ImageCaptureRequestProcessor.this);
                    ImageCaptureRequestProcessor.this.f549d++;
                    this.f553a.a(n2Var);
                    ImageCaptureRequestProcessor imageCaptureRequestProcessor = ImageCaptureRequestProcessor.this;
                    imageCaptureRequestProcessor.f547b = null;
                    imageCaptureRequestProcessor.f548c = null;
                    imageCaptureRequestProcessor.a();
                }
            }
        }

        public ImageCaptureRequestProcessor(int i2, ImageCaptor imageCaptor) {
            this.f551f = i2;
            this.f550e = imageCaptor;
        }

        public void a() {
            synchronized (this.f552g) {
                if (this.f547b == null) {
                    if (this.f549d >= this.f551f) {
                        e2.f("ImageCapture", "Too many acquire images. Close image to be able to process next.", null);
                        return;
                    }
                    e poll = this.f546a.poll();
                    if (poll != null) {
                        this.f547b = poll;
                        d.h.b.a.a.a<ImageProxy> capture = this.f550e.capture(poll);
                        this.f548c = capture;
                        a aVar = new a(poll);
                        capture.a(new e.d(capture, aVar), AppCompatDelegateImpl.e.B());
                    }
                }
            }
        }

        @Override // androidx.camera.core.ForwardingImageProxy.OnImageCloseListener
        public void onImageClose(ImageProxy imageProxy) {
            synchronized (this.f552g) {
                this.f549d--;
                a();
            }
        }
    }

    public interface OnImageSavedCallback {
        void onError(ImageCaptureException imageCaptureException);

        void onImageSaved(i iVar);
    }

    public class a extends m {
        public a(ImageCapture imageCapture) {
        }
    }

    public class b implements ImageSaver.OnImageSavedCallback {

        /* renamed from: a  reason: collision with root package name */
        public final /* synthetic */ OnImageSavedCallback f555a;

        public b(ImageCapture imageCapture, OnImageSavedCallback onImageSavedCallback) {
            this.f555a = onImageSavedCallback;
        }

        @Override // androidx.camera.core.ImageSaver.OnImageSavedCallback
        public void onError(ImageSaver.SaveError saveError, String str, Throwable th) {
            this.f555a.onError(new ImageCaptureException(saveError.ordinal() != 0 ? 0 : 1, str, th));
        }

        @Override // androidx.camera.core.ImageSaver.OnImageSavedCallback
        public void onImageSaved(i iVar) {
            this.f555a.onImageSaved(iVar);
        }
    }

    public class c extends g {

        /* renamed from: a  reason: collision with root package name */
        public final /* synthetic */ h f556a;

        /* renamed from: b  reason: collision with root package name */
        public final /* synthetic */ Executor f557b;

        /* renamed from: c  reason: collision with root package name */
        public final /* synthetic */ ImageSaver.OnImageSavedCallback f558c;

        /* renamed from: d  reason: collision with root package name */
        public final /* synthetic */ OnImageSavedCallback f559d;

        public c(h hVar, Executor executor, ImageSaver.OnImageSavedCallback onImageSavedCallback, OnImageSavedCallback onImageSavedCallback2) {
            this.f556a = hVar;
            this.f557b = executor;
            this.f558c = onImageSavedCallback;
            this.f559d = onImageSavedCallback2;
        }
    }

    public class d implements ThreadFactory {

        /* renamed from: d  reason: collision with root package name */
        public final AtomicInteger f561d = new AtomicInteger(0);

        public d(ImageCapture imageCapture) {
        }

        public Thread newThread(Runnable runnable) {
            StringBuilder B = d.a.a.a.a.B("CameraX-image_capture_");
            B.append(this.f561d.getAndIncrement());
            return new Thread(runnable, B.toString());
        }
    }

    public static class e {

        /* renamed from: a  reason: collision with root package name */
        public final int f562a;

        /* renamed from: b  reason: collision with root package name */
        public final int f563b;

        /* renamed from: c  reason: collision with root package name */
        public final Rational f564c;

        /* renamed from: d  reason: collision with root package name */
        public final Executor f565d;

        /* renamed from: e  reason: collision with root package name */
        public final g f566e;

        /* renamed from: f  reason: collision with root package name */
        public AtomicBoolean f567f = new AtomicBoolean(false);

        /* renamed from: g  reason: collision with root package name */
        public final Rect f568g;

        public e(int i2, int i3, Rational rational, Rect rect, Executor executor, g gVar) {
            boolean z = false;
            this.f562a = i2;
            this.f563b = i3;
            if (rational != null) {
                AppCompatDelegateImpl.e.h(!rational.isZero(), "Target ratio cannot be zero");
                AppCompatDelegateImpl.e.h(rational.floatValue() > 0.0f ? true : z, "Target ratio must be positive");
            }
            this.f564c = rational;
            this.f568g = rect;
            this.f565d = executor;
            this.f566e = gVar;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:10:0x0021, code lost:
            if ((r0 != r0) != false) goto L_0x0023;
         */
        /* JADX WARNING: Removed duplicated region for block: B:16:0x0033  */
        /* JADX WARNING: Removed duplicated region for block: B:22:0x0080  */
        /* JADX WARNING: Removed duplicated region for block: B:25:0x00b6  */
        /* JADX WARNING: Removed duplicated region for block: B:26:0x013f  */
        /* JADX WARNING: Removed duplicated region for block: B:45:0x01a4  */
        public void a(ImageProxy imageProxy) {
            boolean z;
            int i2;
            Size size;
            Rect rect;
            boolean z2;
            Rect rect2;
            int i3;
            int i4;
            int i5 = 0;
            boolean z3 = true;
            if (!this.f567f.compareAndSet(false, true)) {
                ((n2) imageProxy).close();
                return;
            }
            if (((ImageCaptureRotationOptionQuirk) b.d.a.r2.f.b.a.a(ImageCaptureRotationOptionQuirk.class)) != null) {
                Config.a<Integer> aVar = CaptureConfig.f641a;
            }
            if (((ForwardingImageProxy) imageProxy).getFormat() == 256) {
                z = true;
                if (!z) {
                    try {
                        ByteBuffer buffer = ((ForwardingImageProxy) imageProxy).getPlanes()[0].getBuffer();
                        buffer.rewind();
                        byte[] bArr = new byte[buffer.capacity()];
                        buffer.get(bArr);
                        b.n.a.a aVar2 = new b.n.a.a(new ByteArrayInputStream(bArr));
                        b.d.a.q2.d0.b bVar = new b.d.a.q2.d0.b(aVar2);
                        buffer.rewind();
                        size = new Size(aVar2.m("ImageWidth", 0), aVar2.m("ImageLength", 0));
                        i2 = bVar.d();
                    } catch (IOException e2) {
                        b(1, "Unable to parse JPEG exif", e2);
                        ((n2) imageProxy).close();
                        return;
                    }
                } else {
                    ForwardingImageProxy forwardingImageProxy = (ForwardingImageProxy) imageProxy;
                    size = new Size(forwardingImageProxy.getWidth(), forwardingImageProxy.getHeight());
                    i2 = this.f562a;
                }
                ForwardingImageProxy forwardingImageProxy2 = (ForwardingImageProxy) imageProxy;
                l2 l2Var = new l2(imageProxy, size, new n1(forwardingImageProxy2.getImageInfo().getTagBundle(), forwardingImageProxy2.getImageInfo().getTimestamp(), i2));
                rect = this.f568g;
                if (rect == null) {
                    int i6 = this.f562a;
                    Matrix matrix = new Matrix();
                    matrix.setRotate((float) (i2 - i6));
                    float[] fArr = {0.0f, 0.0f, (float) size.getWidth(), 0.0f, (float) size.getWidth(), (float) size.getHeight(), 0.0f, (float) size.getHeight()};
                    matrix.mapPoints(fArr);
                    matrix.postTranslate(-Math.min(Math.min(fArr[0], fArr[2]), Math.min(fArr[4], fArr[6])), -Math.min(Math.min(fArr[1], fArr[3]), Math.min(fArr[5], fArr[7])));
                    matrix.invert(matrix);
                    RectF rectF = new RectF();
                    matrix.mapRect(rectF, new RectF(rect));
                    rectF.sort();
                    Rect rect3 = new Rect();
                    rectF.round(rect3);
                    l2Var.setCropRect(rect3);
                } else {
                    Rational rational = this.f564c;
                    if (rational != null) {
                        if (i2 % 180 != 0) {
                            rational = new Rational(this.f564c.getDenominator(), this.f564c.getNumerator());
                        }
                        Size size2 = new Size(l2Var.getWidth(), l2Var.getHeight());
                        if (rational.floatValue() > 0.0f) {
                            int width = size2.getWidth();
                            int height = size2.getHeight();
                            float numerator = (float) rational.getNumerator();
                            float denominator = (float) rational.getDenominator();
                            if (((height == Math.round((((float) width) / numerator) * denominator) && width == Math.round((((float) height) / denominator) * numerator)) ? false : true) && !rational.isNaN()) {
                                z2 = true;
                                if (z2) {
                                    if (rational.floatValue() <= 0.0f || rational.isNaN()) {
                                        z3 = false;
                                    }
                                    if (!z3) {
                                        e2.f("ImageUtil", "Invalid view ratio.", null);
                                        rect2 = null;
                                    } else {
                                        int width2 = size2.getWidth();
                                        int height2 = size2.getHeight();
                                        float f2 = (float) width2;
                                        float f3 = (float) height2;
                                        int numerator2 = rational.getNumerator();
                                        int denominator2 = rational.getDenominator();
                                        if (rational.floatValue() > f2 / f3) {
                                            i4 = Math.round((f2 / ((float) numerator2)) * ((float) denominator2));
                                            i3 = (height2 - i4) / 2;
                                        } else {
                                            int round = Math.round((f3 / ((float) denominator2)) * ((float) numerator2));
                                            i5 = (width2 - round) / 2;
                                            width2 = round;
                                            i4 = height2;
                                            i3 = 0;
                                        }
                                        rect2 = new Rect(i5, i3, width2 + i5, i4 + i3);
                                    }
                                    l2Var.setCropRect(rect2);
                                }
                            }
                        }
                        z2 = false;
                        if (z2) {
                        }
                    }
                }
                this.f565d.execute(new l(this, l2Var));
            }
            z = false;
            if (!z) {
            }
            ForwardingImageProxy forwardingImageProxy22 = (ForwardingImageProxy) imageProxy;
            l2 l2Var2 = new l2(imageProxy, size, new n1(forwardingImageProxy22.getImageInfo().getTagBundle(), forwardingImageProxy22.getImageInfo().getTimestamp(), i2));
            rect = this.f568g;
            if (rect == null) {
            }
            try {
                this.f565d.execute(new l(this, l2Var2));
            } catch (RejectedExecutionException unused) {
                e2.b("ImageCapture", "Unable to post to the supplied executor.", null);
                ((n2) imageProxy).close();
            }
        }

        public void b(int i2, String str, Throwable th) {
            if (this.f567f.compareAndSet(false, true)) {
                try {
                    this.f565d.execute(new k(this, i2, str, th));
                } catch (RejectedExecutionException unused) {
                    e2.b("ImageCapture", "Unable to post to the supplied executor.", null);
                }
            }
        }
    }

    public static final class f {

        /* renamed from: a  reason: collision with root package name */
        public boolean f569a;

        /* renamed from: b  reason: collision with root package name */
        public boolean f570b = false;
    }

    public static abstract class g {
    }

    public static final class h {

        /* renamed from: a  reason: collision with root package name */
        public final File f571a;

        /* renamed from: b  reason: collision with root package name */
        public final f f572b = new f();

        public h(File file, ContentResolver contentResolver, Uri uri, ContentValues contentValues, OutputStream outputStream, f fVar) {
            this.f571a = file;
        }
    }

    public static class i {
        public i(Uri uri) {
        }
    }

    public static final class j {

        /* renamed from: a  reason: collision with root package name */
        public CameraCaptureResult f573a = new CameraCaptureResult.EmptyCameraCaptureResult();

        /* renamed from: b  reason: collision with root package name */
        public boolean f574b = false;

        /* renamed from: c  reason: collision with root package name */
        public boolean f575c = false;

        /* renamed from: d  reason: collision with root package name */
        public boolean f576d = false;
    }

    public ImageCapture(ImageCaptureConfig imageCaptureConfig) {
        super(imageCaptureConfig);
        boolean z2 = false;
        this.y = false;
        ImageCaptureConfig imageCaptureConfig2 = (ImageCaptureConfig) this.f611f;
        Config.a<Integer> aVar = ImageCaptureConfig.f665a;
        if (imageCaptureConfig2.containsOption(aVar)) {
            this.o = ((Integer) imageCaptureConfig2.retrieveOption(aVar)).intValue();
        } else {
            this.o = 1;
        }
        Executor executor = (Executor) imageCaptureConfig2.retrieveOption(IoConfig.OPTION_IO_EXECUTOR, AppCompatDelegateImpl.e.X());
        Objects.requireNonNull(executor);
        this.n = executor;
        this.G = new SequentialExecutor(executor);
        if (this.o == 0) {
            this.p = true;
        } else {
            this.p = false;
        }
        z2 = b.d.a.r2.f.b.a.a(ImageCaptureWashedOutImageQuirk.class) != null ? true : z2;
        this.z = z2;
        if (z2) {
            e2.a("ImageCapture", "Open and close torch to replace the flash fired by flash mode.");
        }
    }

    public static int y(Throwable th) {
        if (th instanceof CameraClosedException) {
            return 3;
        }
        return th instanceof CaptureFailedException ? 2 : 0;
    }

    public final int A() {
        int i2 = this.o;
        if (i2 == 0) {
            return 100;
        }
        if (i2 == 1) {
            return 95;
        }
        throw new IllegalStateException(d.a.a.a.a.v(d.a.a.a.a.B("CaptureMode "), this.o, " is invalid"));
    }

    public void B(j jVar) {
        if (jVar.f574b) {
            CameraControlInternal b2 = b();
            jVar.f574b = false;
            b2.enableTorch(false).a(b.d.a.i.f2527d, AppCompatDelegateImpl.e.B());
        }
        if (jVar.f575c || jVar.f576d) {
            b().cancelAfAeTrigger(jVar.f575c, jVar.f576d);
            jVar.f575c = false;
            jVar.f576d = false;
        }
        synchronized (this.q) {
            Integer andSet = this.q.getAndSet(null);
            if (andSet != null) {
                if (andSet.intValue() != z()) {
                    F();
                }
            }
        }
    }

    public void C(int i2) {
        if (i2 == 0 || i2 == 1 || i2 == 2) {
            synchronized (this.q) {
                this.r = i2;
                F();
            }
            return;
        }
        throw new IllegalArgumentException(d.a.a.a.a.k("Invalid flash mode: ", i2));
    }

    public void D(int i2) {
        int h2 = h();
        if (u(i2) && this.s != null) {
            this.s = AppCompatDelegateImpl.e.Q(Math.abs(AppCompatDelegateImpl.e.H0(i2) - AppCompatDelegateImpl.e.H0(h2)), this.s);
        }
    }

    public void E(h hVar, Executor executor, OnImageSavedCallback onImageSavedCallback) {
        if (Looper.getMainLooper() != Looper.myLooper()) {
            AppCompatDelegateImpl.e.a0().execute(new q(this, hVar, executor, onImageSavedCallback));
            return;
        }
        c cVar = new c(hVar, executor, new b(this, onImageSavedCallback), onImageSavedCallback);
        ScheduledExecutorService a0 = AppCompatDelegateImpl.e.a0();
        CameraInternal a2 = a();
        if (a2 == null) {
            a0.execute(new b.d.a.m(this, cVar));
            return;
        }
        ImageCaptureRequestProcessor imageCaptureRequestProcessor = this.F;
        e eVar = new e(g(a2), A(), this.s, this.f614i, a0, cVar);
        synchronized (imageCaptureRequestProcessor.f552g) {
            imageCaptureRequestProcessor.f546a.offer(eVar);
            Locale locale = Locale.US;
            Object[] objArr = new Object[2];
            objArr[0] = Integer.valueOf(imageCaptureRequestProcessor.f547b != null ? 1 : 0);
            objArr[1] = Integer.valueOf(imageCaptureRequestProcessor.f546a.size());
            e2.a("ImageCapture", String.format(locale, "Send image capture request [current, pending] = [%d, %d]", objArr));
            imageCaptureRequestProcessor.a();
        }
    }

    public final void F() {
        synchronized (this.q) {
            if (this.q.get() == null) {
                b().setFlashMode(z());
            }
        }
    }

    @Override // androidx.camera.core.UseCase
    public UseCaseConfig<?> d(boolean z2, UseCaseConfigFactory useCaseConfigFactory) {
        Config config = useCaseConfigFactory.getConfig(UseCaseConfigFactory.CaptureType.IMAGE_CAPTURE);
        if (z2) {
            Objects.requireNonNull(f541k);
            config = u.a(config, Defaults.f545a);
        }
        if (config == null) {
            return null;
        }
        return ((Builder) i(config)).getUseCaseConfig();
    }

    @Override // androidx.camera.core.UseCase
    public UseCaseConfig.Builder<?, ?, ?> i(Config config) {
        return new Builder(MutableOptionsBundle.c(config));
    }

    @Override // androidx.camera.core.UseCase
    public void p() {
        UseCaseConfig<?> useCaseConfig = (ImageCaptureConfig) this.f611f;
        CaptureConfig.OptionUnpacker captureOptionUnpacker = useCaseConfig.getCaptureOptionUnpacker(null);
        if (captureOptionUnpacker != null) {
            CaptureConfig.a aVar = new CaptureConfig.a();
            captureOptionUnpacker.unpack(useCaseConfig, aVar);
            this.u = aVar.c();
            this.x = (CaptureProcessor) useCaseConfig.retrieveOption((Config.a<ValueT>) ImageCaptureConfig.f668d, null);
            this.w = ((Integer) useCaseConfig.retrieveOption((Config.a<ValueT>) ImageCaptureConfig.f670f, 2)).intValue();
            this.v = (CaptureBundle) useCaseConfig.retrieveOption((Config.a<ValueT>) ImageCaptureConfig.f667c, AppCompatDelegateImpl.e.F0());
            this.y = ((Boolean) useCaseConfig.retrieveOption((Config.a<ValueT>) ImageCaptureConfig.f672h, Boolean.FALSE)).booleanValue();
            this.t = Executors.newFixedThreadPool(1, new d(this));
            return;
        }
        StringBuilder B2 = d.a.a.a.a.B("Implementation is missing option unpacker for ");
        B2.append(useCaseConfig.getTargetName(useCaseConfig.toString()));
        throw new IllegalStateException(B2.toString());
    }

    @Override // androidx.camera.core.UseCase
    public void r() {
        e eVar;
        d.h.b.a.a.a<ImageProxy> aVar;
        ArrayList arrayList;
        CameraClosedException cameraClosedException = new CameraClosedException("Camera is closed.");
        ImageCaptureRequestProcessor imageCaptureRequestProcessor = this.F;
        synchronized (imageCaptureRequestProcessor.f552g) {
            eVar = imageCaptureRequestProcessor.f547b;
            imageCaptureRequestProcessor.f547b = null;
            aVar = imageCaptureRequestProcessor.f548c;
            imageCaptureRequestProcessor.f548c = null;
            arrayList = new ArrayList(imageCaptureRequestProcessor.f546a);
            imageCaptureRequestProcessor.f546a.clear();
        }
        if (!(eVar == null || aVar == null)) {
            eVar.b(y(cameraClosedException), cameraClosedException.getMessage(), cameraClosedException);
            aVar.cancel(true);
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            ((e) it.next()).b(y(cameraClosedException), cameraClosedException.getMessage(), cameraClosedException);
        }
        AppCompatDelegateImpl.e.k();
        DeferrableSurface deferrableSurface = this.E;
        this.E = null;
        this.B = null;
        this.C = null;
        if (deferrableSurface != null) {
            deferrableSurface.a();
        }
        this.y = false;
        this.t.shutdown();
    }

    @Override // androidx.camera.core.UseCase
    public UseCaseConfig<?> s(CameraInfoInternal cameraInfoInternal, UseCaseConfig.Builder<?, ?, ?> builder) {
        boolean z2;
        boolean z3;
        boolean z4 = true;
        if (builder.getUseCaseConfig().retrieveOption(ImageCaptureConfig.f668d, null) == null || Build.VERSION.SDK_INT < 29) {
            Iterator<Quirk> it = cameraInfoInternal.getCameraQuirks().f2727a.iterator();
            while (true) {
                if (it.hasNext()) {
                    if (SoftwareJpegEncodingPreferredQuirk.class.isAssignableFrom(it.next().getClass())) {
                        z3 = true;
                        break;
                    }
                } else {
                    z3 = false;
                    break;
                }
            }
            if (z3) {
                MutableConfig mutableConfig = builder.getMutableConfig();
                Config.a<Boolean> aVar = ImageCaptureConfig.f672h;
                Boolean bool = Boolean.TRUE;
                if (!((Boolean) mutableConfig.retrieveOption(aVar, bool)).booleanValue()) {
                    e2.f("ImageCapture", "Device quirk suggests software JPEG encoder, but it has been explicitly disabled.", null);
                } else {
                    e2.c("ImageCapture", "Requesting software JPEG due to device quirk.");
                    builder.getMutableConfig().insertOption(aVar, bool);
                }
            }
        } else {
            e2.c("ImageCapture", "Requesting software JPEG due to a CaptureProcessor is set.");
            builder.getMutableConfig().insertOption(ImageCaptureConfig.f672h, Boolean.TRUE);
        }
        MutableConfig mutableConfig2 = builder.getMutableConfig();
        Config.a<Boolean> aVar2 = ImageCaptureConfig.f672h;
        Boolean bool2 = Boolean.FALSE;
        if (((Boolean) mutableConfig2.retrieveOption(aVar2, bool2)).booleanValue()) {
            int i2 = Build.VERSION.SDK_INT;
            if (i2 < 26) {
                e2.f("ImageCapture", "Software JPEG only supported on API 26+, but current API level is " + i2, null);
                z2 = false;
            } else {
                z2 = true;
            }
            Integer num = (Integer) mutableConfig2.retrieveOption(ImageCaptureConfig.f669e, null);
            if (!(num == null || num.intValue() == 256)) {
                e2.f("ImageCapture", "Software JPEG cannot be used with non-JPEG output buffer format.", null);
                z2 = false;
            }
            if (!z2) {
                e2.f("ImageCapture", "Unable to support software JPEG. Disabling.", null);
                mutableConfig2.insertOption(aVar2, bool2);
            }
        } else {
            z2 = false;
        }
        Integer num2 = (Integer) builder.getMutableConfig().retrieveOption(ImageCaptureConfig.f669e, null);
        int i3 = 35;
        if (num2 != null) {
            AppCompatDelegateImpl.e.h(builder.getMutableConfig().retrieveOption(ImageCaptureConfig.f668d, null) == null, "Cannot set buffer format with CaptureProcessor defined.");
            MutableConfig mutableConfig3 = builder.getMutableConfig();
            Config.a<Integer> aVar3 = ImageInputConfig.OPTION_INPUT_FORMAT;
            if (!z2) {
                i3 = num2.intValue();
            }
            mutableConfig3.insertOption(aVar3, Integer.valueOf(i3));
        } else if (builder.getMutableConfig().retrieveOption(ImageCaptureConfig.f668d, null) != null || z2) {
            builder.getMutableConfig().insertOption(ImageInputConfig.OPTION_INPUT_FORMAT, 35);
        } else {
            builder.getMutableConfig().insertOption(ImageInputConfig.OPTION_INPUT_FORMAT, 256);
        }
        if (((Integer) builder.getMutableConfig().retrieveOption(ImageCaptureConfig.f670f, 2)).intValue() < 1) {
            z4 = false;
        }
        AppCompatDelegateImpl.e.h(z4, "Maximum outstanding image count must be at least 1");
        return builder.getUseCaseConfig();
    }

    @Override // androidx.camera.core.UseCase
    public Size t(Size size) {
        SessionConfig.Builder w2 = w(c(), (ImageCaptureConfig) this.f611f, size);
        this.A = w2;
        w2.b();
        l();
        return size;
    }

    public String toString() {
        StringBuilder B2 = d.a.a.a.a.B("ImageCapture:");
        B2.append(f());
        return B2.toString();
    }

    public SessionConfig.Builder w(String str, ImageCaptureConfig imageCaptureConfig, Size size) {
        int i2;
        CaptureProcessor captureProcessor;
        YuvToJpegProcessor yuvToJpegProcessor;
        s1 s1Var;
        m mVar;
        d.h.b.a.a.a aVar;
        s1 s1Var2;
        YuvToJpegProcessor yuvToJpegProcessor2;
        AppCompatDelegateImpl.e.k();
        SessionConfig.Builder c2 = SessionConfig.Builder.c(imageCaptureConfig);
        c2.f693b.a(this.f542l);
        Config.a<ImageReaderProxyProvider> aVar2 = ImageCaptureConfig.f671g;
        if (((ImageReaderProxyProvider) imageCaptureConfig.retrieveOption(aVar2, null)) != null) {
            this.B = new k2(((ImageReaderProxyProvider) imageCaptureConfig.retrieveOption(aVar2, null)).newInstance(size.getWidth(), size.getHeight(), e(), 2, 0));
            this.D = new a(this);
        } else {
            CaptureProcessor captureProcessor2 = this.x;
            if (captureProcessor2 != null || this.y) {
                int e2 = e();
                int e3 = e();
                if (!this.y) {
                    captureProcessor = captureProcessor2;
                    s1Var = null;
                    i2 = e3;
                    yuvToJpegProcessor = null;
                } else if (Build.VERSION.SDK_INT >= 26) {
                    e2.c("ImageCapture", "Using software JPEG encoder.");
                    if (this.x != null) {
                        YuvToJpegProcessor yuvToJpegProcessor3 = new YuvToJpegProcessor(A(), this.w);
                        s1Var2 = new s1(this.x, this.w, yuvToJpegProcessor3, this.t);
                        yuvToJpegProcessor = yuvToJpegProcessor3;
                        yuvToJpegProcessor2 = s1Var2;
                    } else {
                        yuvToJpegProcessor2 = new YuvToJpegProcessor(A(), this.w);
                        yuvToJpegProcessor = yuvToJpegProcessor2;
                        s1Var2 = null;
                    }
                    captureProcessor = yuvToJpegProcessor2;
                    s1Var = s1Var2;
                    i2 = 256;
                } else {
                    throw new IllegalStateException("Software JPEG only supported on API 26+");
                }
                i2 i2Var = new i2(size.getWidth(), size.getHeight(), e2, this.w, this.t, x(AppCompatDelegateImpl.e.F0()), captureProcessor, i2);
                this.C = i2Var;
                synchronized (i2Var.f2533a) {
                    mVar = i2Var.f2539g.f2504b;
                }
                this.D = mVar;
                this.B = new k2(this.C);
                if (yuvToJpegProcessor != null) {
                    i2 i2Var2 = this.C;
                    synchronized (i2Var2.f2533a) {
                        if (!i2Var2.f2537e || i2Var2.f2538f) {
                            if (i2Var2.f2544l == null) {
                                i2Var2.f2544l = AppCompatDelegateImpl.e.H(new l0(i2Var2));
                            }
                            aVar = b.d.a.q2.d0.j.e.e(i2Var2.f2544l);
                        } else {
                            aVar = b.d.a.q2.d0.j.e.d(null);
                        }
                    }
                    aVar.a(new y(yuvToJpegProcessor, s1Var), AppCompatDelegateImpl.e.B());
                }
            } else {
                f2 f2Var = new f2(size.getWidth(), size.getHeight(), e(), 2);
                this.D = f2Var.f2504b;
                this.B = new k2(f2Var);
            }
        }
        this.F = new ImageCaptureRequestProcessor(2, new b.d.a.g(this));
        this.B.setOnImageAvailableListener(this.m, AppCompatDelegateImpl.e.a0());
        k2 k2Var = this.B;
        DeferrableSurface deferrableSurface = this.E;
        if (deferrableSurface != null) {
            deferrableSurface.a();
        }
        ImmediateSurface immediateSurface = new ImmediateSurface(this.B.getSurface());
        this.E = immediateSurface;
        d.h.b.a.a.a<Void> b2 = immediateSurface.b();
        Objects.requireNonNull(k2Var);
        b2.a(new i1(k2Var), AppCompatDelegateImpl.e.a0());
        c2.f692a.add(this.E);
        c2.f696e.add(new o(this, str, imageCaptureConfig, size));
        return c2;
    }

    public final CaptureBundle x(CaptureBundle captureBundle) {
        List<CaptureStage> captureStages = this.v.getCaptureStages();
        return (captureStages == null || captureStages.isEmpty()) ? captureBundle : new r1(captureStages);
    }

    public int z() {
        int i2;
        synchronized (this.q) {
            i2 = this.r;
            if (i2 == -1) {
                i2 = ((Integer) ((ImageCaptureConfig) this.f611f).retrieveOption(ImageCaptureConfig.f666b, 2)).intValue();
            }
        }
        return i2;
    }
}
