package androidx.camera.core.impl.utils;

import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.core.util.Supplier;
import java.util.Objects;

public final class Absent<T> extends Optional<T> {
    public static final Absent<Object> sInstance = new Absent<>();
    private static final long serialVersionUID = 0;

    private Absent() {
    }

    private Object readResolve() {
        return sInstance;
    }

    public static <T> Optional<T> withType() {
        return sInstance;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public boolean equals(Object obj) {
        return obj == this;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public T get() {
        throw new IllegalStateException("Optional.get() cannot be called on an absent value");
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public int hashCode() {
        return 2040732332;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public boolean isPresent() {
        return false;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public T or(T t) {
        AppCompatDelegateImpl.e.l(t, "use Optional.orNull() instead of Optional.or(null)");
        return t;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public T orNull() {
        return null;
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public String toString() {
        return "Optional.absent()";
    }

    @Override // androidx.camera.core.impl.utils.Optional
    public T or(Supplier<? extends T> supplier) {
        T t = (T) supplier.get();
        AppCompatDelegateImpl.e.l(t, "use Optional.orNull() instead of a Supplier that returns null");
        return t;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: androidx.camera.core.impl.utils.Optional<? extends T> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // androidx.camera.core.impl.utils.Optional
    public Optional<T> or(Optional<? extends T> optional) {
        Objects.requireNonNull(optional);
        return optional;
    }
}
