package androidx.camera.core.internal;

import android.graphics.Rect;
import android.util.Rational;
import android.util.Size;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraControl;
import androidx.camera.core.CameraFilter;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CameraConfig;
import androidx.camera.core.impl.CameraControlInternal;
import androidx.camera.core.impl.CameraDeviceSurfaceManager;
import androidx.camera.core.impl.CameraInfoInternal;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.core.impl.Config;
import androidx.camera.core.impl.UseCaseConfig;
import androidx.camera.core.impl.UseCaseConfigFactory;
import b.d.a.e2;
import b.d.a.p2;
import b.d.a.q1;
import b.d.a.q2.p;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public final class CameraUseCaseAdapter implements Camera {

    /* renamed from: d  reason: collision with root package name */
    public CameraInternal f733d;

    /* renamed from: h  reason: collision with root package name */
    public final LinkedHashSet<CameraInternal> f734h;

    /* renamed from: j  reason: collision with root package name */
    public final CameraDeviceSurfaceManager f735j;

    /* renamed from: k  reason: collision with root package name */
    public final UseCaseConfigFactory f736k;

    /* renamed from: l  reason: collision with root package name */
    public final List<UseCase> f737l;
    public p2 m;
    public CameraConfig n;
    public final Object o;
    public boolean p;
    public Config q;

    public static final class CameraException extends Exception {
        public CameraException() {
        }

        public CameraException(String str) {
            super(str);
        }

        public CameraException(Throwable th) {
            super(th);
        }
    }

    public static final class a {

        /* renamed from: a  reason: collision with root package name */
        public final List<String> f738a = new ArrayList();

        public a(LinkedHashSet<CameraInternal> linkedHashSet) {
            Iterator<CameraInternal> it = linkedHashSet.iterator();
            while (it.hasNext()) {
                this.f738a.add(it.next().getCameraInfoInternal().getCameraId());
            }
        }

        public boolean equals(Object obj) {
            if (obj instanceof a) {
                return this.f738a.equals(((a) obj).f738a);
            }
            return false;
        }

        public int hashCode() {
            return this.f738a.hashCode() * 53;
        }
    }

    public static class b {

        /* renamed from: a  reason: collision with root package name */
        public UseCaseConfig<?> f739a;

        /* renamed from: b  reason: collision with root package name */
        public UseCaseConfig<?> f740b;

        public b(UseCaseConfig<?> useCaseConfig, UseCaseConfig<?> useCaseConfig2) {
            this.f739a = useCaseConfig;
            this.f740b = useCaseConfig2;
        }
    }

    public void a(Collection<UseCase> collection) {
        synchronized (this.o) {
            ArrayList arrayList = new ArrayList();
            for (UseCase useCase : collection) {
                if (this.f737l.contains(useCase)) {
                    e2.a("CameraUseCaseAdapter", "Attempting to attach already attached UseCase");
                } else {
                    arrayList.add(useCase);
                }
            }
            Map<UseCase, b> e2 = e(arrayList, this.n.getUseCaseConfigFactory(), this.f736k);
            try {
                Map<UseCase, Size> c2 = c(this.f733d.getCameraInfoInternal(), arrayList, this.f737l, e2);
                i(c2, collection);
                Iterator it = arrayList.iterator();
                while (it.hasNext()) {
                    UseCase useCase2 = (UseCase) it.next();
                    b bVar = (b) ((HashMap) e2).get(useCase2);
                    useCase2.o(this.f733d, bVar.f739a, bVar.f740b);
                    Size size = (Size) ((HashMap) c2).get(useCase2);
                    Objects.requireNonNull(size);
                    useCase2.f612g = useCase2.t(size);
                }
                this.f737l.addAll(arrayList);
                if (this.p) {
                    g(this.f737l);
                    this.f733d.attachUseCases(arrayList);
                }
                Iterator it2 = arrayList.iterator();
                while (it2.hasNext()) {
                    ((UseCase) it2.next()).n();
                }
            } catch (IllegalArgumentException e3) {
                throw new CameraException(e3.getMessage());
            }
        }
    }

    public void b() {
        synchronized (this.o) {
            if (!this.p) {
                this.f733d.attachUseCases(this.f737l);
                g(this.f737l);
                synchronized (this.o) {
                    if (this.q != null) {
                        this.f733d.getCameraControlInternal().addInteropConfig(this.q);
                    }
                }
                for (UseCase useCase : this.f737l) {
                    useCase.n();
                }
                this.p = true;
            }
        }
    }

    public final Map<UseCase, Size> c(CameraInfoInternal cameraInfoInternal, List<UseCase> list, List<UseCase> list2, Map<UseCase, b> map) {
        ArrayList arrayList = new ArrayList();
        String cameraId = cameraInfoInternal.getCameraId();
        HashMap hashMap = new HashMap();
        for (UseCase useCase : list2) {
            arrayList.add(this.f735j.transformSurfaceConfig(cameraId, useCase.e(), useCase.f612g));
            hashMap.put(useCase, useCase.f612g);
        }
        if (!list.isEmpty()) {
            HashMap hashMap2 = new HashMap();
            for (UseCase useCase2 : list) {
                b bVar = map.get(useCase2);
                hashMap2.put(useCase2.k(cameraInfoInternal, bVar.f739a, bVar.f740b), useCase2);
            }
            Map<UseCaseConfig<?>, Size> suggestedResolutions = this.f735j.getSuggestedResolutions(cameraId, arrayList, new ArrayList(hashMap2.keySet()));
            for (Map.Entry entry : hashMap2.entrySet()) {
                hashMap.put((UseCase) entry.getValue(), suggestedResolutions.get(entry.getKey()));
            }
        }
        return hashMap;
    }

    public void d() {
        synchronized (this.o) {
            if (this.p) {
                this.f733d.detachUseCases(new ArrayList(this.f737l));
                synchronized (this.o) {
                    CameraControlInternal cameraControlInternal = this.f733d.getCameraControlInternal();
                    this.q = cameraControlInternal.getInteropConfig();
                    cameraControlInternal.clearInteropConfig();
                }
                this.p = false;
            }
        }
    }

    public final Map<UseCase, b> e(List<UseCase> list, UseCaseConfigFactory useCaseConfigFactory, UseCaseConfigFactory useCaseConfigFactory2) {
        HashMap hashMap = new HashMap();
        for (UseCase useCase : list) {
            hashMap.put(useCase, new b(useCase.d(false, useCaseConfigFactory), useCase.d(true, useCaseConfigFactory2)));
        }
        return hashMap;
    }

    public List<UseCase> f() {
        ArrayList arrayList;
        synchronized (this.o) {
            arrayList = new ArrayList(this.f737l);
        }
        return arrayList;
    }

    public final void g(List<UseCase> list) {
        AppCompatDelegateImpl.e.a0().execute(new b.d.a.r2.a(list));
    }

    @Override // androidx.camera.core.Camera
    public CameraControl getCameraControl() {
        return this.f733d.getCameraControlInternal();
    }

    @Override // androidx.camera.core.Camera
    public CameraInfo getCameraInfo() {
        return this.f733d.getCameraInfoInternal();
    }

    @Override // androidx.camera.core.Camera
    public LinkedHashSet<CameraInternal> getCameraInternals() {
        return this.f734h;
    }

    @Override // androidx.camera.core.Camera
    public CameraConfig getExtendedConfig() {
        CameraConfig cameraConfig;
        synchronized (this.o) {
            cameraConfig = this.n;
        }
        return cameraConfig;
    }

    public void h(Collection<UseCase> collection) {
        synchronized (this.o) {
            this.f733d.detachUseCases(collection);
            for (UseCase useCase : collection) {
                if (this.f737l.contains(useCase)) {
                    useCase.q(this.f733d);
                } else {
                    e2.b("CameraUseCaseAdapter", "Attempting to detach non-attached UseCase: " + useCase, null);
                }
            }
            this.f737l.removeAll(collection);
        }
    }

    public final void i(Map<UseCase, Size> map, Collection<UseCase> collection) {
        synchronized (this.o) {
            if (this.m != null) {
                boolean z = this.f733d.getCameraInfoInternal().getLensFacing().intValue() == 0;
                Rect sensorRect = this.f733d.getCameraControlInternal().getSensorRect();
                Rational rational = this.m.f2616b;
                int sensorRotationDegrees = this.f733d.getCameraInfoInternal().getSensorRotationDegrees(this.m.f2617c);
                p2 p2Var = this.m;
                Map<UseCase, Rect> e2 = AppCompatDelegateImpl.e.e(sensorRect, z, rational, sensorRotationDegrees, p2Var.f2615a, p2Var.f2618d, map);
                for (UseCase useCase : collection) {
                    Rect rect = (Rect) ((HashMap) e2).get(useCase);
                    Objects.requireNonNull(rect);
                    useCase.v(rect);
                }
            }
        }
    }

    @Override // androidx.camera.core.Camera
    public void setExtendedConfig(CameraConfig cameraConfig) {
        synchronized (this.o) {
            if (cameraConfig == null) {
                cameraConfig = p.f2723a;
            }
            CameraFilter cameraFilter = cameraConfig.getCameraFilter();
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            linkedHashSet.add(cameraFilter);
            CameraInternal c2 = new q1(linkedHashSet).c(this.f734h);
            Map<UseCase, b> e2 = e(this.f737l, cameraConfig.getUseCaseConfigFactory(), this.f736k);
            try {
                Map<UseCase, Size> c3 = c(c2.getCameraInfoInternal(), this.f737l, Collections.emptyList(), e2);
                i(c3, this.f737l);
                if (this.p) {
                    this.f733d.detachUseCases(this.f737l);
                }
                for (UseCase useCase : this.f737l) {
                    useCase.q(this.f733d);
                }
                for (UseCase useCase2 : this.f737l) {
                    b bVar = (b) ((HashMap) e2).get(useCase2);
                    useCase2.o(c2, bVar.f739a, bVar.f740b);
                    Size size = (Size) ((HashMap) c3).get(useCase2);
                    Objects.requireNonNull(size);
                    useCase2.f612g = useCase2.t(size);
                }
                if (this.p) {
                    g(this.f737l);
                    c2.attachUseCases(this.f737l);
                }
                for (UseCase useCase3 : this.f737l) {
                    useCase3.n();
                }
                this.f733d = c2;
                this.n = cameraConfig;
            } catch (IllegalArgumentException e3) {
                throw new CameraException(e3.getMessage());
            }
        }
    }
}
