package androidx.camera.lifecycle;

import android.util.Size;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraControl;
import androidx.camera.core.CameraFilter;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CameraConfig;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.core.internal.CameraUseCaseAdapter;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import b.d.a.q1;
import b.d.a.q2.p;
import b.q.g;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public final class LifecycleCamera implements LifecycleObserver, Camera {

    /* renamed from: d  reason: collision with root package name */
    public final Object f752d;

    /* renamed from: h  reason: collision with root package name */
    public final LifecycleOwner f753h;

    /* renamed from: j  reason: collision with root package name */
    public final CameraUseCaseAdapter f754j;

    /* renamed from: k  reason: collision with root package name */
    public boolean f755k;

    public LifecycleOwner a() {
        LifecycleOwner lifecycleOwner;
        synchronized (this.f752d) {
            lifecycleOwner = this.f753h;
        }
        return lifecycleOwner;
    }

    public List<UseCase> b() {
        List<UseCase> unmodifiableList;
        synchronized (this.f752d) {
            unmodifiableList = Collections.unmodifiableList(this.f754j.f());
        }
        return unmodifiableList;
    }

    public boolean c(UseCase useCase) {
        boolean contains;
        synchronized (this.f752d) {
            contains = ((ArrayList) this.f754j.f()).contains(useCase);
        }
        return contains;
    }

    public void d() {
        synchronized (this.f752d) {
            if (!this.f755k) {
                onStop(this.f753h);
                this.f755k = true;
            }
        }
    }

    public void e() {
        synchronized (this.f752d) {
            if (this.f755k) {
                this.f755k = false;
                if (((LifecycleRegistry) this.f753h.getLifecycle()).f1606b.isAtLeast(Lifecycle.State.STARTED)) {
                    onStart(this.f753h);
                }
            }
        }
    }

    @Override // androidx.camera.core.Camera
    public CameraControl getCameraControl() {
        return this.f754j.getCameraControl();
    }

    @Override // androidx.camera.core.Camera
    public CameraInfo getCameraInfo() {
        return this.f754j.getCameraInfo();
    }

    @Override // androidx.camera.core.Camera
    public LinkedHashSet<CameraInternal> getCameraInternals() {
        return this.f754j.f734h;
    }

    @Override // androidx.camera.core.Camera
    public CameraConfig getExtendedConfig() {
        CameraConfig cameraConfig;
        CameraUseCaseAdapter cameraUseCaseAdapter = this.f754j;
        synchronized (cameraUseCaseAdapter.o) {
            cameraConfig = cameraUseCaseAdapter.n;
        }
        return cameraConfig;
    }

    @g(Lifecycle.Event.ON_DESTROY)
    public void onDestroy(LifecycleOwner lifecycleOwner) {
        synchronized (this.f752d) {
            CameraUseCaseAdapter cameraUseCaseAdapter = this.f754j;
            cameraUseCaseAdapter.h(cameraUseCaseAdapter.f());
        }
    }

    @g(Lifecycle.Event.ON_START)
    public void onStart(LifecycleOwner lifecycleOwner) {
        synchronized (this.f752d) {
            if (!this.f755k) {
                this.f754j.b();
            }
        }
    }

    @g(Lifecycle.Event.ON_STOP)
    public void onStop(LifecycleOwner lifecycleOwner) {
        synchronized (this.f752d) {
            if (!this.f755k) {
                this.f754j.d();
            }
        }
    }

    @Override // androidx.camera.core.Camera
    public void setExtendedConfig(CameraConfig cameraConfig) {
        CameraUseCaseAdapter cameraUseCaseAdapter = this.f754j;
        synchronized (cameraUseCaseAdapter.o) {
            if (cameraConfig == null) {
                cameraConfig = p.f2723a;
            }
            CameraFilter cameraFilter = cameraConfig.getCameraFilter();
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            linkedHashSet.add(cameraFilter);
            CameraInternal c2 = new q1(linkedHashSet).c(cameraUseCaseAdapter.f734h);
            Map<UseCase, CameraUseCaseAdapter.b> e2 = cameraUseCaseAdapter.e(cameraUseCaseAdapter.f737l, cameraConfig.getUseCaseConfigFactory(), cameraUseCaseAdapter.f736k);
            try {
                Map<UseCase, Size> c3 = cameraUseCaseAdapter.c(c2.getCameraInfoInternal(), cameraUseCaseAdapter.f737l, Collections.emptyList(), e2);
                cameraUseCaseAdapter.i(c3, cameraUseCaseAdapter.f737l);
                if (cameraUseCaseAdapter.p) {
                    cameraUseCaseAdapter.f733d.detachUseCases(cameraUseCaseAdapter.f737l);
                }
                for (UseCase useCase : cameraUseCaseAdapter.f737l) {
                    useCase.q(cameraUseCaseAdapter.f733d);
                }
                for (UseCase useCase2 : cameraUseCaseAdapter.f737l) {
                    CameraUseCaseAdapter.b bVar = (CameraUseCaseAdapter.b) ((HashMap) e2).get(useCase2);
                    useCase2.o(c2, bVar.f739a, bVar.f740b);
                    Size size = (Size) ((HashMap) c3).get(useCase2);
                    Objects.requireNonNull(size);
                    useCase2.f612g = useCase2.t(size);
                }
                if (cameraUseCaseAdapter.p) {
                    cameraUseCaseAdapter.g(cameraUseCaseAdapter.f737l);
                    c2.attachUseCases(cameraUseCaseAdapter.f737l);
                }
                for (UseCase useCase3 : cameraUseCaseAdapter.f737l) {
                    useCase3.n();
                }
                cameraUseCaseAdapter.f733d = c2;
                cameraUseCaseAdapter.n = cameraConfig;
            } catch (IllegalArgumentException e3) {
                throw new CameraUseCaseAdapter.CameraException(e3.getMessage());
            }
        }
    }
}
