package androidx.camera.view;

import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Rational;
import android.util.Size;
import android.view.Display;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.view.ViewConfiguration;
import android.widget.FrameLayout;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.camera.core.CameraControl;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.Preview;
import androidx.camera.core.SurfaceRequest;
import androidx.camera.core.ZoomState;
import androidx.camera.core.impl.CameraInfoInternal;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.view.internal.compat.quirk.SurfaceViewStretchedQuirk;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import b.d.a.e2;
import b.d.a.g2;
import b.d.a.h2;
import b.d.a.p2;
import b.d.a.s0;
import b.d.a.t1;
import b.d.c.a0;
import b.d.c.b0;
import b.d.c.d0;
import b.d.c.f0;
import b.d.c.g0;
import b.d.c.h;
import b.d.c.i;
import b.d.c.j;
import b.d.c.k;
import b.d.c.u;
import b.d.c.z;
import java.util.Objects;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicReference;

public final class PreviewView extends FrameLayout {

    /* renamed from: d  reason: collision with root package name */
    public static final ImplementationMode f787d = ImplementationMode.PERFORMANCE;

    /* renamed from: h  reason: collision with root package name */
    public ImplementationMode f788h;

    /* renamed from: j  reason: collision with root package name */
    public PreviewViewImplementation f789j;

    /* renamed from: k  reason: collision with root package name */
    public final a0 f790k;

    /* renamed from: l  reason: collision with root package name */
    public final MutableLiveData<StreamState> f791l;
    public final AtomicReference<z> m;
    public u n;
    public b0 o;
    public final ScaleGestureDetector p;
    public MotionEvent q;
    public final View.OnLayoutChangeListener r;
    public final Preview.SurfaceProvider s;

    public enum ImplementationMode {
        PERFORMANCE(0),
        COMPATIBLE(1);
        
        private final int mId;

        private ImplementationMode(int i2) {
            this.mId = i2;
        }

        public static ImplementationMode fromId(int i2) {
            ImplementationMode[] values = values();
            for (int i3 = 0; i3 < 2; i3++) {
                ImplementationMode implementationMode = values[i3];
                if (implementationMode.mId == i2) {
                    return implementationMode;
                }
            }
            throw new IllegalArgumentException(d.a.a.a.a.k("Unknown implementation mode id ", i2));
        }

        public int getId() {
            return this.mId;
        }
    }

    public enum ScaleType {
        FILL_START(0),
        FILL_CENTER(1),
        FILL_END(2),
        FIT_START(3),
        FIT_CENTER(4),
        FIT_END(5);
        
        private final int mId;

        private ScaleType(int i2) {
            this.mId = i2;
        }

        public static ScaleType fromId(int i2) {
            ScaleType[] values = values();
            for (int i3 = 0; i3 < 6; i3++) {
                ScaleType scaleType = values[i3];
                if (scaleType.mId == i2) {
                    return scaleType;
                }
            }
            throw new IllegalArgumentException(d.a.a.a.a.k("Unknown scale type id ", i2));
        }

        public int getId() {
            return this.mId;
        }
    }

    public enum StreamState {
        IDLE,
        STREAMING
    }

    public class a implements Preview.SurfaceProvider {
        public a() {
        }

        /* JADX WARNING: Removed duplicated region for block: B:24:0x0096  */
        /* JADX WARNING: Removed duplicated region for block: B:25:0x00a0  */
        @Override // androidx.camera.core.Preview.SurfaceProvider
        public void onSurfaceRequested(SurfaceRequest surfaceRequest) {
            PreviewViewImplementation previewViewImplementation;
            if (!AppCompatDelegateImpl.e.Z()) {
                b.j.b.a.c(PreviewView.this.getContext()).execute(new j(this, surfaceRequest));
                return;
            }
            e2.a("PreviewView", "Surface requested by Preview.");
            CameraInternal cameraInternal = surfaceRequest.f589c;
            Executor c2 = b.j.b.a.c(PreviewView.this.getContext());
            i iVar = new i(this, cameraInternal, surfaceRequest);
            surfaceRequest.f596j = iVar;
            surfaceRequest.f597k = c2;
            SurfaceRequest.f fVar = surfaceRequest.f595i;
            if (fVar != null) {
                c2.execute(new s0(iVar, fVar));
            }
            PreviewView previewView = PreviewView.this;
            ImplementationMode implementationMode = previewView.f788h;
            boolean equals = surfaceRequest.f589c.getCameraInfoInternal().getImplementationType().equals(CameraInfo.IMPLEMENTATION_TYPE_CAMERA2_LEGACY);
            boolean z = false;
            boolean z2 = b.d.c.h0.a.a.a.f2842a.a(SurfaceViewStretchedQuirk.class) != null;
            if (!surfaceRequest.f588b && Build.VERSION.SDK_INT > 24 && !equals && !z2) {
                int ordinal = implementationMode.ordinal();
                if (ordinal != 0) {
                    if (ordinal != 1) {
                        throw new IllegalArgumentException("Invalid implementation mode: " + implementationMode);
                    }
                }
                if (!z) {
                    PreviewView previewView2 = PreviewView.this;
                    previewViewImplementation = new f0(previewView2, previewView2.f790k);
                } else {
                    PreviewView previewView3 = PreviewView.this;
                    previewViewImplementation = new d0(previewView3, previewView3.f790k);
                }
                previewView.f789j = previewViewImplementation;
                CameraInfoInternal cameraInfoInternal = cameraInternal.getCameraInfoInternal();
                PreviewView previewView4 = PreviewView.this;
                z zVar = new z(cameraInfoInternal, previewView4.f791l, previewView4.f789j);
                PreviewView.this.m.set(zVar);
                cameraInternal.getCameraState().addObserver(b.j.b.a.c(PreviewView.this.getContext()), zVar);
                PreviewView.this.f789j.e(surfaceRequest, new h(this, zVar, cameraInternal));
            }
            z = true;
            if (!z) {
            }
            previewView.f789j = previewViewImplementation;
            CameraInfoInternal cameraInfoInternal2 = cameraInternal.getCameraInfoInternal();
            PreviewView previewView42 = PreviewView.this;
            z zVar2 = new z(cameraInfoInternal2, previewView42.f791l, previewView42.f789j);
            PreviewView.this.m.set(zVar2);
            cameraInternal.getCameraState().addObserver(b.j.b.a.c(PreviewView.this.getContext()), zVar2);
            PreviewView.this.f789j.e(surfaceRequest, new h(this, zVar2, cameraInternal));
        }
    }

    public class b extends ScaleGestureDetector.SimpleOnScaleGestureListener {
        public b() {
        }

        public boolean onScale(ScaleGestureDetector scaleGestureDetector) {
            u uVar = PreviewView.this.n;
            if (uVar == null) {
                return true;
            }
            float scaleFactor = scaleGestureDetector.getScaleFactor();
            if (!uVar.d()) {
                e2.f("CameraController", "Use cases not attached to camera.", null);
                return true;
            } else if (!uVar.o) {
                e2.a("CameraController", "Pinch to zoom disabled.");
                return true;
            } else {
                e2.a("CameraController", "Pinch to zoom with scale: " + scaleFactor);
                AppCompatDelegateImpl.e.k();
                ZoomState d2 = uVar.q.d();
                if (d2 == null) {
                    return true;
                }
                float min = Math.min(Math.max(d2.getZoomRatio() * (scaleFactor > 1.0f ? d.a.a.a.a.b(scaleFactor, 1.0f, 2.0f, 1.0f) : 1.0f - ((1.0f - scaleFactor) * 2.0f)), d2.getMinZoomRatio()), d2.getMaxZoomRatio());
                AppCompatDelegateImpl.e.k();
                if (!uVar.d()) {
                    e2.f("CameraController", "Use cases not attached to camera.", null);
                    return true;
                }
                uVar.f2873h.getCameraControl().setZoomRatio(min);
                return true;
            }
        }
    }

    public PreviewView(Context context) {
        this(context, null);
    }

    private int getViewPortScaleType() {
        int ordinal = getScaleType().ordinal();
        if (ordinal == 0) {
            return 0;
        }
        int i2 = 1;
        if (ordinal != 1) {
            i2 = 2;
            if (ordinal != 2) {
                i2 = 3;
                if (!(ordinal == 3 || ordinal == 4 || ordinal == 5)) {
                    StringBuilder B = d.a.a.a.a.B("Unexpected scale type: ");
                    B.append(getScaleType());
                    throw new IllegalStateException(B.toString());
                }
            }
        }
        return i2;
    }

    public final void a(boolean z) {
        Display display = getDisplay();
        p2 viewPort = getViewPort();
        if (this.n != null && viewPort != null && isAttachedToWindow() && display != null) {
            try {
                this.n.a(getSurfaceProvider(), viewPort, display);
            } catch (IllegalStateException e2) {
                if (z) {
                    e2.b("PreviewView", e2.getMessage(), e2);
                    return;
                }
                throw e2;
            }
        }
    }

    public void b() {
        PreviewViewImplementation previewViewImplementation = this.f789j;
        if (previewViewImplementation != null) {
            previewViewImplementation.f();
        }
        b0 b0Var = this.o;
        Size size = new Size(getWidth(), getHeight());
        int layoutDirection = getLayoutDirection();
        Objects.requireNonNull(b0Var);
        AppCompatDelegateImpl.e.k();
        synchronized (b0Var) {
            if (size.getWidth() != 0) {
                if (size.getHeight() != 0) {
                    b0Var.f2809d = b0Var.f2808c.a(size, layoutDirection);
                    return;
                }
            }
            b0Var.f2809d = null;
        }
    }

    public Bitmap getBitmap() {
        Bitmap b2;
        AppCompatDelegateImpl.e.k();
        PreviewViewImplementation previewViewImplementation = this.f789j;
        if (previewViewImplementation == null || (b2 = previewViewImplementation.b()) == null) {
            return null;
        }
        a0 a0Var = previewViewImplementation.f796c;
        Size size = new Size(previewViewImplementation.f795b.getWidth(), previewViewImplementation.f795b.getHeight());
        int layoutDirection = previewViewImplementation.f795b.getLayoutDirection();
        if (!a0Var.f()) {
            return b2;
        }
        Matrix d2 = a0Var.d();
        RectF e2 = a0Var.e(size, layoutDirection);
        Bitmap createBitmap = Bitmap.createBitmap(size.getWidth(), size.getHeight(), b2.getConfig());
        Canvas canvas = new Canvas(createBitmap);
        Matrix matrix = new Matrix();
        matrix.postConcat(d2);
        matrix.postScale(e2.width() / ((float) a0Var.f2798b.getWidth()), e2.height() / ((float) a0Var.f2798b.getHeight()));
        matrix.postTranslate(e2.left, e2.top);
        canvas.drawBitmap(b2, matrix, new Paint(7));
        return createBitmap;
    }

    public u getController() {
        AppCompatDelegateImpl.e.k();
        return this.n;
    }

    public ImplementationMode getImplementationMode() {
        AppCompatDelegateImpl.e.k();
        return this.f788h;
    }

    public h2 getMeteringPointFactory() {
        AppCompatDelegateImpl.e.k();
        return this.o;
    }

    public b.d.c.i0.a getOutputTransform() {
        Matrix matrix;
        AppCompatDelegateImpl.e.k();
        try {
            matrix = this.f790k.c(new Size(getWidth(), getHeight()), getLayoutDirection());
        } catch (IllegalStateException unused) {
            matrix = null;
        }
        Rect rect = this.f790k.f2799c;
        if (matrix == null || rect == null) {
            e2.a("PreviewView", "Transform info is not ready");
            return null;
        }
        RectF rectF = g0.f2838a;
        RectF rectF2 = new RectF(rect);
        Matrix matrix2 = new Matrix();
        matrix2.setRectToRect(g0.f2838a, rectF2, Matrix.ScaleToFit.FILL);
        matrix.preConcat(matrix2);
        if (this.f789j instanceof f0) {
            matrix.postConcat(getMatrix());
        } else {
            e2.f("PreviewView", "PreviewView needs to be in COMPATIBLE mode for the transform to work correctly.", null);
        }
        return new b.d.c.i0.a(matrix, new Size(rect.width(), rect.height()));
    }

    public LiveData<StreamState> getPreviewStreamState() {
        return this.f791l;
    }

    public ScaleType getScaleType() {
        AppCompatDelegateImpl.e.k();
        return this.f790k.f2804h;
    }

    public Preview.SurfaceProvider getSurfaceProvider() {
        AppCompatDelegateImpl.e.k();
        return this.s;
    }

    public p2 getViewPort() {
        AppCompatDelegateImpl.e.k();
        if (getDisplay() == null) {
            return null;
        }
        int rotation = getDisplay().getRotation();
        AppCompatDelegateImpl.e.k();
        if (getWidth() == 0 || getHeight() == 0) {
            return null;
        }
        Rational rational = new Rational(getWidth(), getHeight());
        int viewPortScaleType = getViewPortScaleType();
        int layoutDirection = getLayoutDirection();
        AppCompatDelegateImpl.e.l(rational, "The crop aspect ratio must be set.");
        return new p2(viewPortScaleType, rational, rotation, layoutDirection);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        addOnLayoutChangeListener(this.r);
        PreviewViewImplementation previewViewImplementation = this.f789j;
        if (previewViewImplementation != null) {
            previewViewImplementation.c();
        }
        a(true);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        removeOnLayoutChangeListener(this.r);
        PreviewViewImplementation previewViewImplementation = this.f789j;
        if (previewViewImplementation != null) {
            previewViewImplementation.d();
        }
        u uVar = this.n;
        if (uVar != null) {
            uVar.b();
        }
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        if (this.n == null) {
            return super.onTouchEvent(motionEvent);
        }
        boolean z = motionEvent.getPointerCount() == 1;
        boolean z2 = motionEvent.getAction() == 1;
        boolean z3 = motionEvent.getEventTime() - motionEvent.getDownTime() < ((long) ViewConfiguration.getLongPressTimeout());
        if (z && z2 && z3) {
            this.q = motionEvent;
            performClick();
            return true;
        } else if (this.p.onTouchEvent(motionEvent) || super.onTouchEvent(motionEvent)) {
            return true;
        } else {
            return false;
        }
    }

    public boolean performClick() {
        if (this.n != null) {
            MotionEvent motionEvent = this.q;
            float x = motionEvent != null ? motionEvent.getX() : ((float) getWidth()) / 2.0f;
            MotionEvent motionEvent2 = this.q;
            float y = motionEvent2 != null ? motionEvent2.getY() : ((float) getHeight()) / 2.0f;
            u uVar = this.n;
            b0 b0Var = this.o;
            if (!uVar.d()) {
                e2.f("CameraController", "Use cases not attached to camera.", null);
            } else if (!uVar.p) {
                e2.a("CameraController", "Tap to focus disabled. ");
            } else {
                e2.a("CameraController", "Tap to focus: " + x + ", " + y);
                g2 b2 = b0Var.b(x, y, 0.16666667f);
                g2 b3 = b0Var.b(x, y, 0.25f);
                CameraControl cameraControl = uVar.f2873h.getCameraControl();
                t1.a aVar = new t1.a(b2, 1);
                aVar.a(b3, 2);
                cameraControl.startFocusAndMetering(new t1(aVar));
            }
        }
        this.q = null;
        return super.performClick();
    }

    public void setController(u uVar) {
        AppCompatDelegateImpl.e.k();
        u uVar2 = this.n;
        if (!(uVar2 == null || uVar2 == uVar)) {
            uVar2.b();
        }
        this.n = uVar;
        a(false);
    }

    public void setImplementationMode(ImplementationMode implementationMode) {
        AppCompatDelegateImpl.e.k();
        this.f788h = implementationMode;
    }

    public void setScaleType(ScaleType scaleType) {
        AppCompatDelegateImpl.e.k();
        this.f790k.f2804h = scaleType;
        b();
        a(false);
    }

    public PreviewView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    /* JADX INFO: finally extract failed */
    public PreviewView(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2, 0);
        ImplementationMode implementationMode = f787d;
        this.f788h = implementationMode;
        a0 a0Var = new a0();
        this.f790k = a0Var;
        this.f791l = new MutableLiveData<>(StreamState.IDLE);
        this.m = new AtomicReference<>();
        this.o = new b0(a0Var);
        this.r = new k(this);
        this.s = new a();
        AppCompatDelegateImpl.e.k();
        Resources.Theme theme = context.getTheme();
        int[] iArr = R$styleable.PreviewView;
        TypedArray obtainStyledAttributes = theme.obtainStyledAttributes(attributeSet, iArr, i2, 0);
        if (Build.VERSION.SDK_INT >= 29) {
            saveAttributeDataForStyleable(context, iArr, attributeSet, obtainStyledAttributes, i2, 0);
        }
        try {
            setScaleType(ScaleType.fromId(obtainStyledAttributes.getInteger(R$styleable.PreviewView_scaleType, a0Var.f2804h.getId())));
            setImplementationMode(ImplementationMode.fromId(obtainStyledAttributes.getInteger(R$styleable.PreviewView_implementationMode, implementationMode.getId())));
            obtainStyledAttributes.recycle();
            this.p = new ScaleGestureDetector(context, new b());
            if (getBackground() == null) {
                setBackgroundColor(b.j.b.a.b(getContext(), 17170444));
            }
        } catch (Throwable th) {
            obtainStyledAttributes.recycle();
            throw th;
        }
    }
}
