package androidx.databinding;

import androidx.databinding.ObservableList;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Objects;

public class ObservableArrayList<T> extends ArrayList<T> implements ObservableList<T> {
    private transient ListChangeRegistry mListeners = new ListChangeRegistry();

    private void notifyAdd(int i2, int i3) {
        ListChangeRegistry listChangeRegistry = this.mListeners;
        if (listChangeRegistry != null) {
            Objects.requireNonNull(listChangeRegistry);
            listChangeRegistry.j(this, 2, ListChangeRegistry.i(i2, 0, i3));
        }
    }

    private void notifyRemove(int i2, int i3) {
        ListChangeRegistry listChangeRegistry = this.mListeners;
        if (listChangeRegistry != null) {
            Objects.requireNonNull(listChangeRegistry);
            listChangeRegistry.j(this, 4, ListChangeRegistry.i(i2, 0, i3));
        }
    }

    @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.AbstractList, java.util.ArrayList
    public boolean add(T t) {
        super.add(t);
        notifyAdd(size() - 1, 1);
        return true;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: java.util.Collection<? extends T> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.ArrayList
    public boolean addAll(Collection<? extends T> collection) {
        int size = size();
        boolean addAll = super.addAll(collection);
        if (addAll) {
            notifyAdd(size, size() - size);
        }
        return addAll;
    }

    @Override // androidx.databinding.ObservableList
    public void addOnListChangedCallback(ObservableList.a aVar) {
        if (this.mListeners == null) {
            this.mListeners = new ListChangeRegistry();
        }
        this.mListeners.a(aVar);
    }

    public void clear() {
        int size = size();
        super.clear();
        if (size != 0) {
            notifyRemove(0, size);
        }
    }

    @Override // java.util.List, java.util.AbstractList, java.util.ArrayList
    public T remove(int i2) {
        T t = (T) super.remove(i2);
        notifyRemove(i2, 1);
        return t;
    }

    @Override // androidx.databinding.ObservableList
    public void removeOnListChangedCallback(ObservableList.a aVar) {
        ListChangeRegistry listChangeRegistry = this.mListeners;
        if (listChangeRegistry != null) {
            listChangeRegistry.f(aVar);
        }
    }

    public void removeRange(int i2, int i3) {
        super.removeRange(i2, i3);
        notifyRemove(i2, i3 - i2);
    }

    @Override // java.util.List, java.util.AbstractList, java.util.ArrayList
    public T set(int i2, T t) {
        T t2 = (T) super.set(i2, t);
        ListChangeRegistry listChangeRegistry = this.mListeners;
        if (listChangeRegistry != null) {
            Objects.requireNonNull(listChangeRegistry);
            listChangeRegistry.j(this, 1, ListChangeRegistry.i(i2, 0, 1));
        }
        return t2;
    }

    @Override // java.util.List, java.util.AbstractList, java.util.ArrayList
    public void add(int i2, T t) {
        super.add(i2, t);
        notifyAdd(i2, 1);
    }

    @Override // java.util.List, java.util.ArrayList
    public boolean remove(Object obj) {
        int indexOf = indexOf(obj);
        if (indexOf < 0) {
            return false;
        }
        remove(indexOf);
        return true;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: java.util.Collection<? extends T> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // java.util.List, java.util.AbstractList, java.util.ArrayList
    public boolean addAll(int i2, Collection<? extends T> collection) {
        boolean addAll = super.addAll(i2, collection);
        if (addAll) {
            notifyAdd(i2, collection.size());
        }
        return addAll;
    }
}
