package androidx.databinding;

import android.annotation.TargetApi;
import android.content.res.ColorStateList;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.LongSparseArray;
import android.util.SparseArray;
import android.util.SparseBooleanArray;
import android.util.SparseIntArray;
import android.util.SparseLongArray;
import android.view.Choreographer;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import androidx.databinding.Observable;
import androidx.databinding.ObservableList;
import androidx.databinding.ObservableMap;
import androidx.databinding.library.R$id;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import androidx.lifecycle.LiveData;
import androidx.lifecycle.Observer;
import androidx.viewbinding.ViewBinding;
import b.l.b;
import java.lang.ref.Reference;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public abstract class ViewDataBinding extends BaseObservable implements ViewBinding {
    private static final int BINDING_NUMBER_START = 8;
    public static final String BINDING_TAG_PREFIX = "binding_";
    private static final CreateWeakListener CREATE_LIST_LISTENER = new b();
    private static final CreateWeakListener CREATE_LIVE_DATA_LISTENER = new d();
    private static final CreateWeakListener CREATE_MAP_LISTENER = new c();
    private static final CreateWeakListener CREATE_PROPERTY_LISTENER = new a();
    private static final int HALTED = 2;
    private static final int REBIND = 1;
    private static final b.a<b.l.e, ViewDataBinding, Void> REBIND_NOTIFIER = new e();
    private static final int REBOUND = 3;
    private static final View.OnAttachStateChangeListener ROOT_REATTACHED_LISTENER = new f();
    public static int SDK_INT;
    private static final boolean USE_CHOREOGRAPHER;
    private static final ReferenceQueue<ViewDataBinding> sReferenceQueue = new ReferenceQueue<>();
    public final DataBindingComponent mBindingComponent;
    private Choreographer mChoreographer;
    private ViewDataBinding mContainingBinding;
    private final Choreographer.FrameCallback mFrameCallback;
    private boolean mInLiveDataRegisterObserver;
    private boolean mIsExecutingPendingBindings;
    private LifecycleOwner mLifecycleOwner;
    private l[] mLocalFieldObservers;
    private OnStartListener mOnStartListener;
    private boolean mPendingRebind;
    private b.l.b<b.l.e, ViewDataBinding, Void> mRebindCallbacks;
    private boolean mRebindHalted;
    private final Runnable mRebindRunnable;
    private final View mRoot;
    private Handler mUIThreadHandler;

    public interface CreateWeakListener {
        l create(ViewDataBinding viewDataBinding, int i2);
    }

    public interface ObservableReference<T> {
        void addListener(T t);

        l<T> getListener();

        void removeListener(T t);

        void setLifecycleOwner(LifecycleOwner lifecycleOwner);
    }

    public static class OnStartListener implements LifecycleObserver {

        /* renamed from: d  reason: collision with root package name */
        public final WeakReference<ViewDataBinding> f1416d;

        public OnStartListener(ViewDataBinding viewDataBinding, a aVar) {
            this.f1416d = new WeakReference<>(viewDataBinding);
        }

        @b.q.g(Lifecycle.Event.ON_START)
        public void onStart() {
            ViewDataBinding viewDataBinding = this.f1416d.get();
            if (viewDataBinding != null) {
                viewDataBinding.executePendingBindings();
            }
        }
    }

    public static abstract class PropertyChangedInverseListener extends Observable.a implements InverseBindingListener {
        @Override // androidx.databinding.Observable.a
        public void a(Observable observable, int i2) {
            if (i2 == 0 || i2 == 0) {
                onChange();
            }
        }
    }

    public static class a implements CreateWeakListener {
        @Override // androidx.databinding.ViewDataBinding.CreateWeakListener
        public l create(ViewDataBinding viewDataBinding, int i2) {
            return new n(viewDataBinding, i2).f1429a;
        }
    }

    public static class b implements CreateWeakListener {
        @Override // androidx.databinding.ViewDataBinding.CreateWeakListener
        public l create(ViewDataBinding viewDataBinding, int i2) {
            return new k(viewDataBinding, i2).f1424a;
        }
    }

    public static class c implements CreateWeakListener {
        @Override // androidx.databinding.ViewDataBinding.CreateWeakListener
        public l create(ViewDataBinding viewDataBinding, int i2) {
            return new m(viewDataBinding, i2).f1428a;
        }
    }

    public static class d implements CreateWeakListener {
        @Override // androidx.databinding.ViewDataBinding.CreateWeakListener
        public l create(ViewDataBinding viewDataBinding, int i2) {
            return new j(viewDataBinding, i2).f1422a;
        }
    }

    public static class e extends b.a<b.l.e, ViewDataBinding, Void> {
        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, java.lang.Object, int, java.lang.Object] */
        @Override // b.l.b.a
        public void a(b.l.e eVar, ViewDataBinding viewDataBinding, int i2, Void r4) {
            b.l.e eVar2 = eVar;
            if (i2 == 1) {
                Objects.requireNonNull(eVar2);
            } else if (i2 == 2) {
                Objects.requireNonNull(eVar2);
            } else if (i2 == 3) {
                Objects.requireNonNull(eVar2);
            }
        }
    }

    public static class f implements View.OnAttachStateChangeListener {
        @TargetApi(19)
        public void onViewAttachedToWindow(View view) {
            ViewDataBinding.getBinding(view).mRebindRunnable.run();
            view.removeOnAttachStateChangeListener(this);
        }

        public void onViewDetachedFromWindow(View view) {
        }
    }

    public class g implements Runnable {
        public g() {
        }

        public void run() {
            synchronized (this) {
                ViewDataBinding.this.mPendingRebind = false;
            }
            ViewDataBinding.processReferenceQueue();
            if (!ViewDataBinding.this.mRoot.isAttachedToWindow()) {
                ViewDataBinding.this.mRoot.removeOnAttachStateChangeListener(ViewDataBinding.ROOT_REATTACHED_LISTENER);
                ViewDataBinding.this.mRoot.addOnAttachStateChangeListener(ViewDataBinding.ROOT_REATTACHED_LISTENER);
                return;
            }
            ViewDataBinding.this.executePendingBindings();
        }
    }

    public class h implements Choreographer.FrameCallback {
        public h() {
        }

        public void doFrame(long j2) {
            ViewDataBinding.this.mRebindRunnable.run();
        }
    }

    public static class i {

        /* renamed from: a  reason: collision with root package name */
        public final String[][] f1419a;

        /* renamed from: b  reason: collision with root package name */
        public final int[][] f1420b;

        /* renamed from: c  reason: collision with root package name */
        public final int[][] f1421c;

        public i(int i2) {
            this.f1419a = new String[i2][];
            this.f1420b = new int[i2][];
            this.f1421c = new int[i2][];
        }

        public void a(int i2, String[] strArr, int[] iArr, int[] iArr2) {
            this.f1419a[i2] = strArr;
            this.f1420b[i2] = iArr;
            this.f1421c[i2] = iArr2;
        }
    }

    public static class j implements Observer, ObservableReference<LiveData<?>> {

        /* renamed from: a  reason: collision with root package name */
        public final l<LiveData<?>> f1422a;

        /* renamed from: b  reason: collision with root package name */
        public LifecycleOwner f1423b;

        public j(ViewDataBinding viewDataBinding, int i2) {
            this.f1422a = new l<>(viewDataBinding, i2, this);
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void addListener(LiveData<?> liveData) {
            LiveData<?> liveData2 = liveData;
            LifecycleOwner lifecycleOwner = this.f1423b;
            if (lifecycleOwner != null) {
                liveData2.e(lifecycleOwner, this);
            }
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public l<LiveData<?>> getListener() {
            return this.f1422a;
        }

        @Override // androidx.lifecycle.Observer
        public void onChanged(Object obj) {
            ViewDataBinding a2 = this.f1422a.a();
            if (a2 != null) {
                l<LiveData<?>> lVar = this.f1422a;
                a2.handleFieldChange(lVar.f1426b, lVar.f1427c, 0);
            }
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void removeListener(LiveData<?> liveData) {
            liveData.j(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void setLifecycleOwner(LifecycleOwner lifecycleOwner) {
            T t = this.f1422a.f1427c;
            if (t != null) {
                if (this.f1423b != null) {
                    t.j(this);
                }
                if (lifecycleOwner != null) {
                    t.e(lifecycleOwner, this);
                }
            }
            this.f1423b = lifecycleOwner;
        }
    }

    public static class k extends ObservableList.a implements ObservableReference<ObservableList> {

        /* renamed from: a  reason: collision with root package name */
        public final l<ObservableList> f1424a;

        public k(ViewDataBinding viewDataBinding, int i2) {
            this.f1424a = new l<>(viewDataBinding, i2, this);
        }

        @Override // androidx.databinding.ObservableList.a
        public void a(ObservableList observableList) {
            l<ObservableList> lVar;
            T t;
            ViewDataBinding a2 = this.f1424a.a();
            if (a2 != null && (t = (lVar = this.f1424a).f1427c) == observableList) {
                a2.handleFieldChange(lVar.f1426b, t, 0);
            }
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void addListener(ObservableList observableList) {
            observableList.addOnListChangedCallback(this);
        }

        @Override // androidx.databinding.ObservableList.a
        public void b(ObservableList observableList, int i2, int i3) {
            a(observableList);
        }

        @Override // androidx.databinding.ObservableList.a
        public void c(ObservableList observableList, int i2, int i3) {
            a(observableList);
        }

        @Override // androidx.databinding.ObservableList.a
        public void d(ObservableList observableList, int i2, int i3, int i4) {
            a(observableList);
        }

        @Override // androidx.databinding.ObservableList.a
        public void e(ObservableList observableList, int i2, int i3) {
            a(observableList);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public l<ObservableList> getListener() {
            return this.f1424a;
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void removeListener(ObservableList observableList) {
            observableList.removeOnListChangedCallback(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void setLifecycleOwner(LifecycleOwner lifecycleOwner) {
        }
    }

    public static class l<T> extends WeakReference<ViewDataBinding> {

        /* renamed from: a  reason: collision with root package name */
        public final ObservableReference<T> f1425a;

        /* renamed from: b  reason: collision with root package name */
        public final int f1426b;

        /* renamed from: c  reason: collision with root package name */
        public T f1427c;

        public l(ViewDataBinding viewDataBinding, int i2, ObservableReference<T> observableReference) {
            super(viewDataBinding, ViewDataBinding.sReferenceQueue);
            this.f1426b = i2;
            this.f1425a = observableReference;
        }

        public ViewDataBinding a() {
            T t = get();
            if (t == null) {
                b();
            }
            return t;
        }

        public boolean b() {
            boolean z;
            T t = this.f1427c;
            if (t != null) {
                this.f1425a.removeListener(t);
                z = true;
            } else {
                z = false;
            }
            this.f1427c = null;
            return z;
        }
    }

    public static class m extends ObservableMap.a implements ObservableReference<ObservableMap> {

        /* renamed from: a  reason: collision with root package name */
        public final l<ObservableMap> f1428a;

        public m(ViewDataBinding viewDataBinding, int i2) {
            this.f1428a = new l<>(viewDataBinding, i2, this);
        }

        @Override // androidx.databinding.ObservableMap.a
        public void a(ObservableMap observableMap, Object obj) {
            ViewDataBinding a2 = this.f1428a.a();
            if (a2 != null) {
                l<ObservableMap> lVar = this.f1428a;
                if (observableMap == lVar.f1427c) {
                    a2.handleFieldChange(lVar.f1426b, observableMap, 0);
                }
            }
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void addListener(ObservableMap observableMap) {
            observableMap.addOnMapChangedCallback(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public l<ObservableMap> getListener() {
            return this.f1428a;
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void removeListener(ObservableMap observableMap) {
            observableMap.removeOnMapChangedCallback(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void setLifecycleOwner(LifecycleOwner lifecycleOwner) {
        }
    }

    public static class n extends Observable.a implements ObservableReference<Observable> {

        /* renamed from: a  reason: collision with root package name */
        public final l<Observable> f1429a;

        public n(ViewDataBinding viewDataBinding, int i2) {
            this.f1429a = new l<>(viewDataBinding, i2, this);
        }

        @Override // androidx.databinding.Observable.a
        public void a(Observable observable, int i2) {
            ViewDataBinding a2 = this.f1429a.a();
            if (a2 != null) {
                l<Observable> lVar = this.f1429a;
                if (lVar.f1427c == observable) {
                    a2.handleFieldChange(lVar.f1426b, observable, i2);
                }
            }
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void addListener(Observable observable) {
            observable.addOnPropertyChangedCallback(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public l<Observable> getListener() {
            return this.f1429a;
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void removeListener(Observable observable) {
            observable.removeOnPropertyChangedCallback(this);
        }

        @Override // androidx.databinding.ViewDataBinding.ObservableReference
        public void setLifecycleOwner(LifecycleOwner lifecycleOwner) {
        }
    }

    static {
        int i2 = Build.VERSION.SDK_INT;
        SDK_INT = i2;
        USE_CHOREOGRAPHER = i2 >= 16;
    }

    public ViewDataBinding(DataBindingComponent dataBindingComponent, View view, int i2) {
        this.mRebindRunnable = new g();
        this.mPendingRebind = false;
        this.mRebindHalted = false;
        this.mBindingComponent = dataBindingComponent;
        this.mLocalFieldObservers = new l[i2];
        this.mRoot = view;
        if (Looper.myLooper() == null) {
            throw new IllegalStateException("DataBinding must be created in view's UI Thread");
        } else if (USE_CHOREOGRAPHER) {
            this.mChoreographer = Choreographer.getInstance();
            this.mFrameCallback = new h();
        } else {
            this.mFrameCallback = null;
            this.mUIThreadHandler = new Handler(Looper.myLooper());
        }
    }

    public static ViewDataBinding bind(Object obj, View view, int i2) {
        return b.l.d.a(checkAndCastToBindingComponent(obj), view, i2);
    }

    private static DataBindingComponent checkAndCastToBindingComponent(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof DataBindingComponent) {
            return (DataBindingComponent) obj;
        }
        throw new IllegalArgumentException("The provided bindingComponent parameter must be an instance of DataBindingComponent. See  https://issuetracker.google.com/issues/116541301 for details of why this parameter is not defined as DataBindingComponent");
    }

    private void executeBindingsInternal() {
        if (this.mIsExecutingPendingBindings) {
            requestRebind();
        } else if (hasPendingBindings()) {
            this.mIsExecutingPendingBindings = true;
            this.mRebindHalted = false;
            b.l.b<b.l.e, ViewDataBinding, Void> bVar = this.mRebindCallbacks;
            if (bVar != null) {
                bVar.c(this, 1, null);
                if (this.mRebindHalted) {
                    this.mRebindCallbacks.c(this, 2, null);
                }
            }
            if (!this.mRebindHalted) {
                executeBindings();
                b.l.b<b.l.e, ViewDataBinding, Void> bVar2 = this.mRebindCallbacks;
                if (bVar2 != null) {
                    bVar2.c(this, 3, null);
                }
            }
            this.mIsExecutingPendingBindings = false;
        }
    }

    public static void executeBindingsOn(ViewDataBinding viewDataBinding) {
        viewDataBinding.executeBindingsInternal();
    }

    private static int findIncludeIndex(String str, int i2, i iVar, int i3) {
        CharSequence subSequence = str.subSequence(str.indexOf(47) + 1, str.length() - 2);
        String[] strArr = iVar.f1419a[i3];
        int length = strArr.length;
        while (i2 < length) {
            if (TextUtils.equals(subSequence, strArr[i2])) {
                return i2;
            }
            i2++;
        }
        return -1;
    }

    private static int findLastMatching(ViewGroup viewGroup, int i2) {
        String str = (String) viewGroup.getChildAt(i2).getTag();
        String substring = str.substring(0, str.length() - 1);
        int length = substring.length();
        int childCount = viewGroup.getChildCount();
        for (int i3 = i2 + 1; i3 < childCount; i3++) {
            View childAt = viewGroup.getChildAt(i3);
            String str2 = childAt.getTag() instanceof String ? (String) childAt.getTag() : null;
            if (str2 != null && str2.startsWith(substring)) {
                if (str2.length() == str.length() && str2.charAt(str2.length() - 1) == '0') {
                    return i2;
                }
                if (isNumeric(str2, length)) {
                    i2 = i3;
                }
            }
        }
        return i2;
    }

    public static ViewDataBinding getBinding(View view) {
        if (view != null) {
            return (ViewDataBinding) view.getTag(R$id.dataBinding);
        }
        return null;
    }

    public static int getBuildSdkInt() {
        return SDK_INT;
    }

    public static int getColorFromResource(View view, int i2) {
        if (Build.VERSION.SDK_INT >= 23) {
            return view.getContext().getColor(i2);
        }
        return view.getResources().getColor(i2);
    }

    public static ColorStateList getColorStateListFromResource(View view, int i2) {
        if (Build.VERSION.SDK_INT >= 23) {
            return view.getContext().getColorStateList(i2);
        }
        return view.getResources().getColorStateList(i2);
    }

    public static Drawable getDrawableFromResource(View view, int i2) {
        return view.getContext().getDrawable(i2);
    }

    public static <K, T> T getFrom(Map<K, T> map, K k2) {
        if (map == null) {
            return null;
        }
        return map.get(k2);
    }

    public static <T> T getFromArray(T[] tArr, int i2) {
        if (tArr == null || i2 < 0 || i2 >= tArr.length) {
            return null;
        }
        return tArr[i2];
    }

    public static <T> T getFromList(List<T> list, int i2) {
        if (list == null || i2 < 0 || i2 >= list.size()) {
            return null;
        }
        return list.get(i2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleFieldChange(int i2, Object obj, int i3) {
        if (!this.mInLiveDataRegisterObserver && onFieldChange(i2, obj, i3)) {
            requestRebind();
        }
    }

    public static <T extends ViewDataBinding> T inflateInternal(LayoutInflater layoutInflater, int i2, ViewGroup viewGroup, boolean z, Object obj) {
        return (T) b.l.d.d(layoutInflater, i2, viewGroup, z, checkAndCastToBindingComponent(obj));
    }

    private static boolean isNumeric(String str, int i2) {
        int length = str.length();
        if (length == i2) {
            return false;
        }
        while (i2 < length) {
            if (!Character.isDigit(str.charAt(i2))) {
                return false;
            }
            i2++;
        }
        return true;
    }

    public static Object[] mapBindings(DataBindingComponent dataBindingComponent, View view, int i2, i iVar, SparseIntArray sparseIntArray) {
        Object[] objArr = new Object[i2];
        mapBindings(dataBindingComponent, view, objArr, iVar, sparseIntArray, true);
        return objArr;
    }

    public static boolean parse(String str, boolean z) {
        return str == null ? z : Boolean.parseBoolean(str);
    }

    private static int parseTagInt(String str, int i2) {
        int length = str.length();
        int i3 = 0;
        while (i2 < length) {
            i3 = (i3 * 10) + (str.charAt(i2) - '0');
            i2++;
        }
        return i3;
    }

    /* access modifiers changed from: private */
    public static void processReferenceQueue() {
        while (true) {
            Reference<? extends ViewDataBinding> poll = sReferenceQueue.poll();
            if (poll == null) {
                return;
            }
            if (poll instanceof l) {
                ((l) poll).b();
            }
        }
    }

    public static int safeUnbox(Integer num) {
        if (num == null) {
            return 0;
        }
        return num.intValue();
    }

    public static void setBindingInverseListener(ViewDataBinding viewDataBinding, InverseBindingListener inverseBindingListener, PropertyChangedInverseListener propertyChangedInverseListener) {
        if (inverseBindingListener != propertyChangedInverseListener) {
            if (inverseBindingListener != null) {
                viewDataBinding.removeOnPropertyChangedCallback((PropertyChangedInverseListener) inverseBindingListener);
            }
            if (propertyChangedInverseListener != null) {
                viewDataBinding.addOnPropertyChangedCallback(propertyChangedInverseListener);
            }
        }
    }

    public static <T> void setTo(T[] tArr, int i2, T t) {
        if (tArr != null && i2 >= 0 && i2 < tArr.length) {
            tArr[i2] = t;
        }
    }

    private boolean updateRegistration(int i2, Object obj, CreateWeakListener createWeakListener) {
        if (obj == null) {
            return unregisterFrom(i2);
        }
        l lVar = this.mLocalFieldObservers[i2];
        if (lVar == null) {
            registerTo(i2, obj, createWeakListener);
            return true;
        } else if (lVar.f1427c == obj) {
            return false;
        } else {
            unregisterFrom(i2);
            registerTo(i2, obj, createWeakListener);
            return true;
        }
    }

    public void addOnRebindCallback(b.l.e eVar) {
        if (this.mRebindCallbacks == null) {
            this.mRebindCallbacks = new b.l.b<>(REBIND_NOTIFIER);
        }
        this.mRebindCallbacks.a(eVar);
    }

    public void ensureBindingComponentIsNotNull(Class<?> cls) {
        if (this.mBindingComponent == null) {
            StringBuilder B = d.a.a.a.a.B("Required DataBindingComponent is null in class ");
            B.append(getClass().getSimpleName());
            B.append(". A BindingAdapter in ");
            B.append(cls.getCanonicalName());
            B.append(" is not static and requires an object to use, retrieved from the DataBindingComponent. If you don't use an inflation method taking a DataBindingComponent, use DataBindingUtil.setDefaultComponent or make all BindingAdapter methods static.");
            throw new IllegalStateException(B.toString());
        }
    }

    public abstract void executeBindings();

    public void executePendingBindings() {
        ViewDataBinding viewDataBinding = this.mContainingBinding;
        if (viewDataBinding == null) {
            executeBindingsInternal();
        } else {
            viewDataBinding.executePendingBindings();
        }
    }

    public void forceExecuteBindings() {
        executeBindings();
    }

    public LifecycleOwner getLifecycleOwner() {
        return this.mLifecycleOwner;
    }

    public Object getObservedField(int i2) {
        l lVar = this.mLocalFieldObservers[i2];
        if (lVar == null) {
            return null;
        }
        return lVar.f1427c;
    }

    @Override // androidx.viewbinding.ViewBinding
    public View getRoot() {
        return this.mRoot;
    }

    public abstract boolean hasPendingBindings();

    public abstract void invalidateAll();

    public abstract boolean onFieldChange(int i2, Object obj, int i3);

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public void registerTo(int i2, Object obj, CreateWeakListener createWeakListener) {
        if (obj != 0) {
            l lVar = this.mLocalFieldObservers[i2];
            if (lVar == null) {
                lVar = createWeakListener.create(this, i2);
                this.mLocalFieldObservers[i2] = lVar;
                LifecycleOwner lifecycleOwner = this.mLifecycleOwner;
                if (lifecycleOwner != null) {
                    lVar.f1425a.setLifecycleOwner(lifecycleOwner);
                }
            }
            lVar.b();
            lVar.f1427c = obj;
            lVar.f1425a.addListener(obj);
        }
    }

    public void removeOnRebindCallback(b.l.e eVar) {
        b.l.b<b.l.e, ViewDataBinding, Void> bVar = this.mRebindCallbacks;
        if (bVar != null) {
            bVar.f(eVar);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:0x002a, code lost:
        if (androidx.databinding.ViewDataBinding.USE_CHOREOGRAPHER == false) goto L_0x0034;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x002c, code lost:
        r2.mChoreographer.postFrameCallback(r2.mFrameCallback);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0034, code lost:
        r2.mUIThreadHandler.post(r2.mRebindRunnable);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:?, code lost:
        return;
     */
    public void requestRebind() {
        ViewDataBinding viewDataBinding = this.mContainingBinding;
        if (viewDataBinding != null) {
            viewDataBinding.requestRebind();
            return;
        }
        LifecycleOwner lifecycleOwner = this.mLifecycleOwner;
        if (lifecycleOwner == null || ((LifecycleRegistry) lifecycleOwner.getLifecycle()).f1606b.isAtLeast(Lifecycle.State.STARTED)) {
            synchronized (this) {
                if (!this.mPendingRebind) {
                    this.mPendingRebind = true;
                }
            }
        }
    }

    public void setContainedBinding(ViewDataBinding viewDataBinding) {
        if (viewDataBinding != null) {
            viewDataBinding.mContainingBinding = this;
        }
    }

    public void setLifecycleOwner(LifecycleOwner lifecycleOwner) {
        LifecycleOwner lifecycleOwner2 = this.mLifecycleOwner;
        if (lifecycleOwner2 != lifecycleOwner) {
            if (lifecycleOwner2 != null) {
                lifecycleOwner2.getLifecycle().b(this.mOnStartListener);
            }
            this.mLifecycleOwner = lifecycleOwner;
            if (lifecycleOwner != null) {
                if (this.mOnStartListener == null) {
                    this.mOnStartListener = new OnStartListener(this, null);
                }
                lifecycleOwner.getLifecycle().a(this.mOnStartListener);
            }
            l[] lVarArr = this.mLocalFieldObservers;
            for (l lVar : lVarArr) {
                if (lVar != null) {
                    lVar.f1425a.setLifecycleOwner(lifecycleOwner);
                }
            }
        }
    }

    public void setRootTag(View view) {
        view.setTag(R$id.dataBinding, this);
    }

    public abstract boolean setVariable(int i2, Object obj);

    public void unbind() {
        l[] lVarArr = this.mLocalFieldObservers;
        for (l lVar : lVarArr) {
            if (lVar != null) {
                lVar.b();
            }
        }
    }

    public boolean unregisterFrom(int i2) {
        l lVar = this.mLocalFieldObservers[i2];
        if (lVar != null) {
            return lVar.b();
        }
        return false;
    }

    public boolean updateLiveDataRegistration(int i2, LiveData<?> liveData) {
        this.mInLiveDataRegisterObserver = true;
        try {
            return updateRegistration(i2, liveData, CREATE_LIVE_DATA_LISTENER);
        } finally {
            this.mInLiveDataRegisterObserver = false;
        }
    }

    public static byte parse(String str, byte b2) {
        try {
            return Byte.parseByte(str);
        } catch (NumberFormatException unused) {
            return b2;
        }
    }

    public static long safeUnbox(Long l2) {
        if (l2 == null) {
            return 0;
        }
        return l2.longValue();
    }

    public void setRootTag(View[] viewArr) {
        for (View view : viewArr) {
            view.setTag(R$id.dataBinding, this);
        }
    }

    public static boolean getFromArray(boolean[] zArr, int i2) {
        if (zArr == null || i2 < 0 || i2 >= zArr.length) {
            return false;
        }
        return zArr[i2];
    }

    public static <T> T getFromList(SparseArray<T> sparseArray, int i2) {
        if (sparseArray == null || i2 < 0) {
            return null;
        }
        return sparseArray.get(i2);
    }

    public static Object[] mapBindings(DataBindingComponent dataBindingComponent, View[] viewArr, int i2, i iVar, SparseIntArray sparseIntArray) {
        Object[] objArr = new Object[i2];
        for (View view : viewArr) {
            mapBindings(dataBindingComponent, view, objArr, iVar, sparseIntArray, true);
        }
        return objArr;
    }

    public static short parse(String str, short s) {
        try {
            return Short.parseShort(str);
        } catch (NumberFormatException unused) {
            return s;
        }
    }

    public static short safeUnbox(Short sh) {
        if (sh == null) {
            return 0;
        }
        return sh.shortValue();
    }

    public static void setTo(boolean[] zArr, int i2, boolean z) {
        if (zArr != null && i2 >= 0 && i2 < zArr.length) {
            zArr[i2] = z;
        }
    }

    @TargetApi(16)
    public static <T> T getFromList(LongSparseArray<T> longSparseArray, int i2) {
        if (longSparseArray == null || i2 < 0) {
            return null;
        }
        return longSparseArray.get((long) i2);
    }

    public static int parse(String str, int i2) {
        try {
            return Integer.parseInt(str);
        } catch (NumberFormatException unused) {
            return i2;
        }
    }

    public static byte safeUnbox(Byte b2) {
        if (b2 == null) {
            return 0;
        }
        return b2.byteValue();
    }

    public static byte getFromArray(byte[] bArr, int i2) {
        if (bArr == null || i2 < 0 || i2 >= bArr.length) {
            return 0;
        }
        return bArr[i2];
    }

    public static <T> T getFromList(b.f.d<T> dVar, int i2) {
        if (dVar == null || i2 < 0) {
            return null;
        }
        return dVar.f((long) i2);
    }

    public static long parse(String str, long j2) {
        try {
            return Long.parseLong(str);
        } catch (NumberFormatException unused) {
            return j2;
        }
    }

    public static char safeUnbox(Character ch) {
        if (ch == null) {
            return 0;
        }
        return ch.charValue();
    }

    public static void setTo(byte[] bArr, int i2, byte b2) {
        if (bArr != null && i2 >= 0 && i2 < bArr.length) {
            bArr[i2] = b2;
        }
    }

    public static boolean getFromList(SparseBooleanArray sparseBooleanArray, int i2) {
        if (sparseBooleanArray == null || i2 < 0) {
            return false;
        }
        return sparseBooleanArray.get(i2);
    }

    /* JADX WARNING: Removed duplicated region for block: B:69:0x0100  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x010d A[SYNTHETIC] */
    private static void mapBindings(DataBindingComponent dataBindingComponent, View view, Object[] objArr, i iVar, SparseIntArray sparseIntArray, boolean z) {
        int i2;
        boolean z2;
        int i3;
        int i4;
        boolean z3;
        int findIncludeIndex;
        int id;
        int i5;
        int i6;
        if (getBinding(view) == null) {
            Object tag = view.getTag();
            String str = tag instanceof String ? (String) tag : null;
            int i7 = 1;
            if (z && str != null && str.startsWith("layout")) {
                int lastIndexOf = str.lastIndexOf(95);
                if (lastIndexOf > 0) {
                    int i8 = lastIndexOf + 1;
                    if (isNumeric(str, i8)) {
                        i6 = parseTagInt(str, i8);
                        if (objArr[i6] == null) {
                            objArr[i6] = view;
                        }
                        if (iVar == null) {
                            i6 = -1;
                        }
                        z2 = true;
                        i2 = i6;
                    }
                }
                i6 = -1;
                z2 = false;
                i2 = i6;
            } else if (str == null || !str.startsWith(BINDING_TAG_PREFIX)) {
                z2 = false;
                i2 = -1;
            } else {
                int parseTagInt = parseTagInt(str, BINDING_NUMBER_START);
                if (objArr[parseTagInt] == null) {
                    objArr[parseTagInt] = view;
                }
                if (iVar == null) {
                    parseTagInt = -1;
                }
                i2 = parseTagInt;
                z2 = true;
            }
            if (!z2 && (id = view.getId()) > 0 && sparseIntArray != null && (i5 = sparseIntArray.get(id, -1)) >= 0 && objArr[i5] == null) {
                objArr[i5] = view;
            }
            if (view instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) view;
                int childCount = viewGroup.getChildCount();
                int i9 = 0;
                int i10 = 0;
                while (i9 < childCount) {
                    View childAt = viewGroup.getChildAt(i9);
                    if (i2 >= 0 && (childAt.getTag() instanceof String)) {
                        String str2 = (String) childAt.getTag();
                        if (str2.endsWith("_0") && str2.startsWith("layout") && str2.indexOf(47) > 0 && (findIncludeIndex = findIncludeIndex(str2, i10, iVar, i2)) >= 0) {
                            int i11 = findIncludeIndex + 1;
                            int i12 = iVar.f1420b[i2][findIncludeIndex];
                            int i13 = iVar.f1421c[i2][findIncludeIndex];
                            int findLastMatching = findLastMatching(viewGroup, i9);
                            if (findLastMatching == i9) {
                                objArr[i12] = b.l.d.a(dataBindingComponent, childAt, i13);
                            } else {
                                int i14 = (findLastMatching - i9) + i7;
                                View[] viewArr = new View[i14];
                                for (int i15 = 0; i15 < i14; i15++) {
                                    viewArr[i15] = viewGroup.getChildAt(i9 + i15);
                                }
                                objArr[i12] = b.l.d.f3521a.getDataBinder(dataBindingComponent, viewArr, i13);
                                i9 += i14 - 1;
                            }
                            i4 = i9;
                            i3 = i11;
                            z3 = true;
                            if (z3) {
                                mapBindings(dataBindingComponent, childAt, objArr, iVar, sparseIntArray, false);
                            }
                            i9 = i4 + 1;
                            i10 = i3;
                            i7 = 1;
                        }
                    }
                    i4 = i9;
                    i3 = i10;
                    z3 = false;
                    if (z3) {
                    }
                    i9 = i4 + 1;
                    i10 = i3;
                    i7 = 1;
                }
            }
        }
    }

    public static float parse(String str, float f2) {
        try {
            return Float.parseFloat(str);
        } catch (NumberFormatException unused) {
            return f2;
        }
    }

    public static double safeUnbox(Double d2) {
        if (d2 == null) {
            return 0.0d;
        }
        return d2.doubleValue();
    }

    public static short getFromArray(short[] sArr, int i2) {
        if (sArr == null || i2 < 0 || i2 >= sArr.length) {
            return 0;
        }
        return sArr[i2];
    }

    public static int getFromList(SparseIntArray sparseIntArray, int i2) {
        if (sparseIntArray == null || i2 < 0) {
            return 0;
        }
        return sparseIntArray.get(i2);
    }

    public static double parse(String str, double d2) {
        try {
            return Double.parseDouble(str);
        } catch (NumberFormatException unused) {
            return d2;
        }
    }

    public static float safeUnbox(Float f2) {
        if (f2 == null) {
            return 0.0f;
        }
        return f2.floatValue();
    }

    public static void setTo(short[] sArr, int i2, short s) {
        if (sArr != null && i2 >= 0 && i2 < sArr.length) {
            sArr[i2] = s;
        }
    }

    public boolean updateRegistration(int i2, Observable observable) {
        return updateRegistration(i2, observable, CREATE_PROPERTY_LISTENER);
    }

    @TargetApi(18)
    public static long getFromList(SparseLongArray sparseLongArray, int i2) {
        if (sparseLongArray == null || i2 < 0) {
            return 0;
        }
        return sparseLongArray.get(i2);
    }

    public static char parse(String str, char c2) {
        return (str == null || str.isEmpty()) ? c2 : str.charAt(0);
    }

    public static boolean safeUnbox(Boolean bool) {
        if (bool == null) {
            return false;
        }
        return bool.booleanValue();
    }

    public boolean updateRegistration(int i2, ObservableList observableList) {
        return updateRegistration(i2, observableList, CREATE_LIST_LISTENER);
    }

    public static char getFromArray(char[] cArr, int i2) {
        if (cArr == null || i2 < 0 || i2 >= cArr.length) {
            return 0;
        }
        return cArr[i2];
    }

    public static void setTo(char[] cArr, int i2, char c2) {
        if (cArr != null && i2 >= 0 && i2 < cArr.length) {
            cArr[i2] = c2;
        }
    }

    public boolean updateRegistration(int i2, ObservableMap observableMap) {
        return updateRegistration(i2, observableMap, CREATE_MAP_LISTENER);
    }

    public static int getFromArray(int[] iArr, int i2) {
        if (iArr == null || i2 < 0 || i2 >= iArr.length) {
            return 0;
        }
        return iArr[i2];
    }

    public static void setTo(int[] iArr, int i2, int i3) {
        if (iArr != null && i2 >= 0 && i2 < iArr.length) {
            iArr[i2] = i3;
        }
    }

    public static long getFromArray(long[] jArr, int i2) {
        if (jArr == null || i2 < 0 || i2 >= jArr.length) {
            return 0;
        }
        return jArr[i2];
    }

    public static void setTo(long[] jArr, int i2, long j2) {
        if (jArr != null && i2 >= 0 && i2 < jArr.length) {
            jArr[i2] = j2;
        }
    }

    public ViewDataBinding(Object obj, View view, int i2) {
        this(checkAndCastToBindingComponent(obj), view, i2);
    }

    public static float getFromArray(float[] fArr, int i2) {
        if (fArr == null || i2 < 0 || i2 >= fArr.length) {
            return 0.0f;
        }
        return fArr[i2];
    }

    public static void setTo(float[] fArr, int i2, float f2) {
        if (fArr != null && i2 >= 0 && i2 < fArr.length) {
            fArr[i2] = f2;
        }
    }

    public static double getFromArray(double[] dArr, int i2) {
        if (dArr == null || i2 < 0 || i2 >= dArr.length) {
            return 0.0d;
        }
        return dArr[i2];
    }

    public static void setTo(double[] dArr, int i2, double d2) {
        if (dArr != null && i2 >= 0 && i2 < dArr.length) {
            dArr[i2] = d2;
        }
    }

    public static <T> void setTo(List<T> list, int i2, T t) {
        if (list != null && i2 >= 0 && i2 < list.size()) {
            list.set(i2, t);
        }
    }

    public static <T> void setTo(SparseArray<T> sparseArray, int i2, T t) {
        if (sparseArray != null && i2 >= 0 && i2 < sparseArray.size()) {
            sparseArray.put(i2, t);
        }
    }

    @TargetApi(16)
    public static <T> void setTo(LongSparseArray<T> longSparseArray, int i2, T t) {
        if (longSparseArray != null && i2 >= 0 && i2 < longSparseArray.size()) {
            longSparseArray.put((long) i2, t);
        }
    }

    public static <T> void setTo(b.f.d<T> dVar, int i2, T t) {
        if (dVar != null && i2 >= 0 && i2 < dVar.l()) {
            dVar.j((long) i2, t);
        }
    }

    public static void setTo(SparseBooleanArray sparseBooleanArray, int i2, boolean z) {
        if (sparseBooleanArray != null && i2 >= 0 && i2 < sparseBooleanArray.size()) {
            sparseBooleanArray.put(i2, z);
        }
    }

    public static void setTo(SparseIntArray sparseIntArray, int i2, int i3) {
        if (sparseIntArray != null && i2 >= 0 && i2 < sparseIntArray.size()) {
            sparseIntArray.put(i2, i3);
        }
    }

    @TargetApi(18)
    public static void setTo(SparseLongArray sparseLongArray, int i2, long j2) {
        if (sparseLongArray != null && i2 >= 0 && i2 < sparseLongArray.size()) {
            sparseLongArray.put(i2, j2);
        }
    }

    public static <K, T> void setTo(Map<K, T> map, K k2, T t) {
        if (map != null) {
            map.put(k2, t);
        }
    }
}
