package androidx.multidex;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Log;
import b.o.a.n;
import b.t.b;
import b.t.c;
import d.a.a.a.a;
import java.io.BufferedOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.nio.channels.FileChannel;
import java.nio.channels.FileLock;
import java.util.ArrayList;
import java.util.List;
import java.util.zip.CRC32;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;
import okhttp3.internal.http2.Http2;

public final class MultiDexExtractor implements Closeable {

    /* renamed from: d  reason: collision with root package name */
    public final File f1747d;

    /* renamed from: h  reason: collision with root package name */
    public final long f1748h;

    /* renamed from: j  reason: collision with root package name */
    public final File f1749j;

    /* renamed from: k  reason: collision with root package name */
    public final RandomAccessFile f1750k;

    /* renamed from: l  reason: collision with root package name */
    public final FileChannel f1751l;
    public final FileLock m;

    public static class ExtractedDex extends File {
        public long crc = -1;

        public ExtractedDex(File file, String str) {
            super(file, str);
        }
    }

    public MultiDexExtractor(File file, File file2) {
        StringBuilder B = a.B("MultiDexExtractor(");
        B.append(file.getPath());
        B.append(", ");
        B.append(file2.getPath());
        B.append(")");
        Log.i("MultiDex", B.toString());
        this.f1747d = file;
        this.f1749j = file2;
        this.f1748h = d(file);
        File file3 = new File(file2, "MultiDex.lock");
        RandomAccessFile randomAccessFile = new RandomAccessFile(file3, "rw");
        this.f1750k = randomAccessFile;
        try {
            FileChannel channel = randomAccessFile.getChannel();
            this.f1751l = channel;
            try {
                Log.i("MultiDex", "Blocking on lock " + file3.getPath());
                this.m = channel.lock();
                Log.i("MultiDex", file3.getPath() + " locked");
            } catch (IOException | Error | RuntimeException e2) {
                a(this.f1751l);
                throw e2;
            }
        } catch (IOException | Error | RuntimeException e3) {
            a(this.f1750k);
            throw e3;
        }
    }

    public static void a(Closeable closeable) {
        try {
            closeable.close();
        } catch (IOException e2) {
            Log.w("MultiDex", "Failed to close resource", e2);
        }
    }

    /* JADX INFO: finally extract failed */
    public static void b(ZipFile zipFile, ZipEntry zipEntry, File file, String str) {
        InputStream inputStream = zipFile.getInputStream(zipEntry);
        File createTempFile = File.createTempFile(a.s("tmp-", str), ".zip", file.getParentFile());
        StringBuilder B = a.B("Extracting ");
        B.append(createTempFile.getPath());
        Log.i("MultiDex", B.toString());
        try {
            ZipOutputStream zipOutputStream = new ZipOutputStream(new BufferedOutputStream(new FileOutputStream(createTempFile)));
            try {
                ZipEntry zipEntry2 = new ZipEntry("classes.dex");
                zipEntry2.setTime(zipEntry.getTime());
                zipOutputStream.putNextEntry(zipEntry2);
                byte[] bArr = new byte[Http2.INITIAL_MAX_FRAME_SIZE];
                for (int read = inputStream.read(bArr); read != -1; read = inputStream.read(bArr)) {
                    zipOutputStream.write(bArr, 0, read);
                }
                zipOutputStream.closeEntry();
                zipOutputStream.close();
                if (createTempFile.setReadOnly()) {
                    Log.i("MultiDex", "Renaming to " + file.getPath());
                    if (!createTempFile.renameTo(file)) {
                        throw new IOException("Failed to rename \"" + createTempFile.getAbsolutePath() + "\" to \"" + file.getAbsolutePath() + "\"");
                    }
                    return;
                }
                throw new IOException("Failed to mark readonly \"" + createTempFile.getAbsolutePath() + "\" (tmp of \"" + file.getAbsolutePath() + "\")");
            } catch (Throwable th) {
                zipOutputStream.close();
                throw th;
            }
        } finally {
            a(inputStream);
            createTempFile.delete();
        }
    }

    public static long c(File file) {
        long lastModified = file.lastModified();
        return lastModified == -1 ? lastModified - 1 : lastModified;
    }

    /* JADX INFO: finally extract failed */
    public static long d(File file) {
        RandomAccessFile randomAccessFile = new RandomAccessFile(file, "r");
        try {
            c k0 = n.k0(randomAccessFile);
            CRC32 crc32 = new CRC32();
            long j2 = k0.f3813b;
            randomAccessFile.seek(k0.f3812a);
            int min = (int) Math.min(16384L, j2);
            byte[] bArr = new byte[Http2.INITIAL_MAX_FRAME_SIZE];
            int read = randomAccessFile.read(bArr, 0, min);
            while (true) {
                if (read == -1) {
                    break;
                }
                crc32.update(bArr, 0, read);
                j2 -= (long) read;
                if (j2 == 0) {
                    break;
                }
                read = randomAccessFile.read(bArr, 0, (int) Math.min(16384L, j2));
            }
            long value = crc32.getValue();
            randomAccessFile.close();
            return value == -1 ? value - 1 : value;
        } catch (Throwable th) {
            randomAccessFile.close();
            throw th;
        }
    }

    public static void h(Context context, String str, long j2, long j3, List<ExtractedDex> list) {
        SharedPreferences.Editor edit = context.getSharedPreferences("multidex.version", 4).edit();
        edit.putLong(str + "timestamp", j2);
        edit.putLong(a.y(new StringBuilder(), str, "crc"), j3);
        edit.putInt(str + "dex.number", list.size() + 1);
        int i2 = 2;
        for (ExtractedDex extractedDex : list) {
            edit.putLong(str + "dex.crc." + i2, extractedDex.crc);
            edit.putLong(str + "dex.time." + i2, extractedDex.lastModified());
            i2++;
        }
        edit.commit();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.m.release();
        this.f1751l.close();
        this.f1750k.close();
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x007e A[SYNTHETIC, Splitter:B:10:0x007e] */
    public List<? extends File> e(Context context, String str, boolean z) {
        List<ExtractedDex> list;
        List<ExtractedDex> list2;
        boolean z2;
        StringBuilder B = a.B("MultiDexExtractor.load(");
        B.append(this.f1747d.getPath());
        B.append(", ");
        B.append(z);
        B.append(", ");
        B.append(str);
        B.append(")");
        Log.i("MultiDex", B.toString());
        if (this.m.isValid()) {
            if (!z) {
                File file = this.f1747d;
                long j2 = this.f1748h;
                SharedPreferences sharedPreferences = context.getSharedPreferences("multidex.version", 4);
                if (sharedPreferences.getLong(str + "timestamp", -1) == c(file)) {
                    if (sharedPreferences.getLong(str + "crc", -1) == j2) {
                        z2 = false;
                        if (!z2) {
                            try {
                                list = f(context, str);
                            } catch (IOException e2) {
                                Log.w("MultiDex", "Failed to reload existing extracted secondary dex files, falling back to fresh extraction", e2);
                                list2 = g();
                                h(context, str, c(this.f1747d), this.f1748h, list2);
                            }
                            StringBuilder B2 = a.B("load found ");
                            B2.append(list.size());
                            B2.append(" secondary dex files");
                            Log.i("MultiDex", B2.toString());
                            return list;
                        }
                    }
                }
                z2 = true;
                if (!z2) {
                }
            }
            if (z) {
                Log.i("MultiDex", "Forced extraction must be performed.");
            } else {
                Log.i("MultiDex", "Detected that extraction must be performed.");
            }
            list2 = g();
            h(context, str, c(this.f1747d), this.f1748h, list2);
            list = list2;
            StringBuilder B22 = a.B("load found ");
            B22.append(list.size());
            B22.append(" secondary dex files");
            Log.i("MultiDex", B22.toString());
            return list;
        }
        throw new IllegalStateException("MultiDexExtractor was closed");
    }

    public final List<ExtractedDex> f(Context context, String str) {
        Log.i("MultiDex", "loading existing secondary dex files");
        String str2 = this.f1747d.getName() + ".classes";
        SharedPreferences sharedPreferences = context.getSharedPreferences("multidex.version", 4);
        int i2 = sharedPreferences.getInt(str + "dex.number", 1);
        ArrayList arrayList = new ArrayList(i2 + -1);
        int i3 = 2;
        while (i3 <= i2) {
            ExtractedDex extractedDex = new ExtractedDex(this.f1749j, a.m(str2, i3, ".zip"));
            if (extractedDex.isFile()) {
                extractedDex.crc = d(extractedDex);
                long j2 = sharedPreferences.getLong(str + "dex.crc." + i3, -1);
                long j3 = sharedPreferences.getLong(str + "dex.time." + i3, -1);
                long lastModified = extractedDex.lastModified();
                if (j3 == lastModified && j2 == extractedDex.crc) {
                    arrayList.add(extractedDex);
                    i3++;
                    sharedPreferences = sharedPreferences;
                    str2 = str2;
                } else {
                    throw new IOException("Invalid extracted dex: " + extractedDex + " (key \"" + str + "\"), expected modification time: " + j3 + ", modification time: " + lastModified + ", expected crc: " + j2 + ", file crc: " + extractedDex.crc);
                }
            } else {
                StringBuilder B = a.B("Missing extracted secondary dex file '");
                B.append(extractedDex.getPath());
                B.append("'");
                throw new IOException(B.toString());
            }
        }
        return arrayList;
    }

    public final List<ExtractedDex> g() {
        String str = this.f1747d.getName() + ".classes";
        File[] listFiles = this.f1749j.listFiles(new b(this));
        if (listFiles == null) {
            StringBuilder B = a.B("Failed to list secondary dex dir content (");
            B.append(this.f1749j.getPath());
            B.append(").");
            Log.w("MultiDex", B.toString());
        } else {
            for (File file : listFiles) {
                StringBuilder B2 = a.B("Trying to delete old file ");
                B2.append(file.getPath());
                B2.append(" of size ");
                B2.append(file.length());
                Log.i("MultiDex", B2.toString());
                if (!file.delete()) {
                    StringBuilder B3 = a.B("Failed to delete old file ");
                    B3.append(file.getPath());
                    Log.w("MultiDex", B3.toString());
                } else {
                    StringBuilder B4 = a.B("Deleted old file ");
                    B4.append(file.getPath());
                    Log.i("MultiDex", B4.toString());
                }
            }
        }
        ArrayList arrayList = new ArrayList();
        ZipFile zipFile = new ZipFile(this.f1747d);
        int i2 = 2;
        try {
            ZipEntry entry = zipFile.getEntry("classes2.dex");
            while (entry != null) {
                ExtractedDex extractedDex = new ExtractedDex(this.f1749j, str + i2 + ".zip");
                arrayList.add(extractedDex);
                Log.i("MultiDex", "Extraction is needed for file " + extractedDex);
                int i3 = 0;
                boolean z = false;
                while (i3 < 3 && !z) {
                    i3++;
                    b(zipFile, entry, extractedDex, str);
                    try {
                        extractedDex.crc = d(extractedDex);
                        z = true;
                    } catch (IOException e2) {
                        Log.w("MultiDex", "Failed to read crc from " + extractedDex.getAbsolutePath(), e2);
                        z = false;
                    }
                    StringBuilder sb = new StringBuilder();
                    sb.append("Extraction ");
                    sb.append(z ? "succeeded" : "failed");
                    sb.append(" '");
                    sb.append(extractedDex.getAbsolutePath());
                    sb.append("': length ");
                    sb.append(extractedDex.length());
                    sb.append(" - crc: ");
                    sb.append(extractedDex.crc);
                    Log.i("MultiDex", sb.toString());
                    if (!z) {
                        extractedDex.delete();
                        if (extractedDex.exists()) {
                            Log.w("MultiDex", "Failed to delete corrupted secondary dex '" + extractedDex.getPath() + "'");
                        }
                    }
                }
                if (z) {
                    i2++;
                    entry = zipFile.getEntry("classes" + i2 + ".dex");
                } else {
                    throw new IOException("Could not create zip file " + extractedDex.getAbsolutePath() + " for secondary dex (" + i2 + ")");
                }
            }
            return arrayList;
        } finally {
            try {
                zipFile.close();
            } catch (IOException e3) {
                Log.w("MultiDex", "Failed to close resource", e3);
            }
        }
    }
}
