package com.chad.library.adapter.base;

import android.content.Context;
import android.util.SparseArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import com.chad.library.adapter.base.provider.BaseItemProvider;
import com.chad.library.adapter.base.viewholder.BaseViewHolder;
import d.l.b.g.g.b;
import h.a;
import h.p.b.m;
import h.p.b.o;
import java.util.Iterator;
import java.util.List;
import kotlin.LazyThreadSafetyMode;

/* compiled from: BaseProviderMultiAdapter.kt */
public abstract class BaseProviderMultiAdapter<T> extends BaseQuickAdapter<T, BaseViewHolder> {
    private final a mItemProviders$delegate;

    public BaseProviderMultiAdapter() {
        this(null, 1, null);
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ BaseProviderMultiAdapter(List list, int i2, m mVar) {
        this((i2 & 1) != 0 ? null : list);
    }

    /* access modifiers changed from: private */
    public final SparseArray<BaseItemProvider<T>> getMItemProviders() {
        return (SparseArray) this.mItemProviders$delegate.getValue();
    }

    public void addItemProvider(BaseItemProvider<T> baseItemProvider) {
        o.f(baseItemProvider, "provider");
        baseItemProvider.setAdapter$com_github_CymChad_brvah(this);
        getMItemProviders().put(baseItemProvider.getItemViewType(), baseItemProvider);
    }

    public void bindChildClick(BaseViewHolder baseViewHolder, int i2) {
        BaseItemProvider<T> itemProvider;
        o.f(baseViewHolder, "viewHolder");
        if (getOnItemChildClickListener() == null) {
            BaseItemProvider<T> itemProvider2 = getItemProvider(i2);
            if (itemProvider2 != null) {
                Iterator<T> it = itemProvider2.getChildClickViewIds().iterator();
                while (it.hasNext()) {
                    View findViewById = baseViewHolder.itemView.findViewById(it.next().intValue());
                    if (findViewById != null) {
                        if (!findViewById.isClickable()) {
                            findViewById.setClickable(true);
                        }
                        findViewById.setOnClickListener(new BaseProviderMultiAdapter$bindChildClick$$inlined$forEach$lambda$1(this, baseViewHolder, itemProvider2));
                    }
                }
            } else {
                return;
            }
        }
        if (getOnItemChildLongClickListener() == null && (itemProvider = getItemProvider(i2)) != null) {
            Iterator<T> it2 = itemProvider.getChildLongClickViewIds().iterator();
            while (it2.hasNext()) {
                View findViewById2 = baseViewHolder.itemView.findViewById(it2.next().intValue());
                if (findViewById2 != null) {
                    if (!findViewById2.isLongClickable()) {
                        findViewById2.setLongClickable(true);
                    }
                    findViewById2.setOnLongClickListener(new BaseProviderMultiAdapter$bindChildClick$$inlined$forEach$lambda$2(this, baseViewHolder, itemProvider));
                }
            }
        }
    }

    public void bindClick(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "viewHolder");
        if (getOnItemClickListener() == null) {
            baseViewHolder.itemView.setOnClickListener(new BaseProviderMultiAdapter$bindClick$1(this, baseViewHolder));
        }
        if (getOnItemLongClickListener() == null) {
            baseViewHolder.itemView.setOnLongClickListener(new BaseProviderMultiAdapter$bindClick$2(this, baseViewHolder));
        }
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void bindViewClickListener(BaseViewHolder baseViewHolder, int i2) {
        o.f(baseViewHolder, "viewHolder");
        super.bindViewClickListener(baseViewHolder, i2);
        bindClick(baseViewHolder);
        bindChildClick(baseViewHolder, i2);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void convert(BaseViewHolder baseViewHolder, T t) {
        o.f(baseViewHolder, "holder");
        BaseItemProvider<T> itemProvider = getItemProvider(baseViewHolder.getItemViewType());
        if (itemProvider != null) {
            itemProvider.convert(baseViewHolder, t);
        } else {
            o.l();
            throw null;
        }
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public int getDefItemViewType(int i2) {
        return getItemType(getData(), i2);
    }

    public BaseItemProvider<T> getItemProvider(int i2) {
        return getMItemProviders().get(i2);
    }

    public abstract int getItemType(List<? extends T> list, int i2);

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public BaseViewHolder onCreateDefViewHolder(ViewGroup viewGroup, int i2) {
        o.f(viewGroup, "parent");
        BaseItemProvider<T> itemProvider = getItemProvider(i2);
        if (itemProvider != null) {
            Context context = viewGroup.getContext();
            o.b(context, "parent.context");
            itemProvider.setContext(context);
            BaseViewHolder onCreateViewHolder = itemProvider.onCreateViewHolder(viewGroup, i2);
            itemProvider.onViewHolderCreated(onCreateViewHolder, i2);
            return onCreateViewHolder;
        }
        throw new IllegalStateException(d.a.a.a.a.m("ViewType: ", i2, " no such provider found，please use addItemProvider() first!").toString());
    }

    public BaseProviderMultiAdapter(List<T> list) {
        super(0, list);
        this.mItemProviders$delegate = b.c0(LazyThreadSafetyMode.NONE, BaseProviderMultiAdapter$mItemProviders$2.INSTANCE);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void convert(BaseViewHolder baseViewHolder, T t, List<? extends Object> list) {
        o.f(baseViewHolder, "holder");
        o.f(list, "payloads");
        BaseItemProvider<T> itemProvider = getItemProvider(baseViewHolder.getItemViewType());
        if (itemProvider != null) {
            itemProvider.convert(baseViewHolder, t, list);
        } else {
            o.l();
            throw null;
        }
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void onViewAttachedToWindow(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "holder");
        super.onViewAttachedToWindow(baseViewHolder);
        BaseItemProvider<T> itemProvider = getItemProvider(baseViewHolder.getItemViewType());
        if (itemProvider != null) {
            itemProvider.onViewAttachedToWindow(baseViewHolder);
        }
    }

    public void onViewDetachedFromWindow(BaseViewHolder baseViewHolder) {
        o.f(baseViewHolder, "holder");
        super.onViewDetachedFromWindow((RecyclerView.ViewHolder) baseViewHolder);
        BaseItemProvider<T> itemProvider = getItemProvider(baseViewHolder.getItemViewType());
        if (itemProvider != null) {
            itemProvider.onViewDetachedFromWindow(baseViewHolder);
        }
    }
}
