package com.chad.library.adapter.base.diff;

import android.os.Handler;
import android.os.Looper;
import androidx.recyclerview.widget.ListUpdateCallback;
import b.u.a.f;
import com.chad.library.adapter.base.BaseQuickAdapter;
import h.p.b.o;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.concurrent.Executor;

public final class BrvahAsyncDiffer<T> implements DifferImp<T> {
    private final BaseQuickAdapter<T, ?> adapter;
    private final BrvahAsyncDifferConfig<T> config;
    private final List<ListChangeListener<T>> mListeners;
    private Executor mMainThreadExecutor;
    private int mMaxScheduledGeneration;
    private final ListUpdateCallback mUpdateCallback;
    private final Executor sMainThreadExecutor;

    public static final class MainThreadExecutor implements Executor {
        private final Handler mHandler = new Handler(Looper.getMainLooper());

        public void execute(Runnable runnable) {
            o.f(runnable, "command");
            this.mHandler.post(runnable);
        }

        public final Handler getMHandler() {
            return this.mHandler;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v1, types: [java.util.concurrent.Executor] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public BrvahAsyncDiffer(BaseQuickAdapter<T, ?> baseQuickAdapter, BrvahAsyncDifferConfig<T> brvahAsyncDifferConfig) {
        o.f(baseQuickAdapter, "adapter");
        o.f(brvahAsyncDifferConfig, "config");
        this.adapter = baseQuickAdapter;
        this.config = brvahAsyncDifferConfig;
        this.mUpdateCallback = new BrvahListUpdateCallback(baseQuickAdapter);
        MainThreadExecutor mainThreadExecutor = new MainThreadExecutor();
        this.sMainThreadExecutor = mainThreadExecutor;
        ?? mainThreadExecutor2 = brvahAsyncDifferConfig.getMainThreadExecutor();
        this.mMainThreadExecutor = mainThreadExecutor2 != 0 ? mainThreadExecutor2 : mainThreadExecutor;
        this.mListeners = new CopyOnWriteArrayList();
    }

    /* access modifiers changed from: public */
    private final void latchList(List<T> list, f.d dVar, Runnable runnable) {
        List<T> data = this.adapter.getData();
        this.adapter.setData$com_github_CymChad_brvah(list);
        dVar.a(this.mUpdateCallback);
        onCurrentListChanged(data, runnable);
    }

    private final void onCurrentListChanged(List<? extends T> list, Runnable runnable) {
        for (ListChangeListener<T> listChangeListener : this.mListeners) {
            listChangeListener.onCurrentListChanged(list, this.adapter.getData());
        }
        if (runnable != null) {
            runnable.run();
        }
    }

    public static /* synthetic */ void submitList$default(BrvahAsyncDiffer brvahAsyncDiffer, List list, Runnable runnable, int i2, Object obj) {
        if ((i2 & 2) != 0) {
            runnable = null;
        }
        brvahAsyncDiffer.submitList(list, runnable);
    }

    public final void addData(int i2, T t) {
        List<T> data = this.adapter.getData();
        this.adapter.getData().add(i2, t);
        this.mUpdateCallback.onInserted(i2, 1);
        onCurrentListChanged(data, null);
    }

    public final void addList(List<? extends T> list) {
        if (list != null) {
            List<T> data = this.adapter.getData();
            this.adapter.getData().addAll(list);
            this.mUpdateCallback.onInserted(data.size(), list.size());
            onCurrentListChanged(data, null);
        }
    }

    @Override // com.chad.library.adapter.base.diff.DifferImp
    public void addListListener(ListChangeListener<T> listChangeListener) {
        o.f(listChangeListener, "listener");
        this.mListeners.add(listChangeListener);
    }

    public final void changeData(int i2, T t, T t2) {
        List<T> data = this.adapter.getData();
        this.adapter.getData().set(i2, t);
        this.mUpdateCallback.onChanged(i2, 1, t2);
        onCurrentListChanged(data, null);
    }

    public final void clearAllListListener() {
        this.mListeners.clear();
    }

    public final void remove(T t) {
        List<T> data = this.adapter.getData();
        int indexOf = this.adapter.getData().indexOf(t);
        if (indexOf != -1) {
            this.adapter.getData().remove(indexOf);
            this.mUpdateCallback.onRemoved(indexOf, 1);
            onCurrentListChanged(data, null);
        }
    }

    public final void removeAt(int i2) {
        List<T> data = this.adapter.getData();
        this.adapter.getData().remove(i2);
        this.mUpdateCallback.onRemoved(i2, 1);
        onCurrentListChanged(data, null);
    }

    public final void removeListListener(ListChangeListener<T> listChangeListener) {
        o.f(listChangeListener, "listener");
        this.mListeners.remove(listChangeListener);
    }

    public final void submitList(List<T> list) {
        submitList$default(this, list, null, 2, null);
    }

    public final void submitList(List<T> list, Runnable runnable) {
        int i2 = this.mMaxScheduledGeneration + 1;
        this.mMaxScheduledGeneration = i2;
        if (list != this.adapter.getData()) {
            List<T> data = this.adapter.getData();
            if (list == null) {
                int size = this.adapter.getData().size();
                this.adapter.setData$com_github_CymChad_brvah(new ArrayList());
                this.mUpdateCallback.onRemoved(0, size);
                onCurrentListChanged(data, runnable);
            } else if (this.adapter.getData().isEmpty()) {
                this.adapter.setData$com_github_CymChad_brvah(list);
                this.mUpdateCallback.onInserted(0, list.size());
                onCurrentListChanged(data, runnable);
            } else {
                this.config.getBackgroundThreadExecutor().execute(new BrvahAsyncDiffer$submitList$1(this, data, list, i2, runnable));
            }
        } else if (runnable != null) {
            runnable.run();
        }
    }

    public final void addData(T t) {
        List<T> data = this.adapter.getData();
        this.adapter.getData().add(t);
        this.mUpdateCallback.onInserted(data.size(), 1);
        onCurrentListChanged(data, null);
    }
}
