package com.danikula.videocache;

import android.text.TextUtils;
import com.danikula.videocache.headers.EmptyHeadersInjector;
import com.danikula.videocache.headers.HeaderInjector;
import com.danikula.videocache.sourcestorage.SourceInfoStorage;
import com.danikula.videocache.sourcestorage.SourceInfoStorageFactory;
import com.lzy.okgo.model.HttpHeaders;
import d.a.a.a.a;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InterruptedIOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Map;

public class HttpUrlSource implements Source {
    private static final int MAX_REDIRECTS = 5;
    private HttpURLConnection connection;
    private final HeaderInjector headerInjector;
    private InputStream inputStream;
    private SourceInfo sourceInfo;
    private final SourceInfoStorage sourceInfoStorage;

    public HttpUrlSource(String str) {
        this(str, SourceInfoStorageFactory.newEmptySourceInfoStorage());
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x005a  */
    /* JADX WARNING: Removed duplicated region for block: B:22:? A[RETURN, SYNTHETIC] */
    private void fetchContentInfo() {
        Throwable th;
        HttpURLConnection httpURLConnection;
        IOException e2;
        InputStream inputStream2 = null;
        try {
            httpURLConnection = openConnection(0, 10000);
            try {
                long contentLength = getContentLength(httpURLConnection);
                String contentType = httpURLConnection.getContentType();
                inputStream2 = httpURLConnection.getInputStream();
                SourceInfo sourceInfo2 = new SourceInfo(this.sourceInfo.url, contentLength, contentType);
                this.sourceInfo = sourceInfo2;
                this.sourceInfoStorage.put(sourceInfo2.url, sourceInfo2);
                ProxyCacheUtils.close(inputStream2);
            } catch (IOException e3) {
                e2 = e3;
                try {
                    HttpProxyCacheDebuger.printfError("Error fetching info from " + this.sourceInfo.url, e2);
                    ProxyCacheUtils.close(inputStream2);
                    if (httpURLConnection == null) {
                        return;
                    }
                    httpURLConnection.disconnect();
                } catch (Throwable th2) {
                    th = th2;
                    ProxyCacheUtils.close(inputStream2);
                    if (httpURLConnection != null) {
                        httpURLConnection.disconnect();
                    }
                    throw th;
                }
            }
        } catch (IOException e4) {
            e2 = e4;
            httpURLConnection = null;
            HttpProxyCacheDebuger.printfError("Error fetching info from " + this.sourceInfo.url, e2);
            ProxyCacheUtils.close(inputStream2);
            if (httpURLConnection == null) {
            }
            httpURLConnection.disconnect();
        } catch (Throwable th3) {
            th = th3;
            httpURLConnection = null;
            ProxyCacheUtils.close(inputStream2);
            if (httpURLConnection != null) {
            }
            throw th;
        }
        httpURLConnection.disconnect();
    }

    private long getContentLength(HttpURLConnection httpURLConnection) {
        String headerField = httpURLConnection.getHeaderField(HttpHeaders.HEAD_KEY_CONTENT_LENGTH);
        if (headerField == null) {
            return -1;
        }
        return Long.parseLong(headerField);
    }

    private void injectCustomHeaders(HttpURLConnection httpURLConnection, String str) {
        Map<String, String> addHeaders = this.headerInjector.addHeaders(str);
        if (addHeaders != null) {
            StringBuilder B = a.B("****** injectCustomHeaders ****** :");
            B.append(addHeaders.size());
            HttpProxyCacheDebuger.printfError(B.toString());
            for (Map.Entry<String, String> entry : addHeaders.entrySet()) {
                httpURLConnection.setRequestProperty(entry.getKey(), entry.getValue());
            }
        }
    }

    private HttpURLConnection openConnection(long j2, int i2) {
        HttpURLConnection httpURLConnection;
        boolean z;
        String str = this.sourceInfo.url;
        int i3 = 0;
        do {
            httpURLConnection = (HttpURLConnection) new URL(str).openConnection();
            injectCustomHeaders(httpURLConnection, str);
            if (j2 > 0) {
                httpURLConnection.setRequestProperty(HttpHeaders.HEAD_KEY_RANGE, "bytes=" + j2 + "-");
            }
            if (i2 > 0) {
                httpURLConnection.setConnectTimeout(i2);
                httpURLConnection.setReadTimeout(i2);
            }
            int responseCode = httpURLConnection.getResponseCode();
            z = responseCode == 301 || responseCode == 302 || responseCode == 303;
            if (z) {
                str = httpURLConnection.getHeaderField("Location");
                i3++;
                httpURLConnection.disconnect();
            }
            if (i3 > 5) {
                throw new ProxyCacheException(a.k("Too many redirects: ", i3));
            }
        } while (z);
        return httpURLConnection;
    }

    private long readSourceAvailableBytes(HttpURLConnection httpURLConnection, long j2, int i2) {
        long contentLength = getContentLength(httpURLConnection);
        if (i2 == 200) {
            return contentLength;
        }
        if (i2 == 206) {
            return contentLength + j2;
        }
        return this.sourceInfo.length;
    }

    @Override // com.danikula.videocache.Source
    public void close() {
        HttpURLConnection httpURLConnection = this.connection;
        if (httpURLConnection != null) {
            try {
                httpURLConnection.disconnect();
            } catch (IllegalArgumentException | NullPointerException e2) {
                throw new RuntimeException("Wait... but why? WTF!? Really shouldn't happen any more after fixing https://github.com/danikula/AndroidVideoCache/issues/43. If you read it on your device log, please, notify me danikula@gmail.com or create issue here https://github.com/danikula/AndroidVideoCache/issues.", e2);
            } catch (ArrayIndexOutOfBoundsException e3) {
                HttpProxyCacheDebuger.printfError("Error closing connection correctly. Should happen only on Android L. If anybody know how to fix it, please visit https://github.com/danikula/AndroidVideoCache/issues/88. Until good solution is not know, just ignore this issue :(", e3);
            }
        }
    }

    public synchronized String getMime() {
        if (TextUtils.isEmpty(this.sourceInfo.mime)) {
            fetchContentInfo();
        }
        return this.sourceInfo.mime;
    }

    public String getUrl() {
        return this.sourceInfo.url;
    }

    @Override // com.danikula.videocache.Source
    public synchronized long length() {
        if (this.sourceInfo.length == -2147483648L) {
            fetchContentInfo();
        }
        return this.sourceInfo.length;
    }

    @Override // com.danikula.videocache.Source
    public void open(long j2) {
        try {
            HttpURLConnection openConnection = openConnection(j2, -1);
            this.connection = openConnection;
            String contentType = openConnection.getContentType();
            this.inputStream = new BufferedInputStream(this.connection.getInputStream(), 8192);
            HttpURLConnection httpURLConnection = this.connection;
            SourceInfo sourceInfo2 = new SourceInfo(this.sourceInfo.url, readSourceAvailableBytes(httpURLConnection, j2, httpURLConnection.getResponseCode()), contentType);
            this.sourceInfo = sourceInfo2;
            this.sourceInfoStorage.put(sourceInfo2.url, sourceInfo2);
        } catch (IOException e2) {
            StringBuilder B = a.B("Error opening connection for ");
            B.append(this.sourceInfo.url);
            B.append(" with offset ");
            B.append(j2);
            throw new ProxyCacheException(B.toString(), e2);
        }
    }

    @Override // com.danikula.videocache.Source
    public int read(byte[] bArr) {
        InputStream inputStream2 = this.inputStream;
        if (inputStream2 != null) {
            try {
                return inputStream2.read(bArr, 0, bArr.length);
            } catch (InterruptedIOException e2) {
                throw new InterruptedProxyCacheException(a.y(a.B("Reading source "), this.sourceInfo.url, " is interrupted"), e2);
            } catch (IOException e3) {
                StringBuilder B = a.B("Error reading data from ");
                B.append(this.sourceInfo.url);
                throw new ProxyCacheException(B.toString(), e3);
            }
        } else {
            throw new ProxyCacheException(a.y(a.B("Error reading data from "), this.sourceInfo.url, ": connection is absent!"));
        }
    }

    public String toString() {
        StringBuilder B = a.B("HttpUrlSource{sourceInfo='");
        B.append(this.sourceInfo);
        B.append("}");
        return B.toString();
    }

    public HttpUrlSource(String str, SourceInfoStorage sourceInfoStorage2) {
        this(str, sourceInfoStorage2, new EmptyHeadersInjector());
    }

    public HttpUrlSource(String str, SourceInfoStorage sourceInfoStorage2, HeaderInjector headerInjector2) {
        this.sourceInfoStorage = (SourceInfoStorage) Preconditions.checkNotNull(sourceInfoStorage2);
        this.headerInjector = (HeaderInjector) Preconditions.checkNotNull(headerInjector2);
        SourceInfo sourceInfo2 = sourceInfoStorage2.get(str);
        this.sourceInfo = sourceInfo2 == null ? new SourceInfo(str, -2147483648L, ProxyCacheUtils.getSupposablyMime(str)) : sourceInfo2;
    }

    public HttpUrlSource(HttpUrlSource httpUrlSource) {
        this.sourceInfo = httpUrlSource.sourceInfo;
        this.sourceInfoStorage = httpUrlSource.sourceInfoStorage;
        this.headerInjector = httpUrlSource.headerInjector;
    }
}
