package com.download.library;

import android.content.Context;
import android.net.Uri;
import android.os.SystemClock;
import android.text.TextUtils;
import d.e.a.d0;
import d.e.a.f;
import d.e.a.g;
import d.e.a.h;
import d.e.a.n;
import d.e.a.v;
import d.n.a.e;
import java.io.File;
import java.io.IOException;
import java.io.Serializable;
import java.util.HashMap;
import java.util.Objects;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class DownloadTask extends Extra implements Serializable, Cloneable {
    public static final int STATUS_CANCELED = 1006;
    public static final int STATUS_DOWNLOADING = 1002;
    public static final int STATUS_ERROR = 1007;
    public static final int STATUS_NEW = 1000;
    public static final int STATUS_PAUSED = 1004;
    public static final int STATUS_PAUSING = 1003;
    public static final int STATUS_PENDDING = 1001;
    public static final int STATUS_SUCCESSFUL = 1005;
    public static final String TAG;
    public String authority = "";
    public long beginTime = 0;
    public int connectTimes = 0;
    public long detalTime = 0;
    public long endTime = 0;
    public volatile boolean isAWait = false;
    public boolean isCustomFile = false;
    public volatile long loaded = 0;
    public Condition mCondition = null;
    public Context mContext;
    public f mDownloadListener;
    public h mDownloadNotifier;
    public n mDownloadStatusListener;
    public v mDownloadingListener;
    public File mFile;
    public int mId = d0.f8443a.f8447e.getAndIncrement();
    public Throwable mThrowable;
    public long mTotalsLength;
    public Lock mutex = null;
    public long pauseTime = 0;
    public String redirect = "";
    private volatile int status = 1000;
    public boolean uniquePath = true;

    public class a implements Runnable {

        /* renamed from: d  reason: collision with root package name */
        public final /* synthetic */ n f4253d;

        /* renamed from: h  reason: collision with root package name */
        public final /* synthetic */ DownloadTask f4254h;

        /* renamed from: j  reason: collision with root package name */
        public final /* synthetic */ int f4255j;

        public a(DownloadTask downloadTask, n nVar, DownloadTask downloadTask2, int i2) {
            this.f4253d = nVar;
            this.f4254h = downloadTask2;
            this.f4255j = i2;
        }

        public void run() {
            this.f4253d.onDownloadStatusChanged(this.f4254h.clone(), this.f4255j);
        }
    }

    static {
        StringBuilder B = d.a.a.a.a.B("Download-");
        B.append(DownloadTask.class.getSimpleName());
        TAG = B.toString();
    }

    private void checkCustomFilePath(File file) {
        if (file != null) {
            String absolutePath = file.getAbsolutePath();
            d0 d0Var = d0.f8443a;
            Context context = getContext();
            Objects.requireNonNull(d0Var);
            File file2 = new File(context.getCacheDir(), "download");
            if (!file2.exists()) {
                file2.mkdirs();
            }
            if (!absolutePath.startsWith(file2.getAbsolutePath())) {
                if (!TextUtils.isEmpty(this.authority)) {
                    setEnableIndicator(true);
                    this.isCustomFile = true;
                    return;
                }
                setEnableIndicator(false);
                this.isCustomFile = true;
                return;
            }
        }
        this.isCustomFile = false;
    }

    public DownloadTask addHeader(String str, String str2) {
        if (this.mHeaders == null) {
            this.mHeaders = new HashMap<>();
        }
        this.mHeaders.put(str, str2);
        return this;
    }

    public void anotify() {
        Lock lock = this.mutex;
        if (lock != null) {
            lock.lock();
            try {
                this.mCondition.signalAll();
            } finally {
                this.mutex.unlock();
            }
        }
    }

    public DownloadTask autoOpenIgnoreMD5() {
        this.mAutoOpen = true;
        if (this.mFile != null && TextUtils.isEmpty(this.authority)) {
            Objects.requireNonNull(d0.f8443a);
            this.mAutoOpen = false;
        }
        return this;
    }

    public DownloadTask autoOpenWithMD5(String str) {
        if (TextUtils.isEmpty(str)) {
            return this;
        }
        this.mAutoOpen = true;
        if (this.mFile != null && TextUtils.isEmpty(this.authority)) {
            Objects.requireNonNull(d0.f8443a);
            this.mAutoOpen = false;
        }
        this.targetCompareMD5 = str;
        this.calculateMD5 = true;
        return this;
    }

    public void await() {
        Lock lock = this.mutex;
        if (lock != null) {
            lock.lock();
            while (!isCompleted()) {
                try {
                    this.isAWait = true;
                    this.mCondition.await();
                } finally {
                    this.mutex.unlock();
                    this.isAWait = false;
                }
            }
        }
    }

    public void cancel() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(1006);
    }

    public DownloadTask closeAutoOpen() {
        this.mAutoOpen = false;
        return this;
    }

    public void completed() {
        this.endTime = SystemClock.elapsedRealtime();
    }

    public void createNotifier() {
        h hVar = this.mDownloadNotifier;
        if (hVar != null) {
            hVar.i(this);
        } else {
            Context applicationContext = getContext().getApplicationContext();
            if (applicationContext != null && isEnableIndicator()) {
                h hVar2 = new h(applicationContext, getId());
                this.mDownloadNotifier = hVar2;
                hVar2.i(this);
            }
        }
        h hVar3 = this.mDownloadNotifier;
        if (hVar3 != null) {
            hVar3.j();
        }
    }

    public void destroy() {
        this.mId = -1;
        this.mUrl = null;
        this.mContext = null;
        this.mFile = null;
        this.mIsParallelDownload = false;
        this.mIsForceDownload = false;
        this.mEnableIndicator = true;
        this.mDownloadIcon = 17301633;
        this.mDownloadDoneIcon = 17301634;
        this.mIsParallelDownload = true;
        this.mIsBreakPointDownload = true;
        this.mUserAgent = "";
        this.mContentDisposition = "";
        this.mMimetype = "";
        this.mContentLength = -1;
        HashMap<String, String> hashMap = this.mHeaders;
        if (hashMap != null) {
            hashMap.clear();
            this.mHeaders = null;
        }
        this.retry = 3;
        this.fileMD5 = "";
        this.targetCompareMD5 = "";
        this.calculateMD5 = false;
    }

    public void error() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(STATUS_ERROR);
    }

    public String getAuthority() {
        return this.authority;
    }

    public long getBeginTime() {
        return this.beginTime;
    }

    public Context getContext() {
        return this.mContext;
    }

    public f getDownloadListener() {
        return this.mDownloadListener;
    }

    public n getDownloadStatusListener() {
        return this.mDownloadStatusListener;
    }

    public v getDownloadingListener() {
        return this.mDownloadingListener;
    }

    public File getFile() {
        return this.mFile;
    }

    @Override // com.download.library.Extra
    public String getFileMD5() {
        if (TextUtils.isEmpty(this.fileMD5)) {
            String h2 = d0.f8443a.h(this.mFile);
            this.fileMD5 = h2;
            if (h2 == null) {
                this.fileMD5 = "";
            }
        }
        return super.getFileMD5();
    }

    public Uri getFileUri() {
        return Uri.fromFile(this.mFile);
    }

    public int getId() {
        return this.mId;
    }

    public long getLoaded() {
        return this.loaded;
    }

    public String getRedirect() {
        return this.redirect;
    }

    public synchronized int getStatus() {
        return this.status;
    }

    public Throwable getThrowable() {
        return this.mThrowable;
    }

    public long getTotalsLength() {
        return this.mTotalsLength;
    }

    public long getUsedTime() {
        long j2;
        long j3;
        if (this.status != 1002) {
            if (this.status == 1006) {
                j2 = this.endTime - this.beginTime;
                j3 = this.detalTime;
            } else if (this.status == 1001) {
                long j4 = this.pauseTime;
                if (j4 > 0) {
                    return (j4 - this.beginTime) - this.detalTime;
                }
                return 0;
            } else if (this.status == 1004 || this.status == 1003) {
                j2 = this.pauseTime - this.beginTime;
                j3 = this.detalTime;
            } else if (this.status == 1000) {
                long j5 = this.pauseTime;
                if (j5 > 0) {
                    return (j5 - this.beginTime) - this.detalTime;
                }
                return 0;
            } else if (this.status != 1005 && this.status != 1007) {
                return 0;
            } else {
                j2 = this.endTime - this.beginTime;
                j3 = this.detalTime;
            }
            return j2 - j3;
        } else if (this.beginTime > 0) {
            return (SystemClock.elapsedRealtime() - this.beginTime) - this.detalTime;
        } else {
            return 0;
        }
    }

    public boolean isCanceled() {
        return getStatus() == 1006;
    }

    public boolean isCompleted() {
        int status2 = getStatus();
        return status2 == 1006 || status2 == 1004 || status2 == 1005 || status2 == 1007;
    }

    public boolean isCustomFile() {
        return this.isCustomFile;
    }

    public boolean isPaused() {
        return getStatus() == 1004;
    }

    public boolean isPausing() {
        return getStatus() == 1003;
    }

    public boolean isSuccessful() {
        return getStatus() == 1005;
    }

    public boolean isUniquePath() {
        return this.uniquePath;
    }

    public void pause() {
        this.pauseTime = SystemClock.elapsedRealtime();
        this.connectTimes = 0;
        setStatus(STATUS_PAUSED);
    }

    public void pausing() {
        setStatus(STATUS_PAUSING);
        this.pauseTime = SystemClock.elapsedRealtime();
    }

    public void resetConnectTimes() {
        this.connectTimes = 0;
    }

    public void resetTime() {
        this.beginTime = 0;
        this.pauseTime = 0;
        this.endTime = 0;
        this.detalTime = 0;
    }

    public DownloadTask setBlockMaxTime(long j2) {
        this.blockMaxTime = j2;
        return this;
    }

    public DownloadTask setBreakPointDownload(boolean z) {
        this.mIsBreakPointDownload = z;
        return this;
    }

    public void setCalculateMD5(boolean z) {
        this.calculateMD5 = z;
    }

    public DownloadTask setConnectTimeOut(long j2) {
        this.connectTimeOut = j2;
        return this;
    }

    public DownloadTask setContentDisposition(String str) {
        this.mContentDisposition = str;
        return this;
    }

    public DownloadTask setContentLength(long j2) {
        this.mContentLength = j2;
        return this;
    }

    public DownloadTask setContext(Context context) {
        this.mContext = context.getApplicationContext();
        return this;
    }

    public DownloadTask setDownloadDoneIcon(int i2) {
        this.mDownloadDoneIcon = i2;
        return this;
    }

    public DownloadTask setDownloadListener(f fVar) {
        this.mDownloadListener = fVar;
        return this;
    }

    public DownloadTask setDownloadListenerAdapter(g gVar) {
        setDownloadListener(gVar);
        setDownloadingListener(gVar);
        setDownloadStatusListener(gVar);
        return this;
    }

    public void setDownloadStatusListener(n nVar) {
        this.mDownloadStatusListener = nVar;
    }

    public DownloadTask setDownloadTimeOut(long j2) {
        this.downloadTimeOut = j2;
        return this;
    }

    public DownloadTask setDownloadingListener(v vVar) {
        this.mDownloadingListener = vVar;
        return this;
    }

    public DownloadTask setEnableIndicator(boolean z) {
        if (!z || this.mFile == null || !TextUtils.isEmpty(this.authority)) {
            this.mEnableIndicator = z;
        } else {
            Objects.requireNonNull(d0.f8443a);
            this.mEnableIndicator = false;
        }
        return this;
    }

    public DownloadTask setFile(File file) {
        if (!file.exists() && file.isFile()) {
            try {
                File file2 = new File(file.getParent());
                if (!file2.exists()) {
                    file2.mkdirs();
                }
                file.createNewFile();
            } catch (IOException e2) {
                e2.printStackTrace();
                Objects.requireNonNull(d0.f8443a);
                return this;
            }
        }
        this.mFile = file;
        this.authority = "";
        checkCustomFilePath(file);
        return this;
    }

    public DownloadTask setFileMD5(String str) {
        this.fileMD5 = str;
        return this;
    }

    public DownloadTask setFileSafe(File file) {
        this.mFile = file;
        return this;
    }

    public DownloadTask setForceDownload(boolean z) {
        this.mIsForceDownload = z;
        return this;
    }

    public DownloadTask setIcon(int i2) {
        this.mDownloadIcon = i2;
        return this;
    }

    public void setLoaded(long j2) {
        this.loaded = j2;
    }

    public DownloadTask setMimetype(String str) {
        this.mMimetype = str;
        return this;
    }

    public DownloadTask setParallelDownload(boolean z) {
        this.mIsParallelDownload = z;
        return this;
    }

    public DownloadTask setQuickProgress(boolean z) {
        this.quickProgress = z;
        return this;
    }

    public void setRedirect(String str) {
        this.redirect = str;
    }

    public DownloadTask setRetry(int i2) {
        if (i2 > 5) {
            i2 = 5;
        }
        if (i2 < 0) {
            i2 = 0;
        }
        this.retry = i2;
        return this;
    }

    public synchronized void setStatus(@DownloadTaskStatus int i2) {
        this.status = i2;
        n nVar = this.mDownloadStatusListener;
        if (nVar != null) {
            e.a().c(new a(this, nVar, this, i2), 0);
        }
    }

    public DownloadTask setTargetCompareMD5(String str) {
        this.targetCompareMD5 = str;
        if (!TextUtils.isEmpty(str)) {
            this.calculateMD5 = true;
        }
        return this;
    }

    public void setThrowable(Throwable th) {
        this.mThrowable = th;
    }

    public void setTotalsLength(long j2) {
        this.mTotalsLength = j2;
    }

    public void setUniquePath(boolean z) {
        this.uniquePath = z;
    }

    public DownloadTask setUrl(String str) {
        this.mUrl = str;
        return this;
    }

    public DownloadTask setUserAgent(String str) {
        this.mUserAgent = str;
        return this;
    }

    public synchronized void setup() {
        if (this.mutex == null) {
            ReentrantLock reentrantLock = new ReentrantLock();
            this.mutex = reentrantLock;
            this.mCondition = reentrantLock.newCondition();
        }
    }

    public void successful() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(1005);
    }

    public void updateTime(long j2) {
        long j3 = this.beginTime;
        if (j3 == 0) {
            this.beginTime = j2;
        } else if (j3 != j2) {
            this.detalTime = Math.abs(j2 - this.pauseTime) + this.detalTime;
        }
    }

    @Override // java.lang.Object
    public DownloadTask clone() {
        try {
            DownloadTask downloadTask = new DownloadTask();
            copy(downloadTask);
            return downloadTask;
        } catch (Throwable th) {
            th.printStackTrace();
            return new DownloadTask();
        }
    }

    public DownloadTask setFile(File file, String str) {
        if (!file.exists() && file.isFile()) {
            try {
                file.createNewFile();
            } catch (IOException e2) {
                e2.printStackTrace();
                Objects.requireNonNull(d0.f8443a);
                return this;
            }
        }
        this.mFile = file;
        this.authority = str;
        checkCustomFilePath(file);
        return this;
    }
}
