package com.grass.mh.view.gridpager;

import android.annotation.SuppressLint;
import android.graphics.PointF;
import android.graphics.Rect;
import android.util.Log;
import android.util.SparseArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import d.a.a.a.a;

public class PagerGridLayoutManager extends RecyclerView.LayoutManager implements RecyclerView.SmoothScroller.ScrollVectorProvider {
    public static final int HORIZONTAL = 1;
    private static final String TAG = "PagerGridLayoutManager";
    public static final int VERTICAL = 0;
    private boolean mAllowContinuousScroll = true;
    private boolean mChangeSelectInScrolling = true;
    private int mColumns;
    private int mHeightUsed = 0;
    private SparseArray<Rect> mItemFrames = new SparseArray<>();
    private int mItemHeight = 0;
    private int mItemWidth = 0;
    private int mLastPageCount = -1;
    private int mLastPageIndex = -1;
    private int mMaxScrollX;
    private int mMaxScrollY;
    private int mOffsetX = 0;
    private int mOffsetY = 0;
    private int mOnePageSize;
    @OrientationType
    private int mOrientation;
    private PageListener mPageListener = null;
    private RecyclerView mRecyclerView;
    private int mRows;
    private int mScrollState = 0;
    private int mWidthUsed = 0;

    public @interface OrientationType {
    }

    public interface PageListener {
        void onPageSelect(int i2);

        void onPageSizeChanged(int i2);
    }

    public PagerGridLayoutManager(int i2, int i3, @OrientationType int i4) {
        this.mOrientation = i4;
        this.mRows = i2;
        this.mColumns = i3;
        this.mOnePageSize = i2 * i3;
    }

    private void addOrRemove(RecyclerView.p pVar, Rect rect, int i2) {
        View view = pVar.l(i2, false, Long.MAX_VALUE).itemView;
        Rect itemFrameByPosition = getItemFrameByPosition(i2);
        if (!Rect.intersects(rect, itemFrameByPosition)) {
            removeAndRecycleView(view, pVar);
            return;
        }
        addView(view);
        measureChildWithMargins(view, this.mWidthUsed, this.mHeightUsed);
        RecyclerView.l lVar = (RecyclerView.l) view.getLayoutParams();
        layoutDecorated(view, getPaddingLeft() + (itemFrameByPosition.left - this.mOffsetX) + ((ViewGroup.MarginLayoutParams) lVar).leftMargin, getPaddingTop() + (itemFrameByPosition.top - this.mOffsetY) + ((ViewGroup.MarginLayoutParams) lVar).topMargin, getPaddingLeft() + ((itemFrameByPosition.right - this.mOffsetX) - ((ViewGroup.MarginLayoutParams) lVar).rightMargin), getPaddingTop() + ((itemFrameByPosition.bottom - this.mOffsetY) - ((ViewGroup.MarginLayoutParams) lVar).bottomMargin));
    }

    private Rect getItemFrameByPosition(int i2) {
        int i3;
        Rect rect = this.mItemFrames.get(i2);
        if (rect == null) {
            rect = new Rect();
            int i4 = i2 / this.mOnePageSize;
            int i5 = 0;
            if (canScrollHorizontally()) {
                i5 = (getUsableWidth() * i4) + 0;
                i3 = 0;
            } else {
                i3 = (getUsableHeight() * i4) + 0;
            }
            int i6 = i2 % this.mOnePageSize;
            int i7 = this.mColumns;
            int i8 = i6 / i7;
            int i9 = i6 - (i7 * i8);
            int i10 = (this.mItemWidth * i9) + i5;
            int i11 = (this.mItemHeight * i8) + i3;
            PagerConfig.Logi("pagePos = " + i6);
            PagerConfig.Logi("行 = " + i8);
            PagerConfig.Logi("列 = " + i9);
            PagerConfig.Logi("offsetX = " + i10);
            PagerConfig.Logi("offsetY = " + i11);
            rect.left = i10;
            rect.top = i11;
            rect.right = i10 + this.mItemWidth;
            rect.bottom = i11 + this.mItemHeight;
            this.mItemFrames.put(i2, rect);
        }
        return rect;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x002a, code lost:
        if ((r2 % r0) > (r0 / 2)) goto L_0x002c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:6:0x0017, code lost:
        if ((r2 % r0) > (r0 / 2)) goto L_0x002c;
     */
    private int getPageIndexByOffset() {
        int i2 = 0;
        if (canScrollVertically()) {
            int usableHeight = getUsableHeight();
            int i3 = this.mOffsetY;
            if (i3 > 0 && usableHeight > 0) {
                i2 = i3 / usableHeight;
            }
            PagerConfig.Logi("getPageIndexByOffset pageIndex = " + i2);
            return i2;
        }
        int usableWidth = getUsableWidth();
        int i4 = this.mOffsetX;
        if (i4 > 0 && usableWidth > 0) {
            i2 = i4 / usableWidth;
        }
        PagerConfig.Logi("getPageIndexByOffset pageIndex = " + i2);
        return i2;
        i2++;
        PagerConfig.Logi("getPageIndexByOffset pageIndex = " + i2);
        return i2;
    }

    private int getPageIndexByPos(int i2) {
        return i2 / this.mOnePageSize;
    }

    private int[] getPageLeftTopByPosition(int i2) {
        int[] iArr = new int[2];
        int pageIndexByPos = getPageIndexByPos(i2);
        if (canScrollHorizontally()) {
            iArr[0] = pageIndexByPos * getUsableWidth();
            iArr[1] = 0;
        } else {
            iArr[0] = 0;
            iArr[1] = pageIndexByPos * getUsableHeight();
        }
        return iArr;
    }

    private int getTotalPageCount() {
        if (getItemCount() <= 0) {
            return 0;
        }
        int itemCount = getItemCount() / this.mOnePageSize;
        return getItemCount() % this.mOnePageSize != 0 ? itemCount + 1 : itemCount;
    }

    private int getUsableHeight() {
        return (getHeight() - getPaddingTop()) - getPaddingBottom();
    }

    private int getUsableWidth() {
        return (getWidth() - getPaddingLeft()) - getPaddingRight();
    }

    @SuppressLint({"CheckResult"})
    private void recycleAndFillItems(RecyclerView.p pVar, RecyclerView.r rVar, boolean z) {
        if (!rVar.f1886g) {
            StringBuilder B = a.B("mOffsetX = ");
            B.append(this.mOffsetX);
            PagerConfig.Logi(B.toString());
            PagerConfig.Logi("mOffsetY = " + this.mOffsetY);
            Rect rect = new Rect(this.mOffsetX - this.mItemWidth, this.mOffsetY - this.mItemHeight, getUsableWidth() + this.mOffsetX + this.mItemWidth, getUsableHeight() + this.mOffsetY + this.mItemHeight);
            int i2 = 0;
            rect.intersect(0, 0, this.mMaxScrollX + getUsableWidth(), this.mMaxScrollY + getUsableHeight());
            PagerConfig.Loge("displayRect = " + rect.toString());
            int pageIndexByOffset = getPageIndexByOffset() * this.mOnePageSize;
            PagerConfig.Logi("startPos = " + pageIndexByOffset);
            int i3 = this.mOnePageSize;
            int i4 = pageIndexByOffset - (i3 * 2);
            if (i4 >= 0) {
                i2 = i4;
            }
            int i5 = (i3 * 4) + i2;
            if (i5 > getItemCount()) {
                i5 = getItemCount();
            }
            PagerConfig.Loge("startPos = " + i2);
            PagerConfig.Loge("stopPos = " + i5);
            detachAndScrapAttachedViews(pVar);
            if (!z) {
                while (true) {
                    i5--;
                    if (i5 < i2) {
                        break;
                    }
                    addOrRemove(pVar, rect, i5);
                }
            } else {
                while (i2 < i5) {
                    addOrRemove(pVar, rect, i2);
                    i2++;
                }
            }
            StringBuilder B2 = a.B("child count = ");
            B2.append(getChildCount());
            PagerConfig.Loge(B2.toString());
        }
    }

    private void setPageCount(int i2) {
        if (i2 >= 0) {
            PageListener pageListener = this.mPageListener;
            if (!(pageListener == null || i2 == this.mLastPageCount)) {
                pageListener.onPageSizeChanged(i2);
            }
            this.mLastPageCount = i2;
        }
    }

    private void setPageIndex(int i2, boolean z) {
        PageListener pageListener;
        PagerConfig.Loge("setPageIndex = " + i2 + ":" + z);
        if (i2 != this.mLastPageIndex) {
            if (isAllowContinuousScroll()) {
                this.mLastPageIndex = i2;
            } else if (!z) {
                this.mLastPageIndex = i2;
            }
            if ((!z || this.mChangeSelectInScrolling) && i2 >= 0 && (pageListener = this.mPageListener) != null) {
                pageListener.onPageSelect(i2);
            }
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public boolean canScrollHorizontally() {
        return this.mOrientation == 1;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public boolean canScrollVertically() {
        return this.mOrientation == 0;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.SmoothScroller.ScrollVectorProvider
    public PointF computeScrollVectorForPosition(int i2) {
        PointF pointF = new PointF();
        int[] snapOffset = getSnapOffset(i2);
        pointF.x = (float) snapOffset[0];
        pointF.y = (float) snapOffset[1];
        return pointF;
    }

    public int findNextPageFirstPos() {
        int i2 = this.mLastPageIndex + 1;
        if (i2 >= getTotalPageCount()) {
            i2 = getTotalPageCount() - 1;
        }
        PagerConfig.Loge("computeScrollVectorForPosition next = " + i2);
        return i2 * this.mOnePageSize;
    }

    public int findPrePageFirstPos() {
        int i2 = this.mLastPageIndex - 1;
        PagerConfig.Loge("computeScrollVectorForPosition pre = " + i2);
        if (i2 < 0) {
            i2 = 0;
        }
        PagerConfig.Loge("computeScrollVectorForPosition pre = " + i2);
        return i2 * this.mOnePageSize;
    }

    public View findSnapView() {
        if (getFocusedChild() != null) {
            return getFocusedChild();
        }
        if (getChildCount() <= 0) {
            return null;
        }
        int pageIndexByOffset = getPageIndexByOffset() * this.mOnePageSize;
        for (int i2 = 0; i2 < getChildCount(); i2++) {
            if (getPosition(getChildAt(i2)) == pageIndexByOffset) {
                return getChildAt(i2);
            }
        }
        return getChildAt(0);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public RecyclerView.l generateDefaultLayoutParams() {
        return new RecyclerView.l(-2, -2);
    }

    public int getOffsetX() {
        return this.mOffsetX;
    }

    public int getOffsetY() {
        return this.mOffsetY;
    }

    public int[] getSnapOffset(int i2) {
        int[] pageLeftTopByPosition = getPageLeftTopByPosition(i2);
        return new int[]{pageLeftTopByPosition[0] - this.mOffsetX, pageLeftTopByPosition[1] - this.mOffsetY};
    }

    public boolean isAllowContinuousScroll() {
        return this.mAllowContinuousScroll;
    }

    public void nextPage() {
        scrollToPage(getPageIndexByOffset() + 1);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onAttachedToWindow(RecyclerView recyclerView) {
        super.onAttachedToWindow(recyclerView);
        this.mRecyclerView = recyclerView;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onLayoutChildren(RecyclerView.p pVar, RecyclerView.r rVar) {
        PagerConfig.Logi("Item onLayoutChildren");
        PagerConfig.Logi("Item onLayoutChildren isPreLayout = " + rVar.f1886g);
        PagerConfig.Logi("Item onLayoutChildren isMeasuring = " + rVar.f1888i);
        PagerConfig.Loge("Item onLayoutChildren state = " + rVar);
        if (!rVar.f1886g && rVar.f1885f) {
            int i2 = 0;
            if (getItemCount() == 0) {
                removeAndRecycleAllViews(pVar);
                setPageCount(0);
                setPageIndex(0, false);
                return;
            }
            setPageCount(getTotalPageCount());
            setPageIndex(getPageIndexByOffset(), false);
            int itemCount = getItemCount() / this.mOnePageSize;
            if (getItemCount() % this.mOnePageSize != 0) {
                itemCount++;
            }
            if (canScrollHorizontally()) {
                int usableWidth = (itemCount - 1) * getUsableWidth();
                this.mMaxScrollX = usableWidth;
                this.mMaxScrollY = 0;
                if (this.mOffsetX > usableWidth) {
                    this.mOffsetX = usableWidth;
                }
            } else {
                this.mMaxScrollX = 0;
                int usableHeight = (itemCount - 1) * getUsableHeight();
                this.mMaxScrollY = usableHeight;
                if (this.mOffsetY > usableHeight) {
                    this.mOffsetY = usableHeight;
                }
            }
            StringBuilder B = a.B("count = ");
            B.append(getItemCount());
            PagerConfig.Logi(B.toString());
            if (this.mItemWidth <= 0) {
                this.mItemWidth = getUsableWidth() / this.mColumns;
            }
            if (this.mItemHeight <= 0) {
                this.mItemHeight = getUsableHeight() / this.mRows;
            }
            this.mWidthUsed = getUsableWidth() - this.mItemWidth;
            this.mHeightUsed = getUsableHeight() - this.mItemHeight;
            for (int i3 = 0; i3 < this.mOnePageSize * 2; i3++) {
                getItemFrameByPosition(i3);
            }
            if (this.mOffsetX == 0 && this.mOffsetY == 0) {
                while (i2 < this.mOnePageSize && i2 < getItemCount()) {
                    View e2 = pVar.e(i2);
                    addView(e2);
                    measureChildWithMargins(e2, this.mWidthUsed, this.mHeightUsed);
                    i2++;
                }
            }
            recycleAndFillItems(pVar, rVar, true);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onLayoutCompleted(RecyclerView.r rVar) {
        super.onLayoutCompleted(rVar);
        if (!rVar.f1886g) {
            setPageCount(getTotalPageCount());
            setPageIndex(getPageIndexByOffset(), false);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onMeasure(RecyclerView.p pVar, RecyclerView.r rVar, int i2, int i3) {
        super.onMeasure(pVar, rVar, i2, i3);
        int size = View.MeasureSpec.getSize(i2);
        int mode = View.MeasureSpec.getMode(i2);
        int size2 = View.MeasureSpec.getSize(i3);
        int mode2 = View.MeasureSpec.getMode(i3);
        if (mode != 1073741824 && size > 0) {
            mode = 1073741824;
        }
        if (mode2 != 1073741824 && size2 > 0) {
            mode2 = 1073741824;
        }
        setMeasuredDimension(View.MeasureSpec.makeMeasureSpec(size, mode), View.MeasureSpec.makeMeasureSpec(size2, mode2));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void onScrollStateChanged(int i2) {
        PagerConfig.Logi("onScrollStateChanged = " + i2);
        this.mScrollState = i2;
        super.onScrollStateChanged(i2);
        if (i2 == 0) {
            setPageIndex(getPageIndexByOffset(), false);
        }
    }

    public void prePage() {
        scrollToPage(getPageIndexByOffset() - 1);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int scrollHorizontallyBy(int i2, RecyclerView.p pVar, RecyclerView.r rVar) {
        int i3 = this.mOffsetX;
        int i4 = i3 + i2;
        int i5 = this.mMaxScrollX;
        if (i4 > i5) {
            i2 = i5 - i3;
        } else if (i4 < 0) {
            i2 = 0 - i3;
        }
        this.mOffsetX = i3 + i2;
        setPageIndex(getPageIndexByOffset(), true);
        offsetChildrenHorizontal(-i2);
        if (i2 > 0) {
            recycleAndFillItems(pVar, rVar, true);
        } else {
            recycleAndFillItems(pVar, rVar, false);
        }
        return i2;
    }

    public void scrollToPage(int i2) {
        int i3;
        int i4;
        if (i2 < 0 || i2 >= this.mLastPageCount) {
            String str = TAG;
            StringBuilder C = a.C("pageIndex = ", i2, " is out of bounds, mast in [0, ");
            C.append(this.mLastPageCount);
            C.append(")");
            Log.e(str, C.toString());
        } else if (this.mRecyclerView == null) {
            Log.e(TAG, "RecyclerView Not Found!");
        } else {
            if (canScrollVertically()) {
                i4 = (getUsableHeight() * i2) - this.mOffsetY;
                i3 = 0;
            } else {
                i3 = (getUsableWidth() * i2) - this.mOffsetX;
                i4 = 0;
            }
            PagerConfig.Loge("mTargetOffsetXBy = " + i3);
            PagerConfig.Loge("mTargetOffsetYBy = " + i4);
            this.mRecyclerView.scrollBy(i3, i4);
            setPageIndex(i2, false);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void scrollToPosition(int i2) {
        scrollToPage(getPageIndexByPos(i2));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public int scrollVerticallyBy(int i2, RecyclerView.p pVar, RecyclerView.r rVar) {
        int i3 = this.mOffsetY;
        int i4 = i3 + i2;
        int i5 = this.mMaxScrollY;
        if (i4 > i5) {
            i2 = i5 - i3;
        } else if (i4 < 0) {
            i2 = 0 - i3;
        }
        this.mOffsetY = i3 + i2;
        setPageIndex(getPageIndexByOffset(), true);
        offsetChildrenVertical(-i2);
        if (i2 > 0) {
            recycleAndFillItems(pVar, rVar, true);
        } else {
            recycleAndFillItems(pVar, rVar, false);
        }
        return i2;
    }

    public void setAllowContinuousScroll(boolean z) {
        this.mAllowContinuousScroll = z;
    }

    public void setChangeSelectInScrolling(boolean z) {
        this.mChangeSelectInScrolling = z;
    }

    @OrientationType
    public int setOrientationType(@OrientationType int i2) {
        int i3 = this.mOrientation;
        if (i3 == i2 || this.mScrollState != 0) {
            return i3;
        }
        this.mOrientation = i2;
        this.mItemFrames.clear();
        int i4 = this.mOffsetX;
        this.mOffsetX = (this.mOffsetY / getUsableHeight()) * getUsableWidth();
        this.mOffsetY = (i4 / getUsableWidth()) * getUsableHeight();
        int i5 = this.mMaxScrollX;
        this.mMaxScrollX = (this.mMaxScrollY / getUsableHeight()) * getUsableWidth();
        this.mMaxScrollY = (i5 / getUsableWidth()) * getUsableHeight();
        return this.mOrientation;
    }

    public void setPageListener(PageListener pageListener) {
        this.mPageListener = pageListener;
    }

    public void smoothNextPage() {
        smoothScrollToPage(getPageIndexByOffset() + 1);
    }

    public void smoothPrePage() {
        smoothScrollToPage(getPageIndexByOffset() - 1);
    }

    public void smoothScrollToPage(int i2) {
        if (i2 < 0 || i2 >= this.mLastPageCount) {
            String str = TAG;
            StringBuilder B = a.B("pageIndex is outOfIndex, must in [0, ");
            B.append(this.mLastPageCount);
            B.append(").");
            Log.e(str, B.toString());
        } else if (this.mRecyclerView == null) {
            Log.e(TAG, "RecyclerView Not Found!");
        } else {
            int pageIndexByOffset = getPageIndexByOffset();
            if (Math.abs(i2 - pageIndexByOffset) > 3) {
                if (i2 > pageIndexByOffset) {
                    scrollToPage(i2 - 3);
                } else if (i2 < pageIndexByOffset) {
                    scrollToPage(i2 + 3);
                }
            }
            PagerGridSmoothScroller pagerGridSmoothScroller = new PagerGridSmoothScroller(this.mRecyclerView);
            pagerGridSmoothScroller.setTargetPosition(i2 * this.mOnePageSize);
            startSmoothScroll(pagerGridSmoothScroller);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
    public void smoothScrollToPosition(RecyclerView recyclerView, RecyclerView.r rVar, int i2) {
        smoothScrollToPage(getPageIndexByPos(i2));
    }
}
