package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View;
import android.widget.TextView;
import androidx.appcompat.app.AppCompatActivity;
import com.luck.picture.lib.app.PictureAppMaster;
import com.luck.picture.lib.compress.Luban;
import com.luck.picture.lib.compress.OnCompressListener;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.dialog.PictureLoadingDialog;
import com.luck.picture.lib.engine.CompressEngine;
import com.luck.picture.lib.engine.PictureSelectorEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.immersive.NavBarUtils;
import com.luck.picture.lib.language.PictureLanguageUtils;
import com.luck.picture.lib.listener.OnCallbackListener;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.model.LocalMediaPageLoader;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureSelectorUIStyle;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.VoiceUtils;
import d.k.a.a.a;
import d.k.a.a.b;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public abstract class PictureBaseActivity extends AppCompatActivity {

    /* renamed from: d  reason: collision with root package name */
    public static final /* synthetic */ int f7285d = 0;
    public int colorPrimary;
    public int colorPrimaryDark;
    public PictureSelectionConfig config;
    public View container;
    public boolean isHasMore = true;
    public boolean isOnSaveInstanceState;
    public Handler mHandler = new Handler(Looper.getMainLooper());
    public PictureLoadingDialog mLoadingDialog;
    public int mPage = 1;
    public boolean numComplete;
    public boolean openWhiteStatusBar;
    public List<LocalMedia> selectionMedias = new ArrayList();

    private void compressToLuban(final List<LocalMedia> list) {
        if (this.config.synOrAsy) {
            PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<List<File>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass2 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public List<File> doInBackground() {
                    return Luban.with(PictureBaseActivity.this.getContext()).loadMediaData(list).isCamera(PictureBaseActivity.this.config.camera).setTargetDir(PictureBaseActivity.this.config.compressSavePath).setCompressQuality(PictureBaseActivity.this.config.compressQuality).isAutoRotating(PictureBaseActivity.this.config.isAutoRotating).setFocusAlpha(PictureBaseActivity.this.config.focusAlpha).setNewCompressFileName(PictureBaseActivity.this.config.renameCompressFileName).ignoreBy(PictureBaseActivity.this.config.minimumCompressSize).get();
                }

                public void onSuccess(List<File> list) {
                    if (list == null || list.size() <= 0 || list.size() != list.size()) {
                        PictureBaseActivity.this.onResult(list);
                    } else {
                        PictureBaseActivity.this.handleCompressCallBack(list, list);
                    }
                }
            });
        } else {
            Luban.with(this).loadMediaData(list).ignoreBy(this.config.minimumCompressSize).isCamera(this.config.camera).setCompressQuality(this.config.compressQuality).setTargetDir(this.config.compressSavePath).isAutoRotating(this.config.isAutoRotating).setFocusAlpha(this.config.focusAlpha).setNewCompressFileName(this.config.renameCompressFileName).setCompressListener(new OnCompressListener() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onError(Throwable th) {
                    PictureBaseActivity.this.onResult(list);
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onStart() {
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onSuccess(List<LocalMedia> list) {
                    PictureBaseActivity.this.onResult(list);
                }
            }).launch();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleCompressCallBack(List<LocalMedia> list, List<File> list2) {
        if (list == null || list2 == null) {
            exit();
            return;
        }
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        int size = list.size();
        if (list2.size() == size) {
            for (int i2 = 0; i2 < size; i2++) {
                File file = list2.get(i2);
                if (file != null) {
                    String absolutePath = file.getAbsolutePath();
                    LocalMedia localMedia = list.get(i2);
                    boolean z = true;
                    boolean z2 = !TextUtils.isEmpty(absolutePath) && PictureMimeType.isHasHttp(absolutePath);
                    boolean isHasVideo = PictureMimeType.isHasVideo(localMedia.getMimeType());
                    if (isHasVideo || z2) {
                        z = false;
                    }
                    localMedia.setCompressed(z);
                    if (isHasVideo || z2) {
                        absolutePath = null;
                    }
                    localMedia.setCompressPath(absolutePath);
                    if (checkedAndroid_Q) {
                        localMedia.setAndroidQToPath(localMedia.getCompressPath());
                    }
                }
            }
        }
        onResult(list);
    }

    private void initConfig() {
        if (this.config.selectionMedias != null) {
            this.selectionMedias.clear();
            this.selectionMedias.addAll(this.config.selectionMedias);
        }
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle != null) {
            this.openWhiteStatusBar = pictureSelectorUIStyle.picture_statusBarChangeTextColor;
            int i2 = pictureSelectorUIStyle.picture_top_titleBarBackgroundColor;
            if (i2 != 0) {
                this.colorPrimary = i2;
            }
            int i3 = pictureSelectorUIStyle.picture_statusBarBackgroundColor;
            if (i3 != 0) {
                this.colorPrimaryDark = i3;
            }
            this.numComplete = pictureSelectorUIStyle.picture_switchSelectTotalStyle;
            this.config.checkNumMode = pictureSelectorUIStyle.picture_switchSelectNumberStyle;
        } else {
            PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
            if (pictureParameterStyle != null) {
                this.openWhiteStatusBar = pictureParameterStyle.isChangeStatusBarFontColor;
                int i4 = pictureParameterStyle.pictureTitleBarBackgroundColor;
                if (i4 != 0) {
                    this.colorPrimary = i4;
                }
                int i5 = pictureParameterStyle.pictureStatusBarColor;
                if (i5 != 0) {
                    this.colorPrimaryDark = i5;
                }
                this.numComplete = pictureParameterStyle.isOpenCompletedNumStyle;
                this.config.checkNumMode = pictureParameterStyle.isOpenCheckNumStyle;
            } else {
                boolean z = this.config.isChangeStatusBarFontColor;
                this.openWhiteStatusBar = z;
                if (!z) {
                    this.openWhiteStatusBar = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
                }
                boolean z2 = this.config.isOpenStyleNumComplete;
                this.numComplete = z2;
                if (!z2) {
                    this.numComplete = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_numComplete);
                }
                PictureSelectionConfig pictureSelectionConfig = this.config;
                boolean z3 = pictureSelectionConfig.isOpenStyleCheckNumMode;
                pictureSelectionConfig.checkNumMode = z3;
                if (!z3) {
                    pictureSelectionConfig.checkNumMode = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_checkNumMode);
                }
                int i6 = this.config.titleBarBackgroundColor;
                if (i6 != 0) {
                    this.colorPrimary = i6;
                } else {
                    this.colorPrimary = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimary);
                }
                int i7 = this.config.pictureStatusBarColor;
                if (i7 != 0) {
                    this.colorPrimaryDark = i7;
                } else {
                    this.colorPrimaryDark = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimaryDark);
                }
            }
        }
        if (this.config.openClickSound) {
            VoiceUtils.getInstance().init(getContext());
        }
    }

    private void newCreateEngine() {
        PictureSelectorEngine pictureSelectorEngine;
        if (PictureSelectionConfig.imageEngine == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.imageEngine = pictureSelectorEngine.createEngine();
        }
    }

    private void newCreateResultCallbackListener() {
        PictureSelectorEngine pictureSelectorEngine;
        if (this.config.isCallbackMode && PictureSelectionConfig.listener == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.listener = pictureSelectorEngine.getResultCallbackListener();
        }
    }

    private void normalResult(List<LocalMedia> list) {
        int size = list.size();
        int i2 = 0;
        for (int i3 = 0; i3 < size; i3++) {
            LocalMedia localMedia = list.get(i3);
            if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                if (localMedia.isCut() && localMedia.isCompressed()) {
                    localMedia.setAndroidQToPath(localMedia.getCompressPath());
                }
                if (this.config.isCheckOriginalImage) {
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                }
            }
        }
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
            if (list.size() > 0) {
                i2 = list.size() - 1;
            }
            list.addAll(i2, this.selectionMedias);
        }
        OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
        if (onResultCallbackListener != null) {
            onResultCallbackListener.onResult(list);
        } else {
            setResult(-1, PictureSelector.putIntentResult(list));
        }
        exit();
    }

    private void onResultToAndroidAsy(List<LocalMedia> list) {
        int size = list.size();
        boolean z = false;
        int i2 = 0;
        while (true) {
            if (i2 >= size) {
                break;
            }
            LocalMedia localMedia = list.get(i2);
            if (localMedia == null || TextUtils.isEmpty(localMedia.getPath()) || (!this.config.isCheckOriginalImage && (localMedia.isCut() || localMedia.isCompressed() || !TextUtils.isEmpty(localMedia.getAndroidQToPath())))) {
                i2++;
            }
        }
        z = true;
        if (z) {
            startThreadCopySandbox(list);
        } else {
            normalResult(list);
        }
    }

    private void releaseResultListener() {
        if (this.config != null) {
            PictureSelectionConfig.destroy();
            LocalMediaPageLoader.setInstanceNull();
            PictureThreadUtils.cancel(PictureThreadUtils.getSinglePool());
        }
    }

    private void startThreadCopySandbox(final List<LocalMedia> list) {
        showPleaseDialog();
        PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
            /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass4 */

            /* JADX WARNING: Removed duplicated region for block: B:28:0x0095  */
            /* JADX WARNING: Removed duplicated region for block: B:38:0x00c9 A[SYNTHETIC] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMedia> doInBackground() {
                boolean z;
                int size = list.size();
                for (int i2 = 0; i2 < size; i2++) {
                    LocalMedia localMedia = (LocalMedia) list.get(i2);
                    if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                        if (!(!localMedia.isCut() && !localMedia.isCompressed() && TextUtils.isEmpty(localMedia.getAndroidQToPath())) || !PictureMimeType.isContent(localMedia.getPath())) {
                            if (localMedia.isCut() && localMedia.isCompressed()) {
                                localMedia.setAndroidQToPath(localMedia.getCompressPath());
                            }
                        } else if (!PictureMimeType.isHasHttp(localMedia.getPath())) {
                            localMedia.setAndroidQToPath(AndroidQTransformUtils.copyPathToAndroidQ(PictureBaseActivity.this.getContext(), localMedia.getId(), localMedia.getPath(), localMedia.getWidth(), localMedia.getHeight(), localMedia.getMimeType(), PictureBaseActivity.this.config.cameraFileName));
                            z = true;
                            if (!PictureBaseActivity.this.config.isCheckOriginalImage) {
                                localMedia.setOriginal(true);
                                if (z) {
                                    localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                                } else {
                                    localMedia.setOriginalPath(AndroidQTransformUtils.copyPathToAndroidQ(PictureBaseActivity.this.getContext(), localMedia.getId(), localMedia.getPath(), localMedia.getWidth(), localMedia.getHeight(), localMedia.getMimeType(), PictureBaseActivity.this.config.cameraFileName));
                                }
                            }
                        }
                        z = false;
                        if (!PictureBaseActivity.this.config.isCheckOriginalImage) {
                        }
                    }
                }
                return list;
            }

            public void onSuccess(List<LocalMedia> list) {
                PictureBaseActivity.this.dismissDialog();
                if (list != null) {
                    PictureSelectionConfig pictureSelectionConfig = PictureBaseActivity.this.config;
                    if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
                        list.addAll(list.size() > 0 ? list.size() - 1 : 0, PictureBaseActivity.this.selectionMedias);
                    }
                    OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
                    if (onResultCallbackListener != null) {
                        onResultCallbackListener.onResult(list);
                    } else {
                        PictureBaseActivity.this.setResult(-1, PictureSelector.putIntentResult(list));
                    }
                    PictureBaseActivity.this.exit();
                }
            }
        });
    }

    @Override // androidx.appcompat.app.AppCompatActivity
    public void attachBaseContext(Context context) {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig == null) {
            super.attachBaseContext(context);
        } else {
            super.attachBaseContext(PictureContextWrapper.wrap(context, pictureSelectionConfig.language));
        }
    }

    public void compressImage(List<LocalMedia> list) {
        CompressEngine compressEngine = PictureSelectionConfig.compressEngine;
        if (compressEngine != null) {
            compressEngine.onCompress(getContext(), list, new OnCallbackListener<List<LocalMedia>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass1 */

                public void onCall(List<LocalMedia> list) {
                    PictureBaseActivity.this.onResult(list);
                }
            });
            return;
        }
        showPleaseDialog();
        compressToLuban(list);
    }

    public void createNewFolder(List<LocalMediaFolder> list) {
        int i2;
        if (list.size() == 0) {
            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
            if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                i2 = R.string.picture_all_audio;
            } else {
                i2 = R.string.picture_camera_roll;
            }
            localMediaFolder.setName(getString(i2));
            localMediaFolder.setFirstImagePath("");
            localMediaFolder.setCameraFolder(true);
            localMediaFolder.setBucketId(-1);
            localMediaFolder.setChecked(true);
            list.add(localMediaFolder);
        }
    }

    public void dismissDialog() {
        if (!isFinishing()) {
            try {
                PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
                if (pictureLoadingDialog != null && pictureLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
            } catch (Exception e2) {
                this.mLoadingDialog = null;
                e2.printStackTrace();
            }
        }
    }

    public void exit() {
        finish();
        if (this.config.camera) {
            overridePendingTransition(0, R.anim.picture_anim_fade_out);
            if ((getContext() instanceof PictureSelectorCameraEmptyActivity) || (getContext() instanceof PictureCustomCameraActivity)) {
                releaseResultListener();
                return;
            }
            return;
        }
        overridePendingTransition(0, PictureSelectionConfig.windowAnimationStyle.activityExitAnimation);
        if (getContext() instanceof PictureSelectorActivity) {
            releaseResultListener();
            if (this.config.openClickSound) {
                VoiceUtils.getInstance().releaseSoundPool();
            }
        }
    }

    public String getAudioPath(Intent intent) {
        try {
            Uri data = intent.getData();
            if (data == null) {
                return "";
            }
            if (PictureMimeType.isContent(data.toString())) {
                return data.toString();
            }
            return data.getPath();
        } catch (Exception e2) {
            e2.printStackTrace();
            return "";
        }
    }

    public Context getContext() {
        return this;
    }

    public LocalMediaFolder getImageFolder(String str, String str2, String str3, List<LocalMediaFolder> list) {
        if (!PictureMimeType.isContent(str)) {
            str2 = str;
        }
        File parentFile = new File(str2).getParentFile();
        for (LocalMediaFolder localMediaFolder : list) {
            if (parentFile != null && localMediaFolder.getName().equals(parentFile.getName())) {
                return localMediaFolder;
            }
        }
        LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
        localMediaFolder2.setName(parentFile != null ? parentFile.getName() : "");
        localMediaFolder2.setFirstImagePath(str);
        localMediaFolder2.setFirstMimeType(str3);
        list.add(localMediaFolder2);
        return localMediaFolder2;
    }

    public abstract int getResourceId();

    public void handlerResult(List<LocalMedia> list) {
        if (this.config.isCompress) {
            compressImage(list);
        } else {
            onResult(list);
        }
    }

    public void immersive() {
        ImmersiveManage.immersiveAboveAPI23(this, this.colorPrimaryDark, this.colorPrimary, this.openWhiteStatusBar);
    }

    public void initCompleteText(int i2) {
    }

    public void initCompleteText(List<LocalMedia> list) {
    }

    public void initPictureSelectorStyle() {
    }

    public void initWidgets() {
    }

    public boolean isImmersive() {
        return true;
    }

    public boolean isRequestedOrientation() {
        return true;
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        int i2;
        this.config = PictureSelectionConfig.getInstance();
        PictureLanguageUtils.setAppLanguage(getContext(), this.config.language);
        int i3 = this.config.themeStyleId;
        if (i3 == 0) {
            i3 = R.style.picture_default_style;
        }
        setTheme(i3);
        super.onCreate(bundle);
        newCreateEngine();
        newCreateResultCallbackListener();
        if (isRequestedOrientation()) {
            setNewRequestedOrientation();
        }
        initConfig();
        if (isImmersive()) {
            immersive();
        }
        PictureSelectorUIStyle pictureSelectorUIStyle = PictureSelectionConfig.uiStyle;
        if (pictureSelectorUIStyle != null) {
            int i4 = pictureSelectorUIStyle.picture_navBarColor;
            if (i4 != 0) {
                NavBarUtils.setNavBarColor(this, i4);
            }
        } else {
            PictureParameterStyle pictureParameterStyle = PictureSelectionConfig.style;
            if (!(pictureParameterStyle == null || (i2 = pictureParameterStyle.pictureNavBarColor) == 0)) {
                NavBarUtils.setNavBarColor(this, i2);
            }
        }
        int resourceId = getResourceId();
        if (resourceId != 0) {
            setContentView(resourceId);
        }
        initWidgets();
        initPictureSelectorStyle();
        this.isOnSaveInstanceState = false;
    }

    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
        if (pictureLoadingDialog != null) {
            pictureLoadingDialog.dismiss();
            this.mLoadingDialog = null;
        }
        super.onDestroy();
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i2, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i2, strArr, iArr);
        if (i2 != 3) {
            return;
        }
        if (iArr[0] == 0) {
            Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
            if (intent.resolveActivity(getPackageManager()) != null) {
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            return;
        }
        ToastUtils.s(getContext(), getString(R.string.picture_audio));
    }

    public void onResult(List<LocalMedia> list) {
        if (!SdkVersionUtils.checkedAndroid_Q() || !this.config.isAndroidQTransform) {
            dismissDialog();
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2) {
                list.addAll(list.size() > 0 ? list.size() - 1 : 0, this.selectionMedias);
            }
            if (this.config.isCheckOriginalImage) {
                int size = list.size();
                for (int i2 = 0; i2 < size; i2++) {
                    LocalMedia localMedia = list.get(i2);
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getPath());
                }
            }
            OnResultCallbackListener<LocalMedia> onResultCallbackListener = PictureSelectionConfig.listener;
            if (onResultCallbackListener != null) {
                onResultCallbackListener.onResult(list);
            } else {
                setResult(-1, PictureSelector.putIntentResult(list));
            }
            exit();
            return;
        }
        onResultToAndroidAsy(list);
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        this.isOnSaveInstanceState = true;
        bundle.putParcelable(PictureConfig.EXTRA_CONFIG, this.config);
    }

    public void setNewRequestedOrientation() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig != null && !pictureSelectionConfig.camera) {
            setRequestedOrientation(pictureSelectionConfig.requestedOrientation);
        }
    }

    public void showPermissionsDialog(boolean z, String[] strArr, String str) {
    }

    public void showPleaseDialog() {
        try {
            if (!isFinishing()) {
                if (this.mLoadingDialog == null) {
                    this.mLoadingDialog = new PictureLoadingDialog(getContext());
                }
                if (this.mLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
                this.mLoadingDialog.show();
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    public void showPromptDialog(String str) {
        if (!isFinishing()) {
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_prompt_dialog);
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
            ((TextView) pictureCustomDialog.findViewById(R.id.btnOk)).setOnClickListener(new b(this, pictureCustomDialog));
            pictureCustomDialog.show();
        }
    }

    public void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, a.f12102d);
    }

    public void startOpenCamera() {
        Uri uri;
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            String str = null;
            PictureSelectionConfig pictureSelectionConfig = this.config;
            int i2 = pictureSelectionConfig.chooseMode;
            if (i2 == 0) {
                i2 = 1;
            }
            if (!TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
                boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.config.cameraFileName);
                PictureSelectionConfig pictureSelectionConfig2 = this.config;
                pictureSelectionConfig2.cameraFileName = !isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig2.cameraFileName, ".jpeg") : pictureSelectionConfig2.cameraFileName;
                PictureSelectionConfig pictureSelectionConfig3 = this.config;
                boolean z = pictureSelectionConfig3.camera;
                str = pictureSelectionConfig3.cameraFileName;
                if (!z) {
                    str = StringUtils.rename(str);
                }
            }
            if (SdkVersionUtils.checkedAndroid_Q()) {
                if (TextUtils.isEmpty(this.config.outPutCameraPath)) {
                    PictureSelectionConfig pictureSelectionConfig4 = this.config;
                    uri = MediaUtils.createImageUri(this, pictureSelectionConfig4.cameraFileName, pictureSelectionConfig4.suffixType);
                } else {
                    PictureSelectionConfig pictureSelectionConfig5 = this.config;
                    File createCameraFile = PictureFileUtils.createCameraFile(this, i2, str, pictureSelectionConfig5.suffixType, pictureSelectionConfig5.outPutCameraPath);
                    this.config.cameraPath = createCameraFile.getAbsolutePath();
                    uri = PictureFileUtils.parUri(this, createCameraFile);
                }
                if (uri != null) {
                    this.config.cameraPath = uri.toString();
                }
            } else {
                PictureSelectionConfig pictureSelectionConfig6 = this.config;
                File createCameraFile2 = PictureFileUtils.createCameraFile(this, i2, str, pictureSelectionConfig6.suffixType, pictureSelectionConfig6.outPutCameraPath);
                this.config.cameraPath = createCameraFile2.getAbsolutePath();
                uri = PictureFileUtils.parUri(this, createCameraFile2);
            }
            if (uri == null) {
                ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                if (this.config.camera) {
                    exit();
                    return;
                }
                return;
            }
            this.config.cameraMimeType = PictureMimeType.ofImage();
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra("output", uri);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }

    public void startOpenCameraAudio() {
        try {
            if (PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
                Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
                if (intent.resolveActivity(getPackageManager()) != null) {
                    this.config.cameraMimeType = PictureMimeType.ofAudio();
                    if (SdkVersionUtils.checkedAndroid_Q()) {
                        Uri createAudioUri = MediaUtils.createAudioUri(this, this.config.suffixType);
                        if (createAudioUri == null) {
                            ToastUtils.s(getContext(), "open is audio error，the uri is empty ");
                            if (this.config.camera) {
                                exit();
                                return;
                            }
                            return;
                        }
                        this.config.cameraPath = createAudioUri.toString();
                        intent.putExtra("output", createAudioUri);
                    }
                    startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                    return;
                }
                ToastUtils.s(getContext(), "System recording is not supported");
                return;
            }
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 3);
        } catch (Exception e2) {
            e2.printStackTrace();
            ToastUtils.s(getContext(), e2.getMessage());
        }
    }

    public void startOpenCameraVideo() {
        Uri uri;
        Intent intent = new Intent("android.media.action.VIDEO_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            String str = null;
            PictureSelectionConfig pictureSelectionConfig = this.config;
            int i2 = pictureSelectionConfig.chooseMode;
            if (i2 == 0) {
                i2 = 2;
            }
            if (!TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
                boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.config.cameraFileName);
                PictureSelectionConfig pictureSelectionConfig2 = this.config;
                pictureSelectionConfig2.cameraFileName = isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig2.cameraFileName, ".mp4") : pictureSelectionConfig2.cameraFileName;
                PictureSelectionConfig pictureSelectionConfig3 = this.config;
                boolean z = pictureSelectionConfig3.camera;
                str = pictureSelectionConfig3.cameraFileName;
                if (!z) {
                    str = StringUtils.rename(str);
                }
            }
            if (SdkVersionUtils.checkedAndroid_Q()) {
                if (TextUtils.isEmpty(this.config.outPutCameraPath)) {
                    PictureSelectionConfig pictureSelectionConfig4 = this.config;
                    uri = MediaUtils.createVideoUri(this, pictureSelectionConfig4.cameraFileName, pictureSelectionConfig4.suffixType);
                } else {
                    PictureSelectionConfig pictureSelectionConfig5 = this.config;
                    File createCameraFile = PictureFileUtils.createCameraFile(this, i2, str, pictureSelectionConfig5.suffixType, pictureSelectionConfig5.outPutCameraPath);
                    this.config.cameraPath = createCameraFile.getAbsolutePath();
                    uri = PictureFileUtils.parUri(this, createCameraFile);
                }
                if (uri != null) {
                    this.config.cameraPath = uri.toString();
                }
            } else {
                PictureSelectionConfig pictureSelectionConfig6 = this.config;
                File createCameraFile2 = PictureFileUtils.createCameraFile(this, i2, str, pictureSelectionConfig6.suffixType, pictureSelectionConfig6.outPutCameraPath);
                this.config.cameraPath = createCameraFile2.getAbsolutePath();
                uri = PictureFileUtils.parUri(this, createCameraFile2);
            }
            if (uri == null) {
                ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                if (this.config.camera) {
                    exit();
                    return;
                }
                return;
            }
            this.config.cameraMimeType = PictureMimeType.ofVideo();
            intent.putExtra("output", uri);
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra(PictureConfig.EXTRA_QUICK_CAPTURE, this.config.isQuickCapture);
            intent.putExtra("android.intent.extra.durationLimit", this.config.recordVideoSecond);
            intent.putExtra("android.intent.extra.videoQuality", this.config.videoQuality);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }
}
