package com.luck.picture.lib.model;

import android.content.ContentResolver;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ValueOf;
import d.k.a.a.f0.a;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

@Deprecated
public final class LocalMediaLoader {
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final String NOT_GIF = " AND (mime_type!='image/gif' AND mime_type!='image/*')";
    private static final String NOT_GIF_UNKNOWN = "!='image/*'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "mime_type", "width", "height", TypedValues.Transition.S_DURATION, "_size", "bucket_display_name", "_display_name", PictureConfig.EXTRA_BUCKET_ID, "date_added"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String TAG = "LocalMediaLoader";

    /* renamed from: a  reason: collision with root package name */
    public static final /* synthetic */ int f7287a = 0;
    private final PictureSelectionConfig config = PictureSelectionConfig.getInstance();
    private final boolean isAndroidQ = SdkVersionUtils.checkedAndroid_Q();
    private final Context mContext;

    public LocalMediaLoader(Context context) {
        this.mContext = context.getApplicationContext();
    }

    private String getDurationCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i2 = pictureSelectionConfig.videoMaxSecond;
        long j2 = i2 == 0 ? Long.MAX_VALUE : (long) i2;
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, (long) pictureSelectionConfig.videoMinSecond));
        objArr[1] = Math.max(0, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j2);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    private String getFileSizeCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        long j2 = pictureSelectionConfig.filterMaxFileSize;
        if (j2 == 0) {
            j2 = Long.MAX_VALUE;
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, pictureSelectionConfig.filterMinFileSize));
        objArr[1] = Math.max(0, this.config.filterMinFileSize) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j2);
        return String.format(locale, "%d <%s _size and _size <= %d", objArr);
    }

    private LocalMediaFolder getImageFolder(String str, String str2, String str3, List<LocalMediaFolder> list) {
        if (!this.config.isFallbackVersion) {
            for (LocalMediaFolder localMediaFolder : list) {
                String name = localMediaFolder.getName();
                if (!TextUtils.isEmpty(name) && name.equals(str3)) {
                    return localMediaFolder;
                }
            }
            LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
            localMediaFolder2.setName(str3);
            localMediaFolder2.setFirstImagePath(str);
            localMediaFolder2.setFirstMimeType(str2);
            list.add(localMediaFolder2);
            return localMediaFolder2;
        }
        File parentFile = new File(str).getParentFile();
        for (LocalMediaFolder localMediaFolder3 : list) {
            String name2 = localMediaFolder3.getName();
            if (!TextUtils.isEmpty(name2) && parentFile != null && name2.equals(parentFile.getName())) {
                return localMediaFolder3;
            }
        }
        LocalMediaFolder localMediaFolder4 = new LocalMediaFolder();
        localMediaFolder4.setName(parentFile != null ? parentFile.getName() : "");
        localMediaFolder4.setFirstImagePath(str);
        localMediaFolder4.setFirstMimeType(str2);
        list.add(localMediaFolder4);
        return localMediaFolder4;
    }

    private String getQueryMimeCondition() {
        HashSet<String> hashSet = this.config.queryMimeTypeHashSet;
        if (hashSet == null) {
            hashSet = new HashSet<>();
        }
        if (!TextUtils.isEmpty(this.config.specifiedFormat)) {
            hashSet.add(this.config.specifiedFormat);
        }
        StringBuilder sb = new StringBuilder();
        Iterator<String> it = hashSet.iterator();
        int i2 = -1;
        while (it.hasNext()) {
            String next = it.next();
            if (!TextUtils.isEmpty(next) && (this.config.chooseMode != PictureMimeType.ofVideo() ? this.config.chooseMode != PictureMimeType.ofImage() ? this.config.chooseMode != PictureMimeType.ofAudio() || (!next.startsWith("video") && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE)) : !next.startsWith("audio") && !next.startsWith("video") : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE) && !next.startsWith("audio"))) {
                i2++;
                sb.append(i2 == 0 ? " AND " : " OR ");
                sb.append("mime_type");
                sb.append("='");
                sb.append(next);
                sb.append("'");
            }
        }
        if (this.config.chooseMode != PictureMimeType.ofVideo() && !this.config.isGif && !hashSet.contains(PictureMimeType.ofGIF())) {
            sb.append(NOT_GIF);
        }
        return sb.toString();
    }

    private String getRealPathAndroid_Q(long j2) {
        return QUERY_URI.buildUpon().appendPath(ValueOf.toString(Long.valueOf(j2))).build().toString();
    }

    private String getSelection() {
        String durationCondition = getDurationCondition();
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return getSelectionArgsForAllMediaCondition(durationCondition, fileSizeCondition, queryMimeCondition);
        }
        if (i2 == 1) {
            return getSelectionArgsForImageMediaCondition(fileSizeCondition, queryMimeCondition);
        }
        if (i2 == 2) {
            return getSelectionArgsForVideoOrAudioMediaCondition(fileSizeCondition, queryMimeCondition);
        }
        if (i2 != 3) {
            return null;
        }
        return getSelectionArgsForVideoOrAudioMediaCondition(durationCondition, queryMimeCondition);
    }

    private String[] getSelectionArgs() {
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return getSelectionArgsForAllMediaType();
        }
        if (i2 == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i2 == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i2 != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private static String getSelectionArgsForAllMediaCondition(String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str3);
        sb.append(" OR ");
        sb.append("media_type");
        sb.append("=? AND ");
        sb.append(str);
        sb.append(") AND ");
        sb.append(str2);
        sb.toString();
        return sb.toString();
    }

    private static String[] getSelectionArgsForAllMediaType() {
        return new String[]{String.valueOf(1), String.valueOf(3)};
    }

    private static String getSelectionArgsForImageMediaCondition(String str, String str2) {
        return "media_type=?" + str2 + " AND " + str;
    }

    private static String[] getSelectionArgsForSingleMediaType(int i2) {
        return new String[]{String.valueOf(i2)};
    }

    private static String getSelectionArgsForVideoOrAudioMediaCondition(String str, String str2) {
        return "media_type=?" + str2 + " AND " + str;
    }

    private void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, a.f12148d);
    }

    /* JADX WARNING: Removed duplicated region for block: B:70:0x021e A[LOOP:0: B:6:0x008a->B:70:0x021e, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x01c5 A[EDGE_INSN: B:90:0x01c5->B:63:0x01c5 ?: BREAK  , SYNTHETIC] */
    public List<LocalMediaFolder> loadAllMedia() {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        LocalMediaFolder localMediaFolder;
        ArrayList arrayList;
        String str;
        ContentResolver contentResolver = this.mContext.getContentResolver();
        Uri uri = QUERY_URI;
        String[] strArr = PROJECTION;
        Cursor query = contentResolver.query(uri, strArr, getSelection(), getSelectionArgs(), ORDER_BY);
        if (query != null) {
            try {
                ArrayList arrayList2 = new ArrayList();
                LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
                ArrayList arrayList3 = new ArrayList();
                if (query.getCount() > 0) {
                    int columnIndexOrThrow = query.getColumnIndexOrThrow(strArr[0]);
                    int columnIndexOrThrow2 = query.getColumnIndexOrThrow(strArr[1]);
                    int columnIndexOrThrow3 = query.getColumnIndexOrThrow(strArr[2]);
                    int columnIndexOrThrow4 = query.getColumnIndexOrThrow(strArr[3]);
                    int columnIndexOrThrow5 = query.getColumnIndexOrThrow(strArr[4]);
                    int columnIndexOrThrow6 = query.getColumnIndexOrThrow(strArr[5]);
                    int columnIndexOrThrow7 = query.getColumnIndexOrThrow(strArr[6]);
                    int columnIndexOrThrow8 = query.getColumnIndexOrThrow(strArr[7]);
                    int columnIndexOrThrow9 = query.getColumnIndexOrThrow(strArr[8]);
                    int columnIndexOrThrow10 = query.getColumnIndexOrThrow(strArr[9]);
                    int columnIndexOrThrow11 = query.getColumnIndexOrThrow(strArr[10]);
                    query.moveToFirst();
                    LocalMediaFolder localMediaFolder3 = localMediaFolder2;
                    ArrayList arrayList4 = arrayList3;
                    while (true) {
                        long j2 = query.getLong(columnIndexOrThrow);
                        String string = query.getString(columnIndexOrThrow2);
                        String realPathAndroid_Q = this.isAndroidQ ? getRealPathAndroid_Q(j2) : string;
                        String string2 = query.getString(columnIndexOrThrow3);
                        if (TextUtils.isEmpty(string2)) {
                            string2 = PictureMimeType.ofJPEG();
                        }
                        String str2 = string2;
                        if (str2.endsWith("image/*")) {
                            if (PictureMimeType.isContent(realPathAndroid_Q)) {
                                str2 = PictureMimeType.getImageMimeType(string);
                            } else {
                                str2 = PictureMimeType.getImageMimeType(realPathAndroid_Q);
                            }
                            if (!this.config.isGif && PictureMimeType.isGif(str2)) {
                                i5 = columnIndexOrThrow8;
                                i4 = columnIndexOrThrow9;
                                i7 = columnIndexOrThrow4;
                                i6 = columnIndexOrThrow5;
                                i3 = columnIndexOrThrow6;
                                i2 = columnIndexOrThrow7;
                                localMediaFolder = localMediaFolder3;
                                arrayList = arrayList4;
                                if (!query.moveToNext()) {
                                    break;
                                }
                                arrayList4 = arrayList;
                                localMediaFolder3 = localMediaFolder;
                                columnIndexOrThrow = columnIndexOrThrow;
                                columnIndexOrThrow2 = columnIndexOrThrow2;
                                columnIndexOrThrow3 = columnIndexOrThrow3;
                                columnIndexOrThrow4 = i7;
                                columnIndexOrThrow5 = i6;
                                columnIndexOrThrow8 = i5;
                                columnIndexOrThrow9 = i4;
                                columnIndexOrThrow6 = i3;
                                columnIndexOrThrow7 = i2;
                            }
                        }
                        if (this.config.isWebp || !str2.startsWith(PictureMimeType.ofWEBP())) {
                            if (this.config.isBmp || !str2.startsWith(PictureMimeType.ofBMP())) {
                                int i8 = query.getInt(columnIndexOrThrow4);
                                int i9 = query.getInt(columnIndexOrThrow5);
                                long j3 = query.getLong(columnIndexOrThrow6);
                                i7 = columnIndexOrThrow4;
                                long j4 = query.getLong(columnIndexOrThrow7);
                                i6 = columnIndexOrThrow5;
                                String string3 = query.getString(columnIndexOrThrow8);
                                String string4 = query.getString(columnIndexOrThrow9);
                                long j5 = query.getLong(columnIndexOrThrow10);
                                i5 = columnIndexOrThrow8;
                                float f2 = this.config.filterFileSize;
                                i4 = columnIndexOrThrow9;
                                if (f2 <= 0.0f || ((float) j4) <= f2 * 1048576.0f) {
                                    if (PictureMimeType.isHasVideo(str2)) {
                                        PictureSelectionConfig pictureSelectionConfig = this.config;
                                        int i10 = pictureSelectionConfig.videoMinSecond;
                                        i3 = columnIndexOrThrow6;
                                        i2 = columnIndexOrThrow7;
                                        if (i10 <= 0 || j3 >= ((long) i10)) {
                                            int i11 = pictureSelectionConfig.videoMaxSecond;
                                            if (i11 <= 0 || j3 <= ((long) i11)) {
                                                if (j3 != 0) {
                                                    if (j4 <= 0) {
                                                    }
                                                }
                                            }
                                        }
                                        localMediaFolder = localMediaFolder3;
                                        arrayList = arrayList4;
                                        if (!query.moveToNext()) {
                                        }
                                    } else {
                                        i3 = columnIndexOrThrow6;
                                        i2 = columnIndexOrThrow7;
                                    }
                                    LocalMedia localMedia = new LocalMedia(j2, realPathAndroid_Q, string, string4, string3, j3, this.config.chooseMode, str2, i8, i9, j4, j5, query.getLong(columnIndexOrThrow11));
                                    LocalMediaFolder imageFolder = getImageFolder(realPathAndroid_Q, str2, string3, arrayList2);
                                    imageFolder.setBucketId(localMedia.getBucketId());
                                    imageFolder.getData().add(localMedia);
                                    imageFolder.setImageNum(imageFolder.getImageNum() + 1);
                                    imageFolder.setBucketId(localMedia.getBucketId());
                                    arrayList = arrayList4;
                                    arrayList.add(localMedia);
                                    localMediaFolder = localMediaFolder3;
                                    localMediaFolder.setImageNum(localMediaFolder3.getImageNum() + 1);
                                    if (!query.moveToNext()) {
                                    }
                                } else {
                                    i3 = columnIndexOrThrow6;
                                    i2 = columnIndexOrThrow7;
                                    localMediaFolder = localMediaFolder3;
                                    arrayList = arrayList4;
                                    if (!query.moveToNext()) {
                                    }
                                }
                            }
                        }
                        i5 = columnIndexOrThrow8;
                        i4 = columnIndexOrThrow9;
                        i7 = columnIndexOrThrow4;
                        i6 = columnIndexOrThrow5;
                        i3 = columnIndexOrThrow6;
                        i2 = columnIndexOrThrow7;
                        localMediaFolder = localMediaFolder3;
                        arrayList = arrayList4;
                        if (!query.moveToNext()) {
                        }
                    }
                    if (arrayList.size() > 0) {
                        sortFolder(arrayList2);
                        arrayList2.add(0, localMediaFolder);
                        localMediaFolder.setFirstImagePath(((LocalMedia) arrayList.get(0)).getPath());
                        localMediaFolder.setFirstMimeType(((LocalMedia) arrayList.get(0)).getMimeType());
                        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                            str = this.mContext.getString(R.string.picture_all_audio);
                        } else {
                            str = this.mContext.getString(R.string.picture_camera_roll);
                        }
                        localMediaFolder.setName(str);
                        localMediaFolder.setBucketId(-1);
                        localMediaFolder.setOfAllType(this.config.chooseMode);
                        localMediaFolder.setCameraFolder(true);
                        localMediaFolder.setData(arrayList);
                    }
                }
                if (!query.isClosed()) {
                    query.close();
                }
                return arrayList2;
            } catch (Exception e2) {
                e2.printStackTrace();
                String str3 = TAG;
                Log.i(str3, "loadAllMedia Data Error: " + e2.getMessage());
                if (query.isClosed()) {
                    return null;
                }
                query.close();
                return null;
            } catch (Throwable th) {
                if (!query.isClosed()) {
                    query.close();
                }
                throw th;
            }
        } else if (query == null || query.isClosed()) {
            return null;
        } else {
            query.close();
            return null;
        }
    }
}
