package com.luck.picture.lib.model;

import android.annotation.SuppressLint;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.entity.MediaData;
import com.luck.picture.lib.listener.OnQueryDataResultListener;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ValueOf;
import d.a.a.a.a;
import d.k.a.a.f0.b;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;

public final class LocalMediaPageLoader {
    private static final String COLUMN_BUCKET_DISPLAY_NAME = "bucket_display_name";
    private static final String COLUMN_BUCKET_ID = "bucket_id";
    private static final String COLUMN_COUNT = "count";
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final String GROUP_BY_BUCKET_Id = " GROUP BY (bucket_id";
    private static final String NOT_GIF = " AND (mime_type!='image/gif' AND mime_type!='image/*')";
    private static final String NOT_GIF_UNKNOWN = "!='image/*'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type", "COUNT(*) AS count"};
    private static final String[] PROJECTION_29 = {"_id", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type"};
    private static final String[] PROJECTION_PAGE = {"_id", "_data", "mime_type", "width", "height", TypedValues.Transition.S_DURATION, "_size", COLUMN_BUCKET_DISPLAY_NAME, "_display_name", "bucket_id", "date_added"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String TAG = "LocalMediaPageLoader";

    /* renamed from: a  reason: collision with root package name */
    public static final /* synthetic */ int f7288a = 0;
    @SuppressLint({"StaticFieldLeak"})
    private static LocalMediaPageLoader instance;
    private final PictureSelectionConfig config = PictureSelectionConfig.getInstance();
    private final Context mContext;

    public LocalMediaPageLoader(Context context) {
        this.mContext = context;
    }

    private String getDurationCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i2 = pictureSelectionConfig.videoMaxSecond;
        long j2 = i2 == 0 ? Long.MAX_VALUE : (long) i2;
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, (long) pictureSelectionConfig.videoMinSecond));
        objArr[1] = Math.max(0, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j2);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    private String getFileSizeCondition() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        long j2 = pictureSelectionConfig.filterMaxFileSize;
        if (j2 == 0) {
            j2 = Long.MAX_VALUE;
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(0L, pictureSelectionConfig.filterMinFileSize));
        objArr[1] = Math.max(0, this.config.filterMinFileSize) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j2);
        return String.format(locale, "%d <%s _size and _size <= %d", objArr);
    }

    /* access modifiers changed from: private */
    public static String getFirstCoverMimeType(Cursor cursor) {
        return cursor.getString(cursor.getColumnIndex("mime_type"));
    }

    /* access modifiers changed from: private */
    public static String getFirstUri(Cursor cursor) {
        return getRealPathAndroid_Q(cursor.getLong(cursor.getColumnIndex("_id")));
    }

    /* access modifiers changed from: private */
    public static String getFirstUrl(Cursor cursor) {
        return cursor.getString(cursor.getColumnIndex("_data"));
    }

    public static LocalMediaPageLoader getInstance(Context context) {
        if (instance == null) {
            synchronized (LocalMediaPageLoader.class) {
                if (instance == null) {
                    instance = new LocalMediaPageLoader(context.getApplicationContext());
                }
            }
        }
        return instance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getPageSelection(long j2) {
        String durationCondition = getDurationCondition();
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return getPageSelectionArgsForAllMediaCondition(j2, queryMimeCondition, durationCondition, fileSizeCondition);
        }
        if (i2 == 1) {
            return getPageSelectionArgsForImageMediaCondition(j2, queryMimeCondition, fileSizeCondition);
        }
        if (i2 == 2 || i2 == 3) {
            return getPageSelectionArgsForVideoOrAudioMediaCondition(j2, queryMimeCondition, durationCondition, fileSizeCondition);
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getPageSelectionArgs(long j2) {
        int i2 = this.config.chooseMode;
        if (i2 != 0) {
            if (i2 == 1) {
                return getSelectionArgsForPageSingleMediaType(1, j2);
            }
            if (i2 == 2) {
                return getSelectionArgsForPageSingleMediaType(3, j2);
            }
            if (i2 != 3) {
                return null;
            }
            return getSelectionArgsForPageSingleMediaType(2, j2);
        } else if (j2 == -1) {
            return new String[]{String.valueOf(1), String.valueOf(3)};
        } else {
            return new String[]{String.valueOf(1), String.valueOf(3), ValueOf.toString(Long.valueOf(j2))};
        }
    }

    private static String getPageSelectionArgsForAllMediaCondition(long j2, String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(" OR ");
        sb.append("media_type");
        sb.append("=? AND ");
        sb.append(str2);
        sb.append(") AND ");
        if (j2 != -1) {
            return a.z(sb, "bucket_id", "=? AND ", str3);
        }
        sb.append(str3);
        return sb.toString();
    }

    private static String getPageSelectionArgsForImageMediaCondition(long j2, String str, String str2) {
        StringBuilder G = a.G("(", "media_type", "=?");
        if (j2 == -1) {
            return a.z(G, str, ") AND ", str2);
        }
        G.append(str);
        G.append(") AND ");
        G.append("bucket_id");
        G.append("=? AND ");
        G.append(str2);
        return G.toString();
    }

    private static String getPageSelectionArgsForVideoOrAudioMediaCondition(long j2, String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(" AND ");
        sb.append(str2);
        sb.append(") AND ");
        if (j2 != -1) {
            return a.z(sb, "bucket_id", "=? AND ", str3);
        }
        sb.append(str3);
        return sb.toString();
    }

    private String getQueryMimeCondition() {
        HashSet<String> hashSet = this.config.queryMimeTypeHashSet;
        if (hashSet == null) {
            hashSet = new HashSet<>();
        }
        if (!TextUtils.isEmpty(this.config.specifiedFormat)) {
            hashSet.add(this.config.specifiedFormat);
        }
        StringBuilder sb = new StringBuilder();
        Iterator<String> it = hashSet.iterator();
        int i2 = -1;
        while (it.hasNext()) {
            String next = it.next();
            if (!TextUtils.isEmpty(next) && (this.config.chooseMode != PictureMimeType.ofVideo() ? this.config.chooseMode != PictureMimeType.ofImage() ? this.config.chooseMode != PictureMimeType.ofAudio() || (!next.startsWith("video") && !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE)) : !next.startsWith("audio") && !next.startsWith("video") : !next.startsWith(PictureMimeType.MIME_TYPE_PREFIX_IMAGE) && !next.startsWith("audio"))) {
                i2++;
                sb.append(i2 == 0 ? " AND " : " OR ");
                sb.append("mime_type");
                sb.append("='");
                sb.append(next);
                sb.append("'");
            }
        }
        if (this.config.chooseMode != PictureMimeType.ofVideo() && !this.config.isGif && !hashSet.contains(PictureMimeType.ofGIF())) {
            sb.append(NOT_GIF);
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    public static String getRealPathAndroid_Q(long j2) {
        return QUERY_URI.buildUpon().appendPath(ValueOf.toString(Long.valueOf(j2))).build().toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getSelection() {
        String fileSizeCondition = getFileSizeCondition();
        String queryMimeCondition = getQueryMimeCondition();
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return getSelectionArgsForAllMediaCondition(getDurationCondition(), fileSizeCondition, queryMimeCondition);
        }
        if (i2 == 1) {
            return getSelectionArgsForImageMediaCondition(queryMimeCondition, fileSizeCondition);
        }
        if (i2 == 2 || i2 == 3) {
            return getSelectionArgsForVideoOrAudioMediaCondition(queryMimeCondition, fileSizeCondition);
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getSelectionArgs() {
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return getSelectionArgsForAllMediaType();
        }
        if (i2 == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i2 == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i2 != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private static String getSelectionArgsForAllMediaCondition(String str, String str2, String str3) {
        StringBuilder sb = new StringBuilder();
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str3);
        sb.append(" OR ");
        sb.append("media_type");
        sb.append("=? AND ");
        sb.append(str);
        sb.append(") AND ");
        sb.append(str2);
        if (SdkVersionUtils.checkedAndroid_Q()) {
            return sb.toString();
        }
        return a.y(sb, ")", GROUP_BY_BUCKET_Id);
    }

    private static String[] getSelectionArgsForAllMediaType() {
        return new String[]{String.valueOf(1), String.valueOf(3)};
    }

    private static String getSelectionArgsForImageMediaCondition(String str, String str2) {
        StringBuilder sb = new StringBuilder();
        if (SdkVersionUtils.checkedAndroid_Q()) {
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(" AND ");
            sb.append(str2);
            return sb.toString();
        }
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(") AND ");
        sb.append(str2);
        sb.append(")");
        sb.append(GROUP_BY_BUCKET_Id);
        return sb.toString();
    }

    private static String[] getSelectionArgsForPageSingleMediaType(int i2, long j2) {
        if (j2 == -1) {
            return new String[]{String.valueOf(i2)};
        }
        return new String[]{String.valueOf(i2), ValueOf.toString(Long.valueOf(j2))};
    }

    private static String[] getSelectionArgsForSingleMediaType(int i2) {
        return new String[]{String.valueOf(i2)};
    }

    private static String getSelectionArgsForVideoOrAudioMediaCondition(String str, String str2) {
        StringBuilder sb = new StringBuilder();
        if (SdkVersionUtils.checkedAndroid_Q()) {
            sb.append("media_type");
            sb.append("=?");
            sb.append(str);
            sb.append(" AND ");
            sb.append(str2);
            return sb.toString();
        }
        sb.append("(");
        sb.append("media_type");
        sb.append("=?");
        sb.append(str);
        sb.append(") AND ");
        sb.append(str2);
        sb.append(")");
        sb.append(GROUP_BY_BUCKET_Id);
        return sb.toString();
    }

    public static void setInstanceNull() {
        instance = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, b.f12149d);
    }

    public String getFirstCover(long j2) {
        Throwable th;
        Cursor cursor;
        Exception e2;
        Cursor cursor2;
        String str;
        Cursor cursor3 = null;
        try {
            if (SdkVersionUtils.checkedAndroid_R()) {
                cursor2 = this.mContext.getContentResolver().query(QUERY_URI, new String[]{"_id", "_data"}, MediaUtils.createQueryArgsBundle(getPageSelection(j2), getPageSelectionArgs(j2), 1, 0), null);
            } else {
                cursor2 = this.mContext.getContentResolver().query(QUERY_URI, new String[]{"_id", "_data"}, getPageSelection(j2), getPageSelectionArgs(j2), "_id DESC limit 1 offset 0");
            }
            if (cursor2 != null) {
                try {
                    if (cursor2.getCount() > 0) {
                        if (cursor2.moveToFirst()) {
                            long j3 = cursor2.getLong(cursor2.getColumnIndexOrThrow("_id"));
                            if (SdkVersionUtils.checkedAndroid_Q()) {
                                str = getRealPathAndroid_Q(j3);
                            } else {
                                str = cursor2.getString(cursor2.getColumnIndexOrThrow("_data"));
                            }
                            if (!cursor2.isClosed()) {
                                cursor2.close();
                            }
                            return str;
                        }
                        if (!cursor2.isClosed()) {
                            cursor2.close();
                        }
                        return null;
                    }
                } catch (Exception e3) {
                    cursor = cursor2;
                    e2 = e3;
                    try {
                        e2.printStackTrace();
                        if (cursor != null && !cursor.isClosed()) {
                            cursor.close();
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor3 = cursor;
                        cursor3.close();
                        throw th;
                    }
                } catch (Throwable th3) {
                    cursor3 = cursor2;
                    th = th3;
                    if (cursor3 != null && !cursor3.isClosed()) {
                        cursor3.close();
                    }
                    throw th;
                }
            }
            if (cursor2 != null && !cursor2.isClosed()) {
                cursor2.close();
            }
        } catch (Exception e4) {
            e2 = e4;
            cursor = null;
            e2.printStackTrace();
            cursor.close();
            return null;
        } catch (Throwable th4) {
            th = th4;
            cursor3.close();
            throw th;
        }
        return null;
    }

    public void loadAllMedia(final OnQueryDataResultListener<LocalMediaFolder> onQueryDataResultListener) {
        PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<List<LocalMediaFolder>>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass2 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMediaFolder> doInBackground() {
                int i2;
                String str;
                long j2;
                Cursor query = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.PROJECTION_29 : LocalMediaPageLoader.PROJECTION, LocalMediaPageLoader.this.getSelection(), LocalMediaPageLoader.this.getSelectionArgs(), LocalMediaPageLoader.ORDER_BY);
                if (query != null) {
                    try {
                        int count = query.getCount();
                        ArrayList arrayList = new ArrayList();
                        if (count > 0) {
                            if (SdkVersionUtils.checkedAndroid_Q()) {
                                HashMap hashMap = new HashMap();
                                while (query.moveToNext()) {
                                    long j3 = query.getLong(query.getColumnIndex("bucket_id"));
                                    Long l2 = (Long) hashMap.get(Long.valueOf(j3));
                                    if (l2 == null) {
                                        j2 = 1L;
                                    } else {
                                        j2 = Long.valueOf(l2.longValue() + 1);
                                    }
                                    hashMap.put(Long.valueOf(j3), j2);
                                }
                                if (query.moveToFirst()) {
                                    HashSet hashSet = new HashSet();
                                    i2 = 0;
                                    do {
                                        long j4 = query.getLong(query.getColumnIndex("bucket_id"));
                                        if (!hashSet.contains(Long.valueOf(j4))) {
                                            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
                                            localMediaFolder.setBucketId(j4);
                                            String string = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                            String string2 = query.getString(query.getColumnIndex("mime_type"));
                                            long longValue = ((Long) hashMap.get(Long.valueOf(j4))).longValue();
                                            long j5 = query.getLong(query.getColumnIndex("_id"));
                                            localMediaFolder.setName(string);
                                            localMediaFolder.setImageNum(ValueOf.toInt(Long.valueOf(longValue)));
                                            localMediaFolder.setFirstImagePath(LocalMediaPageLoader.getRealPathAndroid_Q(j5));
                                            localMediaFolder.setFirstMimeType(string2);
                                            arrayList.add(localMediaFolder);
                                            hashSet.add(Long.valueOf(j4));
                                            i2 = (int) (((long) i2) + longValue);
                                        }
                                    } while (query.moveToNext());
                                } else {
                                    i2 = 0;
                                }
                            } else {
                                query.moveToFirst();
                                int i3 = 0;
                                do {
                                    LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
                                    long j6 = query.getLong(query.getColumnIndex("bucket_id"));
                                    String string3 = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                    String string4 = query.getString(query.getColumnIndex("mime_type"));
                                    int i4 = query.getInt(query.getColumnIndex("count"));
                                    localMediaFolder2.setBucketId(j6);
                                    localMediaFolder2.setFirstImagePath(query.getString(query.getColumnIndex("_data")));
                                    localMediaFolder2.setName(string3);
                                    localMediaFolder2.setFirstMimeType(string4);
                                    localMediaFolder2.setImageNum(i4);
                                    arrayList.add(localMediaFolder2);
                                    i3 += i4;
                                } while (query.moveToNext());
                                i2 = i3;
                            }
                            LocalMediaPageLoader.this.sortFolder(arrayList);
                            LocalMediaFolder localMediaFolder3 = new LocalMediaFolder();
                            localMediaFolder3.setImageNum(i2);
                            localMediaFolder3.setChecked(true);
                            localMediaFolder3.setBucketId(-1);
                            if (query.moveToFirst()) {
                                localMediaFolder3.setFirstImagePath(SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.getFirstUri(query) : LocalMediaPageLoader.getFirstUrl(query));
                                localMediaFolder3.setFirstMimeType(LocalMediaPageLoader.getFirstCoverMimeType(query));
                            }
                            if (LocalMediaPageLoader.this.config.chooseMode == PictureMimeType.ofAudio()) {
                                str = LocalMediaPageLoader.this.mContext.getString(R.string.picture_all_audio);
                            } else {
                                str = LocalMediaPageLoader.this.mContext.getString(R.string.picture_camera_roll);
                            }
                            localMediaFolder3.setName(str);
                            localMediaFolder3.setOfAllType(LocalMediaPageLoader.this.config.chooseMode);
                            localMediaFolder3.setCameraFolder(true);
                            arrayList.add(0, localMediaFolder3);
                            if (!query.isClosed()) {
                                query.close();
                            }
                            return arrayList;
                        }
                    } catch (Exception e2) {
                        e2.printStackTrace();
                        String str2 = LocalMediaPageLoader.TAG;
                        Log.i(str2, "loadAllMedia Data Error: " + e2.getMessage());
                        if (!query.isClosed()) {
                            query.close();
                        }
                        return null;
                    } catch (Throwable th) {
                        if (!query.isClosed()) {
                            query.close();
                        }
                        throw th;
                    }
                }
                if (query != null && !query.isClosed()) {
                    query.close();
                }
                return new ArrayList();
            }

            public void onSuccess(List<LocalMediaFolder> list) {
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null && list != null) {
                    onQueryDataResultListener.onComplete(list, 1, false);
                }
            }
        });
    }

    public void loadPageMediaData(long j2, int i2, int i3, OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        loadPageMediaData(j2, i2, i3, this.config.pageSize, onQueryDataResultListener);
    }

    public void loadPageMediaData(long j2, int i2, OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        int i3 = this.config.pageSize;
        loadPageMediaData(j2, i2, i3, i3, onQueryDataResultListener);
    }

    public void loadPageMediaData(final long j2, final int i2, final int i3, final int i4, final OnQueryDataResultListener<LocalMedia> onQueryDataResultListener) {
        PictureThreadUtils.executeBySingle(new PictureThreadUtils.SimpleTask<MediaData>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass1 */

            /* JADX WARNING: Removed duplicated region for block: B:116:0x025b A[EDGE_INSN: B:116:0x025b->B:83:0x025b ?: BREAK  , SYNTHETIC] */
            /* JADX WARNING: Removed duplicated region for block: B:84:0x025c A[Catch:{ Exception -> 0x027e }, LOOP:0: B:22:0x0123->B:84:0x025c, LOOP_END] */
            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public MediaData doInBackground() {
                Throwable th;
                Cursor cursor;
                Exception e2;
                Cursor cursor2;
                int i2;
                int i3;
                int i4;
                String str;
                String str2;
                Cursor cursor3 = null;
                try {
                    if (SdkVersionUtils.checkedAndroid_R()) {
                        try {
                            cursor2 = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, LocalMediaPageLoader.PROJECTION_PAGE, MediaUtils.createQueryArgsBundle(LocalMediaPageLoader.this.getPageSelection(j2), LocalMediaPageLoader.this.getPageSelectionArgs(j2), i3, (i2 - 1) * i4), null);
                        } catch (Exception e3) {
                            e2 = e3;
                            cursor = null;
                        } catch (Throwable th2) {
                            th = th2;
                            cursor3.close();
                            throw th;
                        }
                    } else {
                        if (i2 == -1) {
                            str2 = LocalMediaPageLoader.ORDER_BY;
                        } else {
                            str2 = "_id DESC limit " + i3 + " offset " + ((i2 - 1) * i4);
                        }
                        cursor2 = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, LocalMediaPageLoader.PROJECTION_PAGE, LocalMediaPageLoader.this.getPageSelection(j2), LocalMediaPageLoader.this.getPageSelectionArgs(j2), str2);
                    }
                    cursor = cursor2;
                    if (cursor != null) {
                        try {
                            ArrayList arrayList = new ArrayList();
                            if (cursor.getCount() > 0) {
                                int columnIndexOrThrow = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[0]);
                                int columnIndexOrThrow2 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[1]);
                                int columnIndexOrThrow3 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[2]);
                                int columnIndexOrThrow4 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[3]);
                                int columnIndexOrThrow5 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[4]);
                                int columnIndexOrThrow6 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[5]);
                                int columnIndexOrThrow7 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[6]);
                                int columnIndexOrThrow8 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[7]);
                                int columnIndexOrThrow9 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[8]);
                                int columnIndexOrThrow10 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[9]);
                                int columnIndexOrThrow11 = cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[10]);
                                cursor.moveToFirst();
                                while (true) {
                                    long j2 = cursor.getLong(columnIndexOrThrow);
                                    String string = cursor.getString(columnIndexOrThrow2);
                                    String realPathAndroid_Q = SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.getRealPathAndroid_Q(j2) : string;
                                    if (!LocalMediaPageLoader.this.config.isFilterInvalidFile || PictureFileUtils.isFileExists(string)) {
                                        String string2 = cursor.getString(columnIndexOrThrow3);
                                        if (TextUtils.isEmpty(string2)) {
                                            string2 = PictureMimeType.ofJPEG();
                                        }
                                        if (string2.endsWith("image/*")) {
                                            if (PictureMimeType.isContent(realPathAndroid_Q)) {
                                                str = PictureMimeType.getImageMimeType(string);
                                            } else {
                                                str = PictureMimeType.getImageMimeType(realPathAndroid_Q);
                                            }
                                            if (!LocalMediaPageLoader.this.config.isGif && PictureMimeType.isGif(str)) {
                                            }
                                        } else {
                                            str = string2;
                                        }
                                        if (LocalMediaPageLoader.this.config.isWebp || !str.startsWith(PictureMimeType.ofWEBP())) {
                                            if (LocalMediaPageLoader.this.config.isBmp || !str.startsWith(PictureMimeType.ofBMP())) {
                                                int i5 = cursor.getInt(columnIndexOrThrow4);
                                                int i6 = cursor.getInt(columnIndexOrThrow5);
                                                long j3 = cursor.getLong(columnIndexOrThrow6);
                                                i4 = columnIndexOrThrow;
                                                long j4 = cursor.getLong(columnIndexOrThrow7);
                                                String string3 = cursor.getString(columnIndexOrThrow8);
                                                String string4 = cursor.getString(columnIndexOrThrow9);
                                                long j5 = cursor.getLong(columnIndexOrThrow10);
                                                i3 = columnIndexOrThrow2;
                                                if (LocalMediaPageLoader.this.config.filterFileSize > 0.0f) {
                                                    i2 = columnIndexOrThrow3;
                                                    if (((float) j4) > LocalMediaPageLoader.this.config.filterFileSize * 1048576.0f) {
                                                        if (cursor.moveToNext()) {
                                                            break;
                                                        }
                                                        columnIndexOrThrow = i4;
                                                        columnIndexOrThrow2 = i3;
                                                        columnIndexOrThrow3 = i2;
                                                    }
                                                } else {
                                                    i2 = columnIndexOrThrow3;
                                                }
                                                if (PictureMimeType.isHasVideo(str)) {
                                                    if (LocalMediaPageLoader.this.config.videoMinSecond <= 0 || j3 >= ((long) LocalMediaPageLoader.this.config.videoMinSecond)) {
                                                        if (LocalMediaPageLoader.this.config.videoMaxSecond <= 0 || j3 <= ((long) LocalMediaPageLoader.this.config.videoMaxSecond)) {
                                                            if (j3 != 0) {
                                                                if (j4 <= 0) {
                                                                }
                                                            }
                                                            if (cursor.moveToNext()) {
                                                            }
                                                        } else if (cursor.moveToNext()) {
                                                        }
                                                    } else if (cursor.moveToNext()) {
                                                    }
                                                }
                                                arrayList.add(new LocalMedia(j2, realPathAndroid_Q, string, string4, string3, j3, LocalMediaPageLoader.this.config.chooseMode, str, i5, i6, j4, j5, cursor.getLong(columnIndexOrThrow11)));
                                                if (cursor.moveToNext()) {
                                                }
                                            }
                                        }
                                    }
                                    i4 = columnIndexOrThrow;
                                    i3 = columnIndexOrThrow2;
                                    i2 = columnIndexOrThrow3;
                                    if (cursor.moveToNext()) {
                                    }
                                }
                            }
                            MediaData mediaData = new MediaData(cursor.getCount() > 0, arrayList);
                            if (!cursor.isClosed()) {
                                cursor.close();
                            }
                            return mediaData;
                        } catch (Exception e4) {
                            e2 = e4;
                            try {
                                e2.printStackTrace();
                                Log.i(LocalMediaPageLoader.TAG, "loadMedia Page Data Error: " + e2.getMessage());
                                if (cursor == null && !cursor.isClosed()) {
                                    cursor.close();
                                    return null;
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                cursor3 = cursor;
                                cursor3.close();
                                throw th;
                            }
                        }
                    } else if (cursor == null || cursor.isClosed()) {
                        return null;
                    } else {
                        cursor.close();
                        return null;
                    }
                } catch (Exception e5) {
                    e2 = e5;
                    cursor = null;
                    e2.printStackTrace();
                    Log.i(LocalMediaPageLoader.TAG, "loadMedia Page Data Error: " + e2.getMessage());
                    return cursor == null ? null : null;
                } catch (Throwable th4) {
                    th = th4;
                    cursor3 = null;
                    if (cursor3 != null && !cursor3.isClosed()) {
                        cursor3.close();
                    }
                    throw th;
                }
            }

            public void onSuccess(MediaData mediaData) {
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null && mediaData != null) {
                    onQueryDataResultListener.onComplete(mediaData.data, i2, mediaData.isHasNextMore);
                }
            }
        });
    }
}
