package com.lzy.okgo.cache;

import android.content.ContentValues;
import android.database.Cursor;
import com.lzy.okgo.model.HttpHeaders;
import d.a.a.a.a;
import d.l.b.g.g.b;
import java.io.Serializable;

public class CacheEntity<T> implements Serializable {
    public static final long CACHE_NEVER_EXPIRE = -1;
    public static final String DATA = "data";
    public static final String HEAD = "head";
    public static final String KEY = "key";
    public static final String LOCAL_EXPIRE = "localExpire";
    private static final long serialVersionUID = -4337711009801627866L;
    private T data;
    private boolean isExpire;
    private String key;
    private long localExpire;
    private HttpHeaders responseHeaders;

    public static <T> ContentValues getContentValues(CacheEntity<T> cacheEntity) {
        ContentValues contentValues = new ContentValues();
        contentValues.put(KEY, cacheEntity.getKey());
        contentValues.put(LOCAL_EXPIRE, Long.valueOf(cacheEntity.getLocalExpire()));
        contentValues.put(HEAD, b.G0(cacheEntity.getResponseHeaders()));
        contentValues.put(DATA, b.G0(cacheEntity.getData()));
        return contentValues;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: com.lzy.okgo.cache.CacheEntity<T> */
    /* JADX WARN: Multi-variable type inference failed */
    public static <T> CacheEntity<T> parseCursorToBean(Cursor cursor) {
        CacheEntity<T> cacheEntity = (CacheEntity<T>) new CacheEntity();
        cacheEntity.setKey(cursor.getString(cursor.getColumnIndex(KEY)));
        cacheEntity.setLocalExpire(cursor.getLong(cursor.getColumnIndex(LOCAL_EXPIRE)));
        cacheEntity.setResponseHeaders((HttpHeaders) b.I0(cursor.getBlob(cursor.getColumnIndex(HEAD))));
        cacheEntity.setData(b.I0(cursor.getBlob(cursor.getColumnIndex(DATA))));
        return cacheEntity;
    }

    public boolean checkExpire(CacheMode cacheMode, long j2, long j3) {
        if (cacheMode == CacheMode.DEFAULT) {
            return getLocalExpire() < j3;
        }
        if (j2 != -1 && getLocalExpire() + j2 < j3) {
            return true;
        }
        return false;
    }

    public T getData() {
        return this.data;
    }

    public String getKey() {
        return this.key;
    }

    public long getLocalExpire() {
        return this.localExpire;
    }

    public HttpHeaders getResponseHeaders() {
        return this.responseHeaders;
    }

    public boolean isExpire() {
        return this.isExpire;
    }

    public void setData(T t) {
        this.data = t;
    }

    public void setExpire(boolean z) {
        this.isExpire = z;
    }

    public void setKey(String str) {
        this.key = str;
    }

    public void setLocalExpire(long j2) {
        this.localExpire = j2;
    }

    public void setResponseHeaders(HttpHeaders httpHeaders) {
        this.responseHeaders = httpHeaders;
    }

    public String toString() {
        StringBuilder B = a.B("CacheEntity{key='");
        a.W(B, this.key, '\'', ", responseHeaders=");
        B.append(this.responseHeaders);
        B.append(", data=");
        B.append((Object) this.data);
        B.append(", localExpire=");
        B.append(this.localExpire);
        B.append('}');
        return B.toString();
    }
}
