package com.lzy.okgo.interceptor;

import com.lzy.okgo.model.HttpHeaders;
import d.a.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.concurrent.TimeUnit;
import java.util.logging.Logger;
import okhttp3.Connection;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okio.Buffer;

public class HttpLoggingInterceptor implements Interceptor {

    /* renamed from: a  reason: collision with root package name */
    public static final Charset f7372a = Charset.forName("UTF-8");

    /* renamed from: b  reason: collision with root package name */
    public volatile Level f7373b = Level.NONE;

    /* renamed from: c  reason: collision with root package name */
    public java.util.logging.Level f7374c;

    /* renamed from: d  reason: collision with root package name */
    public Logger f7375d;

    public enum Level {
        NONE,
        BASIC,
        HEADERS,
        BODY
    }

    public HttpLoggingInterceptor(String str) {
        this.f7375d = Logger.getLogger(str);
    }

    public static boolean b(MediaType mediaType) {
        if (mediaType == null) {
            return false;
        }
        if (mediaType.type() != null && mediaType.type().equals("text")) {
            return true;
        }
        String subtype = mediaType.subtype();
        if (subtype != null) {
            String lowerCase = subtype.toLowerCase();
            if (lowerCase.contains("x-www-form-urlencoded") || lowerCase.contains("json") || lowerCase.contains("xml") || lowerCase.contains("html")) {
                return true;
            }
        }
        return false;
    }

    public final void a(Request request) {
        try {
            RequestBody body = request.newBuilder().build().body();
            if (body != null) {
                Buffer buffer = new Buffer();
                body.writeTo(buffer);
                MediaType contentType = body.contentType();
                Charset charset = contentType != null ? contentType.charset(f7372a) : f7372a;
                if (charset == null) {
                    charset = f7372a;
                }
                c("\tbody:" + buffer.readString(charset));
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    public final void c(String str) {
        this.f7375d.log(this.f7374c, str);
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        StringBuilder sb;
        Request request = chain.request();
        if (this.f7373b == Level.NONE) {
            return chain.proceed(request);
        }
        Connection connection = chain.connection();
        Level level = this.f7373b;
        Level level2 = Level.BODY;
        boolean z = level == level2;
        boolean z2 = this.f7373b == level2 || this.f7373b == Level.HEADERS;
        RequestBody body = request.body();
        boolean z3 = body != null;
        Protocol protocol = connection != null ? connection.protocol() : Protocol.HTTP_1_1;
        try {
            c("--> " + request.method() + ' ' + request.url() + ' ' + protocol);
            if (z2) {
                if (z3) {
                    if (body.contentType() != null) {
                        c("\tContent-Type: " + body.contentType());
                    }
                    if (body.contentLength() != -1) {
                        c("\tContent-Length: " + body.contentLength());
                    }
                }
                Headers headers = request.headers();
                int size = headers.size();
                for (int i2 = 0; i2 < size; i2++) {
                    String name = headers.name(i2);
                    if (!HttpHeaders.HEAD_KEY_CONTENT_TYPE.equalsIgnoreCase(name) && !HttpHeaders.HEAD_KEY_CONTENT_LENGTH.equalsIgnoreCase(name)) {
                        c("\t" + name + ": " + headers.value(i2));
                    }
                }
                this.f7375d.log(this.f7374c, " ");
                if (z && z3) {
                    if (b(body.contentType())) {
                        a(request);
                    } else {
                        this.f7375d.log(this.f7374c, "\tbody: maybe [binary body], omitted!");
                    }
                }
            }
            sb = new StringBuilder();
        } catch (Exception e2) {
            e2.printStackTrace();
            sb = new StringBuilder();
        } catch (Throwable th) {
            StringBuilder B = a.B("--> END ");
            B.append(request.method());
            c(B.toString());
            throw th;
        }
        sb.append("--> END ");
        sb.append(request.method());
        c(sb.toString());
        long nanoTime = System.nanoTime();
        try {
            Response proceed = chain.proceed(request);
            long millis = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - nanoTime);
            Response build = proceed.newBuilder().build();
            ResponseBody body2 = build.body();
            Level level3 = this.f7373b;
            Level level4 = Level.BODY;
            boolean z4 = level3 == level4;
            boolean z5 = this.f7373b == level4 || this.f7373b == Level.HEADERS;
            try {
                c("<-- " + build.code() + ' ' + build.message() + ' ' + build.request().url() + " (" + millis + "ms）");
                if (z5) {
                    Headers headers2 = build.headers();
                    int size2 = headers2.size();
                    for (int i3 = 0; i3 < size2; i3++) {
                        c("\t" + headers2.name(i3) + ": " + headers2.value(i3));
                    }
                    this.f7375d.log(this.f7374c, " ");
                    if (z4 && okhttp3.internal.http.HttpHeaders.hasBody(build)) {
                        if (body2 != null) {
                            if (b(body2.contentType())) {
                                InputStream byteStream = body2.byteStream();
                                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                                byte[] bArr = new byte[4096];
                                while (true) {
                                    int read = byteStream.read(bArr);
                                    if (read == -1) {
                                        break;
                                    }
                                    byteArrayOutputStream.write(bArr, 0, read);
                                }
                                byteArrayOutputStream.close();
                                byte[] byteArray = byteArrayOutputStream.toByteArray();
                                MediaType contentType = body2.contentType();
                                Charset charset = contentType != null ? contentType.charset(f7372a) : f7372a;
                                if (charset == null) {
                                    charset = f7372a;
                                }
                                String str = new String(byteArray, charset);
                                c("\tbody:" + str);
                                proceed = proceed.newBuilder().body(ResponseBody.create(body2.contentType(), byteArray)).build();
                            } else {
                                this.f7375d.log(this.f7374c, "\tbody: maybe [binary body], omitted!");
                            }
                        }
                    }
                }
            } catch (Exception e3) {
                e3.printStackTrace();
            } catch (Throwable th2) {
                this.f7375d.log(this.f7374c, "<-- END HTTP");
                throw th2;
            }
            this.f7375d.log(this.f7374c, "<-- END HTTP");
            return proceed;
        } catch (Exception e4) {
            c("<-- HTTP FAILED: " + e4);
            throw e4;
        }
    }
}
