package com.lzy.okgo.request.base;

import android.text.TextUtils;
import com.lzy.okgo.cache.CacheEntity;
import com.lzy.okgo.cache.CacheMode;
import com.lzy.okgo.model.HttpHeaders;
import com.lzy.okgo.model.HttpMethod;
import com.lzy.okgo.model.HttpParams;
import com.lzy.okgo.request.base.Request;
import d.m.a.a;
import d.m.a.b.c;
import d.m.a.b.d;
import d.m.a.c.a.b;
import d.m.a.e.a;
import d.m.a.f.b;
import d.m.a.i.a.b;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import okhttp3.Call;
import okhttp3.OkHttpClient;
import okhttp3.RequestBody;
import okhttp3.Response;

public abstract class Request<T, R extends Request> implements Serializable {
    private static final long serialVersionUID = -7174118653689916252L;
    public String baseUrl;
    public String cacheKey;
    public CacheMode cacheMode;
    public transient b<T> cachePolicy;
    public long cacheTime;
    public transient c<T> call;
    public transient d.m.a.d.b<T> callback;
    public transient OkHttpClient client;
    public transient a<T> converter;
    public HttpHeaders headers = new HttpHeaders();
    public transient okhttp3.Request mRequest;
    public HttpParams params = new HttpParams();
    public int retryCount;
    public transient Object tag;
    public transient b.AbstractC0104b uploadInterceptor;
    public String url;

    public Request(String str) {
        this.url = str;
        this.baseUrl = str;
        d.m.a.a aVar = a.b.f12292a;
        String acceptLanguage = HttpHeaders.getAcceptLanguage();
        if (!TextUtils.isEmpty(acceptLanguage)) {
            headers(HttpHeaders.HEAD_KEY_ACCEPT_LANGUAGE, acceptLanguage);
        }
        String userAgent = HttpHeaders.getUserAgent();
        if (!TextUtils.isEmpty(userAgent)) {
            headers(HttpHeaders.HEAD_KEY_USER_AGENT, userAgent);
        }
        Objects.requireNonNull(aVar);
        HttpHeaders httpHeaders = aVar.f12288d;
        if (httpHeaders != null) {
            headers(httpHeaders);
        }
        this.retryCount = aVar.f12289e;
        this.cacheMode = aVar.f12290f;
        this.cacheTime = aVar.f12291g;
    }

    public c<T> adapt() {
        c<T> cVar = this.call;
        return cVar == null ? new d.m.a.b.b(this) : cVar;
    }

    public R addUrlParams(String str, List<String> list) {
        this.params.putUrlParams(str, list);
        return this;
    }

    public R cacheKey(String str) {
        Objects.requireNonNull(str, "cacheKey == null");
        this.cacheKey = str;
        return this;
    }

    public R cacheMode(CacheMode cacheMode2) {
        this.cacheMode = cacheMode2;
        return this;
    }

    public R cachePolicy(d.m.a.c.a.b<T> bVar) {
        Objects.requireNonNull(bVar, "cachePolicy == null");
        this.cachePolicy = bVar;
        return this;
    }

    public R cacheTime(long j2) {
        if (j2 <= -1) {
            j2 = -1;
        }
        this.cacheTime = j2;
        return this;
    }

    public R call(c<T> cVar) {
        Objects.requireNonNull(cVar, "call == null");
        this.call = cVar;
        return this;
    }

    public R client(OkHttpClient okHttpClient) {
        Objects.requireNonNull(okHttpClient, "OkHttpClient == null");
        this.client = okHttpClient;
        return this;
    }

    public R converter(d.m.a.e.a<T> aVar) {
        Objects.requireNonNull(aVar, "converter == null");
        this.converter = aVar;
        return this;
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x009a  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00af  */
    public void execute(d.m.a.d.b<T> bVar) {
        CacheEntity<T> cacheEntity;
        HttpHeaders responseHeaders;
        String str;
        long lastModified;
        Objects.requireNonNull(bVar, "callback == null");
        this.callback = bVar;
        d.m.a.b.b bVar2 = (d.m.a.b.b) adapt();
        Objects.requireNonNull(bVar2);
        d.m.a.c.a.a aVar = (d.m.a.c.a.a) bVar2.f12293a;
        if (aVar.f12295a.getCacheKey() == null) {
            Request<T, ? extends Request> request = aVar.f12295a;
            request.cacheKey(d.l.b.g.g.b.v(request.getBaseUrl(), aVar.f12295a.getParams().urlParamsMap));
        }
        if (aVar.f12295a.getCacheMode() == null) {
            aVar.f12295a.cacheMode(CacheMode.NO_CACHE);
        }
        CacheMode cacheMode2 = aVar.f12295a.getCacheMode();
        if (cacheMode2 != CacheMode.NO_CACHE) {
            d.m.a.f.b bVar3 = b.C0101b.f12339a;
            String cacheKey2 = aVar.f12295a.getCacheKey();
            Objects.requireNonNull(bVar3);
            if (cacheKey2 != null) {
                ArrayList arrayList = (ArrayList) bVar3.e(null, "key=?", new String[]{cacheKey2}, null, null, null, null);
                if (arrayList.size() > 0) {
                    cacheEntity = (CacheEntity) arrayList.get(0);
                    aVar.f12300f = cacheEntity;
                    Request<T, ? extends Request> request2 = aVar.f12295a;
                    if (!(cacheEntity == null || cacheMode2 != CacheMode.DEFAULT || (responseHeaders = cacheEntity.getResponseHeaders()) == null)) {
                        str = responseHeaders.get(HttpHeaders.HEAD_KEY_E_TAG);
                        if (str != null) {
                            request2.headers(HttpHeaders.HEAD_KEY_IF_NONE_MATCH, str);
                        }
                        lastModified = HttpHeaders.getLastModified(responseHeaders.get(HttpHeaders.HEAD_KEY_LAST_MODIFIED));
                        if (lastModified > 0) {
                            request2.headers(HttpHeaders.HEAD_KEY_IF_MODIFIED_SINCE, HttpHeaders.formatMillisToGMT(lastModified));
                        }
                    }
                    CacheEntity<T> cacheEntity2 = aVar.f12300f;
                    if (cacheEntity2 != null && cacheEntity2.checkExpire(cacheMode2, aVar.f12295a.getCacheTime(), System.currentTimeMillis())) {
                        aVar.f12300f.setExpire(true);
                    }
                }
            }
            cacheEntity = null;
            aVar.f12300f = cacheEntity;
            Request<T, ? extends Request> request22 = aVar.f12295a;
            str = responseHeaders.get(HttpHeaders.HEAD_KEY_E_TAG);
            if (str != null) {
            }
            lastModified = HttpHeaders.getLastModified(responseHeaders.get(HttpHeaders.HEAD_KEY_LAST_MODIFIED));
            if (lastModified > 0) {
            }
            CacheEntity<T> cacheEntity22 = aVar.f12300f;
            aVar.f12300f.setExpire(true);
        }
        CacheEntity<T> cacheEntity3 = aVar.f12300f;
        if (cacheEntity3 == null || cacheEntity3.isExpire() || aVar.f12300f.getData() == null || aVar.f12300f.getResponseHeaders() == null) {
            aVar.f12300f = null;
        }
        bVar2.f12293a.a(aVar.f12300f, bVar);
    }

    public abstract okhttp3.Request generateRequest(RequestBody requestBody);

    public abstract RequestBody generateRequestBody();

    public String getBaseUrl() {
        return this.baseUrl;
    }

    public String getCacheKey() {
        return this.cacheKey;
    }

    public CacheMode getCacheMode() {
        return this.cacheMode;
    }

    public d.m.a.c.a.b<T> getCachePolicy() {
        return this.cachePolicy;
    }

    public long getCacheTime() {
        return this.cacheTime;
    }

    public d.m.a.e.a<T> getConverter() {
        if (this.converter == null) {
            this.converter = this.callback;
        }
        Objects.requireNonNull(this.converter, "converter == null, do you forget to call Request#converter(Converter<T>) ?");
        return this.converter;
    }

    public HttpParams.FileWrapper getFileParam(String str) {
        List<HttpParams.FileWrapper> list = this.params.fileParamsMap.get(str);
        if (list == null || list.size() <= 0) {
            return null;
        }
        return list.get(0);
    }

    public HttpHeaders getHeaders() {
        return this.headers;
    }

    public abstract HttpMethod getMethod();

    public HttpParams getParams() {
        return this.params;
    }

    public Call getRawCall() {
        RequestBody generateRequestBody = generateRequestBody();
        if (generateRequestBody != null) {
            d.m.a.i.a.b bVar = new d.m.a.i.a.b(generateRequestBody, this.callback);
            bVar.f12364c = this.uploadInterceptor;
            this.mRequest = generateRequest(bVar);
        } else {
            this.mRequest = generateRequest(null);
        }
        if (this.client == null) {
            this.client = a.b.f12292a.c();
        }
        return this.client.newCall(this.mRequest);
    }

    public okhttp3.Request getRequest() {
        return this.mRequest;
    }

    public int getRetryCount() {
        return this.retryCount;
    }

    public Object getTag() {
        return this.tag;
    }

    public String getUrl() {
        return this.url;
    }

    public String getUrlParam(String str) {
        List<String> list = this.params.urlParamsMap.get(str);
        if (list == null || list.size() <= 0) {
            return null;
        }
        return list.get(0);
    }

    public R headers(HttpHeaders httpHeaders) {
        this.headers.put(httpHeaders);
        return this;
    }

    public R params(HttpParams httpParams) {
        this.params.put(httpParams);
        return this;
    }

    public R removeAllHeaders() {
        this.headers.clear();
        return this;
    }

    public R removeAllParams() {
        this.params.clear();
        return this;
    }

    public R removeHeader(String str) {
        this.headers.remove(str);
        return this;
    }

    public R removeParam(String str) {
        this.params.remove(str);
        return this;
    }

    public R retryCount(int i2) {
        if (i2 >= 0) {
            this.retryCount = i2;
            return this;
        }
        throw new IllegalArgumentException("retryCount must > 0");
    }

    public void setCallback(d.m.a.d.b<T> bVar) {
        this.callback = bVar;
    }

    public R tag(Object obj) {
        this.tag = obj;
        return this;
    }

    public R uploadInterceptor(b.AbstractC0104b bVar) {
        this.uploadInterceptor = bVar;
        return this;
    }

    public R headers(String str, String str2) {
        this.headers.put(str, str2);
        return this;
    }

    public R params(Map<String, String> map, boolean... zArr) {
        this.params.put(map, zArr);
        return this;
    }

    public <E> E adapt(d<T, E> dVar) {
        c<T> cVar = this.call;
        if (cVar == null) {
            cVar = new d.m.a.b.b<>(this);
        }
        return dVar.a(cVar, null);
    }

    public R params(String str, String str2, boolean... zArr) {
        this.params.put(str, str2, zArr);
        return this;
    }

    public R params(String str, int i2, boolean... zArr) {
        this.params.put(str, i2, zArr);
        return this;
    }

    public R params(String str, float f2, boolean... zArr) {
        this.params.put(str, f2, zArr);
        return this;
    }

    public <E> E adapt(d.m.a.b.a aVar, d<T, E> dVar) {
        c<T> cVar = this.call;
        if (cVar == null) {
            cVar = new d.m.a.b.b<>(this);
        }
        return dVar.a(cVar, aVar);
    }

    public R params(String str, double d2, boolean... zArr) {
        this.params.put(str, d2, zArr);
        return this;
    }

    public R params(String str, long j2, boolean... zArr) {
        this.params.put(str, j2, zArr);
        return this;
    }

    public R params(String str, char c2, boolean... zArr) {
        this.params.put(str, c2, zArr);
        return this;
    }

    public R params(String str, boolean z, boolean... zArr) {
        this.params.put(str, z, zArr);
        return this;
    }

    public Response execute() {
        return getRawCall().execute();
    }
}
