package com.shuyu.gsyvideoplayer.utils;

import java.io.OutputStream;

/* compiled from: AnimatedGifEncoder */
public class LZWEncoder {
    public static final int BITS = 12;
    private static final int EOF = -1;
    public static final int HSIZE = 5003;
    public int ClearCode;
    public int EOFCode;
    public int a_count;
    public byte[] accum = new byte[256];
    public boolean clear_flg = false;
    public int[] codetab = new int[HSIZE];
    private int curPixel;
    public int cur_accum = 0;
    public int cur_bits = 0;
    public int free_ent = 0;
    public int g_init_bits;
    public int hsize = HSIZE;
    public int[] htab = new int[HSIZE];
    private int imgH;
    private int imgW;
    private int initCodeSize;
    public int[] masks = {0, 1, 3, 7, 15, 31, 63, 127, NeuQuant.maxnetpos, 511, 1023, 2047, 4095, 8191, 16383, 32767, 65535};
    public int maxbits = 12;
    public int maxcode;
    public int maxmaxcode = 4096;
    public int n_bits;
    private byte[] pixAry;
    private int remaining;

    public LZWEncoder(int i2, int i3, byte[] bArr, int i4) {
        this.imgW = i2;
        this.imgH = i3;
        this.pixAry = bArr;
        this.initCodeSize = Math.max(2, i4);
    }

    private int nextPixel() {
        int i2 = this.remaining;
        if (i2 == 0) {
            return -1;
        }
        this.remaining = i2 - 1;
        byte[] bArr = this.pixAry;
        int i3 = this.curPixel;
        this.curPixel = i3 + 1;
        return bArr[i3] & 255;
    }

    public final int MAXCODE(int i2) {
        return (1 << i2) - 1;
    }

    public void char_out(byte b2, OutputStream outputStream) {
        byte[] bArr = this.accum;
        int i2 = this.a_count;
        int i3 = i2 + 1;
        this.a_count = i3;
        bArr[i2] = b2;
        if (i3 >= 254) {
            flush_char(outputStream);
        }
    }

    public void cl_block(OutputStream outputStream) {
        cl_hash(this.hsize);
        int i2 = this.ClearCode;
        this.free_ent = i2 + 2;
        this.clear_flg = true;
        output(i2, outputStream);
    }

    public void cl_hash(int i2) {
        for (int i3 = 0; i3 < i2; i3++) {
            this.htab[i3] = -1;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:25:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0084  */
    public void compress(int i2, OutputStream outputStream) {
        int i3;
        this.g_init_bits = i2;
        int i4 = 0;
        this.clear_flg = false;
        this.n_bits = i2;
        this.maxcode = MAXCODE(i2);
        int i5 = 1 << (i2 - 1);
        this.ClearCode = i5;
        this.EOFCode = i5 + 1;
        this.free_ent = i5 + 2;
        this.a_count = 0;
        int nextPixel = nextPixel();
        for (int i6 = this.hsize; i6 < 65536; i6 *= 2) {
            i4++;
        }
        int i7 = 8 - i4;
        int i8 = this.hsize;
        cl_hash(i8);
        output(this.ClearCode, outputStream);
        while (true) {
            int nextPixel2 = nextPixel();
            if (nextPixel2 != -1) {
                int i9 = (nextPixel2 << this.maxbits) + nextPixel;
                int i10 = (nextPixel2 << i7) ^ nextPixel;
                int[] iArr = this.htab;
                if (iArr[i10] == i9) {
                    nextPixel = this.codetab[i10];
                } else if (iArr[i10] >= 0) {
                    int i11 = i8 - i10;
                    if (i10 == 0) {
                        i11 = 1;
                    }
                    while (true) {
                        i10 -= i11;
                        if (i10 < 0) {
                            i10 += i8;
                        }
                        int[] iArr2 = this.htab;
                        if (iArr2[i10] != i9) {
                            if (iArr2[i10] < 0) {
                                break;
                            }
                        } else {
                            nextPixel = this.codetab[i10];
                            break;
                        }
                    }
                    output(nextPixel, outputStream);
                    i3 = this.free_ent;
                    if (i3 >= this.maxmaxcode) {
                        int[] iArr3 = this.codetab;
                        this.free_ent = i3 + 1;
                        iArr3[i10] = i3;
                        this.htab[i10] = i9;
                    } else {
                        cl_block(outputStream);
                    }
                    nextPixel = nextPixel2;
                } else {
                    output(nextPixel, outputStream);
                    i3 = this.free_ent;
                    if (i3 >= this.maxmaxcode) {
                    }
                    nextPixel = nextPixel2;
                }
            } else {
                output(nextPixel, outputStream);
                output(this.EOFCode, outputStream);
                return;
            }
        }
    }

    public void encode(OutputStream outputStream) {
        outputStream.write(this.initCodeSize);
        this.remaining = this.imgW * this.imgH;
        this.curPixel = 0;
        compress(this.initCodeSize + 1, outputStream);
        outputStream.write(0);
    }

    public void flush_char(OutputStream outputStream) {
        int i2 = this.a_count;
        if (i2 > 0) {
            outputStream.write(i2);
            outputStream.write(this.accum, 0, this.a_count);
            this.a_count = 0;
        }
    }

    public void output(int i2, OutputStream outputStream) {
        int i3 = this.cur_accum;
        int[] iArr = this.masks;
        int i4 = this.cur_bits;
        int i5 = i3 & iArr[i4];
        this.cur_accum = i5;
        if (i4 > 0) {
            this.cur_accum = i5 | (i2 << i4);
        } else {
            this.cur_accum = i2;
        }
        this.cur_bits = i4 + this.n_bits;
        while (this.cur_bits >= 8) {
            char_out((byte) (this.cur_accum & NeuQuant.maxnetpos), outputStream);
            this.cur_accum >>= 8;
            this.cur_bits -= 8;
        }
        if (this.free_ent > this.maxcode || this.clear_flg) {
            if (this.clear_flg) {
                int i6 = this.g_init_bits;
                this.n_bits = i6;
                this.maxcode = MAXCODE(i6);
                this.clear_flg = false;
            } else {
                int i7 = this.n_bits + 1;
                this.n_bits = i7;
                if (i7 == this.maxbits) {
                    this.maxcode = this.maxmaxcode;
                } else {
                    this.maxcode = MAXCODE(i7);
                }
            }
        }
        if (i2 == this.EOFCode) {
            while (this.cur_bits > 0) {
                char_out((byte) (this.cur_accum & NeuQuant.maxnetpos), outputStream);
                this.cur_accum >>= 8;
                this.cur_bits -= 8;
            }
            flush_char(outputStream);
        }
    }
}
