package freemarker.template;

import e.b.d1;
import e.b.m0;
import e.b.p;
import e.b.q0;
import e.b.v0;
import freemarker.core.Environment;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Set;

public class TemplateException extends Exception {
    private static final String FTL_INSTRUCTION_STACK_TRACE_TITLE = "FTL stack trace (\"~\" means nesting-related):";
    private final transient p blamedExpression;
    private String blamedExpressionString;
    private boolean blamedExpressionStringCalculated;
    private Integer columnNumber;
    private String description;
    private transient d1 descriptionBuilder;
    private Integer endColumnNumber;
    private Integer endLineNumber;
    private final transient Environment env;
    private transient m0[] ftlInstructionStackSnapshot;
    private Integer lineNumber;
    private transient Object lock;
    private transient String message;
    private transient ThreadLocal messageWasAlreadyPrintedForThisTrace;
    private transient String messageWithoutStackTop;
    private boolean positionsCalculated;
    private String renderedFtlInstructionStackSnapshot;
    private String renderedFtlInstructionStackSnapshotTop;
    private String templateName;
    private String templateSourceName;

    public static class a implements c {

        /* renamed from: a  reason: collision with root package name */
        public final PrintStream f13225a;

        public a(PrintStream printStream) {
            this.f13225a = printStream;
        }

        @Override // freemarker.template.TemplateException.c
        public void a(Object obj) {
            this.f13225a.print(obj);
        }

        @Override // freemarker.template.TemplateException.c
        public void b(Throwable th) {
            if (th instanceof TemplateException) {
                ((TemplateException) th).printStandardStackTrace(this.f13225a);
            } else {
                th.printStackTrace(this.f13225a);
            }
        }

        @Override // freemarker.template.TemplateException.c
        public void c() {
            this.f13225a.println();
        }

        @Override // freemarker.template.TemplateException.c
        public void d(Object obj) {
            this.f13225a.println(obj);
        }
    }

    public static class b implements c {

        /* renamed from: a  reason: collision with root package name */
        public final PrintWriter f13226a;

        public b(PrintWriter printWriter) {
            this.f13226a = printWriter;
        }

        @Override // freemarker.template.TemplateException.c
        public void a(Object obj) {
            this.f13226a.print(obj);
        }

        @Override // freemarker.template.TemplateException.c
        public void b(Throwable th) {
            if (th instanceof TemplateException) {
                ((TemplateException) th).printStandardStackTrace(this.f13226a);
            } else {
                th.printStackTrace(this.f13226a);
            }
        }

        @Override // freemarker.template.TemplateException.c
        public void c() {
            this.f13226a.println();
        }

        @Override // freemarker.template.TemplateException.c
        public void d(Object obj) {
            this.f13226a.println(obj);
        }
    }

    public interface c {
        void a(Object obj);

        void b(Throwable th);

        void c();

        void d(Object obj);
    }

    public TemplateException(Environment environment) {
        this((String) null, (Exception) null, environment);
    }

    private void calculatePosition() {
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                q0 q0Var = this.blamedExpression;
                String str = null;
                if (q0Var == null) {
                    q0[] q0VarArr = this.ftlInstructionStackSnapshot;
                    q0Var = (q0VarArr == null || q0VarArr.length == 0) ? null : q0VarArr[0];
                }
                if (q0Var != null && q0Var.f12714j > 0) {
                    Template template = q0Var.f12712d;
                    this.templateName = template != null ? template.T : null;
                    if (template != null) {
                        str = template.f();
                    }
                    this.templateSourceName = str;
                    this.lineNumber = Integer.valueOf(q0Var.f12714j);
                    this.columnNumber = Integer.valueOf(q0Var.f12713h);
                    this.endLineNumber = Integer.valueOf(q0Var.f12716l);
                    this.endColumnNumber = Integer.valueOf(q0Var.f12715k);
                }
                this.positionsCalculated = true;
                deleteFTLInstructionStackSnapshotIfNotNeeded();
            }
        }
    }

    private void deleteFTLInstructionStackSnapshotIfNotNeeded() {
        if (this.renderedFtlInstructionStackSnapshot != null && this.renderedFtlInstructionStackSnapshotTop != null) {
            if (this.positionsCalculated || this.blamedExpression != null) {
                this.ftlInstructionStackSnapshot = null;
            }
        }
    }

    private String getDescription() {
        String str;
        d1 d1Var;
        synchronized (this.lock) {
            if (this.description == null && (d1Var = this.descriptionBuilder) != null) {
                m0 failingInstruction = getFailingInstruction();
                Environment environment = this.env;
                this.description = d1Var.f(failingInstruction, environment != null ? environment.c() : true);
                this.descriptionBuilder = null;
            }
            str = this.description;
        }
        return str;
    }

    private String getFTLInstructionStackTopFew() {
        String str;
        synchronized (this.lock) {
            m0[] m0VarArr = this.ftlInstructionStackSnapshot;
            String str2 = null;
            if (m0VarArr == null) {
                if (this.renderedFtlInstructionStackSnapshotTop == null) {
                    return null;
                }
            }
            if (this.renderedFtlInstructionStackSnapshotTop == null) {
                if (m0VarArr.length == 0) {
                    str = "";
                } else {
                    StringWriter stringWriter = new StringWriter();
                    v0.a(this.ftlInstructionStackSnapshot, true, stringWriter);
                    str = stringWriter.toString();
                }
                if (this.renderedFtlInstructionStackSnapshotTop == null) {
                    this.renderedFtlInstructionStackSnapshotTop = str;
                    deleteFTLInstructionStackSnapshotIfNotNeeded();
                }
            }
            if (this.renderedFtlInstructionStackSnapshotTop.length() != 0) {
                str2 = this.renderedFtlInstructionStackSnapshotTop;
            }
            return str2;
        }
    }

    private m0 getFailingInstruction() {
        m0[] m0VarArr = this.ftlInstructionStackSnapshot;
        if (m0VarArr == null || m0VarArr.length <= 0) {
            return null;
        }
        return m0VarArr[0];
    }

    private void readObject(ObjectInputStream objectInputStream) {
        this.lock = new Object();
        objectInputStream.defaultReadObject();
    }

    private void renderMessages() {
        String description2 = getDescription();
        if (description2 != null && description2.length() != 0) {
            this.messageWithoutStackTop = description2;
        } else if (getCause() != null) {
            StringBuilder B = d.a.a.a.a.B("No error description was specified for this error; low-level message: ");
            B.append(getCause().getClass().getName());
            B.append(": ");
            B.append(getCause().getMessage());
            this.messageWithoutStackTop = B.toString();
        } else {
            this.messageWithoutStackTop = "[No error description was available.]";
        }
        String fTLInstructionStackTopFew = getFTLInstructionStackTopFew();
        if (fTLInstructionStackTopFew != null) {
            String str = this.messageWithoutStackTop + "\n\n" + "----" + "\n" + FTL_INSTRUCTION_STACK_TRACE_TITLE + "\n" + fTLInstructionStackTopFew + "----";
            this.message = str;
            this.messageWithoutStackTop = str.substring(0, this.messageWithoutStackTop.length());
            return;
        }
        this.message = this.messageWithoutStackTop;
    }

    private void writeObject(ObjectOutputStream objectOutputStream) {
        getFTLInstructionStack();
        getFTLInstructionStackTopFew();
        getDescription();
        calculatePosition();
        getBlamedExpressionString();
        objectOutputStream.defaultWriteObject();
    }

    public p getBlamedExpression() {
        return this.blamedExpression;
    }

    public String getBlamedExpressionString() {
        String str;
        synchronized (this.lock) {
            if (!this.blamedExpressionStringCalculated) {
                p pVar = this.blamedExpression;
                if (pVar != null) {
                    this.blamedExpressionString = pVar.e();
                }
                this.blamedExpressionStringCalculated = true;
            }
            str = this.blamedExpressionString;
        }
        return str;
    }

    @Deprecated
    public Exception getCauseException() {
        if (getCause() instanceof Exception) {
            return (Exception) getCause();
        }
        StringBuilder B = d.a.a.a.a.B("Wrapped to Exception: ");
        B.append(getCause());
        return new Exception(B.toString(), getCause());
    }

    public Integer getColumnNumber() {
        Integer num;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            num = this.columnNumber;
        }
        return num;
    }

    public Integer getEndColumnNumber() {
        Integer num;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            num = this.endColumnNumber;
        }
        return num;
    }

    public Integer getEndLineNumber() {
        Integer num;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            num = this.endLineNumber;
        }
        return num;
    }

    public Environment getEnvironment() {
        return this.env;
    }

    public String getFTLInstructionStack() {
        synchronized (this.lock) {
            if (this.ftlInstructionStackSnapshot == null) {
                if (this.renderedFtlInstructionStackSnapshot == null) {
                    return null;
                }
            }
            if (this.renderedFtlInstructionStackSnapshot == null) {
                StringWriter stringWriter = new StringWriter();
                PrintWriter printWriter = new PrintWriter(stringWriter);
                v0.a(this.ftlInstructionStackSnapshot, false, printWriter);
                printWriter.close();
                if (this.renderedFtlInstructionStackSnapshot == null) {
                    this.renderedFtlInstructionStackSnapshot = stringWriter.toString();
                    deleteFTLInstructionStackSnapshotIfNotNeeded();
                }
            }
            return this.renderedFtlInstructionStackSnapshot;
        }
    }

    public Integer getLineNumber() {
        Integer num;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            num = this.lineNumber;
        }
        return num;
    }

    public String getMessage() {
        String str;
        ThreadLocal threadLocal = this.messageWasAlreadyPrintedForThisTrace;
        if (threadLocal != null && threadLocal.get() == Boolean.TRUE) {
            return "[... Exception message was already printed; see it above ...]";
        }
        synchronized (this.lock) {
            if (this.message == null) {
                renderMessages();
            }
            str = this.message;
        }
        return str;
    }

    public String getMessageWithoutStackTop() {
        String str;
        synchronized (this.lock) {
            if (this.messageWithoutStackTop == null) {
                renderMessages();
            }
            str = this.messageWithoutStackTop;
        }
        return str;
    }

    @Deprecated
    public String getTemplateName() {
        String str;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            str = this.templateName;
        }
        return str;
    }

    public String getTemplateSourceName() {
        String str;
        synchronized (this.lock) {
            if (!this.positionsCalculated) {
                calculatePosition();
            }
            str = this.templateSourceName;
        }
        return str;
    }

    @Override // java.lang.Throwable
    public void printStackTrace(PrintStream printStream) {
        printStackTrace(printStream, true, true, true);
    }

    public void printStandardStackTrace(PrintStream printStream) {
        super.printStackTrace(printStream);
    }

    public TemplateException(String str, Environment environment) {
        this(str, (Exception) null, environment);
    }

    @Override // java.lang.Throwable
    public void printStackTrace(PrintWriter printWriter) {
        printStackTrace(printWriter, true, true, true);
    }

    public void printStandardStackTrace(PrintWriter printWriter) {
        super.printStackTrace(printWriter);
    }

    public TemplateException(Exception exc, Environment environment) {
        this((String) null, exc, environment);
    }

    public void printStackTrace(PrintWriter printWriter, boolean z, boolean z2, boolean z3) {
        synchronized (printWriter) {
            printStackTrace(new b(printWriter), z, z2, z3);
        }
    }

    public TemplateException(Throwable th, Environment environment) {
        this((String) null, th, environment);
    }

    public TemplateException(String str, Exception exc, Environment environment) {
        this(str, exc, environment, null, null);
    }

    public TemplateException(String str, Throwable th, Environment environment) {
        this(str, th, environment, null, null);
    }

    public void printStackTrace(PrintStream printStream, boolean z, boolean z2, boolean z3) {
        synchronized (printStream) {
            printStackTrace(new a(printStream), z, z2, z3);
        }
    }

    public TemplateException(Throwable th, Environment environment, p pVar, d1 d1Var) {
        this(null, th, environment, pVar, d1Var);
    }

    private TemplateException(String str, Throwable th, Environment environment, p pVar, d1 d1Var) {
        super(th);
        m0[] m0VarArr;
        this.lock = new Object();
        environment = environment == null ? Environment.e() : environment;
        this.env = environment;
        this.blamedExpression = pVar;
        this.descriptionBuilder = d1Var;
        this.description = str;
        if (environment != null) {
            Set<String> set = v0.f12722a;
            int i2 = environment.V;
            int i3 = 0;
            for (int i4 = 0; i4 < i2; i4++) {
                m0 m0Var = environment.U[i4];
                if (i4 == i2 - 1 || m0Var.m()) {
                    i3++;
                }
            }
            if (i3 == 0) {
                m0VarArr = null;
            } else {
                m0[] m0VarArr2 = new m0[i3];
                int i5 = i3 - 1;
                for (int i6 = 0; i6 < i2; i6++) {
                    m0 m0Var2 = environment.U[i6];
                    if (i6 == i2 - 1 || m0Var2.m()) {
                        m0VarArr2[i5] = m0Var2;
                        i5--;
                    }
                }
                m0VarArr = m0VarArr2;
            }
            this.ftlInstructionStackSnapshot = m0VarArr;
        }
    }

    private void printStackTrace(c cVar, boolean z, boolean z2, boolean z3) {
        synchronized (cVar) {
            if (z) {
                try {
                    cVar.d("FreeMarker template error:");
                } catch (Throwable th) {
                    throw th;
                }
            }
            if (z2) {
                String fTLInstructionStack = getFTLInstructionStack();
                if (fTLInstructionStack != null) {
                    cVar.d(getMessageWithoutStackTop());
                    cVar.c();
                    cVar.d("----");
                    cVar.d(FTL_INSTRUCTION_STACK_TRACE_TITLE);
                    cVar.a(fTLInstructionStack);
                    cVar.d("----");
                } else {
                    z2 = false;
                    z3 = true;
                }
            }
            if (z3) {
                if (z2) {
                    cVar.c();
                    cVar.d("Java stack trace (for programmers):");
                    cVar.d("----");
                    synchronized (this.lock) {
                        if (this.messageWasAlreadyPrintedForThisTrace == null) {
                            this.messageWasAlreadyPrintedForThisTrace = new ThreadLocal();
                        }
                        this.messageWasAlreadyPrintedForThisTrace.set(Boolean.TRUE);
                    }
                    try {
                        cVar.b(this);
                    } finally {
                        this.messageWasAlreadyPrintedForThisTrace.set(Boolean.FALSE);
                    }
                } else {
                    cVar.b(this);
                }
                if (getCause() != null && getCause().getCause() == null) {
                    try {
                        Throwable th2 = (Throwable) getCause().getClass().getMethod("getRootCause", e.f.m0.c.f12914b).invoke(getCause(), e.f.m0.c.f12913a);
                        if (th2 != null) {
                            cVar.d("ServletException root cause: ");
                            cVar.b(th2);
                        }
                    } catch (Throwable unused) {
                    }
                }
            }
        }
    }
}
