package io.reactivex.internal.operators.observable;

import f.a.r;
import f.a.t;
import f.a.z.b;
import io.reactivex.internal.disposables.DisposableHelper;
import io.reactivex.internal.disposables.EmptyDisposable;
import java.util.ArrayDeque;
import java.util.Collection;
import java.util.Iterator;
import java.util.Objects;
import java.util.concurrent.Callable;
import java.util.concurrent.atomic.AtomicBoolean;

public final class ObservableBuffer<T, U extends Collection<? super T>> extends f.a.c0.e.d.a<T, U> {

    /* renamed from: h  reason: collision with root package name */
    public final int f13387h;

    /* renamed from: j  reason: collision with root package name */
    public final int f13388j;

    /* renamed from: k  reason: collision with root package name */
    public final Callable<U> f13389k;

    public static final class BufferSkipObserver<T, U extends Collection<? super T>> extends AtomicBoolean implements t<T>, b {
        private static final long serialVersionUID = -8223395059921494546L;
        public final Callable<U> bufferSupplier;
        public final ArrayDeque<U> buffers = new ArrayDeque<>();
        public final int count;
        public final t<? super U> downstream;
        public long index;
        public final int skip;
        public b upstream;

        public BufferSkipObserver(t<? super U> tVar, int i2, int i3, Callable<U> callable) {
            this.downstream = tVar;
            this.count = i2;
            this.skip = i3;
            this.bufferSupplier = callable;
        }

        @Override // f.a.z.b
        public void dispose() {
            this.upstream.dispose();
        }

        @Override // f.a.z.b
        public boolean isDisposed() {
            return this.upstream.isDisposed();
        }

        @Override // f.a.t
        public void onComplete() {
            while (!this.buffers.isEmpty()) {
                this.downstream.onNext(this.buffers.poll());
            }
            this.downstream.onComplete();
        }

        @Override // f.a.t
        public void onError(Throwable th) {
            this.buffers.clear();
            this.downstream.onError(th);
        }

        @Override // f.a.t
        public void onNext(T t) {
            long j2 = this.index;
            this.index = 1 + j2;
            if (j2 % ((long) this.skip) == 0) {
                try {
                    U call = this.bufferSupplier.call();
                    Objects.requireNonNull(call, "The bufferSupplier returned a null collection. Null values are generally not allowed in 2.x operators and sources.");
                    this.buffers.offer(call);
                } catch (Throwable th) {
                    this.buffers.clear();
                    this.upstream.dispose();
                    this.downstream.onError(th);
                    return;
                }
            }
            Iterator<U> it = this.buffers.iterator();
            while (it.hasNext()) {
                U next = it.next();
                next.add(t);
                if (this.count <= next.size()) {
                    it.remove();
                    this.downstream.onNext(next);
                }
            }
        }

        @Override // f.a.t
        public void onSubscribe(b bVar) {
            if (DisposableHelper.validate(this.upstream, bVar)) {
                this.upstream = bVar;
                this.downstream.onSubscribe(this);
            }
        }
    }

    public static final class a<T, U extends Collection<? super T>> implements t<T>, b {

        /* renamed from: d  reason: collision with root package name */
        public final t<? super U> f13390d;

        /* renamed from: h  reason: collision with root package name */
        public final int f13391h;

        /* renamed from: j  reason: collision with root package name */
        public final Callable<U> f13392j;

        /* renamed from: k  reason: collision with root package name */
        public U f13393k;

        /* renamed from: l  reason: collision with root package name */
        public int f13394l;
        public b m;

        public a(t<? super U> tVar, int i2, Callable<U> callable) {
            this.f13390d = tVar;
            this.f13391h = i2;
            this.f13392j = callable;
        }

        public boolean a() {
            try {
                U call = this.f13392j.call();
                Objects.requireNonNull(call, "Empty buffer supplied");
                this.f13393k = call;
                return true;
            } catch (Throwable th) {
                d.l.b.g.g.b.D0(th);
                this.f13393k = null;
                b bVar = this.m;
                if (bVar == null) {
                    EmptyDisposable.error(th, this.f13390d);
                    return false;
                }
                bVar.dispose();
                this.f13390d.onError(th);
                return false;
            }
        }

        @Override // f.a.z.b
        public void dispose() {
            this.m.dispose();
        }

        @Override // f.a.z.b
        public boolean isDisposed() {
            return this.m.isDisposed();
        }

        @Override // f.a.t
        public void onComplete() {
            U u = this.f13393k;
            if (u != null) {
                this.f13393k = null;
                if (!u.isEmpty()) {
                    this.f13390d.onNext(u);
                }
                this.f13390d.onComplete();
            }
        }

        @Override // f.a.t
        public void onError(Throwable th) {
            this.f13393k = null;
            this.f13390d.onError(th);
        }

        @Override // f.a.t
        public void onNext(T t) {
            U u = this.f13393k;
            if (u != null) {
                u.add(t);
                int i2 = this.f13394l + 1;
                this.f13394l = i2;
                if (i2 >= this.f13391h) {
                    this.f13390d.onNext(u);
                    this.f13394l = 0;
                    a();
                }
            }
        }

        @Override // f.a.t
        public void onSubscribe(b bVar) {
            if (DisposableHelper.validate(this.m, bVar)) {
                this.m = bVar;
                this.f13390d.onSubscribe(this);
            }
        }
    }

    public ObservableBuffer(r<T> rVar, int i2, int i3, Callable<U> callable) {
        super(rVar);
        this.f13387h = i2;
        this.f13388j = i3;
        this.f13389k = callable;
    }

    @Override // f.a.o
    public void j(t<? super U> tVar) {
        int i2 = this.f13388j;
        int i3 = this.f13387h;
        if (i2 == i3) {
            a aVar = new a(tVar, i3, this.f13389k);
            if (aVar.a()) {
                this.f12986d.subscribe(aVar);
                return;
            }
            return;
        }
        this.f12986d.subscribe(new BufferSkipObserver(tVar, this.f13387h, this.f13388j, this.f13389k));
    }
}
