package io.reactivex.internal.operators.observable;

import f.a.b0.h;
import f.a.c0.c.g;
import f.a.c0.e.d.a;
import f.a.d0.c;
import f.a.r;
import f.a.t;
import f.a.z.b;
import io.reactivex.internal.disposables.DisposableHelper;
import io.reactivex.internal.functions.Functions;
import io.reactivex.internal.util.AtomicThrowable;
import io.reactivex.internal.util.ErrorMode;
import java.util.Objects;
import java.util.concurrent.Callable;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;

public final class ObservableConcatMap<T, U> extends a<T, U> {

    /* renamed from: h  reason: collision with root package name */
    public final int f13395h;

    /* renamed from: j  reason: collision with root package name */
    public final ErrorMode f13396j;

    public static final class ConcatMapDelayErrorObserver<T, R> extends AtomicInteger implements t<T>, b {
        private static final long serialVersionUID = -6951100001833242599L;
        public volatile boolean active;
        public final int bufferSize;
        public volatile boolean cancelled;
        public volatile boolean done;
        public final t<? super R> downstream;
        public final AtomicThrowable error = new AtomicThrowable();
        public final h<? super T, ? extends r<? extends R>> mapper;
        public final DelayErrorInnerObserver<R> observer;
        public g<T> queue;
        public int sourceMode;
        public final boolean tillTheEnd;
        public b upstream;

        public static final class DelayErrorInnerObserver<R> extends AtomicReference<b> implements t<R> {
            private static final long serialVersionUID = 2620149119579502636L;
            public final t<? super R> downstream;
            public final ConcatMapDelayErrorObserver<?, R> parent;

            public DelayErrorInnerObserver(t<? super R> tVar, ConcatMapDelayErrorObserver<?, R> concatMapDelayErrorObserver) {
                this.downstream = tVar;
                this.parent = concatMapDelayErrorObserver;
            }

            public void dispose() {
                DisposableHelper.dispose(this);
            }

            @Override // f.a.t
            public void onComplete() {
                ConcatMapDelayErrorObserver<?, R> concatMapDelayErrorObserver = this.parent;
                concatMapDelayErrorObserver.active = false;
                concatMapDelayErrorObserver.drain();
            }

            @Override // f.a.t
            public void onError(Throwable th) {
                ConcatMapDelayErrorObserver<?, R> concatMapDelayErrorObserver = this.parent;
                if (concatMapDelayErrorObserver.error.addThrowable(th)) {
                    if (!concatMapDelayErrorObserver.tillTheEnd) {
                        concatMapDelayErrorObserver.upstream.dispose();
                    }
                    concatMapDelayErrorObserver.active = false;
                    concatMapDelayErrorObserver.drain();
                    return;
                }
                d.l.b.g.g.b.q0(th);
            }

            @Override // f.a.t
            public void onNext(R r) {
                this.downstream.onNext(r);
            }

            @Override // f.a.t
            public void onSubscribe(b bVar) {
                DisposableHelper.replace(this, bVar);
            }
        }

        public ConcatMapDelayErrorObserver(t<? super R> tVar, h<? super T, ? extends r<? extends R>> hVar, int i2, boolean z) {
            this.downstream = tVar;
            this.mapper = hVar;
            this.bufferSize = i2;
            this.tillTheEnd = z;
            this.observer = new DelayErrorInnerObserver<>(tVar, this);
        }

        @Override // f.a.z.b
        public void dispose() {
            this.cancelled = true;
            this.upstream.dispose();
            this.observer.dispose();
        }

        public void drain() {
            if (getAndIncrement() == 0) {
                t<? super R> tVar = this.downstream;
                g<T> gVar = this.queue;
                AtomicThrowable atomicThrowable = this.error;
                while (true) {
                    if (!this.active) {
                        if (this.cancelled) {
                            gVar.clear();
                            return;
                        } else if (this.tillTheEnd || ((Throwable) atomicThrowable.get()) == null) {
                            boolean z = this.done;
                            try {
                                T poll = gVar.poll();
                                boolean z2 = poll == null;
                                if (z && z2) {
                                    this.cancelled = true;
                                    Throwable terminate = atomicThrowable.terminate();
                                    if (terminate != null) {
                                        tVar.onError(terminate);
                                        return;
                                    } else {
                                        tVar.onComplete();
                                        return;
                                    }
                                } else if (!z2) {
                                    try {
                                        Object apply = this.mapper.apply(poll);
                                        Objects.requireNonNull(apply, "The mapper returned a null ObservableSource");
                                        r rVar = (r) apply;
                                        if (rVar instanceof Callable) {
                                            try {
                                                Object obj = (Object) ((Callable) rVar).call();
                                                if (obj != 0 && !this.cancelled) {
                                                    tVar.onNext(obj);
                                                }
                                            } catch (Throwable th) {
                                                d.l.b.g.g.b.D0(th);
                                                atomicThrowable.addThrowable(th);
                                            }
                                        } else {
                                            this.active = true;
                                            rVar.subscribe(this.observer);
                                        }
                                    } catch (Throwable th2) {
                                        d.l.b.g.g.b.D0(th2);
                                        this.cancelled = true;
                                        this.upstream.dispose();
                                        gVar.clear();
                                        atomicThrowable.addThrowable(th2);
                                        tVar.onError(atomicThrowable.terminate());
                                        return;
                                    }
                                }
                            } catch (Throwable th3) {
                                d.l.b.g.g.b.D0(th3);
                                this.cancelled = true;
                                this.upstream.dispose();
                                atomicThrowable.addThrowable(th3);
                                tVar.onError(atomicThrowable.terminate());
                                return;
                            }
                        } else {
                            gVar.clear();
                            this.cancelled = true;
                            tVar.onError(atomicThrowable.terminate());
                            return;
                        }
                    }
                    if (decrementAndGet() == 0) {
                        return;
                    }
                }
            }
        }

        @Override // f.a.z.b
        public boolean isDisposed() {
            return this.cancelled;
        }

        @Override // f.a.t
        public void onComplete() {
            this.done = true;
            drain();
        }

        @Override // f.a.t
        public void onError(Throwable th) {
            if (this.error.addThrowable(th)) {
                this.done = true;
                drain();
                return;
            }
            d.l.b.g.g.b.q0(th);
        }

        @Override // f.a.t
        public void onNext(T t) {
            if (this.sourceMode == 0) {
                this.queue.offer(t);
            }
            drain();
        }

        @Override // f.a.t
        public void onSubscribe(b bVar) {
            if (DisposableHelper.validate(this.upstream, bVar)) {
                this.upstream = bVar;
                if (bVar instanceof f.a.c0.c.b) {
                    f.a.c0.c.b bVar2 = (f.a.c0.c.b) bVar;
                    int requestFusion = bVar2.requestFusion(3);
                    if (requestFusion == 1) {
                        this.sourceMode = requestFusion;
                        this.queue = bVar2;
                        this.done = true;
                        this.downstream.onSubscribe(this);
                        drain();
                        return;
                    } else if (requestFusion == 2) {
                        this.sourceMode = requestFusion;
                        this.queue = bVar2;
                        this.downstream.onSubscribe(this);
                        return;
                    }
                }
                this.queue = new f.a.c0.f.a(this.bufferSize);
                this.downstream.onSubscribe(this);
            }
        }
    }

    public static final class SourceObserver<T, U> extends AtomicInteger implements t<T>, b {
        private static final long serialVersionUID = 8828587559905699186L;
        public volatile boolean active;
        public final int bufferSize;
        public volatile boolean disposed;
        public volatile boolean done;
        public final t<? super U> downstream;
        public int fusionMode;
        public final InnerObserver<U> inner;
        public final h<? super T, ? extends r<? extends U>> mapper;
        public g<T> queue;
        public b upstream;

        public static final class InnerObserver<U> extends AtomicReference<b> implements t<U> {
            private static final long serialVersionUID = -7449079488798789337L;
            public final t<? super U> downstream;
            public final SourceObserver<?, ?> parent;

            public InnerObserver(t<? super U> tVar, SourceObserver<?, ?> sourceObserver) {
                this.downstream = tVar;
                this.parent = sourceObserver;
            }

            public void dispose() {
                DisposableHelper.dispose(this);
            }

            @Override // f.a.t
            public void onComplete() {
                this.parent.innerComplete();
            }

            @Override // f.a.t
            public void onError(Throwable th) {
                this.parent.dispose();
                this.downstream.onError(th);
            }

            @Override // f.a.t
            public void onNext(U u) {
                this.downstream.onNext(u);
            }

            @Override // f.a.t
            public void onSubscribe(b bVar) {
                DisposableHelper.replace(this, bVar);
            }
        }

        public SourceObserver(t<? super U> tVar, h<? super T, ? extends r<? extends U>> hVar, int i2) {
            this.downstream = tVar;
            this.mapper = hVar;
            this.bufferSize = i2;
            this.inner = new InnerObserver<>(tVar, this);
        }

        @Override // f.a.z.b
        public void dispose() {
            this.disposed = true;
            this.inner.dispose();
            this.upstream.dispose();
            if (getAndIncrement() == 0) {
                this.queue.clear();
            }
        }

        public void drain() {
            if (getAndIncrement() == 0) {
                while (!this.disposed) {
                    if (!this.active) {
                        boolean z = this.done;
                        try {
                            T poll = this.queue.poll();
                            boolean z2 = poll == null;
                            if (z && z2) {
                                this.disposed = true;
                                this.downstream.onComplete();
                                return;
                            } else if (!z2) {
                                try {
                                    Object apply = this.mapper.apply(poll);
                                    Objects.requireNonNull(apply, "The mapper returned a null ObservableSource");
                                    r rVar = (r) apply;
                                    this.active = true;
                                    rVar.subscribe(this.inner);
                                } catch (Throwable th) {
                                    d.l.b.g.g.b.D0(th);
                                    dispose();
                                    this.queue.clear();
                                    this.downstream.onError(th);
                                    return;
                                }
                            }
                        } catch (Throwable th2) {
                            d.l.b.g.g.b.D0(th2);
                            dispose();
                            this.queue.clear();
                            this.downstream.onError(th2);
                            return;
                        }
                    }
                    if (decrementAndGet() == 0) {
                        return;
                    }
                }
                this.queue.clear();
            }
        }

        public void innerComplete() {
            this.active = false;
            drain();
        }

        @Override // f.a.z.b
        public boolean isDisposed() {
            return this.disposed;
        }

        @Override // f.a.t
        public void onComplete() {
            if (!this.done) {
                this.done = true;
                drain();
            }
        }

        @Override // f.a.t
        public void onError(Throwable th) {
            if (this.done) {
                d.l.b.g.g.b.q0(th);
                return;
            }
            this.done = true;
            dispose();
            this.downstream.onError(th);
        }

        @Override // f.a.t
        public void onNext(T t) {
            if (!this.done) {
                if (this.fusionMode == 0) {
                    this.queue.offer(t);
                }
                drain();
            }
        }

        @Override // f.a.t
        public void onSubscribe(b bVar) {
            if (DisposableHelper.validate(this.upstream, bVar)) {
                this.upstream = bVar;
                if (bVar instanceof f.a.c0.c.b) {
                    f.a.c0.c.b bVar2 = (f.a.c0.c.b) bVar;
                    int requestFusion = bVar2.requestFusion(3);
                    if (requestFusion == 1) {
                        this.fusionMode = requestFusion;
                        this.queue = bVar2;
                        this.done = true;
                        this.downstream.onSubscribe(this);
                        drain();
                        return;
                    } else if (requestFusion == 2) {
                        this.fusionMode = requestFusion;
                        this.queue = bVar2;
                        this.downstream.onSubscribe(this);
                        return;
                    }
                }
                this.queue = new f.a.c0.f.a(this.bufferSize);
                this.downstream.onSubscribe(this);
            }
        }
    }

    public ObservableConcatMap(r<T> rVar, h<? super T, ? extends r<? extends U>> hVar, int i2, ErrorMode errorMode) {
        super(rVar);
        this.f13396j = errorMode;
        this.f13395h = Math.max(8, i2);
    }

    @Override // f.a.o
    public void j(t<? super U> tVar) {
        r<T> rVar = this.f12986d;
        h<Object, Object> hVar = Functions.f13354a;
        if (!d.l.b.g.g.b.L0(rVar, tVar, hVar)) {
            if (this.f13396j == ErrorMode.IMMEDIATE) {
                this.f12986d.subscribe(new SourceObserver(new c(tVar), hVar, this.f13395h));
            } else {
                this.f12986d.subscribe(new ConcatMapDelayErrorObserver(tVar, hVar, this.f13395h, this.f13396j == ErrorMode.END));
            }
        }
    }
}
