package io.reactivex.internal.operators.observable;

import f.a.b0.f;
import f.a.c0.f.a;
import f.a.o;
import f.a.p;
import f.a.q;
import f.a.t;
import f.a.z.b;
import io.reactivex.internal.disposables.CancellableDisposable;
import io.reactivex.internal.disposables.DisposableHelper;
import io.reactivex.internal.util.AtomicThrowable;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;

public final class ObservableCreate<T> extends o<T> {

    /* renamed from: d  reason: collision with root package name */
    public final q<T> f13397d;

    public static final class CreateEmitter<T> extends AtomicReference<b> implements p<T>, b {
        private static final long serialVersionUID = -3434801548987643227L;
        public final t<? super T> observer;

        public CreateEmitter(t<? super T> tVar) {
            this.observer = tVar;
        }

        @Override // f.a.z.b
        public void dispose() {
            DisposableHelper.dispose(this);
        }

        @Override // f.a.z.b, f.a.p
        public boolean isDisposed() {
            return DisposableHelper.isDisposed((b) get());
        }

        @Override // f.a.f
        public void onComplete() {
            if (!isDisposed()) {
                try {
                    this.observer.onComplete();
                } finally {
                    dispose();
                }
            }
        }

        @Override // f.a.f
        public void onError(Throwable th) {
            if (!tryOnError(th)) {
                d.l.b.g.g.b.q0(th);
            }
        }

        @Override // f.a.f
        public void onNext(T t) {
            if (t == null) {
                onError(new NullPointerException("onNext called with null. Null values are generally not allowed in 2.x operators and sources."));
            } else if (!isDisposed()) {
                this.observer.onNext(t);
            }
        }

        public p<T> serialize() {
            return new SerializedEmitter(this);
        }

        @Override // f.a.p
        public void setCancellable(f fVar) {
            setDisposable(new CancellableDisposable(fVar));
        }

        @Override // f.a.p
        public void setDisposable(b bVar) {
            DisposableHelper.set(this, bVar);
        }

        public String toString() {
            return String.format("%s{%s}", CreateEmitter.class.getSimpleName(), super.toString());
        }

        /* JADX INFO: finally extract failed */
        public boolean tryOnError(Throwable th) {
            if (th == null) {
                th = new NullPointerException("onError called with null. Null values are generally not allowed in 2.x operators and sources.");
            }
            if (isDisposed()) {
                return false;
            }
            try {
                this.observer.onError(th);
                dispose();
                return true;
            } catch (Throwable th2) {
                dispose();
                throw th2;
            }
        }
    }

    public static final class SerializedEmitter<T> extends AtomicInteger implements p<T> {
        private static final long serialVersionUID = 4883307006032401862L;
        public volatile boolean done;
        public final p<T> emitter;
        public final AtomicThrowable error = new AtomicThrowable();
        public final a<T> queue = new a<>(16);

        public SerializedEmitter(p<T> pVar) {
            this.emitter = pVar;
        }

        public void drain() {
            if (getAndIncrement() == 0) {
                drainLoop();
            }
        }

        public void drainLoop() {
            p<T> pVar = this.emitter;
            a<T> aVar = this.queue;
            AtomicThrowable atomicThrowable = this.error;
            int i2 = 1;
            while (!pVar.isDisposed()) {
                if (atomicThrowable.get() != null) {
                    aVar.clear();
                    pVar.onError(atomicThrowable.terminate());
                    return;
                }
                boolean z = this.done;
                T poll = aVar.poll();
                boolean z2 = poll == null;
                if (z && z2) {
                    pVar.onComplete();
                    return;
                } else if (z2) {
                    i2 = addAndGet(-i2);
                    if (i2 == 0) {
                        return;
                    }
                } else {
                    pVar.onNext(poll);
                }
            }
            aVar.clear();
        }

        @Override // f.a.p
        public boolean isDisposed() {
            return this.emitter.isDisposed();
        }

        @Override // f.a.f
        public void onComplete() {
            if (!this.emitter.isDisposed() && !this.done) {
                this.done = true;
                drain();
            }
        }

        @Override // f.a.f
        public void onError(Throwable th) {
            if (!tryOnError(th)) {
                d.l.b.g.g.b.q0(th);
            }
        }

        @Override // f.a.f
        public void onNext(T t) {
            if (!this.emitter.isDisposed() && !this.done) {
                if (t == null) {
                    onError(new NullPointerException("onNext called with null. Null values are generally not allowed in 2.x operators and sources."));
                    return;
                }
                if (get() != 0 || !compareAndSet(0, 1)) {
                    a<T> aVar = this.queue;
                    synchronized (aVar) {
                        aVar.offer(t);
                    }
                    if (getAndIncrement() != 0) {
                        return;
                    }
                } else {
                    this.emitter.onNext(t);
                    if (decrementAndGet() == 0) {
                        return;
                    }
                }
                drainLoop();
            }
        }

        public p<T> serialize() {
            return this;
        }

        @Override // f.a.p
        public void setCancellable(f fVar) {
            this.emitter.setCancellable(fVar);
        }

        @Override // f.a.p
        public void setDisposable(b bVar) {
            this.emitter.setDisposable(bVar);
        }

        public String toString() {
            return this.emitter.toString();
        }

        public boolean tryOnError(Throwable th) {
            if (!this.emitter.isDisposed() && !this.done) {
                if (th == null) {
                    th = new NullPointerException("onError called with null. Null values are generally not allowed in 2.x operators and sources.");
                }
                if (this.error.addThrowable(th)) {
                    this.done = true;
                    drain();
                    return true;
                }
            }
            return false;
        }
    }

    public ObservableCreate(q<T> qVar) {
        this.f13397d = qVar;
    }

    @Override // f.a.o
    public void j(t<? super T> tVar) {
        CreateEmitter createEmitter = new CreateEmitter(tVar);
        tVar.onSubscribe(createEmitter);
        try {
            this.f13397d.a(createEmitter);
        } catch (Throwable th) {
            d.l.b.g.g.b.D0(th);
            createEmitter.onError(th);
        }
    }
}
