package okio;

import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.lzy.okgo.cache.CacheEntity;
import h.l.h;
import h.p.b.m;
import h.p.b.o;
import h.u.a;
import h.u.i;
import java.io.EOFException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.util.Arrays;
import java.util.Objects;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.internal._ByteStringKt;

/* compiled from: ByteString.kt */
public class ByteString implements Serializable, Comparable<ByteString> {
    public static final Companion Companion = new Companion(null);
    public static final ByteString EMPTY = new ByteString(new byte[0]);
    private static final long serialVersionUID = 1;
    private final byte[] data;
    private transient int hashCode;
    private transient String utf8;

    /* compiled from: ByteString.kt */
    public static final class Companion {
        private Companion() {
        }

        public static /* synthetic */ ByteString encodeString$default(Companion companion, String str, Charset charset, int i2, Object obj) {
            if ((i2 & 1) != 0) {
                charset = a.f13344a;
            }
            return companion.encodeString(str, charset);
        }

        public static /* synthetic */ ByteString of$default(Companion companion, byte[] bArr, int i2, int i3, int i4, Object obj) {
            if ((i4 & 1) != 0) {
                i2 = 0;
            }
            if ((i4 & 2) != 0) {
                i3 = bArr.length;
            }
            return companion.of(bArr, i2, i3);
        }

        /* renamed from: -deprecated_decodeBase64  reason: not valid java name */
        public final ByteString m22deprecated_decodeBase64(String str) {
            o.e(str, TypedValues.Custom.S_STRING);
            return decodeBase64(str);
        }

        /* renamed from: -deprecated_decodeHex  reason: not valid java name */
        public final ByteString m23deprecated_decodeHex(String str) {
            o.e(str, TypedValues.Custom.S_STRING);
            return decodeHex(str);
        }

        /* renamed from: -deprecated_encodeString  reason: not valid java name */
        public final ByteString m24deprecated_encodeString(String str, Charset charset) {
            o.e(str, TypedValues.Custom.S_STRING);
            o.e(charset, "charset");
            return encodeString(str, charset);
        }

        /* renamed from: -deprecated_encodeUtf8  reason: not valid java name */
        public final ByteString m25deprecated_encodeUtf8(String str) {
            o.e(str, TypedValues.Custom.S_STRING);
            return encodeUtf8(str);
        }

        /* renamed from: -deprecated_of  reason: not valid java name */
        public final ByteString m26deprecated_of(ByteBuffer byteBuffer) {
            o.e(byteBuffer, "buffer");
            return of(byteBuffer);
        }

        /* renamed from: -deprecated_read  reason: not valid java name */
        public final ByteString m28deprecated_read(InputStream inputStream, int i2) {
            o.e(inputStream, "inputstream");
            return read(inputStream, i2);
        }

        public final ByteString decodeBase64(String str) {
            o.e(str, "$this$decodeBase64");
            byte[] decodeBase64ToArray = _Base64Kt.decodeBase64ToArray(str);
            if (decodeBase64ToArray != null) {
                return new ByteString(decodeBase64ToArray);
            }
            return null;
        }

        public final ByteString decodeHex(String str) {
            o.e(str, "$this$decodeHex");
            if (str.length() % 2 == 0) {
                int length = str.length() / 2;
                byte[] bArr = new byte[length];
                for (int i2 = 0; i2 < length; i2++) {
                    int i3 = i2 * 2;
                    bArr[i2] = (byte) (_ByteStringKt.access$decodeHexDigit(str.charAt(i3 + 1)) + (_ByteStringKt.access$decodeHexDigit(str.charAt(i3)) << 4));
                }
                return new ByteString(bArr);
            }
            throw new IllegalArgumentException(d.a.a.a.a.s("Unexpected hex string: ", str).toString());
        }

        public final ByteString encodeString(String str, Charset charset) {
            o.e(str, "$this$encode");
            o.e(charset, "charset");
            byte[] bytes = str.getBytes(charset);
            o.d(bytes, "(this as java.lang.String).getBytes(charset)");
            return new ByteString(bytes);
        }

        public final ByteString encodeUtf8(String str) {
            o.e(str, "$this$encodeUtf8");
            ByteString byteString = new ByteString(_JvmPlatformKt.asUtf8ToByteArray(str));
            byteString.setUtf8$okio(str);
            return byteString;
        }

        public final ByteString of(ByteBuffer byteBuffer) {
            o.e(byteBuffer, "$this$toByteString");
            byte[] bArr = new byte[byteBuffer.remaining()];
            byteBuffer.get(bArr);
            return new ByteString(bArr);
        }

        public final ByteString read(InputStream inputStream, int i2) {
            o.e(inputStream, "$this$readByteString");
            int i3 = 0;
            if (i2 >= 0) {
                byte[] bArr = new byte[i2];
                while (i3 < i2) {
                    int read = inputStream.read(bArr, i3, i2 - i3);
                    if (read != -1) {
                        i3 += read;
                    } else {
                        throw new EOFException();
                    }
                }
                return new ByteString(bArr);
            }
            throw new IllegalArgumentException(d.a.a.a.a.k("byteCount < 0: ", i2).toString());
        }

        public /* synthetic */ Companion(m mVar) {
            this();
        }

        /* renamed from: -deprecated_of  reason: not valid java name */
        public final ByteString m27deprecated_of(byte[] bArr, int i2, int i3) {
            o.e(bArr, "array");
            return of(bArr, i2, i3);
        }

        public final ByteString of(byte... bArr) {
            o.e(bArr, CacheEntity.DATA);
            byte[] copyOf = Arrays.copyOf(bArr, bArr.length);
            o.d(copyOf, "java.util.Arrays.copyOf(this, size)");
            return new ByteString(copyOf);
        }

        public final ByteString of(byte[] bArr, int i2, int i3) {
            o.e(bArr, "$this$toByteString");
            _UtilKt.checkOffsetAndCount((long) bArr.length, (long) i2, (long) i3);
            return new ByteString(h.d(bArr, i2, i3 + i2));
        }
    }

    public ByteString(byte[] bArr) {
        o.e(bArr, CacheEntity.DATA);
        this.data = bArr;
    }

    public static final ByteString decodeBase64(String str) {
        return Companion.decodeBase64(str);
    }

    public static final ByteString decodeHex(String str) {
        return Companion.decodeHex(str);
    }

    public static final ByteString encodeString(String str, Charset charset) {
        return Companion.encodeString(str, charset);
    }

    public static final ByteString encodeUtf8(String str) {
        return Companion.encodeUtf8(str);
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, ByteString byteString2, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 2) != 0) {
                i2 = 0;
            }
            return byteString.indexOf(byteString2, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, byte[] bArr, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 2) != 0) {
                i2 = 0;
            }
            return byteString.indexOf(bArr, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, ByteString byteString2, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 2) != 0) {
                i2 = byteString.size();
            }
            return byteString.lastIndexOf(byteString2, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, byte[] bArr, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 2) != 0) {
                i2 = byteString.size();
            }
            return byteString.lastIndexOf(bArr, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static final ByteString of(ByteBuffer byteBuffer) {
        return Companion.of(byteBuffer);
    }

    public static final ByteString of(byte... bArr) {
        return Companion.of(bArr);
    }

    public static final ByteString of(byte[] bArr, int i2, int i3) {
        return Companion.of(bArr, i2, i3);
    }

    public static final ByteString read(InputStream inputStream, int i2) {
        return Companion.read(inputStream, i2);
    }

    private final void readObject(ObjectInputStream objectInputStream) {
        ByteString read = Companion.read(objectInputStream, objectInputStream.readInt());
        Field declaredField = ByteString.class.getDeclaredField(CacheEntity.DATA);
        o.d(declaredField, "field");
        declaredField.setAccessible(true);
        declaredField.set(this, read.data);
    }

    public static /* synthetic */ ByteString substring$default(ByteString byteString, int i2, int i3, int i4, Object obj) {
        if (obj == null) {
            if ((i4 & 1) != 0) {
                i2 = 0;
            }
            if ((i4 & 2) != 0) {
                i3 = byteString.size();
            }
            return byteString.substring(i2, i3);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: substring");
    }

    private final void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.writeInt(this.data.length);
        objectOutputStream.write(this.data);
    }

    /* renamed from: -deprecated_getByte  reason: not valid java name */
    public final byte m20deprecated_getByte(int i2) {
        return getByte(i2);
    }

    /* renamed from: -deprecated_size  reason: not valid java name */
    public final int m21deprecated_size() {
        return size();
    }

    public ByteBuffer asByteBuffer() {
        ByteBuffer asReadOnlyBuffer = ByteBuffer.wrap(this.data).asReadOnlyBuffer();
        o.d(asReadOnlyBuffer, "ByteBuffer.wrap(data).asReadOnlyBuffer()");
        return asReadOnlyBuffer;
    }

    public String base64() {
        return _Base64Kt.encodeBase64$default(getData$okio(), null, 1, null);
    }

    public String base64Url() {
        return _Base64Kt.encodeBase64(getData$okio(), _Base64Kt.getBASE64_URL_SAFE());
    }

    public ByteString digest$okio(String str) {
        o.e(str, "algorithm");
        MessageDigest instance = MessageDigest.getInstance(str);
        instance.update(this.data, 0, size());
        byte[] digest = instance.digest();
        o.d(digest, "digestBytes");
        return new ByteString(digest);
    }

    public final boolean endsWith(ByteString byteString) {
        o.e(byteString, "suffix");
        return rangeEquals(size() - byteString.size(), byteString, 0, byteString.size());
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof ByteString) {
            ByteString byteString = (ByteString) obj;
            return byteString.size() == getData$okio().length && byteString.rangeEquals(0, getData$okio(), 0, getData$okio().length);
        }
    }

    public final byte getByte(int i2) {
        return internalGet$okio(i2);
    }

    public final byte[] getData$okio() {
        return this.data;
    }

    public final int getHashCode$okio() {
        return this.hashCode;
    }

    public int getSize$okio() {
        return getData$okio().length;
    }

    public final String getUtf8$okio() {
        return this.utf8;
    }

    public int hashCode() {
        int hashCode$okio = getHashCode$okio();
        if (hashCode$okio != 0) {
            return hashCode$okio;
        }
        int hashCode2 = Arrays.hashCode(getData$okio());
        setHashCode$okio(hashCode2);
        return hashCode2;
    }

    public String hex() {
        char[] cArr = new char[(getData$okio().length * 2)];
        byte[] data$okio = getData$okio();
        int i2 = 0;
        for (byte b2 : data$okio) {
            int i3 = i2 + 1;
            cArr[i2] = _ByteStringKt.getHEX_DIGIT_CHARS()[(b2 >> 4) & 15];
            i2 = i3 + 1;
            cArr[i3] = _ByteStringKt.getHEX_DIGIT_CHARS()[b2 & 15];
        }
        return new String(cArr);
    }

    public ByteString hmac$okio(String str, ByteString byteString) {
        o.e(str, "algorithm");
        o.e(byteString, CacheEntity.KEY);
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            byte[] doFinal = instance.doFinal(this.data);
            o.d(doFinal, "mac.doFinal(data)");
            return new ByteString(doFinal);
        } catch (InvalidKeyException e2) {
            throw new IllegalArgumentException(e2);
        }
    }

    public ByteString hmacSha1(ByteString byteString) {
        o.e(byteString, CacheEntity.KEY);
        return hmac$okio("HmacSHA1", byteString);
    }

    public ByteString hmacSha256(ByteString byteString) {
        o.e(byteString, CacheEntity.KEY);
        return hmac$okio("HmacSHA256", byteString);
    }

    public ByteString hmacSha512(ByteString byteString) {
        o.e(byteString, CacheEntity.KEY);
        return hmac$okio("HmacSHA512", byteString);
    }

    public final int indexOf(ByteString byteString) {
        return indexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int indexOf(ByteString byteString, int i2) {
        o.e(byteString, "other");
        return indexOf(byteString.internalArray$okio(), i2);
    }

    public final int indexOf(byte[] bArr) {
        return indexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public byte[] internalArray$okio() {
        return getData$okio();
    }

    public byte internalGet$okio(int i2) {
        return getData$okio()[i2];
    }

    public final int lastIndexOf(ByteString byteString) {
        return lastIndexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int lastIndexOf(ByteString byteString, int i2) {
        o.e(byteString, "other");
        return lastIndexOf(byteString.internalArray$okio(), i2);
    }

    public final int lastIndexOf(byte[] bArr) {
        return lastIndexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public final ByteString md5() {
        return digest$okio("MD5");
    }

    public boolean rangeEquals(int i2, ByteString byteString, int i3, int i4) {
        o.e(byteString, "other");
        return byteString.rangeEquals(i3, getData$okio(), i2, i4);
    }

    public final void setHashCode$okio(int i2) {
        this.hashCode = i2;
    }

    public final void setUtf8$okio(String str) {
        this.utf8 = str;
    }

    public final ByteString sha1() {
        return digest$okio("SHA-1");
    }

    public final ByteString sha256() {
        return digest$okio("SHA-256");
    }

    public final ByteString sha512() {
        return digest$okio("SHA-512");
    }

    public final int size() {
        return getSize$okio();
    }

    public final boolean startsWith(ByteString byteString) {
        o.e(byteString, "prefix");
        return rangeEquals(0, byteString, 0, byteString.size());
    }

    public String string(Charset charset) {
        o.e(charset, "charset");
        return new String(this.data, charset);
    }

    public final ByteString substring() {
        return substring$default(this, 0, 0, 3, null);
    }

    public final ByteString substring(int i2) {
        return substring$default(this, i2, 0, 2, null);
    }

    public ByteString substring(int i2, int i3) {
        boolean z = true;
        if (i2 >= 0) {
            if (i3 <= getData$okio().length) {
                if (i3 - i2 < 0) {
                    z = false;
                }
                if (z) {
                    return (i2 == 0 && i3 == getData$okio().length) ? this : new ByteString(h.d(getData$okio(), i2, i3));
                }
                throw new IllegalArgumentException("endIndex < beginIndex".toString());
            }
            throw new IllegalArgumentException(d.a.a.a.a.u(d.a.a.a.a.B("endIndex > length("), getData$okio().length, ')').toString());
        }
        throw new IllegalArgumentException("beginIndex < 0".toString());
    }

    public ByteString toAsciiLowercase() {
        byte b2;
        for (int i2 = 0; i2 < getData$okio().length; i2++) {
            byte b3 = getData$okio()[i2];
            byte b4 = (byte) 65;
            if (b3 >= b4 && b3 <= (b2 = (byte) 90)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                o.d(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i2] = (byte) (b3 + 32);
                for (int i3 = i2 + 1; i3 < copyOf.length; i3++) {
                    byte b5 = copyOf[i3];
                    if (b5 >= b4 && b5 <= b2) {
                        copyOf[i3] = (byte) (b5 + 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public ByteString toAsciiUppercase() {
        byte b2;
        for (int i2 = 0; i2 < getData$okio().length; i2++) {
            byte b3 = getData$okio()[i2];
            byte b4 = (byte) 97;
            if (b3 >= b4 && b3 <= (b2 = (byte) 122)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                o.d(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i2] = (byte) (b3 - 32);
                for (int i3 = i2 + 1; i3 < copyOf.length; i3++) {
                    byte b5 = copyOf[i3];
                    if (b5 >= b4 && b5 <= b2) {
                        copyOf[i3] = (byte) (b5 - 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public byte[] toByteArray() {
        byte[] data$okio = getData$okio();
        byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
        o.d(copyOf, "java.util.Arrays.copyOf(this, size)");
        return copyOf;
    }

    public String toString() {
        ByteString byteString;
        boolean z = true;
        if (getData$okio().length == 0) {
            return "[size=0]";
        }
        int access$codePointIndexToCharIndex = _ByteStringKt.access$codePointIndexToCharIndex(getData$okio(), 64);
        if (access$codePointIndexToCharIndex != -1) {
            String utf82 = utf8();
            Objects.requireNonNull(utf82, "null cannot be cast to non-null type java.lang.String");
            String substring = utf82.substring(0, access$codePointIndexToCharIndex);
            o.d(substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            String l2 = i.l(i.l(i.l(substring, "\\", "\\\\", false, 4), "\n", "\\n", false, 4), "\r", "\\r", false, 4);
            if (access$codePointIndexToCharIndex < utf82.length()) {
                StringBuilder B = d.a.a.a.a.B("[size=");
                B.append(getData$okio().length);
                B.append(" text=");
                B.append(l2);
                B.append("…]");
                return B.toString();
            }
            return "[text=" + l2 + ']';
        } else if (getData$okio().length <= 64) {
            StringBuilder B2 = d.a.a.a.a.B("[hex=");
            B2.append(hex());
            B2.append(']');
            return B2.toString();
        } else {
            StringBuilder B3 = d.a.a.a.a.B("[size=");
            B3.append(getData$okio().length);
            B3.append(" hex=");
            if (64 > getData$okio().length) {
                z = false;
            }
            if (z) {
                if (64 == getData$okio().length) {
                    byteString = this;
                } else {
                    byteString = new ByteString(h.d(getData$okio(), 0, 64));
                }
                B3.append(byteString.hex());
                B3.append("…]");
                return B3.toString();
            }
            throw new IllegalArgumentException(d.a.a.a.a.u(d.a.a.a.a.B("endIndex > length("), getData$okio().length, ')').toString());
        }
    }

    public String utf8() {
        String utf8$okio = getUtf8$okio();
        if (utf8$okio != null) {
            return utf8$okio;
        }
        String utf8String = _JvmPlatformKt.toUtf8String(internalArray$okio());
        setUtf8$okio(utf8String);
        return utf8String;
    }

    public void write(OutputStream outputStream) {
        o.e(outputStream, "out");
        outputStream.write(this.data);
    }

    public void write$okio(Buffer buffer, int i2, int i3) {
        o.e(buffer, "buffer");
        _ByteStringKt.commonWrite(this, buffer, i2, i3);
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0032 A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x0030 A[RETURN, SYNTHETIC] */
    public int compareTo(ByteString byteString) {
        o.e(byteString, "other");
        int size = size();
        int size2 = byteString.size();
        int min = Math.min(size, size2);
        for (int i2 = 0; i2 < min; i2++) {
            int i3 = getByte(i2) & 255;
            int i4 = byteString.getByte(i2) & 255;
            if (i3 != i4) {
                return i3 < i4 ? -1 : 1;
            }
        }
        if (size == size2) {
            return 0;
        }
        if (size < size2) {
        }
    }

    public final boolean endsWith(byte[] bArr) {
        o.e(bArr, "suffix");
        return rangeEquals(size() - bArr.length, bArr, 0, bArr.length);
    }

    public int indexOf(byte[] bArr, int i2) {
        o.e(bArr, "other");
        int length = getData$okio().length - bArr.length;
        int max = Math.max(i2, 0);
        if (max <= length) {
            while (!_UtilKt.arrayRangeEquals(getData$okio(), max, bArr, 0, bArr.length)) {
                if (max != length) {
                    max++;
                }
            }
            return max;
        }
        return -1;
    }

    public int lastIndexOf(byte[] bArr, int i2) {
        o.e(bArr, "other");
        for (int min = Math.min(i2, getData$okio().length - bArr.length); min >= 0; min--) {
            if (_UtilKt.arrayRangeEquals(getData$okio(), min, bArr, 0, bArr.length)) {
                return min;
            }
        }
        return -1;
    }

    public boolean rangeEquals(int i2, byte[] bArr, int i3, int i4) {
        o.e(bArr, "other");
        return i2 >= 0 && i2 <= getData$okio().length - i4 && i3 >= 0 && i3 <= bArr.length - i4 && _UtilKt.arrayRangeEquals(getData$okio(), i2, bArr, i3, i4);
    }

    public final boolean startsWith(byte[] bArr) {
        o.e(bArr, "prefix");
        return rangeEquals(0, bArr, 0, bArr.length);
    }
}
