package okio;

import com.lzy.okgo.cache.CacheEntity;
import h.p.b.m;
import h.p.b.o;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;

/* compiled from: HashingSink.kt */
public final class HashingSink extends ForwardingSink implements Sink {
    public static final Companion Companion = new Companion(null);
    private final Mac mac;
    private final MessageDigest messageDigest;

    /* compiled from: HashingSink.kt */
    public static final class Companion {
        private Companion() {
        }

        public final HashingSink hmacSha1(Sink sink, ByteString byteString) {
            o.e(sink, "sink");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSink(sink, byteString, "HmacSHA1");
        }

        public final HashingSink hmacSha256(Sink sink, ByteString byteString) {
            o.e(sink, "sink");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSink(sink, byteString, "HmacSHA256");
        }

        public final HashingSink hmacSha512(Sink sink, ByteString byteString) {
            o.e(sink, "sink");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSink(sink, byteString, "HmacSHA512");
        }

        public final HashingSink md5(Sink sink) {
            o.e(sink, "sink");
            return new HashingSink(sink, "MD5");
        }

        public final HashingSink sha1(Sink sink) {
            o.e(sink, "sink");
            return new HashingSink(sink, "SHA-1");
        }

        public final HashingSink sha256(Sink sink) {
            o.e(sink, "sink");
            return new HashingSink(sink, "SHA-256");
        }

        public final HashingSink sha512(Sink sink) {
            o.e(sink, "sink");
            return new HashingSink(sink, "SHA-512");
        }

        public /* synthetic */ Companion(m mVar) {
            this();
        }
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSink(Sink sink, MessageDigest messageDigest2) {
        super(sink);
        o.e(sink, "sink");
        o.e(messageDigest2, "digest");
        this.messageDigest = messageDigest2;
        this.mac = null;
    }

    public static final HashingSink hmacSha1(Sink sink, ByteString byteString) {
        return Companion.hmacSha1(sink, byteString);
    }

    public static final HashingSink hmacSha256(Sink sink, ByteString byteString) {
        return Companion.hmacSha256(sink, byteString);
    }

    public static final HashingSink hmacSha512(Sink sink, ByteString byteString) {
        return Companion.hmacSha512(sink, byteString);
    }

    public static final HashingSink md5(Sink sink) {
        return Companion.md5(sink);
    }

    public static final HashingSink sha1(Sink sink) {
        return Companion.sha1(sink);
    }

    public static final HashingSink sha256(Sink sink) {
        return Companion.sha256(sink);
    }

    public static final HashingSink sha512(Sink sink) {
        return Companion.sha512(sink);
    }

    /* renamed from: -deprecated_hash  reason: not valid java name */
    public final ByteString m32deprecated_hash() {
        return hash();
    }

    public final ByteString hash() {
        byte[] bArr;
        MessageDigest messageDigest2 = this.messageDigest;
        if (messageDigest2 != null) {
            bArr = messageDigest2.digest();
        } else {
            Mac mac2 = this.mac;
            o.c(mac2);
            bArr = mac2.doFinal();
        }
        o.d(bArr, "result");
        return new ByteString(bArr);
    }

    @Override // okio.ForwardingSink, okio.Sink
    public void write(Buffer buffer, long j2) {
        o.e(buffer, "source");
        _UtilKt.checkOffsetAndCount(buffer.size(), 0, j2);
        Segment segment = buffer.head;
        o.c(segment);
        long j3 = 0;
        while (j3 < j2) {
            int min = (int) Math.min(j2 - j3, (long) (segment.limit - segment.pos));
            MessageDigest messageDigest2 = this.messageDigest;
            if (messageDigest2 != null) {
                messageDigest2.update(segment.data, segment.pos, min);
            } else {
                Mac mac2 = this.mac;
                o.c(mac2);
                mac2.update(segment.data, segment.pos, min);
            }
            j3 += (long) min;
            segment = segment.next;
            o.c(segment);
        }
        super.write(buffer, j2);
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public HashingSink(Sink sink, String str) {
        this(sink, r3);
        o.e(sink, "sink");
        o.e(str, "algorithm");
        MessageDigest instance = MessageDigest.getInstance(str);
        o.d(instance, "MessageDigest.getInstance(algorithm)");
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSink(Sink sink, Mac mac2) {
        super(sink);
        o.e(sink, "sink");
        o.e(mac2, "mac");
        this.mac = mac2;
        this.messageDigest = null;
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public HashingSink(Sink sink, ByteString byteString, String str) {
        this(sink, r0);
        o.e(sink, "sink");
        o.e(byteString, CacheEntity.KEY);
        o.e(str, "algorithm");
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            o.d(instance, "try {\n      Mac.getInsta…rgumentException(e)\n    }");
        } catch (InvalidKeyException e2) {
            throw new IllegalArgumentException(e2);
        }
    }
}
