package okio;

import com.lzy.okgo.cache.CacheEntity;
import h.p.b.m;
import h.p.b.o;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;

/* compiled from: HashingSource.kt */
public final class HashingSource extends ForwardingSource implements Source {
    public static final Companion Companion = new Companion(null);
    private final Mac mac;
    private final MessageDigest messageDigest;

    /* compiled from: HashingSource.kt */
    public static final class Companion {
        private Companion() {
        }

        public final HashingSource hmacSha1(Source source, ByteString byteString) {
            o.e(source, "source");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSource(source, byteString, "HmacSHA1");
        }

        public final HashingSource hmacSha256(Source source, ByteString byteString) {
            o.e(source, "source");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSource(source, byteString, "HmacSHA256");
        }

        public final HashingSource hmacSha512(Source source, ByteString byteString) {
            o.e(source, "source");
            o.e(byteString, CacheEntity.KEY);
            return new HashingSource(source, byteString, "HmacSHA512");
        }

        public final HashingSource md5(Source source) {
            o.e(source, "source");
            return new HashingSource(source, "MD5");
        }

        public final HashingSource sha1(Source source) {
            o.e(source, "source");
            return new HashingSource(source, "SHA-1");
        }

        public final HashingSource sha256(Source source) {
            o.e(source, "source");
            return new HashingSource(source, "SHA-256");
        }

        public final HashingSource sha512(Source source) {
            o.e(source, "source");
            return new HashingSource(source, "SHA-512");
        }

        public /* synthetic */ Companion(m mVar) {
            this();
        }
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSource(Source source, MessageDigest messageDigest2) {
        super(source);
        o.e(source, "source");
        o.e(messageDigest2, "digest");
        this.messageDigest = messageDigest2;
        this.mac = null;
    }

    public static final HashingSource hmacSha1(Source source, ByteString byteString) {
        return Companion.hmacSha1(source, byteString);
    }

    public static final HashingSource hmacSha256(Source source, ByteString byteString) {
        return Companion.hmacSha256(source, byteString);
    }

    public static final HashingSource hmacSha512(Source source, ByteString byteString) {
        return Companion.hmacSha512(source, byteString);
    }

    public static final HashingSource md5(Source source) {
        return Companion.md5(source);
    }

    public static final HashingSource sha1(Source source) {
        return Companion.sha1(source);
    }

    public static final HashingSource sha256(Source source) {
        return Companion.sha256(source);
    }

    public static final HashingSource sha512(Source source) {
        return Companion.sha512(source);
    }

    /* renamed from: -deprecated_hash  reason: not valid java name */
    public final ByteString m33deprecated_hash() {
        return hash();
    }

    public final ByteString hash() {
        byte[] bArr;
        MessageDigest messageDigest2 = this.messageDigest;
        if (messageDigest2 != null) {
            bArr = messageDigest2.digest();
        } else {
            Mac mac2 = this.mac;
            o.c(mac2);
            bArr = mac2.doFinal();
        }
        o.d(bArr, "result");
        return new ByteString(bArr);
    }

    @Override // okio.Source, okio.ForwardingSource
    public long read(Buffer buffer, long j2) {
        o.e(buffer, "sink");
        long read = super.read(buffer, j2);
        if (read != -1) {
            long size = buffer.size() - read;
            long size2 = buffer.size();
            Segment segment = buffer.head;
            o.c(segment);
            while (size2 > size) {
                segment = segment.prev;
                o.c(segment);
                size2 -= (long) (segment.limit - segment.pos);
            }
            while (size2 < buffer.size()) {
                int i2 = (int) ((((long) segment.pos) + size) - size2);
                MessageDigest messageDigest2 = this.messageDigest;
                if (messageDigest2 != null) {
                    messageDigest2.update(segment.data, i2, segment.limit - i2);
                } else {
                    Mac mac2 = this.mac;
                    o.c(mac2);
                    mac2.update(segment.data, i2, segment.limit - i2);
                }
                size2 += (long) (segment.limit - segment.pos);
                segment = segment.next;
                o.c(segment);
                size = size2;
            }
        }
        return read;
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public HashingSource(Source source, String str) {
        this(source, r3);
        o.e(source, "source");
        o.e(str, "algorithm");
        MessageDigest instance = MessageDigest.getInstance(str);
        o.d(instance, "MessageDigest.getInstance(algorithm)");
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public HashingSource(Source source, Mac mac2) {
        super(source);
        o.e(source, "source");
        o.e(mac2, "mac");
        this.mac = mac2;
        this.messageDigest = null;
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public HashingSource(Source source, ByteString byteString, String str) {
        this(source, r0);
        o.e(source, "source");
        o.e(byteString, CacheEntity.KEY);
        o.e(str, "algorithm");
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            o.d(instance, "try {\n      Mac.getInsta…rgumentException(e)\n    }");
        } catch (InvalidKeyException e2) {
            throw new IllegalArgumentException(e2);
        }
    }
}
