package okio;

import com.lzy.okgo.cache.CacheEntity;
import d.a.a.a.a;
import d.l.b.g.g.b;
import h.l.h;
import h.p.b.o;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.util.Arrays;
import java.util.Objects;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import okio.internal._SegmentedByteStringKt;

/* compiled from: SegmentedByteString.kt */
public final class SegmentedByteString extends ByteString {
    private final transient int[] directory;
    private final transient byte[][] segments;

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public SegmentedByteString(byte[][] bArr, int[] iArr) {
        super(ByteString.EMPTY.getData$okio());
        o.e(bArr, "segments");
        o.e(iArr, "directory");
        this.segments = bArr;
        this.directory = iArr;
    }

    private final ByteString toByteString() {
        return new ByteString(toByteArray());
    }

    private final Object writeReplace() {
        ByteString byteString = toByteString();
        Objects.requireNonNull(byteString, "null cannot be cast to non-null type java.lang.Object");
        return byteString;
    }

    @Override // okio.ByteString
    public ByteBuffer asByteBuffer() {
        ByteBuffer asReadOnlyBuffer = ByteBuffer.wrap(toByteArray()).asReadOnlyBuffer();
        o.d(asReadOnlyBuffer, "ByteBuffer.wrap(toByteArray()).asReadOnlyBuffer()");
        return asReadOnlyBuffer;
    }

    @Override // okio.ByteString
    public String base64() {
        return toByteString().base64();
    }

    @Override // okio.ByteString
    public String base64Url() {
        return toByteString().base64Url();
    }

    @Override // okio.ByteString
    public ByteString digest$okio(String str) {
        o.e(str, "algorithm");
        MessageDigest instance = MessageDigest.getInstance(str);
        int length = getSegments$okio().length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            int i4 = getDirectory$okio()[length + i2];
            int i5 = getDirectory$okio()[i2];
            instance.update(getSegments$okio()[i2], i4, i5 - i3);
            i2++;
            i3 = i5;
        }
        byte[] digest = instance.digest();
        o.d(digest, "digestBytes");
        return new ByteString(digest);
    }

    @Override // okio.ByteString
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof ByteString) {
            ByteString byteString = (ByteString) obj;
            return byteString.size() == size() && rangeEquals(0, byteString, 0, size());
        }
    }

    public final int[] getDirectory$okio() {
        return this.directory;
    }

    public final byte[][] getSegments$okio() {
        return this.segments;
    }

    @Override // okio.ByteString
    public int getSize$okio() {
        return getDirectory$okio()[getSegments$okio().length - 1];
    }

    @Override // okio.ByteString
    public int hashCode() {
        int hashCode$okio = getHashCode$okio();
        if (hashCode$okio != 0) {
            return hashCode$okio;
        }
        int length = getSegments$okio().length;
        int i2 = 0;
        int i3 = 1;
        int i4 = 0;
        while (i2 < length) {
            int i5 = getDirectory$okio()[length + i2];
            int i6 = getDirectory$okio()[i2];
            byte[] bArr = getSegments$okio()[i2];
            int i7 = (i6 - i4) + i5;
            while (i5 < i7) {
                i3 = (i3 * 31) + bArr[i5];
                i5++;
            }
            i2++;
            i4 = i6;
        }
        setHashCode$okio(i3);
        return i3;
    }

    @Override // okio.ByteString
    public String hex() {
        return toByteString().hex();
    }

    @Override // okio.ByteString
    public ByteString hmac$okio(String str, ByteString byteString) {
        o.e(str, "algorithm");
        o.e(byteString, CacheEntity.KEY);
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            int length = getSegments$okio().length;
            int i2 = 0;
            int i3 = 0;
            while (i2 < length) {
                int i4 = getDirectory$okio()[length + i2];
                int i5 = getDirectory$okio()[i2];
                instance.update(getSegments$okio()[i2], i4, i5 - i3);
                i2++;
                i3 = i5;
            }
            byte[] doFinal = instance.doFinal();
            o.d(doFinal, "mac.doFinal()");
            return new ByteString(doFinal);
        } catch (InvalidKeyException e2) {
            throw new IllegalArgumentException(e2);
        }
    }

    @Override // okio.ByteString
    public int indexOf(byte[] bArr, int i2) {
        o.e(bArr, "other");
        return toByteString().indexOf(bArr, i2);
    }

    @Override // okio.ByteString
    public byte[] internalArray$okio() {
        return toByteArray();
    }

    @Override // okio.ByteString
    public byte internalGet$okio(int i2) {
        int i3;
        _UtilKt.checkOffsetAndCount((long) getDirectory$okio()[getSegments$okio().length - 1], (long) i2, 1);
        int segment = _SegmentedByteStringKt.segment(this, i2);
        if (segment == 0) {
            i3 = 0;
        } else {
            i3 = getDirectory$okio()[segment - 1];
        }
        return getSegments$okio()[segment][(i2 - i3) + getDirectory$okio()[getSegments$okio().length + segment]];
    }

    @Override // okio.ByteString
    public int lastIndexOf(byte[] bArr, int i2) {
        o.e(bArr, "other");
        return toByteString().lastIndexOf(bArr, i2);
    }

    @Override // okio.ByteString
    public boolean rangeEquals(int i2, ByteString byteString, int i3, int i4) {
        int i5;
        o.e(byteString, "other");
        if (i2 < 0 || i2 > size() - i4) {
            return false;
        }
        int i6 = i4 + i2;
        int segment = _SegmentedByteStringKt.segment(this, i2);
        while (i2 < i6) {
            if (segment == 0) {
                i5 = 0;
            } else {
                i5 = getDirectory$okio()[segment - 1];
            }
            int i7 = getDirectory$okio()[getSegments$okio().length + segment];
            int min = Math.min(i6, (getDirectory$okio()[segment] - i5) + i5) - i2;
            if (!byteString.rangeEquals(i3, getSegments$okio()[segment], (i2 - i5) + i7, min)) {
                return false;
            }
            i3 += min;
            i2 += min;
            segment++;
        }
        return true;
    }

    @Override // okio.ByteString
    public String string(Charset charset) {
        o.e(charset, "charset");
        return toByteString().string(charset);
    }

    @Override // okio.ByteString
    public ByteString substring(int i2, int i3) {
        int i4 = 0;
        if (i2 >= 0) {
            if (i3 <= size()) {
                int i5 = i3 - i2;
                if (!(i5 >= 0)) {
                    throw new IllegalArgumentException(("endIndex=" + i3 + " < beginIndex=" + i2).toString());
                } else if (i2 == 0 && i3 == size()) {
                    return this;
                } else {
                    if (i2 == i3) {
                        return ByteString.EMPTY;
                    }
                    int segment = _SegmentedByteStringKt.segment(this, i2);
                    int segment2 = _SegmentedByteStringKt.segment(this, i3 - 1);
                    byte[][] segments$okio = getSegments$okio();
                    int i6 = segment2 + 1;
                    o.e(segments$okio, "$this$copyOfRangeImpl");
                    b.s(i6, segments$okio.length);
                    Object[] copyOfRange = Arrays.copyOfRange(segments$okio, segment, i6);
                    o.d(copyOfRange, "java.util.Arrays.copyOfR…this, fromIndex, toIndex)");
                    byte[][] bArr = (byte[][]) copyOfRange;
                    int[] iArr = new int[(bArr.length * 2)];
                    if (segment <= segment2) {
                        int i7 = 0;
                        int i8 = segment;
                        while (true) {
                            iArr[i7] = Math.min(getDirectory$okio()[i8] - i2, i5);
                            int i9 = i7 + 1;
                            iArr[i7 + bArr.length] = getDirectory$okio()[getSegments$okio().length + i8];
                            if (i8 == segment2) {
                                break;
                            }
                            i8++;
                            i7 = i9;
                        }
                    }
                    if (segment != 0) {
                        i4 = getDirectory$okio()[segment - 1];
                    }
                    int length = bArr.length;
                    iArr[length] = (i2 - i4) + iArr[length];
                    return new SegmentedByteString(bArr, iArr);
                }
            } else {
                StringBuilder C = a.C("endIndex=", i3, " > length(");
                C.append(size());
                C.append(')');
                throw new IllegalArgumentException(C.toString().toString());
            }
        } else {
            throw new IllegalArgumentException(a.m("beginIndex=", i2, " < 0").toString());
        }
    }

    @Override // okio.ByteString
    public ByteString toAsciiLowercase() {
        return toByteString().toAsciiLowercase();
    }

    @Override // okio.ByteString
    public ByteString toAsciiUppercase() {
        return toByteString().toAsciiUppercase();
    }

    @Override // okio.ByteString
    public byte[] toByteArray() {
        byte[] bArr = new byte[size()];
        int length = getSegments$okio().length;
        int i2 = 0;
        int i3 = 0;
        int i4 = 0;
        while (i2 < length) {
            int i5 = getDirectory$okio()[length + i2];
            int i6 = getDirectory$okio()[i2];
            int i7 = i6 - i3;
            h.a(getSegments$okio()[i2], bArr, i4, i5, i5 + i7);
            i4 += i7;
            i2++;
            i3 = i6;
        }
        return bArr;
    }

    @Override // okio.ByteString
    public String toString() {
        return toByteString().toString();
    }

    @Override // okio.ByteString
    public void write(OutputStream outputStream) {
        o.e(outputStream, "out");
        int length = getSegments$okio().length;
        int i2 = 0;
        int i3 = 0;
        while (i2 < length) {
            int i4 = getDirectory$okio()[length + i2];
            int i5 = getDirectory$okio()[i2];
            outputStream.write(getSegments$okio()[i2], i4, i5 - i3);
            i2++;
            i3 = i5;
        }
    }

    @Override // okio.ByteString
    public void write$okio(Buffer buffer, int i2, int i3) {
        int i4;
        o.e(buffer, "buffer");
        int i5 = i2 + i3;
        int segment = _SegmentedByteStringKt.segment(this, i2);
        while (i2 < i5) {
            if (segment == 0) {
                i4 = 0;
            } else {
                i4 = getDirectory$okio()[segment - 1];
            }
            int i6 = getDirectory$okio()[getSegments$okio().length + segment];
            int min = Math.min(i5, (getDirectory$okio()[segment] - i4) + i4) - i2;
            int i7 = (i2 - i4) + i6;
            Segment segment2 = new Segment(getSegments$okio()[segment], i7, i7 + min, true, false);
            Segment segment3 = buffer.head;
            if (segment3 == null) {
                segment2.prev = segment2;
                segment2.next = segment2;
                buffer.head = segment2;
            } else {
                o.c(segment3);
                Segment segment4 = segment3.prev;
                o.c(segment4);
                segment4.push(segment2);
            }
            i2 += min;
            segment++;
        }
        buffer.setSize$okio(buffer.size() + ((long) i3));
    }

    @Override // okio.ByteString
    public boolean rangeEquals(int i2, byte[] bArr, int i3, int i4) {
        int i5;
        o.e(bArr, "other");
        if (i2 < 0 || i2 > size() - i4 || i3 < 0 || i3 > bArr.length - i4) {
            return false;
        }
        int i6 = i4 + i2;
        int segment = _SegmentedByteStringKt.segment(this, i2);
        while (i2 < i6) {
            if (segment == 0) {
                i5 = 0;
            } else {
                i5 = getDirectory$okio()[segment - 1];
            }
            int i7 = getDirectory$okio()[getSegments$okio().length + segment];
            int min = Math.min(i6, (getDirectory$okio()[segment] - i5) + i5) - i2;
            if (!_UtilKt.arrayRangeEquals(getSegments$okio()[segment], (i2 - i5) + i7, bArr, i3, min)) {
                return false;
            }
            i3 += min;
            i2 += min;
            segment++;
        }
        return true;
    }
}
